@@ -31,7 +31,7 @@
 #include "annotationsketch/canvas_rep.h"
 #include "annotationsketch/cliptype.h"
 #include "annotationsketch/coords.h"
-#include "annotationsketch/graphics_cairo.h"
+#include "annotationsketch/graphics_cairo_api.h"
 #include "annotationsketch/style.h"
 
 /* this is a Cairo-based implementation of the GtCanvas interface hooks */
@@ -65,7 +65,7 @@ int gt_canvas_cairo_visit_track_pre(GtCanvas *canvas, GtTrack *track,
                                     GtError *err)
 {
   int had_err = 0;
-  unsigned long exceeded;
+  GtUword exceeded;
   bool show_track_captions = true;
 
   GtColor color;
@@ -128,7 +128,7 @@ int gt_canvas_cairo_visit_track_pre(GtCanvas *canvas, GtTrack *track,
         msg = "(1 block not shown due to exceeded line limit)";
         strncpy(buf, msg, BUFSIZ);
       } else {
-        msg = "(%lu blocks not shown due to exceeded line limit)";
+        msg = "("GT_WU" blocks not shown due to exceeded line limit)";
         /*@ignore@*/
         snprintf(buf, BUFSIZ, msg, exceeded);
         /*@end@*/
@@ -326,14 +326,14 @@ int gt_canvas_cairo_visit_block(GtCanvas *canvas, GtBlock *block,
     if (canvas->pvt->bt && draw_range.end-draw_range.start <= 1.1)
     {
       if (!gt_bittab_bit_is_set(canvas->pvt->bt,
-                                (unsigned long) draw_range.start)) {
+                                (GtUword) draw_range.start)) {
         gt_graphics_draw_vertical_line(canvas->pvt->g,
                                        block_start,
                                        canvas->pvt->y - bar_height/2,
                                        strokecolor,
                                        bar_height,
                                        stroke_width);
-        gt_bittab_set_bit(canvas->pvt->bt, (unsigned long) draw_range.start);
+        gt_bittab_set_bit(canvas->pvt->bt, (GtUword) draw_range.start);
       }
     } else {
       if (gt_style_get_color_with_track(canvas->pvt->sty,
@@ -470,7 +470,7 @@ int gt_canvas_cairo_visit_element(GtCanvas *canvas, GtElement *elem,
          /*&& gt_dlistelem_next(delem) == NULL*/)
     arrow_status = (arrow_status == ARROW_LEFT ? ARROW_BOTH : ARROW_RIGHT);
 
-  gt_log_log("processing element from %lu to %lu, strand %d\n",
+  gt_log_log("processing element from "GT_WU" to "GT_WU", strand %d\n",
              elem_range.start, elem_range.end, (int) strand);
 
   draw_range = gt_coords_calc_generic_range(elem_range, canvas->pvt->viewrange);
@@ -529,9 +529,9 @@ int gt_canvas_cairo_visit_element(GtCanvas *canvas, GtElement *elem,
   if (canvas->pvt->bt &&
           gt_double_smaller_double(draw_range.end-draw_range.start, 1.1))
   {
-    if ((unsigned long) draw_range.start > gt_bittab_size(canvas->pvt->bt))
+    if ((GtUword) draw_range.start > gt_bittab_size(canvas->pvt->bt))
       return had_err;
-    if (gt_bittab_bit_is_set(canvas->pvt->bt, (unsigned long) draw_range.start))
+    if (gt_bittab_bit_is_set(canvas->pvt->bt, (GtUword) draw_range.start))
       return had_err;
     gt_graphics_draw_vertical_line(canvas->pvt->g,
                                    elem_start,
@@ -539,7 +539,7 @@ int gt_canvas_cairo_visit_element(GtCanvas *canvas, GtElement *elem,
                                    elem_color,
                                    bar_height,
                                    stroke_width);
-    gt_bittab_set_bit(canvas->pvt->bt, (unsigned long) draw_range.start);
+    gt_bittab_set_bit(canvas->pvt->bt, (GtUword) draw_range.start);
   }
 
   /* register coordinates in GtImageInfo object if available */
@@ -747,7 +747,7 @@ int gt_canvas_cairo_draw_ruler(GtCanvas *canvas, GtRange viewrange,
 {
   double step, minorstep, vmajor, vminor,
          theight = gt_graphics_get_text_height(canvas->pvt->g);
-  long base_length, tick;
+  GtWord base_length, tick;
   GtColor rulercol, gridcol;
   GtStr *left_str, *right_str, *unit;
   char str[BUFSIZ];
