@@ -176,7 +176,7 @@ static int get_caption_display_status(GtDiagram *d, const char *gft,
   status = (bool*) gt_hashmap_get(d->caption_display_status, gft);
   if (!status)
   {
-    unsigned long threshold = GT_UNDEF_ULONG;
+    GtUword threshold = GT_UNDEF_UWORD;
     double tmp = GT_UNDEF_DOUBLE;
     status = gt_malloc(sizeof (bool));
     *status = true;
@@ -202,7 +202,7 @@ static int get_caption_display_status(GtDiagram *d, const char *gft,
         default:
           gt_assert(tmp != GT_UNDEF_DOUBLE);
           threshold = tmp;
-          gt_assert(tmp != GT_UNDEF_ULONG);
+          gt_assert(tmp != GT_UNDEF_UWORD);
           *status = (gt_range_length(&d->range) <= threshold);
           break;
       }
@@ -436,8 +436,8 @@ static int process_node(GtDiagram *d, GtFeatureNode *node,
              *parent_gft = NULL;
   double tmp;
   GtStyleQueryStatus rval;
-  unsigned long max_show_width = GT_UNDEF_ULONG,
-                par_max_show_width = GT_UNDEF_ULONG;
+  GtUword max_show_width = GT_UNDEF_UWORD,
+                par_max_show_width = GT_UNDEF_UWORD;
 
   gt_assert(d && node);
 
@@ -491,11 +491,11 @@ static int process_node(GtDiagram *d, GtFeatureNode *node,
           break;
       }
     } else
-      par_max_show_width = GT_UNDEF_ULONG;
+      par_max_show_width = GT_UNDEF_UWORD;
   }
 
   /* check if this type is to be displayed at all */
-  if (max_show_width != GT_UNDEF_ULONG &&
+  if (max_show_width != GT_UNDEF_UWORD &&
       gt_range_length(&d->range) > max_show_width)
   {
     return 0;
@@ -503,7 +503,7 @@ static int process_node(GtDiagram *d, GtFeatureNode *node,
 
   /* disregard parent node if it is configured not to be shown */
   if (parent
-        && par_max_show_width != GT_UNDEF_ULONG
+        && par_max_show_width != GT_UNDEF_UWORD
         && gt_range_length(&d->range) > par_max_show_width)
   {
     parent = NULL;
@@ -630,7 +630,7 @@ static int process_node(GtDiagram *d, GtFeatureNode *node,
 static int visit_child(GtFeatureNode* fn, void *nti, GtError *err)
 {
   NodeTraverseInfo* gt_genome_node_info;
-  int had_err;
+  int had_err = 0;
   gt_genome_node_info = (NodeTraverseInfo*) nti;
   gt_error_check(err);
 
@@ -683,11 +683,11 @@ static int collect_blocks(GT_UNUSED void *key, void *value, void *data,
   GtDiagram *diagram = (GtDiagram*) data;
   GtBlock *block = NULL;
   GtStr *trackid_str;
-  unsigned long i = 0;
+  GtUword i = 0;
   trackid_str = gt_str_new();
   for (i = 0; i < gt_str_array_size(ni->types); i++) {
     const char *type;
-    unsigned long j;
+    GtUword j;
     GtArray *list;
     PerTypeInfo *type_struc = NULL;
     GtBlock* mainblock = NULL;
@@ -764,7 +764,7 @@ static int traverse_genome_nodes(GtFeatureNode *fn, void *nti)
 
 static void blocklist_delete(void *value)
 {
-  unsigned long i;
+  GtUword i;
   GtArray *a;
   if (!value) return;
   a = (GtArray*) value;
@@ -775,7 +775,7 @@ static void blocklist_delete(void *value)
 
 static int gt_diagram_build(GtDiagram *diagram, GtError *err)
 {
-  unsigned long i = 0;
+  GtUword i = 0;
   int had_err = 0;
   NodeTraverseInfo nti;
   gt_assert(diagram);
@@ -950,7 +950,7 @@ void* gt_diagram_unit_test_sketch_func(void *data)
 {
   int had_err = 0;
   GtLayout *l = NULL;
-  unsigned long height;
+  GtUword height;
   GtCanvas *c = NULL;
   GtDiagramTestShared *sh = (GtDiagramTestShared*) data;
 
@@ -994,7 +994,7 @@ int gt_diagram_unit_test(GtError *err)
 
   /* removed the multithreading test for now until it is fixed */
   gt_diagram_unit_test_sketch_func(&sh);
-  gt_ensure(had_err, sh.errstatus == 0);
+  gt_ensure(sh.errstatus == 0);
 
   gt_style_delete(sh.sty);
   gt_diagram_delete(sh.d);
