@@ -1,6 +1,6 @@
 /*
   Copyright (c) 2007-2012 Sascha Steinbiss <steinbiss@zbh.uni-hamburg.de>
-  Copyright (c) 2007-2008 Gordon Gremme <gremme@zbh.uni-hamburg.de>,
+  Copyright (c) 2007-2008 Gordon Gremme <gordon@gremme.org>,
   Copyright (c) 2007-2012 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -30,7 +30,7 @@
 
 #include <math.h>
 #include "annotationsketch/default_formats.h"
-#include "annotationsketch/graphics_cairo.h"
+#include "annotationsketch/graphics_cairo_api.h"
 #include "annotationsketch/graphics_rep.h"
 #include "core/file.h"
 #include "core/fileutils_api.h"
@@ -54,6 +54,8 @@ struct GtGraphicsCairo {
   int font_height;
 };
 
+const GtGraphicsClass* gt_graphics_cairo_class(void);
+
 #define gt_graphics_cairo_cast(G)\
         gt_graphics_cast(gt_graphics_cairo_class(), G)
 
@@ -825,10 +827,10 @@ GtGraphics* gt_graphics_cairo_new_from_context(cairo_t *context,
 
 void gt_graphics_cairo_draw_curve_data(GtGraphics *gg, double x, double y,
                                        GtColor color, double data[],
-                                       unsigned long ndata, GtRange valrange,
-                                       unsigned long height)
+                                       GtUword ndata, GtRange valrange,
+                                       GtUword height)
 {
-  unsigned long i, rnglen;
+  GtUword i, rnglen;
   double xpos;
   GtGraphicsCairo *g;
   g = gt_graphics_cairo_cast(gg);
