@@ -1,8 +1,8 @@
 /*
-  Copyright (c) 2007-2008 Sascha Steinbiss <steinbiss@zbh.uni-hamburg.de>
+  Copyright (c) 2007-2013 Sascha Steinbiss <steinbiss@zbh.uni-hamburg.de>
   Copyright (c) 2007      Malte Mader <mader@zbh.uni-hamburg.de>
   Copyright (c) 2007      Christin Schaerfer <schaerfer@zbh.uni-hamburg.de>
-  Copyright (c) 2007-2008 Center for Bioinformatics, University of Hamburg
+  Copyright (c) 2007-2013 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
   purpose with or without fee is hereby granted, provided that the above
@@ -17,8 +17,8 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#include <string.h>
 #include <cairo.h>
+#include <string.h>
 #include "core/cstr_api.h"
 #include "core/fileutils_api.h"
 #include "core/gtdatapath.h"
@@ -54,21 +54,40 @@ typedef struct {
        showrecmaps,
        flattenfiles,
        unsafe,
+       force,
        use_streams;
   GtStr *seqid, *format, *stylefile, *input;
-  unsigned long start,
+  GtUword start,
                 end;
   unsigned int width;
-} AnnotationSketchArguments;
+} GtSketchArguments;
 
-static GtOPrval sketch_parse_options(int *parsed_args,
-                                     AnnotationSketchArguments *arguments,
-                                     int argc, const char **argv, GtError *err)
+static void* gt_sketch_arguments_new(void)
 {
+  GtSketchArguments *arguments = gt_calloc(1, sizeof *arguments);
+  arguments->seqid = gt_str_new();
+  arguments->format = gt_str_new();
+  arguments->input = gt_str_new();
+  arguments->stylefile = gt_str_new();
+  return arguments;
+}
+
+static void gt_sketch_arguments_delete(void *tool_arguments)
+{
+  GtSketchArguments *arguments = tool_arguments;
+  if (!arguments) return;
+  gt_str_delete(arguments->seqid);
+  gt_str_delete(arguments->format);
+  gt_str_delete(arguments->input);
+  gt_str_delete(arguments->stylefile);
+  gt_free(arguments);
+}
+
+static GtOptionParser* gt_sketch_option_parser_new(void *tool_arguments)
+{
+  GtSketchArguments *arguments = tool_arguments;
   GtOptionParser *op;
-  GtOption  *option, *option2;
-  GtOPrval oprval;
-  bool force;
+  GtOption *option, *option2;
   static const char *formats[] = { "png",
 #ifdef CAIRO_HAS_PDF_SURFACE
     "pdf",
@@ -87,7 +106,7 @@ static GtOPrval sketch_parse_options(int *parsed_args,
     "gtf",
     NULL
   };
-  gt_error_check(err);
+  gt_assert(arguments);
 
   /* init */
   op = gt_option_parser_new("[option ...] image_file [GFF3_file ...]",
@@ -113,15 +132,15 @@ static GtOPrval sketch_parse_options(int *parsed_args,
   gt_option_hide_default(option);
 
   /* -start */
-  option = gt_option_new_ulong_min("start", "start position\n"
+  option = gt_option_new_uword_min("start", "start position\n"
                                          "default: first region start",
-                            &arguments->start, GT_UNDEF_ULONG, 1);
+                            &arguments->start, GT_UNDEF_UWORD, 1);
   gt_option_parser_add_option(op, option);
   gt_option_hide_default(option);
 
   /* -end */
-  option2 = gt_option_new_ulong("end", "end position\ndefault: last region end",
-                            &arguments->end, GT_UNDEF_ULONG);
+  option2 = gt_option_new_uword("end", "end position\ndefault: last region end",
+                            &arguments->end, GT_UNDEF_UWORD);
   gt_option_parser_add_option(op, option2);
   /* -start and -end must be given together */
   gt_option_imply(option, option2);
@@ -192,25 +211,33 @@ static GtOPrval sketch_parse_options(int *parsed_args,
 
   /* -force */
   option = gt_option_new_bool(GT_FORCE_OPT_CSTR, "force writing to output file",
-                              &force, false);
+                              &arguments->force, false);
   gt_option_parser_add_option(op, option);
 
-  /* parse options */
   gt_option_parser_set_min_args(op, 1);
-  oprval = gt_option_parser_parse(op, parsed_args, argc, argv, gt_versionfunc,
-                                  err);
 
-  if (oprval == GT_OPTION_PARSER_OK && !force &&
-      gt_file_exists(argv[*parsed_args])) {
-    gt_error_set(err, "file \"%s\" exists already. use option -%s to "
-                      "overwrite", argv[*parsed_args], GT_FORCE_OPT_CSTR);
-    oprval = GT_OPTION_PARSER_ERROR;
+  return op;
+}
+
+static int gt_sketch_arguments_check(GT_UNUSED int rest_argc,
+                                     void *tool_arguments,
+                                     GT_UNUSED GtError *err)
+{
+  GtSketchArguments *arguments = tool_arguments;
+  int had_err = 0;
+  gt_error_check(err);
+  gt_assert(arguments);
+
+  if (arguments->start != GT_UNDEF_UWORD &&
+      arguments->end != GT_UNDEF_UWORD &&
+      !(arguments->start < arguments->end)) {
+    gt_error_set(err, "start of query range ("GT_WU") must be before "
+                      "end of query range ("GT_WU")",
+                      arguments->start, arguments->end);
+    had_err = -1;
   }
 
-  /* free */
-  gt_option_parser_delete(op);
-
-  return oprval;
+  return had_err;
 }
 
 /* this track selector function is used to disregard file names in track
@@ -223,98 +250,64 @@ static void flattened_file_track_selector(GtBlock *block, GtStr *result,
   gt_str_append_cstr(result, gt_block_get_type(block));
 }
 
-int gt_sketch(int argc, const char **argv, GtError *err)
+static int gt_sketch_runner(int argc, const char **argv, int parsed_args,
+                              void *tool_arguments, GT_UNUSED GtError *err)
 {
+  GtSketchArguments *arguments = tool_arguments;
   GtNodeStream *in_stream = NULL,
                *add_introns_stream = NULL,
                *gff3_out_stream = NULL,
                *feature_stream = NULL,
                *sort_stream = NULL,
                *last_stream;
-  AnnotationSketchArguments arguments;
   GtFeatureIndex *features = NULL;
-  int parsed_args, had_err=0;
   const char *file;
   char *seqid = NULL;
   GtRange qry_range, sequence_region_range;
   GtArray *results = NULL;
   GtStyle *sty = NULL;
-  GtStr *prog, *gt_style_file = NULL;
+  GtStr *prog, *defaultstylefile = NULL;
   GtDiagram *d = NULL;
   GtLayout *l = NULL;
   GtImageInfo* ii = NULL;
   GtCanvas *canvas = NULL;
-  unsigned long height;
+  GtUword height;
   bool has_seqid;
-
+  int had_err = 0;
   gt_error_check(err);
+  gt_assert(arguments);
 
-  /* option parsing */
-  arguments.seqid = gt_str_new();
-  arguments.format = gt_str_new();
-  arguments.input = gt_str_new();
   prog = gt_str_new();
   gt_str_append_cstr_nt(prog, argv[0],
                         gt_cstr_length_up_to_char(argv[0], ' '));
-  gt_style_file = gt_get_gtdata_path(gt_str_get(prog), err);
+  defaultstylefile = gt_get_gtdata_path(gt_str_get(prog), err);
   gt_str_delete(prog);
-  if (!gt_style_file)
+  if (!defaultstylefile)
     had_err = -1;
   if (!had_err) {
-    gt_str_append_cstr(gt_style_file, "/sketch/default.style");
-    arguments.stylefile = gt_str_new_cstr(gt_str_get(gt_style_file));
-    switch (sketch_parse_options(&parsed_args, &arguments, argc, argv, err)) {
-      case GT_OPTION_PARSER_OK: break;
-      case GT_OPTION_PARSER_ERROR:
-        gt_str_delete(arguments.stylefile);
-        gt_str_delete(gt_style_file);
-        gt_str_delete(arguments.seqid);
-        gt_str_delete(arguments.format);
-        gt_str_delete(arguments.input);
-        return -1;
-      case GT_OPTION_PARSER_REQUESTS_EXIT:
-        gt_str_delete(arguments.stylefile);
-        gt_str_delete(gt_style_file);
-        gt_str_delete(arguments.seqid);
-        gt_str_delete(arguments.format);
-        gt_str_delete(arguments.input);
-        return 0;
-    }
+    gt_str_append_cstr(defaultstylefile, "/sketch/default.style");
   }
 
-  /* save name of output file */
   file = argv[parsed_args];
-
-  /* check for correct order: range end < range start */
-  if (!had_err &&
-      arguments.start != GT_UNDEF_ULONG &&
-      arguments.end != GT_UNDEF_ULONG &&
-      !(arguments.start < arguments.end)) {
-    gt_error_set(err, "start of query range (%lu) must be before "
-                      "end of query range (%lu)",
-                      arguments.start, arguments.end);
-    had_err = -1;
-  }
-
   if (!had_err) {
     /* create feature index */
     features = gt_feature_index_memory_new();
     parsed_args++;
 
     /* create an input stream */
-    if (strcmp(gt_str_get(arguments.input), "gff") == 0)
+    if (strcmp(gt_str_get(arguments->input), "gff") == 0)
     {
       in_stream = gt_gff3_in_stream_new_unsorted(argc - parsed_args,
                                                  argv + parsed_args);
-      if (arguments.verbose)
+      if (arguments->verbose)
         gt_gff3_in_stream_show_progress_bar((GtGFF3InStream*) in_stream);
-    } else if (strcmp(gt_str_get(arguments.input), "bed") == 0)
+    } else if (strcmp(gt_str_get(arguments->input), "bed") == 0)
     {
       if (argc - parsed_args == 0)
         in_stream = gt_bed_in_stream_new(NULL);
       else
         in_stream = gt_bed_in_stream_new(argv[parsed_args]);
-    } else if (strcmp(gt_str_get(arguments.input), "gtf") == 0)
+    } else if (strcmp(gt_str_get(arguments->input), "gtf") == 0)
     {
       if (argc - parsed_args == 0)
         in_stream = gt_gtf_in_stream_new(NULL);
@@ -324,14 +317,14 @@ int gt_sketch(int argc, const char **argv, GtError *err)
     last_stream = in_stream;
 
     /* create add introns stream if -addintrons was used */
-    if (arguments.addintrons) {
+    if (arguments->addintrons) {
       sort_stream = gt_sort_stream_new(last_stream);
       add_introns_stream = gt_add_introns_stream_new(sort_stream);
       last_stream = add_introns_stream;
     }
 
     /* create gff3 output stream if -pipe was used */
-    if (arguments.pipe) {
+    if (arguments->pipe) {
       gff3_out_stream = gt_gff3_out_stream_new(last_stream, NULL);
       last_stream = gff3_out_stream;
     }
@@ -352,12 +345,12 @@ int gt_sketch(int argc, const char **argv, GtError *err)
   if (!had_err) {
     had_err = gt_feature_index_has_seqid(features,
                                          &has_seqid,
-                                         gt_str_get(arguments.seqid),
+                                         gt_str_get(arguments->seqid),
                                          err);
   }
 
   /* if seqid is empty, take first one added to index */
-  if (!had_err && strcmp(gt_str_get(arguments.seqid),"") == 0) {
+  if (!had_err && strcmp(gt_str_get(arguments->seqid),"") == 0) {
     seqid = gt_feature_index_get_first_seqid(features, err);
     if (seqid == NULL) {
       gt_error_set(err, "GFF input file must contain a sequence region!");
@@ -366,11 +359,11 @@ int gt_sketch(int argc, const char **argv, GtError *err)
   }
   else if (!had_err && !has_seqid) {
     gt_error_set(err, "sequence region '%s' does not exist in GFF input file",
-                 gt_str_get(arguments.seqid));
+                 gt_str_get(arguments->seqid));
     had_err = -1;
   }
   else if (!had_err)
-    seqid = gt_str_get(arguments.seqid);
+    seqid = gt_str_get(arguments->seqid);
 
   results = gt_array_new(sizeof (GtGenomeNode*));
   if (!had_err) {
@@ -380,62 +373,71 @@ int gt_sketch(int argc, const char **argv, GtError *err)
                                                    err);
   }
   if (!had_err) {
-    qry_range.start = (arguments.start == GT_UNDEF_ULONG ?
+    qry_range.start = (arguments->start == GT_UNDEF_UWORD ?
                          sequence_region_range.start :
-                         arguments.start);
-    qry_range.end   = (arguments.end == GT_UNDEF_ULONG ?
+                         arguments->start);
+    qry_range.end   = (arguments->end == GT_UNDEF_UWORD ?
                          sequence_region_range.end :
-                         arguments.end);
+                         arguments->end);
   }
 
   if (!had_err) {
-    if (arguments.verbose)
-      fprintf(stderr, "# of results: %lu\n", gt_array_size(results));
+    if (arguments->verbose)
+      fprintf(stderr, "# of results: "GT_WU"\n", gt_array_size(results));
 
     /* find and load style file */
     if (!(sty = gt_style_new(err)))
       had_err = -1;
-    if (!had_err && gt_file_exists(gt_str_get(arguments.stylefile))) {
-      if (arguments.unsafe)
-        gt_style_unsafe_mode(sty);
-      had_err = gt_style_load_file(sty, gt_str_get(arguments.stylefile), err);
-    }
-    else
-    {
-      had_err = -1;
-      gt_error_set(err, "style file '%s' does not exist!",
-                        gt_str_get(arguments.stylefile));
+    if (gt_str_length(arguments->stylefile) == 0) {
+      gt_str_append_str(arguments->stylefile, defaultstylefile);
+    } else {
+      if (!had_err && gt_file_exists(gt_str_get(arguments->stylefile))) {
+        if (arguments->unsafe)
+          gt_style_unsafe_mode(sty);
+      }
+      else
+      {
+        had_err = -1;
+        gt_error_set(err, "style file '%s' does not exist!",
+                          gt_str_get(arguments->stylefile));
+      }
     }
+    if (!had_err)
+      had_err = gt_style_load_file(sty, gt_str_get(arguments->stylefile), err);
   }
 
   if (!had_err) {
     /* create and write image file */
     if (!(d = gt_diagram_new(features, seqid, &qry_range, sty, err)))
       had_err = -1;
-    if (!had_err && arguments.flattenfiles)
+    if (!had_err && arguments->flattenfiles)
       gt_diagram_set_track_selector_func(d, flattened_file_track_selector,
                                          NULL);
-    if (had_err || !(l = gt_layout_new(d, arguments.width, sty, err)))
+    if (had_err || !(l = gt_layout_new(d, arguments->width, sty, err)))
       had_err = -1;
     if (!had_err)
       had_err = gt_layout_get_height(l, &height, err);
     if (!had_err) {
       ii = gt_image_info_new();
 
-      if (strcmp(gt_str_get(arguments.format),"pdf")==0) {
-        canvas = gt_canvas_cairo_file_new(sty, GT_GRAPHICS_PDF, arguments.width,
+      if (strcmp(gt_str_get(arguments->format),"pdf")==0) {
+        canvas = gt_canvas_cairo_file_new(sty, GT_GRAPHICS_PDF,
+                                          arguments->width,
                                           height, ii, err);
       }
-      else if (strcmp(gt_str_get(arguments.format),"ps")==0) {
-        canvas = gt_canvas_cairo_file_new(sty, GT_GRAPHICS_PS, arguments.width,
+      else if (strcmp(gt_str_get(arguments->format),"ps")==0) {
+        canvas = gt_canvas_cairo_file_new(sty, GT_GRAPHICS_PS,
+                                          arguments->width,
                                           height, ii, err);
       }
-      else if (strcmp(gt_str_get(arguments.format),"svg")==0) {
-        canvas = gt_canvas_cairo_file_new(sty, GT_GRAPHICS_SVG, arguments.width,
+      else if (strcmp(gt_str_get(arguments->format),"svg")==0) {
+        canvas = gt_canvas_cairo_file_new(sty, GT_GRAPHICS_SVG,
+                                          arguments->width,
                                           height, ii, err);
       }
       else {
-        canvas = gt_canvas_cairo_file_new(sty, GT_GRAPHICS_PNG, arguments.width,
+        canvas = gt_canvas_cairo_file_new(sty, GT_GRAPHICS_PNG,
+                                          arguments->width,
                                           height, ii, err);
       }
       if (!canvas)
@@ -444,8 +446,8 @@ int gt_sketch(int argc, const char **argv, GtError *err)
         had_err = gt_layout_sketch(l, canvas, err);
       }
       if (!had_err) {
-        if (arguments.showrecmaps) {
-          unsigned long i;
+        if (arguments->showrecmaps) {
+          GtUword i;
           const GtRecMap *rm;
           for (i = 0; i < gt_image_info_num_of_rec_maps(ii) ;i++) {
             char buf[BUFSIZ];
@@ -456,7 +458,7 @@ int gt_sketch(int argc, const char **argv, GtError *err)
                    gt_feature_node_get_type(gt_rec_map_get_genome_feature(rm)));
           }
         }
-        if (arguments.use_streams) {
+        if (arguments->use_streams) {
           GtFile *outfile;
           GtStr *str = gt_str_new();
           gt_canvas_cairo_file_to_stream((GtCanvasCairoFile*) canvas, str);
@@ -483,14 +485,19 @@ int gt_sketch(int argc, const char **argv, GtError *err)
   gt_layout_delete(l);
   gt_image_info_delete(ii);
   gt_style_delete(sty);
-  gt_str_delete(gt_style_file);
   gt_diagram_delete(d);
-  gt_str_delete(arguments.seqid);
-  gt_str_delete(arguments.stylefile);
-  gt_str_delete(arguments.format);
-  gt_str_delete(arguments.input);
   gt_array_delete(results);
+  gt_str_delete(defaultstylefile);
   gt_feature_index_delete(features);
 
   return had_err;
 }
+
+GtTool* gt_sketch(void)
+{
+  return gt_tool_new(gt_sketch_arguments_new,
+                     gt_sketch_arguments_delete,
+                     gt_sketch_option_parser_new,
+                     gt_sketch_arguments_check,
+                     gt_sketch_runner);
+}
