@@ -1,6 +1,6 @@
 /*
   Copyright (c) 2007-2009 Stefan Kurtz <kurtz@zbh.uni-hamburg.de>
-  Copyright (c) 2007-2009 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2007-2009 Gordon Gremme <gordon@gremme.org>
   Copyright (c)      2011 Sascha Steinbiss <steinbiss@zbh.uni-hamburg.de>
   Copyright (c) 2007-2011 Center for Bioinformatics, University of Hamburg
 
@@ -144,7 +144,7 @@ static int read_symbolmap_from_lines(GtAlphabet *alpha,
 {
   char cc;
   unsigned int cnum, allocateddomainsize = 0;
-  unsigned long linecount, column;
+  GtUword linecount, column;
   bool blankfound, ignore, preamble = true, haserr = false;
   const char *currentline;
   GtUchar chartoshow;
@@ -215,13 +215,14 @@ static int read_symbolmap_from_lines(GtAlphabet *alpha,
             }
             if (mapfile != NULL) {
               gt_error_set(err,
-                           "illegal character '%c' in line %lu of mapfile %s",
-                           cc,linecount,mapfile);
+                           "illegal character '%c' in line " GT_WU
+                           " of mapfile %s",
+                           cc, linecount,mapfile);
             } else {
               gt_error_set(err,
-                           "illegal character '%c' in line %lu of alphabet "
-                           "definition",
-                           cc,linecount);
+                           "illegal character '%c' in line " GT_WU
+                           " of alphabet definition",
+                           cc, linecount);
             }
             haserr = true;
             break;
@@ -237,12 +238,12 @@ static int read_symbolmap_from_lines(GtAlphabet *alpha,
           {
             if (mapfile != NULL) {
               gt_error_set(err,"illegal character '%c' at the end of "
-                            "line %lu in mapfile %s",
-                            LINE(column+1),linecount,mapfile);
+                           "line "GT_WU" in mapfile %s",
+                           LINE(column+1),linecount,mapfile);
             } else {
               gt_error_set(err,"illegal character '%c' at the end of "
-                            "line %lu of alphabet definition",
-                            LINE(column+1),linecount);
+                           "line "GT_WU" of alphabet definition",
+                           LINE(column+1),linecount);
             }
             haserr  = true;
             break;
@@ -280,7 +281,7 @@ static int read_symbolmap_from_lines(GtAlphabet *alpha,
      hence there are mapsize+1 symbols in the range 0..mapsize.
      that is, mapsize is the largest symbol and we obtain */
   alpha->bitspersymbol
-    = gt_determinebitspervalue((unsigned long) alpha->mapsize);
+    = gt_determinebitspervalue((GtUword) alpha->mapsize);
   return haserr ? -1 : 0;
 }
 
@@ -415,7 +416,7 @@ void gt_alphabet_add_mapping(GtAlphabet *alphabet, const char *characters)
     alphabet->symbolmap[(int) characters[i]] = (GtUchar) alphabet->mapsize;
   alphabet->mapsize++;
   alphabet->bitspersymbol
-    = gt_determinebitspervalue((unsigned long) alphabet->mapsize);
+    = gt_determinebitspervalue((GtUword) alphabet->mapsize);
 }
 
 void gt_alphabet_add_wildcard(GtAlphabet *alphabet, char wildcard)
@@ -607,12 +608,12 @@ GtAlphabet* gt_alphabet_new_empty(void)
   return a;
 }
 
-GtAlphabet* gt_alphabet_guess(const char *sequence, unsigned long seqlen)
+GtAlphabet* gt_alphabet_guess(const char *sequence, GtUword seqlen)
 {
-  unsigned long i;
+  GtUword i;
   gt_assert(sequence && seqlen);
   for (i = 0;
-       i < seqlen && i < (unsigned long) ALPHABET_GUESS_MAX_LENGTH;
+       i < seqlen && i < (GtUword) ALPHABET_GUESS_MAX_LENGTH;
         i++) {
     if (strchr(ALPHABET_GUESS_PROTEIN_CHARS, sequence[i]) != NULL)
       return gt_alphabet_new_protein();
@@ -726,9 +727,9 @@ void gt_alphabet_output(const GtAlphabet *alphabet, FILE *fpout)
 }
 
 void gt_alphabet_decode_seq_to_fp(const GtAlphabet *alphabet, FILE *fpout,
-                                  const GtUchar *src, unsigned long len)
+                                  const GtUchar *src, GtUword len)
 {
-  unsigned long i;
+  GtUword i;
   const GtUchar *characters;
   gt_assert(fpout != NULL && (len == 0 || src != NULL));
 
@@ -746,7 +747,7 @@ void gt_alphabet_decode_seq_to_fp(const GtAlphabet *alphabet, FILE *fpout,
 }
 
 void gt_alphabet_printf_symbolstring(const GtAlphabet *alphabet,
-                                     const GtUchar *w, unsigned long len)
+                                     const GtUchar *w, GtUword len)
 {
   gt_alphabet_decode_seq_to_fp(alphabet, stdout, w, len);
 }
@@ -763,9 +764,9 @@ static inline char converttoprettysymbol(const GtAlphabet *alphabet,
 }
 
 void gt_alphabet_decode_seq_to_cstr(const GtAlphabet *alphabet, char *dest,
-                                      const GtUchar *src, unsigned long len)
+                                      const GtUchar *src, GtUword len)
 {
-  unsigned long i;
+  GtUword i;
 
   for (i = 0; i < len; i++)
   {
@@ -776,7 +777,7 @@ void gt_alphabet_decode_seq_to_cstr(const GtAlphabet *alphabet, char *dest,
 
 GtStr* gt_alphabet_decode_seq_to_str(const GtAlphabet *alphabet,
                                      const GtUchar *src,
-                                     unsigned long len)
+                                     GtUword len)
 {
   char *buffer;
   GtStr *ret;
@@ -835,8 +836,8 @@ static int comparechar(const void *a,const void *b)
 bool gt_alphabet_is_protein(const GtAlphabet *alphabet)
 {
   GtAlphabet proteinalphabet;
-  unsigned int i, reduceddomainsize1, reduceddomainsize2;
-  bool isprot = false;
+  unsigned int reduceddomainsize1, reduceddomainsize2;
+  bool isprot;
   GtUchar domainbuf1[GT_MAXALPHABETCHARACTER+1],
         domainbuf2[GT_MAXALPHABETCHARACTER+1];
 
@@ -848,15 +849,14 @@ bool gt_alphabet_is_protein(const GtAlphabet *alphabet)
   {
     qsort(&domainbuf1[0],(size_t) reduceddomainsize1,sizeof (char),comparechar);
     qsort(&domainbuf2[0],(size_t) reduceddomainsize2,sizeof (char),comparechar);
-    for (i=0; i < reduceddomainsize2; i++)
+    if (memcmp((const void *) domainbuf1,(const void *) domainbuf2,
+               reduceddomainsize2 * sizeof (GtUchar)) == 0)
     {
-      if (domainbuf1[i] != domainbuf2[i])
-      {
-        isprot = false;
-        break;
-      }
+      isprot = true;
+    } else
+    {
+      isprot = false;
     }
-    isprot = true;
   } else
   {
     isprot = false;
@@ -935,9 +935,9 @@ char gt_alphabet_decode(const GtAlphabet *alphabet, GtUchar c)
 }
 
 void gt_alphabet_encode_seq(const GtAlphabet *alphabet, GtUchar *out,
-                            const char *in, unsigned long length)
+                            const char *in, GtUword length)
 {
-  unsigned long i;
+  GtUword i;
   gt_assert(alphabet && out && in);
   for (i = 0; i < length; i++) {
     gt_assert(alphabet->symbolmap[(int) in[i]] != (GtUchar) UNDEFCHAR);
@@ -958,10 +958,10 @@ GtAlphabet *gt_alphabet_new_from_file(const char *filename,
   return a;
 }
 
-GtAlphabet* gt_alphabet_new_from_string(const char *alphadef, unsigned long len,
+GtAlphabet* gt_alphabet_new_from_string(const char *alphadef, GtUword len,
                                         GtError *err)
 {
-  unsigned long i, j;
+  GtUword i, j;
   GtStrArray *sa;
   GtAlphabet *alpha;
   gt_assert(alphadef && len > 0);
@@ -1085,12 +1085,12 @@ int gt_alphabet_unit_test(GtError *err)
   b = gt_alphabet_new_protein();
   c = gt_alphabet_clone(a);
 
-  gt_ensure(had_err, gt_alphabet_equals(a, a));
-  gt_ensure(had_err, gt_alphabet_equals(b, b));
-  gt_ensure(had_err, gt_alphabet_equals(c, c));
+  gt_ensure(gt_alphabet_equals(a, a));
+  gt_ensure(gt_alphabet_equals(b, b));
+  gt_ensure(gt_alphabet_equals(c, c));
 
-  gt_ensure(had_err, !gt_alphabet_equals(a, b));
-  gt_ensure(had_err, gt_alphabet_equals(a, c));
+  gt_ensure(!gt_alphabet_equals(a, b));
+  gt_ensure(gt_alphabet_equals(a, c));
 
   gt_alphabet_delete(a);
   gt_alphabet_delete(b);
