@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2010, 2012 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2010, 2012 Gordon Gremme <gordon@gremme.org>
 
   Permission to use, copy, modify, and distribute this software for any
   purpose with or without fee is hereby granted, provided that the above
@@ -18,19 +18,21 @@
 #include "core/bioseq_col.h"
 #include "core/class_alloc_lock.h"
 #include "core/cstr_api.h"
-#include "core/grep_api.h"
+#include "core/grep.h"
 #include "core/hashmap_api.h"
 #include "core/ma.h"
 #include "core/md5_seqid.h"
 #include "core/seq_col_rep.h"
 #include "core/seq_info_cache.h"
 #include "core/undef_api.h"
+#include "core/warning_api.h"
 
 struct GtBioseqCol {
   GtSeqCol parent_instance;
   GtBioseq **bioseqs;
-  unsigned long num_of_seqfiles;
+  GtUword num_of_seqfiles;
   GtSeqInfoCache *grep_cache;
+  bool matchdescstart;
 };
 
 const GtSeqColClass* gt_bioseq_col_class(void);
@@ -39,7 +41,7 @@ const GtSeqColClass* gt_bioseq_col_class(void);
 
 static void gt_bioseq_col_delete(GtSeqCol *sc)
 {
-  unsigned long i;
+  GtUword i;
   GtBioseqCol *bsc;
   bsc = gt_bioseq_col_cast(sc);
   if (!bsc) return;
@@ -49,13 +51,14 @@ static void gt_bioseq_col_delete(GtSeqCol *sc)
   gt_free(bsc->bioseqs);
 }
 
-static int grep_desc(GtBioseqCol *bsc, unsigned long *filenum,
-                     unsigned long *seqnum, GtStr *seqid, GtError *err)
+static int grep_desc(GtBioseqCol *bsc, GtUword *filenum,
+                     GtUword *seqnum, GtStr *seqid, GtError *err)
 {
-  unsigned long i, j;
+  GtUword i, j, num_matches = 0;
   const GtSeqInfo *seq_info_ptr;
   GtSeqInfo seq_info;
-  bool match;
+  GtStr *pattern, *escaped;
+  bool match = false;
   int had_err = 0;
   gt_error_check(err);
   gt_assert(bsc && filenum && seqnum && seqid);
@@ -69,25 +72,41 @@ static int grep_desc(GtBioseqCol *bsc, unsigned long *filenum,
     *seqnum = seq_info_ptr->seqnum;
     return 0;
   }
+  pattern = gt_str_new();
+  escaped = gt_str_new();
+  gt_grep_escape_extended(escaped, gt_str_get(seqid), gt_str_length(seqid));
+  if (bsc->matchdescstart)
+    gt_str_append_cstr(pattern, "^");
+  gt_str_append_str(pattern, escaped);
+  if (bsc->matchdescstart)
+    gt_str_append_cstr(pattern, "([[:space:]]|$)");
   for (i = 0; !had_err && i < bsc->num_of_seqfiles; i++) {
     GtBioseq *bioseq = bsc->bioseqs[i];
     for (j = 0; !had_err && j < gt_bioseq_number_of_sequences(bioseq); j++) {
       const char *desc = gt_bioseq_get_description(bioseq, j);
-      had_err = gt_grep(&match, gt_str_get(seqid), desc, err);
+      had_err = gt_grep(&match, gt_str_get(pattern), desc, err);
       if (!had_err && match) {
+        num_matches++;
+        if (num_matches > 1) {
+          gt_error_set(err, "query seqid '%s' could match more than one "
+                            "sequence description", gt_str_get(seqid));
+          had_err = -1;
+          break;
+        }
         *filenum = i;
         *seqnum = j;
         /* cache results */
         seq_info.filenum = i;
         seq_info.seqnum = j;
         gt_seq_info_cache_add(bsc->grep_cache, gt_str_get(seqid), &seq_info);
-        break;
       }
     }
     if (match)
       break;
   }
-  if (!had_err && !match) {
+  gt_str_delete(pattern);
+  gt_str_delete(escaped);
+  if (!had_err && num_matches == 0) {
     gt_error_set(err, "no description matched sequence ID '%s'",
                  gt_str_get(seqid));
     had_err = -1;
@@ -95,11 +114,19 @@ static int grep_desc(GtBioseqCol *bsc, unsigned long *filenum,
   return had_err;
 }
 
+static void gt_bioseq_col_enable_match_desc_start(GtSeqCol *sc)
+{
+  GtBioseqCol *bsc;
+  gt_assert(sc);
+  bsc = gt_bioseq_col_cast(sc);
+  bsc->matchdescstart = true;
+}
+
 static int gt_bioseq_col_grep_desc(GtSeqCol *sc, char **seq,
-                                   unsigned long start, unsigned long end,
+                                   GtUword start, GtUword end,
                                    GtStr *seqid, GtError *err)
 {
-  unsigned long filenum = 0, seqnum = 0, seqlength;
+  GtUword filenum = 0, seqnum = 0, seqlength;
   int had_err;
   GtBioseqCol *bsc;
   bsc = gt_bioseq_col_cast(sc);
@@ -110,9 +137,9 @@ static int gt_bioseq_col_grep_desc(GtSeqCol *sc, char **seq,
     seqlength = gt_bioseq_get_sequence_length(bsc->bioseqs[filenum], seqnum);
     if (start > seqlength - 1 || end > seqlength - 1) {
       had_err = -1;
-      gt_error_set(err, "trying to extract range %lu-%lu on sequence "
-                         "``%s''which is not covered by that sequence (only "
-                         "%lu characters in size). Has the sequence-region "
+      gt_error_set(err, "trying to extract range "GT_WU"-"GT_WU" on sequence "
+                         "``%s'' which is not covered by that sequence (only "
+                         ""GT_WU" characters in size). Has the sequence-region "
                          "to sequence mapping been defined correctly?",
                          start, end, gt_str_get(seqid), seqlength);
     }
@@ -127,7 +154,7 @@ static int gt_bioseq_col_grep_desc(GtSeqCol *sc, char **seq,
 static int gt_bioseq_col_grep_desc_md5(GtSeqCol *sc, const char **md5,
                                        GtStr *seqid, GtError *err)
 {
-  unsigned long filenum = 0, seqnum = 0;
+  GtUword filenum = 0, seqnum = 0;
   int had_err;
   GtBioseqCol *bsc;
   bsc = gt_bioseq_col_cast(sc);
@@ -140,11 +167,11 @@ static int gt_bioseq_col_grep_desc_md5(GtSeqCol *sc, const char **md5,
 }
 
 static int gt_bioseq_col_grep_desc_sequence_length(GtSeqCol *sc,
-                                                   unsigned long *length,
+                                                   GtUword *length,
                                                    GtStr *seqid,
                                                    GtError *err)
 {
-  unsigned long filenum = 0, seqnum = 0;
+  GtUword filenum = 0, seqnum = 0;
   int had_err;
   GtBioseqCol *bsc;
   bsc = gt_bioseq_col_cast(sc);
@@ -156,19 +183,15 @@ static int gt_bioseq_col_grep_desc_sequence_length(GtSeqCol *sc,
   return had_err;
 }
 
-static int gt_bioseq_col_md5_to_seq(GtSeqCol *sc, char **seq,
-                                    unsigned long start, unsigned long end,
-                                    GtStr *md5_seqid, GtError *err)
+static int md5_to_index(GtBioseq **bioseq, GtUword *seqnum,
+                        GtBioseqCol *bsc, GtStr *md5_seqid, GtError *err)
 {
-  unsigned long i, seqnum = GT_UNDEF_ULONG;
+  bool seqid_changed = false;
   char *seqid = NULL;
+  GtUword i;
   int had_err = 0;
-  GtBioseq *bioseq = NULL;
-  GtBioseqCol *bsc;
-  bsc = gt_bioseq_col_cast(sc);
   gt_error_check(err);
-  gt_assert(bsc && seq && md5_seqid && err);
-  gt_assert(gt_md5_seqid_has_prefix(gt_str_get(md5_seqid)));
+  gt_assert(seqnum && bsc && md5_seqid);
   /* performance hack to avoid string duplication */
   if (gt_str_length(md5_seqid) >= GT_MD5_SEQID_TOTAL_LEN) {
     seqid = gt_str_get(md5_seqid);
@@ -177,26 +200,42 @@ static int gt_bioseq_col_md5_to_seq(GtSeqCol *sc, char **seq,
                    gt_str_get(md5_seqid), GT_MD5_SEQID_SEPARATOR);
       had_err = -1;
     }
-    if (!had_err)
+    if (!had_err) {
       seqid[GT_MD5_SEQID_TOTAL_LEN-1] = '\0';
+      seqid_changed = true;
+    }
   }
   for (i = 0; !had_err && i < bsc->num_of_seqfiles; i++) {
-    bioseq = bsc->bioseqs[i];
-    seqnum = gt_bioseq_md5_to_index(bioseq, gt_str_get(md5_seqid) +
-                                    GT_MD5_SEQID_PREFIX_LEN);
-    if (seqnum != GT_UNDEF_ULONG)
+    *bioseq = bsc->bioseqs[i];
+    *seqnum = gt_bioseq_md5_to_index(*bioseq, gt_str_get(md5_seqid) +
+                                     GT_MD5_SEQID_PREFIX_LEN);
+    if (*seqnum != GT_UNDEF_UWORD)
       break;
   }
-  if (!had_err) {
-    if (gt_str_length(md5_seqid) >= GT_MD5_SEQID_TOTAL_LEN)
-      seqid[GT_MD5_SEQID_TOTAL_LEN-1] = GT_MD5_SEQID_SEPARATOR;
-    if (seqnum != GT_UNDEF_ULONG) {
-      *seq = gt_bioseq_get_sequence_range(bioseq, seqnum, start, end);
-    }
-    else {
-      gt_error_set(err, "sequence %s not found", gt_str_get(md5_seqid));
-      had_err = -1;
-    }
+  if (seqid_changed) /* reset seqid no matter what */
+    seqid[GT_MD5_SEQID_TOTAL_LEN-1] = GT_MD5_SEQID_SEPARATOR;
+  if (!had_err && *seqnum == GT_UNDEF_UWORD) {
+    gt_error_set(err, "sequence %s not found", gt_str_get(md5_seqid));
+    had_err = -1;
+  }
+  return had_err;
+}
+
+static int gt_bioseq_col_md5_to_seq(GtSeqCol *sc, char **seq,
+                                    GtUword start, GtUword end,
+                                    GtStr *md5_seqid, GtError *err)
+{
+  GtUword seqnum = GT_UNDEF_UWORD;
+  GtBioseq *bioseq = NULL;
+  GtBioseqCol *bsc;
+  int had_err = 0;
+  bsc = gt_bioseq_col_cast(sc);
+  gt_error_check(err);
+  gt_assert(bsc && seq && md5_seqid && err);
+  gt_assert(gt_md5_seqid_has_prefix(gt_str_get(md5_seqid)));
+  if (!(had_err = md5_to_index(&bioseq, &seqnum, bsc, md5_seqid, err))) {
+    gt_assert(seqnum != GT_UNDEF_UWORD);
+    *seq = gt_bioseq_get_sequence_range(bioseq, seqnum, start, end);
   }
   return had_err;
 }
@@ -204,59 +243,40 @@ static int gt_bioseq_col_md5_to_seq(GtSeqCol *sc, char **seq,
 static int gt_bioseq_col_md5_to_description(GtSeqCol *sc, GtStr *desc,
                                             GtStr *md5_seqid, GtError *err)
 {
-  unsigned long i, seqnum = GT_UNDEF_ULONG;
-  int had_err = 0;
-  GtBioseq *bioseq;
+  GtUword seqnum = GT_UNDEF_UWORD;
+  GtBioseq *bioseq = NULL;
   GtBioseqCol *bsc;
+  int had_err = 0;
   bsc = gt_bioseq_col_cast(sc);
   gt_error_check(err);
   gt_assert(bsc && desc && md5_seqid && err);
   gt_assert(gt_md5_seqid_has_prefix(gt_str_get(md5_seqid)));
-  /* XXX: extract method */
-  for (i = 0; i < bsc->num_of_seqfiles; i++) {
-    bioseq = bsc->bioseqs[i];
-    seqnum = gt_bioseq_md5_to_index(bioseq, gt_str_get(md5_seqid) +
-                                    GT_MD5_SEQID_PREFIX_LEN);
-    if (seqnum != GT_UNDEF_ULONG)
-      break;
-  }
-  if (seqnum != GT_UNDEF_ULONG)
+  if (!(had_err = md5_to_index(&bioseq, &seqnum, bsc, md5_seqid, err))) {
+    gt_assert(seqnum != GT_UNDEF_UWORD);
     gt_str_append_cstr(desc, gt_bioseq_get_description(bioseq, seqnum));
-  else  {
-    gt_error_set(err, "sequence %s not found", gt_str_get(md5_seqid));
-    had_err = -1;
   }
   return had_err;
 }
 
-int gt_bioseq_col_md5_to_sequence_length(GtSeqCol *sc, unsigned long *len,
+int gt_bioseq_col_md5_to_sequence_length(GtSeqCol *sc, GtUword *len,
                                          GtStr *md5_seqid, GtError *err)
 {
-  unsigned long i, seqnum = GT_UNDEF_ULONG;
-  int had_err = 0;
-  GtBioseq *bioseq;
+  GtUword seqnum = GT_UNDEF_UWORD;
+  GtBioseq *bioseq = NULL;
   GtBioseqCol *bsc;
+  int had_err = 0;
   bsc = gt_bioseq_col_cast(sc);
   gt_error_check(err);
   gt_assert(bsc && len && md5_seqid && err);
   gt_assert(gt_md5_seqid_has_prefix(gt_str_get(md5_seqid)));
-  for (i = 0; i < bsc->num_of_seqfiles; i++) {
-    bioseq = bsc->bioseqs[i];
-    seqnum = gt_bioseq_md5_to_index(bioseq, gt_str_get(md5_seqid) +
-                                    GT_MD5_SEQID_PREFIX_LEN);
-    if (seqnum != GT_UNDEF_ULONG)
-      break;
-  }
-  if (seqnum != GT_UNDEF_ULONG)
+  if (!(had_err = md5_to_index(&bioseq, &seqnum, bsc, md5_seqid, err))) {
+    gt_assert(seqnum != GT_UNDEF_UWORD);
     *len = gt_bioseq_get_sequence_length(bioseq, seqnum);
-  else  {
-    gt_error_set(err, "sequence %s not found", gt_str_get(md5_seqid));
-    had_err = -1;
   }
   return had_err;
 }
 
-static unsigned long gt_bioseq_col_num_of_files(const GtSeqCol *sc)
+static GtUword gt_bioseq_col_num_of_files(const GtSeqCol *sc)
 {
   const GtBioseqCol *bsc;
   bsc = gt_bioseq_col_cast(sc);
@@ -264,8 +284,8 @@ static unsigned long gt_bioseq_col_num_of_files(const GtSeqCol *sc)
   return bsc->num_of_seqfiles;
 }
 
-static unsigned long gt_bioseq_col_num_of_seqs(const GtSeqCol *sc,
-                                               unsigned long filenum)
+static GtUword gt_bioseq_col_num_of_seqs(const GtSeqCol *sc,
+                                               GtUword filenum)
 {
   GtBioseqCol *bsc;
   bsc = gt_bioseq_col_cast(sc);
@@ -274,8 +294,8 @@ static unsigned long gt_bioseq_col_num_of_seqs(const GtSeqCol *sc,
 }
 
 static const char* gt_bioseq_col_get_md5_fingerprint(const GtSeqCol *sc,
-                                                     unsigned long filenum,
-                                                     unsigned long seqnum)
+                                                     GtUword filenum,
+                                                     GtUword seqnum)
 {
   GtBioseqCol *bsc;
   bsc = gt_bioseq_col_cast(sc);
@@ -284,10 +304,10 @@ static const char* gt_bioseq_col_get_md5_fingerprint(const GtSeqCol *sc,
 }
 
 static char* gt_bioseq_col_get_sequence(const GtSeqCol *sc,
-                                        unsigned long filenum,
-                                        unsigned long seqnum,
-                                        unsigned long start,
-                                        unsigned long end)
+                                        GtUword filenum,
+                                        GtUword seqnum,
+                                        GtUword start,
+                                        GtUword end)
 {
   GtBioseqCol *bsc;
   bsc = gt_bioseq_col_cast(sc);
@@ -297,8 +317,8 @@ static char* gt_bioseq_col_get_sequence(const GtSeqCol *sc,
 }
 
 static char* gt_bioseq_col_get_description(const GtSeqCol *sc,
-                                           unsigned long filenum,
-                                           unsigned long seqnum)
+                                           GtUword filenum,
+                                           GtUword seqnum)
 {
   GtBioseqCol *bsc;
   bsc = gt_bioseq_col_cast(sc);
@@ -306,9 +326,9 @@ static char* gt_bioseq_col_get_description(const GtSeqCol *sc,
   return gt_cstr_dup(gt_bioseq_get_description(bsc->bioseqs[filenum], seqnum));
 }
 
-static unsigned long gt_bioseq_col_get_sequence_length(const GtSeqCol *sc,
-                                                       unsigned long filenum,
-                                                       unsigned long seqnum)
+static GtUword gt_bioseq_col_get_sequence_length(const GtSeqCol *sc,
+                                                       GtUword filenum,
+                                                       GtUword seqnum)
 {
   GtBioseqCol *bsc;
   bsc = gt_bioseq_col_cast(sc);
@@ -323,6 +343,7 @@ const GtSeqColClass* gt_bioseq_col_class(void)
   if (!bsc_class) {
       bsc_class = gt_seq_col_class_new(sizeof (GtBioseqCol),
                                        gt_bioseq_col_delete,
+                                       gt_bioseq_col_enable_match_desc_start,
                                        gt_bioseq_col_grep_desc,
                                        gt_bioseq_col_grep_desc_md5,
                                        gt_bioseq_col_grep_desc_sequence_length,
@@ -344,7 +365,7 @@ GtSeqCol* gt_bioseq_col_new(GtStrArray *sequence_files, GtError *err)
 {
   GtSeqCol *sc;
   GtBioseqCol *bsc;
-  unsigned long i;
+  GtUword i;
   int had_err = 0;
   gt_error_check(err);
   gt_assert(sequence_files);
@@ -362,5 +383,6 @@ GtSeqCol* gt_bioseq_col_new(GtStrArray *sequence_files, GtError *err)
     gt_bioseq_col_delete(sc);
     return NULL;
   }
+  bsc->matchdescstart = false;
   return sc;
 }
