@@ -82,23 +82,23 @@ typedef struct GtEncseqReader GtEncseqReader;
 const char*       gt_encseq_indexname(const GtEncseq *encseq);
 /* Returns the total number of characters in all sequences of <encseq>,
    including separators and wildcards. */
-unsigned long     gt_encseq_total_length(const GtEncseq *encseq);
+GtUword           gt_encseq_total_length(const GtEncseq *encseq);
 /* Returns the total number of sequences contained in <encseq>. */
-unsigned long     gt_encseq_num_of_sequences(const GtEncseq *encseq);
+GtUword           gt_encseq_num_of_sequences(const GtEncseq *encseq);
 /* Returns the encoded representation of the character at position <pos> of
    <encseq> read in the direction as indicated by <readmode>. */
 GtUchar           gt_encseq_get_encoded_char(const GtEncseq *encseq,
-                                             unsigned long pos,
+                                             GtUword pos,
                                              GtReadmode readmode);
 /* Returns the decoded representation of the character at position <pos> of
    <encseq> read in the direction as indicated by <readmode>. */
 char              gt_encseq_get_decoded_char(const GtEncseq *encseq,
-                                             unsigned long pos,
+                                             GtUword pos,
                                              GtReadmode readmode);
 /* Returns true iff <pos> is a separator position of <encseq>
    read in the direction as indicated by <readmode>. */
 bool              gt_encseq_position_is_separator(const GtEncseq *encseq,
-                                                  unsigned long pos,
+                                                  GtUword pos,
                                                   GtReadmode readmode);
 /* Increases the reference count of <encseq>. */
 GtEncseq*         gt_encseq_ref(GtEncseq *encseq);
@@ -109,29 +109,29 @@ GtEncseq*         gt_encseq_ref(GtEncseq *encseq);
    <GT_READMODE_REVCOMPL> readmodes are only used on DNA alphabets. */
 GtEncseqReader*   gt_encseq_create_reader_with_readmode(const GtEncseq *encseq,
                                                         GtReadmode readmode,
-                                                        unsigned long startpos);
+                                                        GtUword startpos);
 /* Returns the encoded representation of the substring from position <frompos>
    to position <topos> of <encseq>. The result is written to the location
    pointed to by <buffer>, which must be large enough to hold the result. */
 void              gt_encseq_extract_encoded(const GtEncseq *encseq,
-                                              GtUchar *buffer,
-                                              unsigned long frompos,
-                                              unsigned long topos);
+                                            GtUchar *buffer,
+                                            GtUword frompos,
+                                            GtUword topos);
 /* Returns the decoded version of the substring from position <frompos>
    to position <topos> of <encseq>. The result is written to the location
    pointed to by <buffer>, which must be large enough to hold the result. */
 void              gt_encseq_extract_decoded(const GtEncseq *encseq,
                                             char *buffer,
-                                            unsigned long frompos,
-                                            unsigned long topos);
+                                            GtUword frompos,
+                                            GtUword topos);
 /* Returns the length of the <seqnum>-th sequence in the <encseq>.
    Requires multiple sequence support enabled in <encseq>. */
-unsigned long     gt_encseq_seqlength(const GtEncseq *encseq,
-                                      unsigned long seqnum);
+GtUword           gt_encseq_seqlength(const GtEncseq *encseq,
+                                      GtUword seqnum);
 /* Returns the length of the shortest sequence in the <encseq>. */
-unsigned long     gt_encseq_min_seq_length(const GtEncseq *encseq);
+GtUword           gt_encseq_min_seq_length(const GtEncseq *encseq);
 /* Returns the length of the longest sequence in the <encseq>. */
-unsigned long     gt_encseq_max_seq_length(const GtEncseq *encseq);
+GtUword           gt_encseq_max_seq_length(const GtEncseq *encseq);
 /* Returns <true> if <encseq> has multiple sequence support. */
 bool              gt_encseq_has_multiseq_support(const GtEncseq *encseq);
 /* Returns <true> if <encseq> has description support. */
@@ -140,41 +140,41 @@ bool              gt_encseq_has_description_support(const GtEncseq *encseq);
 bool              gt_encseq_has_md5_support(const GtEncseq *encseq);
 /* Returns the start position of the <seqnum>-th sequence in the <encseq>.
    Requires multiple sequence support enabled in <encseq>. */
-unsigned long     gt_encseq_seqstartpos(const GtEncseq *encseq,
-                                        unsigned long seqnum);
+GtUword           gt_encseq_seqstartpos(const GtEncseq *encseq,
+                                        GtUword seqnum);
 /* Returns the sequence number from the given <position> for a given
    GtEncseq <encseq>. */
-unsigned long     gt_encseq_seqnum(const GtEncseq *encseq,
-                                   unsigned long position);
+GtUword           gt_encseq_seqnum(const GtEncseq *encseq,
+                                   GtUword position);
 /* Returns a pointer to the description of the <seqnum>-th sequence in the
    <encseq>. The length of the returned string is written to the
    location pointed at by <desclen>.
    The returned description pointer is not <\0>-terminated!
    Requires description support enabled in <encseq>. */
 const char*       gt_encseq_description(const GtEncseq *encseq,
-                                        unsigned long *desclen,
-                                        unsigned long seqnum);
+                                        GtUword *desclen,
+                                        GtUword seqnum);
 /* Returns a <GtStrArray> of the names of the original sequence files
    contained in <encseq>. */
 const GtStrArray* gt_encseq_filenames(const GtEncseq *encseq);
 /* Returns the number of files contained in <encseq>. */
-unsigned long     gt_encseq_num_of_files(const GtEncseq *encseq);
+GtUword           gt_encseq_num_of_files(const GtEncseq *encseq);
 /* Returns the effective length (sum of sequence lengths and separators
    between them) of the <filenum>-th file contained in <encseq>. */
-uint64_t          gt_encseq_effective_filelength(const GtEncseq *encseq,
-                                                 unsigned long filenum);
+GtUint64          gt_encseq_effective_filelength(const GtEncseq *encseq,
+                                                 GtUword filenum);
 /* Returns the start position of the sequences of the  <filenum>-th file in the
    <encseq>. Requires multiple file support enabled in <encseq>. */
-unsigned long     gt_encseq_filestartpos(const GtEncseq *encseq,
-                                         unsigned long filenum);
+GtUword           gt_encseq_filestartpos(const GtEncseq *encseq,
+                                         GtUword filenum);
 /* Returns the file number from the given <position> for a given
    GtEncseq <encseq>. */
-unsigned long     gt_encseq_filenum(const GtEncseq *encseq,
-                                    unsigned long position);
+GtUword           gt_encseq_filenum(const GtEncseq *encseq,
+                                    GtUword position);
 /* Returns the first sequence number of the sequences in file <filenum> for a
    given GtEncseq <encseq>. */
-unsigned long     gt_encseq_filenum_first_seqnum(const GtEncseq *encseq,
-                                                 unsigned long filenum);
+GtUword           gt_encseq_filenum_first_seqnum(const GtEncseq *encseq,
+                                                 GtUword filenum);
 /* Returns the <GtAlphabet> associated with <encseq>. */
 GtAlphabet*       gt_encseq_alphabet(const GtEncseq *encseq);
 /* Extends <encseq>  by virtual reverse complement sequences.
@@ -189,7 +189,7 @@ void              gt_encseq_unmirror(GtEncseq *encseq);
 bool              gt_encseq_is_mirrored(const GtEncseq *encseq);
 /* Returns the version number of the file representation of <encseq> if it
    exists, or 0 if it was not mapped from a file. */
-unsigned long     gt_encseq_version(const GtEncseq *encseq);
+GtUword           gt_encseq_version(const GtEncseq *encseq);
 /* Returns TRUE if <encseq> was created on a 64-bit system. */
 bool              gt_encseq_is_64_bit(const GtEncseq *encseq);
 /* Deletes <encseq> and frees all associated space. */
@@ -200,7 +200,7 @@ void              gt_encseq_delete(GtEncseq *encseq);
 void              gt_encseq_reader_reinit_with_readmode(GtEncseqReader *esr,
                                                       const GtEncseq *encseq,
                                                       GtReadmode readmode,
-                                                      unsigned long startpos);
+                                                      GtUword startpos);
 /* Returns the next encoded character from current position of <esr>, advancing
    the iterator by one position. */
 GtUchar           gt_encseq_reader_next_encoded_char(GtEncseqReader *esr);
@@ -255,24 +255,27 @@ void              gt_encseq_encoder_disable_description_support(
    sequence encoded by <ee>. That is, the .ssp table is created.
    This is a prerequisite for being able to activate description support in
    <gt_encseq_loader_require_multiseq_support()>. Activated by default. */
-void             gt_encseq_encoder_enable_multiseq_support(GtEncseqEncoder *ee);
+void              gt_encseq_encoder_enable_multiseq_support(
+                                                           GtEncseqEncoder *ee);
 /* Disables support for random access to multiple sequences in the encoded
    sequence encoded by <ee>. That is, the .ssp table is not created.
    Encoded sequences created without this support will not be able to be
    loaded via a <GtEncseqLoader> with
    <gt_encseq_loader_require_multiseq_support()> enabled. */
-void            gt_encseq_encoder_disable_multiseq_support(GtEncseqEncoder *ee);
+void              gt_encseq_encoder_disable_multiseq_support(
+                                                           GtEncseqEncoder *ee);
 /* Enables support for lossless reproduction of the original sequence,
    regardless of alphabet transformations that may apply. Deactivated by
    default. */
-void             gt_encseq_encoder_enable_lossless_support(GtEncseqEncoder *ee);
+void              gt_encseq_encoder_enable_lossless_support(
+                                                           GtEncseqEncoder *ee);
 /* Enables support for lossless reproduction of the original sequence,
    regardless of alphabet transformations that may apply. Encoded sequences
    created without this support will not be able to be loaded via a
    <GtEncseqLoader> with <gt_encseq_loader_require_lossless_support()>
    enabled. */
-void              gt_encseq_encoder_disable_lossless_support(GtEncseqEncoder
-                                                                           *ee);
+void              gt_encseq_encoder_disable_lossless_support(
+                                                           GtEncseqEncoder *ee);
 /* Enables support for quick MD5 indexing of the sequences in <ee>. Activated by
    default. */
 void              gt_encseq_encoder_enable_md5_support(GtEncseqEncoder *ee);
@@ -287,7 +290,8 @@ void              gt_encseq_encoder_create_des_tab(GtEncseqEncoder *ee);
 void              gt_encseq_encoder_do_not_create_des_tab(GtEncseqEncoder *ee);
 /* Returns <true> if the creation of the .des table has been requested,
    <false> otherwise. */
-bool             gt_encseq_encoder_des_tab_requested(const GtEncseqEncoder *ee);
+bool              gt_encseq_encoder_des_tab_requested(
+                                                     const GtEncseqEncoder *ee);
 /* Enables creation of the .ssp table containing indexes for multiple sequences.
    Enabled by default. */
 void              gt_encseq_encoder_create_ssp_tab(GtEncseqEncoder *ee);
@@ -295,7 +299,8 @@ void              gt_encseq_encoder_create_ssp_tab(GtEncseqEncoder *ee);
 void              gt_encseq_encoder_do_not_create_ssp_tab(GtEncseqEncoder *ee);
 /* Returns <true> if the creation of the .ssp table has been requested,
    <false> otherwise. */
-bool             gt_encseq_encoder_ssp_tab_requested(const GtEncseqEncoder *ee);
+bool              gt_encseq_encoder_ssp_tab_requested(
+                                                     const GtEncseqEncoder *ee);
 /* Enables creation of the .sds table containing indexes for sequence
    descriptions. Enabled by default. */
 void              gt_encseq_encoder_create_sds_tab(GtEncseqEncoder *ee);
@@ -303,7 +308,8 @@ void              gt_encseq_encoder_create_sds_tab(GtEncseqEncoder *ee);
 void              gt_encseq_encoder_do_not_create_sds_tab(GtEncseqEncoder *ee);
 /* Returns <true> if the creation of the .sds table has been requested,
    <false> otherwise. */
-bool             gt_encseq_encoder_sds_tab_requested(const GtEncseqEncoder *ee);
+bool              gt_encseq_encoder_sds_tab_requested(
+                                                     const GtEncseqEncoder *ee);
 /* Enables creation of the .md5 table containing MD5 sums. Enabled by
    default. */
 void              gt_encseq_encoder_create_md5_tab(GtEncseqEncoder *ee);
@@ -311,7 +317,8 @@ void              gt_encseq_encoder_create_md5_tab(GtEncseqEncoder *ee);
 void              gt_encseq_encoder_do_not_create_md5_tab(GtEncseqEncoder *ee);
 /* Returns <true> if the creation of the .md5 table has been requested,
    <false> otherwise. */
-bool             gt_encseq_encoder_md5_tab_requested(const GtEncseqEncoder *ee);
+bool              gt_encseq_encoder_md5_tab_requested(
+                                                     const GtEncseqEncoder *ee);
 /* Sets the sequence input type for <ee> to DNA. */
 void              gt_encseq_encoder_set_input_dna(GtEncseqEncoder *ee);
 /* Returns <true> if the input sequence has been defined as being DNA. */
@@ -320,6 +327,11 @@ bool              gt_encseq_encoder_is_input_dna(GtEncseqEncoder *ee);
 void              gt_encseq_encoder_set_input_protein(GtEncseqEncoder *ee);
 /* Returns <true> if the input sequence has been defined as being protein. */
 bool              gt_encseq_encoder_is_input_protein(GtEncseqEncoder *ee);
+/* Makes <ee> ignore all description suffixes after the first whitespace
+   character per description (as defined via isspace(3)). */
+void              gt_encseq_encoder_clip_desc(GtEncseqEncoder *ee);
+/* Returns <true> if <ee> clips all descriptions after the first whitespace. */
+bool              gt_encseq_encoder_are_descs_clipped(GtEncseqEncoder *ee);
 /* Encodes the sequence files given in <seqfiles> using the settings in <ee>
    and <indexname> as the prefix for the index tables. Returns 0 on success, or
    a negative value on error (<err> is set accordingly). */
@@ -448,7 +460,8 @@ void              gt_encseq_builder_disable_description_support(
 /* Enables support for random access to multiple sequences in the encoded
    sequence to be built by <eb>. Requires additional memory for an index of
    starting positions. Activated by default. */
-void             gt_encseq_builder_enable_multiseq_support(GtEncseqBuilder *eb);
+void              gt_encseq_builder_enable_multiseq_support(
+                                                           GtEncseqBuilder *eb);
 /* Disables support for random access to multiple sequences in the encoded
    sequence to be built by <eb>. Disabling this support will result in an
    error when trying to call the method <gt_encseq_seqlength()> or
@@ -482,7 +495,7 @@ void              gt_encseq_builder_do_not_create_sds_tab(GtEncseqBuilder *eb);
    must only contain symbols compatible with the alphabet. */
 void              gt_encseq_builder_add_cstr(GtEncseqBuilder *eb,
                                              const char *str,
-                                             unsigned long strlen,
+                                             GtUword strlen,
                                              const char *desc);
 /* Adds a sequence given as a GtStr <str> to the encoded sequence to be built
    by <eb>. Additionally, a description can be given. If description support
@@ -494,13 +507,13 @@ void              gt_encseq_builder_add_str(GtEncseqBuilder *eb, GtStr *str,
                                            const char *desc);
 /* Adds a sequence given as a pre-encoded string  <str> of length <strlen> to
    the encoded sequence to be built by <eb>. <str> must be encoded using the
-   alphabet set at the construction time of <eb>.
-   Does not take ownership of <str>.
+   alphabet set at the construction time of <eb>. <str> is not allowed to
+   include sequence separators. Does not take ownership of <str>.
    Additionally, a description <desc> can be given. If description support
    is enabled, this must not be <NULL>. */
 void              gt_encseq_builder_add_encoded(GtEncseqBuilder *eb,
                                                const GtUchar *str,
-                                               unsigned long strlen,
+                                               GtUword strlen,
                                                const char *desc);
 /* Adds a sequence given as a pre-encoded string  <str> of length <strlen> to
    the encoded sequence to be built by <eb>. <str> must be encoded using the
@@ -511,8 +524,15 @@ void              gt_encseq_builder_add_encoded(GtEncseqBuilder *eb,
    is enabled, this must not be <NULL>. */
 void              gt_encseq_builder_add_encoded_own(GtEncseqBuilder *eb,
                                                    const GtUchar *str,
-                                                   unsigned long strlen,
+                                                   GtUword strlen,
                                                    const char *desc);
+/* Adds a sequence given as a pre-encoded string  <str> of length <strlen> to
+   the encoded sequence to be built by <eb>. <str> must be encoded using the
+   alphabet set at the construction time of <eb>. <str> may include
+   sequence separators. Does not take ownership of <str>.*/
+void              gt_encseq_builder_add_multiple_encoded(GtEncseqBuilder *eb,
+                                                         const GtUchar *str,
+                                                         GtUword strlen);
 /* Sets the logger to use by <ee> during encoding to <l>. Default is <NULL> (no
    logging). */
 void              gt_encseq_builder_set_logger(GtEncseqBuilder*, GtLogger *l);
