@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2010 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2007-2010 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2007-2008 Center for Bioinforfatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -88,14 +88,19 @@ enum tmpfp_flags
   TMPFP_OPENBINARY    = 1 << 2, /**< use stdio mode "w+b", "w+" otherwise */
   TMPFP_DEFAULT_FLAGS = 0,
 };
-#define gt_xtmpfp_generic(template, flags) \
-        gt_xtmpfp_generic_func(template, TMPFP_DEFAULT_FLAGS, \
+#define gt_xtmpfp_generic(template_code, flags) \
+        gt_xtmpfp_generic_func(template_code, TMPFP_DEFAULT_FLAGS, \
                                __FILE__, __LINE__)
-FILE*   gt_xtmpfp_generic_func(GtStr *template, enum tmpfp_flags flags,
+FILE*   gt_xtmpfp_generic_func(GtStr *template_code, enum tmpfp_flags flags,
                                const char*, int);
-#define gt_xtmpfp(template)\
-        gt_xtmpfp_generic(template, TMPFP_DEFAULT_FLAGS)
+#define gt_xtmpfp(template_code)\
+        gt_xtmpfp_generic(template_code, TMPFP_DEFAULT_FLAGS)
 
+#define gt_fa_heap_read(PATH,LENPTR,ERR)\
+        gt_fa_heap_read_func(PATH,LENPTR,__FILE__,__LINE__,ERR)
+
+void *gt_fa_heap_read_func(const char *path, size_t *len,
+                           const char *src_file, int src_line, GtError *err);
 /* memory map functions */
 #define gt_fa_mmap_read(path, len, err)\
         gt_fa_mmap_read_func(path, len, __FILE__, __LINE__, err)
@@ -158,7 +163,7 @@ void*   gt_fa_mmap_read_with_suffix_func(const char *path, const char *suffix,
                                          size_t *len, const char *src_file,
                                          int src_line, GtError *err);
 void*   gt_fa_mmap_check_size_with_suffix(const char *path, const char *suffix,
-                                          unsigned long expectedunits,
+                                          GtUword expectedunits,
                                           size_t sizeofunit, GtError *err);
 
 /* check if all allocated file pointer have been released, prints to stderr */
@@ -166,8 +171,8 @@ int     gt_fa_check_fptr_leak(void);
 /* check if all allocated memory maps have been freed, prints to stderr */
 int     gt_fa_check_mmap_leak(void);
 void    gt_fa_enable_global_spacepeak(void);
-unsigned long gt_fa_get_space_peak(void);
-unsigned long gt_fa_get_space_current(void);
+GtUword gt_fa_get_space_peak(void);
+GtUword gt_fa_get_space_current(void);
 void    gt_fa_show_space_peak(FILE*);
 void    gt_fa_clean(void);
 
