@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2010 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2006-2010 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2006-2008 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -26,8 +26,8 @@
    accordingly. */
 void gt_fasta_show_entry_with_suffix(const char *description,
                                      const char *sequence,
-                                     unsigned long sequence_length,
-                                     const char *suffix, unsigned long width,
+                                     GtUword sequence_length,
+                                     const char *suffix, GtUword width,
                                      GtFile *outfp);
 
 #endif
