@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2010 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2006-2010 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2006-2008 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -19,11 +19,13 @@
 #define FASTA_API_H
 
 #include "core/file_api.h"
+#include "core/types_api.h"
+
+/* FASTA module */
 
 /* Print a fasta entry with optional <description> and mandatory <sequence> to
    <outfp>. If <width> is != 0 the sequence is formatted accordingly. */
 void gt_fasta_show_entry(const char *description, const char *sequence,
-                         unsigned long sequence_length, unsigned long width,
-                         GtFile *outfp);
+                         GtUword sequence_length, GtUword width, GtFile *outfp);
 
 #endif
