@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2012 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2006-2013 Gordon Gremme <gordon@gremme.org>
   Copyright (c)      2007 Stefan Kurtz <kurtz@zbh.uni-hamburg.de>
   Copyright (c) 2006-2008 Center for Bioinformatics, University of Hamburg
 
@@ -22,13 +22,14 @@
 #ifndef S_SPLINT_S
 #include <fcntl.h>
 #endif
-#include "core/xposix.h"
-#include "core/fileutils_api.h"
-#include "core/xansi_api.h"
-#include "core/ma.h"
-#include "core/splitter.h"
-#include "core/sequence_buffer.h"
+#include "core/compat.h"
 #include "core/cstr_api.h"
+#include "core/fileutils_api.h"
+#include "core/ma.h"
+#include "core/sequence_buffer.h"
+#include "core/splitter.h"
+#include "core/xansi_api.h"
+#include "core/xposix.h"
 
 typedef bool (*FileExistsFunc)(const char *path);
 
@@ -41,16 +42,34 @@ bool gt_file_exists(const char *path)
   return true;
 }
 
+bool gt_file_exists_and_is_dir(const char *path)
+{
+  struct stat sb;
+  if (stat(path, &sb))
+    return false;
+  if (S_ISDIR(sb.st_mode))
+    return true;
+  return false;
+}
+
 static bool file_exists_and_is_regular_executable(const char *path)
 {
   bool is_exec = false;
   struct stat sb;
   FILE *file;
+#ifdef _WIN32
+  size_t len = strlen(path);
+#endif
   if ((file = fopen(path, "r")) == NULL)
     return false;
   gt_xfstat(fileno(file), &sb);
   if (S_ISREG(sb.st_mode) &&
-      (sb.st_mode & S_IXUSR || sb.st_mode & S_IXGRP || sb.st_mode & S_IXOTH)) {
+#ifndef _WIN32
+      (sb.st_mode & S_IXUSR || sb.st_mode & S_IXGRP || sb.st_mode & S_IXOTH )
+#else
+      (len > 4 && !strcmp(path + len - 4, ".exe"))
+#endif
+     ) {
     is_exec = true;
   }
   gt_xfclose(file);
@@ -89,9 +108,9 @@ bool gt_file_is_newer(const char *a, const char *b)
   return false;
 }
 
-unsigned long gt_file_number_of_lines(const char *path)
+GtUword gt_file_number_of_lines(const char *path)
 {
-  unsigned long number_of_lines = 0;
+  GtUword number_of_lines = 0;
   GtFile *fp;
   int cc;
   gt_assert(path);
@@ -108,7 +127,7 @@ const char* gt_file_suffix(const char *path)
   gt_assert(path);
   suffixptr = path + gt_file_basename_length(path) - 1;
   while (suffixptr > path) {
-    if (*suffixptr == '/')
+    if (*suffixptr == GT_PATH_SEPARATOR)
       return "";
     else if (*suffixptr == '.')
       break;
@@ -119,33 +138,51 @@ const char* gt_file_suffix(const char *path)
 
 void gt_file_dirname(GtStr *path, const char *file)
 {
-  long i;
+  GtWord i;
   gt_str_reset(path);
-  for (i = (long) (strlen(file) - 1); i >= 0; i--) {
-    if (file[i] == '/')
+  for (i = (GtWord) (strlen(file) - 1); i >= 0; i--) {
+    if (file[i] == GT_PATH_SEPARATOR)
       break;
   }
   if (i > 0)
-    gt_str_append_cstr_nt(path, file, (unsigned long) i);
+    gt_str_append_cstr_nt(path, file, (GtUword) i);
 }
 
-static int file_find_in_env_generic(GtStr *path, const char *file,
+#ifdef _WIN32
+static void append_dot_exe_if_necessary(GtStr *file)
+{
+  GtUword length;
+  gt_assert(file);
+  length = gt_str_length(file);
+  if (length < 4 || strcmp(gt_str_get(file) + length - 4, ".exe"))
+    gt_str_append_cstr(file, ".exe");
+}
+#endif
+
+static int file_find_in_env_generic(GtStr *path, const char *file_path,
                                     const char *env, FileExistsFunc file_exists,
                                     GtError *err)
 {
   char *pathvariable, *pathcomponent = NULL;
   GtSplitter *splitter = NULL;
-  unsigned long i;
+  bool found = false;
+  GtStr *file;
+  GtUword i;
   int had_err = 0;
 
   gt_error_check(err);
-  gt_assert(file);
+  gt_assert(file_path);
   gt_assert(file_exists);
 
+  /* make writeable copy of 'file_path' */
+  file = gt_str_new_cstr(file_path);
+
   /* check if 'file' has dirname */
-  gt_file_dirname(path, file);
-  if (gt_str_length(path))
+  gt_file_dirname(path, gt_str_get(file));
+  if (gt_str_length(path)) {
+    gt_str_delete(file);
     return had_err;
+  }
   /* 'file' has no dirname -> scan $env */
   pathvariable = getenv(env);
   if (pathvariable != NULL)
@@ -155,16 +192,33 @@ static int file_find_in_env_generic(GtStr *path, const char *file,
     had_err = -1;
   }
 
-  if (!had_err) {
+#ifdef _WIN32
+  if (!had_err && file_exists == file_exists_and_is_regular_executable) {
+    append_dot_exe_if_necessary(file);
+    /* in Windows '.' is implicitly included in $PATH, check first */
+    gt_str_reset(path);
+    gt_str_append_char(path, '.');
+    gt_str_append_char(path, GT_PATH_SEPARATOR);
+    gt_str_append_str(path, file);
+    if (file_exists(gt_str_get(path))) {
+      gt_str_reset(path);
+      gt_str_append_char(path, '.');
+      gt_str_append_char(path, GT_PATH_SEPARATOR);
+      found = true;
+    }
+  }
+#endif
+
+  if (!had_err && !found) {
     splitter = gt_splitter_new();
     gt_splitter_split(splitter, pathvariable,
-                      (unsigned long) strlen(pathvariable), ':');
+                      (GtUword) strlen(pathvariable), GT_PATH_VAR_SEPARATOR);
     for (i = 0; i < gt_splitter_size(splitter); i++) {
       pathcomponent = gt_splitter_get_token(splitter, i);
       gt_str_reset(path);
       gt_str_append_cstr(path, pathcomponent);
-      gt_str_append_char(path, '/');
-      gt_str_append_cstr(path, file);
+      gt_str_append_char(path, GT_PATH_SEPARATOR);
+      gt_str_append_str(path, file);
       if (file_exists(gt_str_get(path)))
         break;
     }
@@ -182,6 +236,7 @@ static int file_find_in_env_generic(GtStr *path, const char *file,
   /* free */
   gt_free(pathvariable);
   gt_splitter_delete(splitter);
+  gt_str_delete(file);
 
   return had_err;
 }
@@ -249,8 +304,8 @@ void gt_xfile_cmp(const char *file1,const char *file2)
     cc2 = fgetc(fp2);
     if (cc1 != cc2)
     {
-      fprintf(stderr,"files %s and %s differ in byte %lu: %d != %d\n",
-                      file1,file2,(unsigned long) offset,cc1,cc2);
+      fprintf(stderr,"files %s and %s differ in byte "GT_WU": %d != %d\n",
+                      file1,file2,(GtUword) offset,cc1,cc2);
       exit(EXIT_FAILURE);
     }
     if (cc1 == EOF)
@@ -278,7 +333,7 @@ off_t gt_file_size_with_suffix(const char *path, const char *suffix)
 
 off_t gt_files_estimate_total_size(const GtStrArray *filenames)
 {
-  unsigned long filenum;
+  GtUword filenum;
   off_t totalsize = 0;
 
   for (filenum = 0; filenum < gt_str_array_size(filenames); filenum++)
