@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2008 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2006-2008 Gordon Gremme <gordon@gremme.org>
   Copyright (c)      2012 Dirk Willrodt <willrodt@zbh.uni-hamburg.de>
   Copyright (c) 2006-2012 Center for Bioinformatics, University of Hamburg
 
@@ -16,11 +16,14 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#include <math.h>
-#include <stdio.h>
 #include <inttypes.h>
 #include <limits.h>
+#include <math.h>
+#include <stdio.h>
+
+#include "core/byte_select_api.h"
 #include "core/ensure.h"
+#include "core/intbits.h"
 #include "core/mathsupport.h"
 #include "core/yarandom.h" /* necessary to define random() correctly */
 
@@ -78,9 +81,9 @@ bool gt_double_larger_double(double d1, double d2)
   return gt_double_compare(d1, d2) > 0;
 }
 
-unsigned long gt_rand_max(unsigned long maximal_value)
+GtUword gt_rand_max(GtUword maximal_value)
 {
-  unsigned long r;
+  GtUword r;
   gt_assert(maximal_value);
   r = ((double) random() / ((double) RAND_MAX + 1) * (maximal_value + 1));
   gt_assert(r <= maximal_value);
@@ -114,38 +117,34 @@ char gt_rand_char(void)
   return c;
 }
 
-/*
-  Find the log base 2 of an integer in O(wordsize) operations.
-  where N is the number of bits. There are faster methods, see
-  \url{http://graphics.stanford.edu/~seander/bithacks.html#IntegerLogObvious}
-*/
-unsigned int gt_determinebitspervalue(unsigned long maxvalue)
+#define GT_MAXLOG2VALUE (GT_INTWORDSIZE - 1)
+/* Find the log base 2 of an integer in O(wordsize/CHAR_BIT) operations. where N
+   is the number of bits. There are faster methods, see
+   \url{http://graphics.stanford.edu/~seander/bithacks.html#IntegerLogObvious}
+   */
+unsigned int gt_determinebitspervalue(GtUword maxvalue)
 {
   unsigned int bits = 0;
-  unsigned long value;
+#ifndef USEbuiltin_clzl
+  GtUword value, mask = (~0) << CHAR_BIT;
 
-  for (value = maxvalue; value > 0; value >>= 1)
-  {
-    bits++;
+  for (value = maxvalue; (value & mask) != 0; value >>= CHAR_BIT) {
+    bits += CHAR_BIT;
   }
-#define GT_MAXLOG2VALUE 63
-  gt_assert(bits <= GT_MAXLOG2VALUE);
-#ifdef USEbuiltin_clzl
+  bits += CHAR_BIT - gt_byte_select[value];
+#else
   {
-    unsigned int fastbits = (unsigned int) (sizeof(unsigned long) * CHAR_BIT) -
-                            __builtin_clzl(maxvalue);
-    if (bits != fastbits)
-    {
-      fprintf(stderr,"maxvalue=%lu: bits = %u != %d = clzl\n",
-                        maxvalue,bits,fastbits);
-      exit(EXIT_FAILURE);
+    if (maxvalue != 0) { /*__builtin_clz only defined != 0 */
+      bits = (unsigned int) (sizeof(GtUword) * CHAR_BIT) -
+             __builtin_clzl(maxvalue);
     }
   }
 #endif
+  gt_assert(bits <= GT_MAXLOG2VALUE);
   return bits;
 }
 
-unsigned long gt_power_for_small_exponents(unsigned int base,
+GtUword gt_power_for_small_exponents(unsigned int base,
                                            unsigned int exponent)
 {
   unsigned int logvalue = 0;
@@ -183,8 +182,9 @@ unsigned long gt_power_for_small_exponents(unsigned int base,
   if (logvalue > 0) {
     gt_assert(logvalue * exponent < sizeof (void *) * 8);
     return 1UL << (logvalue * exponent);
-  } else {
-    unsigned long powervalue = (unsigned long) base;
+  }
+  else {
+    GtUword powervalue = (GtUword) base;
 
     while (exponent > 1U) {
       powervalue *= base;
@@ -202,7 +202,7 @@ static inline double gt_round(double x)
   return integer - x >= 0.5 ? integer - 1.0 : integer;
 }
 
-long int gt_round_to_long(double x)
+GtWord gt_round_to_long(double x)
 {
   int64_t intgr;
   double rounded = gt_round(x);
@@ -214,7 +214,30 @@ long int gt_round_to_long(double x)
     /* 1 with the sign of result, i.e. -1 or 1. */
     intgr -= ((intgr >> 62) | ((int64_t) 1));
   }
-  return (long int) intgr;
+  return (GtWord) intgr;
+}
+
+unsigned int gt_gcd_uint(unsigned int m, unsigned int n)
+{
+  unsigned int r;
+
+  if (m < n) {
+    r = m;
+    m = n;
+    n = r;
+  }
+  do {
+    gt_assert(m >= n);
+    r = m % n;
+    m = n;
+    n = r;
+  } while (r != 0);
+  return m;
+}
+
+unsigned int gt_lcm_uint(unsigned int m, unsigned int n)
+{
+  return (m * n)/gt_gcd_uint(m,n);
 }
 
 /* Make some unit tests for this? */
@@ -223,19 +246,19 @@ void gt_out_power_for_small_exponents(void)
   unsigned int exponent;
 
   for (exponent=1U; exponent<64U; exponent++) {
-    printf("pow(2UL,%u)=%lu\n",exponent,
+    printf("pow(2UL,%u)="GT_WU"\n",exponent,
             gt_power_for_small_exponents(2U,exponent));
   }
   for (exponent=1U; exponent<32U; exponent++) {
-    printf("pow(4UL,%u)=%lu\n",exponent,
+    printf("pow(4UL,%u)="GT_WU"\n",exponent,
             gt_power_for_small_exponents(4U,exponent));
   }
   for (exponent=1U; exponent<16U; exponent++) {
-    printf("pow(8UL,%u)=%lu\n",exponent,
+    printf("pow(8UL,%u)="GT_WU"\n",exponent,
             gt_power_for_small_exponents(8U,exponent));
   }
   for (exponent=1U; exponent<32U; exponent++) {
-    printf("pow(3UL,%u)=%lu\n",exponent,
+    printf("pow(3UL,%u)="GT_WU"\n",exponent,
             gt_power_for_small_exponents(3U,exponent));
   }
 }
@@ -243,52 +266,56 @@ void gt_out_power_for_small_exponents(void)
 int gt_mathsupport_unit_test(GtError *err)
 {
   int had_err = 0;
+  GtUword i;
   double less_than_epsilon = 0.0000000000000001;
   gt_error_check(err);
 
-  gt_ensure(had_err, !gt_double_equals_one(1.1));
-  gt_ensure(had_err, gt_double_equals_one(1));
-  gt_ensure(had_err, gt_double_equals_one(1+less_than_epsilon));
-  gt_ensure(had_err, !gt_double_equals_one(-1-less_than_epsilon));
+  gt_ensure(!gt_double_equals_one(1.1));
+  gt_ensure(gt_double_equals_one(1));
+  gt_ensure(gt_double_equals_one(1+less_than_epsilon));
+  gt_ensure(!gt_double_equals_one(-1-less_than_epsilon));
 
-  gt_ensure(had_err, !gt_double_equals_double(1.0, 2.0));
-  gt_ensure(had_err, !gt_double_equals_double(-1.0, 1.0));
-  gt_ensure(had_err, !gt_double_equals_double(1.0, -1.0));
-  gt_ensure(had_err, !gt_double_equals_double(-1.0, 1+less_than_epsilon));
-  gt_ensure(had_err, !gt_double_equals_double(1.0, 1.1));
-  gt_ensure(had_err, gt_double_equals_double(1.0, 1+less_than_epsilon));
-  gt_ensure(had_err, gt_double_equals_double(1.0, 1.0));
-  gt_ensure(had_err, gt_double_equals_double(0.0, 0.0));
-  gt_ensure(had_err, gt_double_equals_double(-1.0, -1.0));
-  gt_ensure(had_err, gt_double_equals_double(-1.0+less_than_epsilon, -1.0));
-  gt_ensure(had_err, gt_double_equals_double(-1.0, -1.0+less_than_epsilon));
-  gt_ensure(had_err, gt_double_equals_double(1.0+less_than_epsilon, 1.0));
-  gt_ensure(had_err, gt_double_equals_double(1.0, 1.0+less_than_epsilon));
+  gt_ensure(!gt_double_equals_double(1.0, 2.0));
+  gt_ensure(!gt_double_equals_double(-1.0, 1.0));
+  gt_ensure(!gt_double_equals_double(1.0, -1.0));
+  gt_ensure(!gt_double_equals_double(-1.0, 1+less_than_epsilon));
+  gt_ensure(!gt_double_equals_double(1.0, 1.1));
+  gt_ensure(gt_double_equals_double(1.0, 1+less_than_epsilon));
+  gt_ensure(gt_double_equals_double(1.0, 1.0));
+  gt_ensure(gt_double_equals_double(0.0, 0.0));
+  gt_ensure(gt_double_equals_double(-1.0, -1.0));
+  gt_ensure(gt_double_equals_double(-1.0+less_than_epsilon, -1.0));
+  gt_ensure(gt_double_equals_double(-1.0, -1.0+less_than_epsilon));
+  gt_ensure(gt_double_equals_double(1.0+less_than_epsilon, 1.0));
+  gt_ensure(gt_double_equals_double(1.0, 1.0+less_than_epsilon));
 
-  gt_ensure(had_err, gt_double_compare(1.0, 1.0) == 0);
-  gt_ensure(had_err, gt_double_compare(1.0, 1.1) < 0);
-  gt_ensure(had_err, gt_double_compare(1.1, 1.0) > 0);
-  gt_ensure(had_err, gt_double_compare(1.1, -1.0) > 0);
-  gt_ensure(had_err, gt_double_compare(-1.1, -1.0) < 0);
-  gt_ensure(had_err, gt_double_compare(1+less_than_epsilon, 1.0) == 0);
-  gt_ensure(had_err, gt_double_compare(1+less_than_epsilon, -1.0) > 0);
-  gt_ensure(had_err, gt_double_compare(-1+less_than_epsilon, -1.0) == 0);
-  gt_ensure(had_err, gt_double_compare(-1+less_than_epsilon, 1.0) < 0);
+  gt_ensure(gt_double_compare(1.0, 1.0) == 0);
+  gt_ensure(gt_double_compare(1.0, 1.1) < 0);
+  gt_ensure(gt_double_compare(1.1, 1.0) > 0);
+  gt_ensure(gt_double_compare(1.1, -1.0) > 0);
+  gt_ensure(gt_double_compare(-1.1, -1.0) < 0);
+  gt_ensure(gt_double_compare(1+less_than_epsilon, 1.0) == 0);
+  gt_ensure(gt_double_compare(1+less_than_epsilon, -1.0) > 0);
+  gt_ensure(gt_double_compare(-1+less_than_epsilon, -1.0) == 0);
+  gt_ensure(gt_double_compare(-1+less_than_epsilon, 1.0) < 0);
 
-  gt_ensure(had_err, gt_double_smaller_double(1.0, 1.1));
-  gt_ensure(had_err, gt_double_smaller_double(-1.0, 1.1));
-  gt_ensure(had_err, gt_double_smaller_double(-1.1, -1.0));
-  gt_ensure(had_err, !gt_double_smaller_double(-1.0, -1.1));
-  gt_ensure(had_err, !gt_double_smaller_double(1.0-less_than_epsilon, 1.0));
+  gt_ensure(gt_double_smaller_double(1.0, 1.1));
+  gt_ensure(gt_double_smaller_double(-1.0, 1.1));
+  gt_ensure(gt_double_smaller_double(-1.1, -1.0));
+  gt_ensure(!gt_double_smaller_double(-1.0, -1.1));
+  gt_ensure(!gt_double_smaller_double(1.0-less_than_epsilon, 1.0));
 
-  gt_ensure(had_err,  0L == gt_round_to_long(0.5));
-  gt_ensure(had_err,  1L == gt_round_to_long(0.51));
-  gt_ensure(had_err, -1L == gt_round_to_long(-0.51));
-  gt_ensure(had_err,  0L == gt_round_to_long(-0.5));
-  gt_ensure(had_err, -2L == gt_round_to_long(-1.5));
-  gt_ensure(had_err, -2L == gt_round_to_long(-2.5));
-  gt_ensure(had_err, -3L == gt_round_to_long(-2.51));
+  gt_ensure(0L == gt_round_to_long(0.5));
+  gt_ensure(1L == gt_round_to_long(0.51));
+  gt_ensure(-1L == gt_round_to_long(-0.51));
+  gt_ensure(0L == gt_round_to_long(-0.5));
+  gt_ensure(-2L == gt_round_to_long(-1.5));
+  gt_ensure(-2L == gt_round_to_long(-2.5));
+  gt_ensure(-3L == gt_round_to_long(-2.51));
 
+  for (i = 0; !had_err && i < GT_MAXLOG2VALUE; ++i) {
+    gt_ensure(i+1 == gt_determinebitspervalue(1UL << i));
+  }
   return had_err;
 }
 #endif /* S_SPLINT_S */
