@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2011 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2006-2011 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2006-2008 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -16,23 +16,31 @@
 */
 
 #include <ctype.h>
+#include <fcntl.h>
 #include <stdio.h>
 #include <string.h>
+#include "gt_config.h"
 #include "core/cstr_api.h"
+#include "core/error.h"
 #include "core/fa.h"
+#include "core/fileutils_api.h"
 #include "core/hashmap_api.h"
 #include "core/grep_api.h"
 #include "core/ma.h"
 #include "core/mail_address.h"
-#include "core/option_api.h"
+#include "core/option.h"
 #include "core/parseutils.h"
 #include "core/undef_api.h"
+#include "core/unused_api.h"
+#include "core/warning_api.h"
 #include "core/xansi_api.h"
+#include "core/xposix.h"
 
 typedef enum {
   OPTION_BOOL,
   OPTION_CHOICE,
   OPTION_DOUBLE,
+  OPTION_FILENAME,
   OPTION_HELP,
   OPTION_HELPPLUS,
   OPTION_HELPDEV,
@@ -56,8 +64,8 @@ struct GtOptionParser {
        *synopsis,
        *one_liner;
   GtArray *options,
-        *hooks;
-  bool parser_called,
+          *hooks;
+  bool common_options_added,
        refer_to_manual;
   GtShowCommentFunc comment_func;
   void *comment_func_data;
@@ -78,8 +86,8 @@ struct GtOption {
     double d;
     int i;
     unsigned int ui;
-    long l;
-    unsigned long ul;
+    GtWord l;
+    GtUword ul;
     GtRange r;
     const char *s;
   } default_value;
@@ -88,13 +96,13 @@ struct GtOption {
     double d;
     int i;
     unsigned int ui;
-    unsigned long ul;
+    GtUword ul;
   } min_value;
   union {
     double d;
     int i;
     unsigned int ui;
-    unsigned long ul;
+    GtUword ul;
   } max_value;
   bool is_set,
        is_mandatory,
@@ -112,7 +120,7 @@ struct GtOption {
 };
 
 static GtOption *gt_option_new(const char *option_str, const char *description,
-                          void *value)
+                               void *value)
 {
   GtOption *o = gt_calloc(1, sizeof (GtOption));
   gt_assert(option_str && strlen(option_str));
@@ -139,7 +147,7 @@ static GtOption* gt_option_new_help(bool has_extended_options)
 static GtOption* gt_option_new_helpplus(void)
 {
   GtOption *o = gt_option_new("help+", "display help for all options and exit",
-                         NULL);
+                              NULL);
   o->option_type = OPTION_HELPPLUS;
   o->default_value.b = false;
   return o;
@@ -155,10 +163,10 @@ static GtOption* gt_option_new_helpdev(void)
   return o;
 }
 
-static GtOption* gt_option_new_version(GtShowVersionFunc versionfunc)
+static GtOption* gt_option_new_version(void )
 {
   GtOption *o = gt_option_new("version", "display version information and exit",
-                         versionfunc);
+                              NULL);
   o->option_type = OPTION_VERSION;
   return o;
 }
@@ -170,6 +178,36 @@ GtOption* gt_option_ref(GtOption *o)
   return o;
 }
 
+static void gt_option_reset(GtOption *option)
+{
+  gt_assert(option);
+  if (option->option_type == OPTION_BOOL) {
+    *(bool*) option->value = option->default_value.b;
+  }
+  else if (option->option_type == OPTION_CHOICE
+             || option->option_type == OPTION_STRING) {
+    gt_str_set((GtStr*) option->value, option->default_value.s);
+  }
+  else if (option->option_type == OPTION_DOUBLE) {
+    *(double*) option->value = option->default_value.d;
+  }
+  else if (option->option_type == OPTION_INT) {
+    *(int*) option->value = option->default_value.i;
+  }
+  else if (option->option_type == OPTION_UINT) {
+    *(unsigned int*) option->value = option->default_value.ui;
+  }
+  else if (option->option_type == OPTION_LONG) {
+    *(GtWord*) option->value = option->default_value.l;
+  }
+  else if (option->option_type == OPTION_ULONG) {
+    *(GtUword*) option->value = option->default_value.ul;
+  }
+  else if (option->option_type == OPTION_RANGE) {
+   *(GtRange*) option->value = option->default_value.r;
+  }
+}
+
 GtOptionParser* gt_option_parser_new(const char *synopsis,
                                      const char *one_liner)
 {
@@ -237,18 +275,34 @@ void gt_option_parser_register_hook(GtOptionParser *op,
   gt_array_add(op->hooks, hookinfo);
 }
 
+static int reset_option(GT_UNUSED void *key, void *value, GT_UNUSED void *data,
+                        GT_UNUSED GtError *err)
+{
+  GtOption *o = (GtOption*) value;
+  gt_option_reset(o);
+  return 0;
+}
+
+void gt_option_parser_reset(GtOptionParser *op)
+{
+  GT_UNUSED int rval;
+  gt_assert(op);
+  rval = gt_hashmap_foreach(op->optionindex, reset_option, NULL, NULL);
+  gt_assert(!rval); /* reset_option() is sane */
+}
+
 void gt_option_parser_set_mail_address(GtOptionParser *op, const char *address)
 {
   gt_assert(op && address);
   op->mail_address = address;
 }
 
-static void show_description(unsigned long initial_space, const char *desc,
-                             unsigned long len)
+static void show_description(GtUword initial_space, const char *desc,
+                             GtUword len)
 {
-  const unsigned long width = GT_OPTION_PARSER_TERMINAL_WIDTH - initial_space;
+  const GtUword width = GT_OPTION_PARSER_TERMINAL_WIDTH - initial_space;
   const char *tmp_ptr, *desc_ptr = desc;
-  unsigned long i;
+  GtUword i;
   bool continue_while = false;
 
   /* got space to show option */
@@ -305,12 +359,12 @@ static void show_description(unsigned long initial_space, const char *desc,
 
 static int show_help(GtOptionParser *op, GtOptionType optiontype, GtError *err)
 {
-  unsigned long i, max_option_length = 0;
+  GtUword i, max_option_length = 0;
   GtOption *option;
   int had_err = 0;
   gt_error_check(err);
   gt_assert(optiontype == OPTION_HELP || optiontype == OPTION_HELPPLUS ||
-         optiontype == OPTION_HELPDEV);
+            optiontype == OPTION_HELPDEV);
 
   /* determine maximum option length */
   for (i = 0; i < gt_array_size(op->options); i++) {
@@ -378,28 +432,29 @@ static int show_help(GtOptionParser *op, GtOptionType optiontype, GtError *err)
       }
       else if (option->option_type == OPTION_LONG) {
         printf("%*s  default: ", (int) max_option_length, "");
-        if (option->default_value.ul == GT_UNDEF_LONG)
+        if (option->default_value.ul == GT_UNDEF_WORD)
           gt_xputs("undefined");
         else
-          printf("%ld\n", option->default_value.l);
+          printf(""GT_WD"\n", option->default_value.l);
       }
       else if (option->option_type == OPTION_ULONG) {
         printf("%*s  default: ", (int) max_option_length, "");
-        if (option->default_value.ul == GT_UNDEF_ULONG)
+        if (option->default_value.ul == GT_UNDEF_UWORD)
           gt_xputs("undefined");
         else
-          printf("%lu\n", option->default_value.ul);
+          printf(""GT_WU"\n", option->default_value.ul);
       }
       else if (option->option_type == OPTION_RANGE) {
         printf("%*s  default: ", (int) max_option_length, "");
-        if (option->default_value.r.start == GT_UNDEF_ULONG)
+        if (option->default_value.r.start == GT_UNDEF_UWORD)
           gt_xputs("undefined");
         else {
-          printf("%lu %lu\n", option->default_value.r.start,
+          printf(""GT_WU" "GT_WU"\n", option->default_value.r.start,
                  option->default_value.r.end);
         }
       }
-      else if (option->option_type == OPTION_STRING) {
+      else if (option->option_type == OPTION_FILENAME ||
+               option->option_type == OPTION_STRING) {
         printf("%*s  default: ", (int) max_option_length, "");
         if (!option->default_value.s || !strlen(option->default_value.s))
           gt_xputs("undefined");
@@ -421,6 +476,266 @@ static int show_help(GtOptionParser *op, GtOptionType optiontype, GtError *err)
   return had_err;
 }
 
+static void print_asciidoc_header(const char *hdr, GtStr *outstr) {
+  GtUword i;
+  gt_str_append_cstr(outstr, hdr);
+  gt_str_append_char(outstr, '\n');
+  for (i = 0; i < strlen(hdr); i++)
+    gt_str_append_char(outstr, '-');
+  gt_str_append_cstr(outstr, "\n\n");
+}
+
+static void print_toolname(const char *toolname, GtStr *outstr, bool upper) {
+  GtUword i;
+  for (i = 0; i < strlen(toolname); i++) {
+    char c = toolname[i];
+    if (c == ' ')
+      gt_str_append_char(outstr, '-');
+    else {
+      if (upper)
+        gt_str_append_char(outstr, toupper(c));
+      else
+        gt_str_append_char(outstr, c);
+    }
+  }
+}
+
+static bool has_extended_option(GtArray *options)
+{
+  GtUword i;
+  GtOption *option;
+  gt_assert(options);
+  for (i = 0; i < gt_array_size(options); i++) {
+    option = *(GtOption**) gt_array_get(options, i);
+    if (option->is_extended_option)
+      return true;
+  }
+  return false;
+}
+
+static void add_common_options(GtOptionParser *op)
+{
+  bool has_extended_options;
+  GtOption *option;
+  gt_assert(op);
+  has_extended_options = has_extended_option(op->options);
+  option = gt_option_new_help(has_extended_options);
+  gt_option_parser_add_option(op, option);
+  if (has_extended_options) {
+    option = gt_option_new_helpplus();
+    gt_option_parser_add_option(op, option);
+  }
+  option = gt_option_new_helpdev();
+  gt_option_parser_add_option(op, option);
+  option = gt_option_new_version();
+  gt_option_parser_add_option(op, option);
+}
+
+int gt_option_parser_manpage(GtOptionParser *op, const char *toolname,
+                             GtStr *outstr, GtError *err)
+{
+  GtUword i;
+  GtOption *option;
+  GtStr *default_string;
+  int had_err = 0;
+  gt_assert(op);
+  gt_error_check(err);
+  gt_assert(strlen(toolname) > 0);
+
+  /* add common options, if necessary */
+  if (!op->common_options_added) {
+    op->common_options_added = true;
+    add_common_options(op);
+  }
+
+  /* title and section */
+  print_toolname(toolname, outstr, true);
+  gt_str_append_cstr(outstr, "(1)\n");
+  for (i = 0; i < strlen(toolname) + 3; i++)
+    gt_str_append_char(outstr, '=');
+  gt_str_append_char(outstr, '\n');
+  gt_str_append_cstr(outstr, ":man source:   GenomeTools\n");
+  gt_str_append_cstr(outstr, ":man version:  ");
+  gt_str_append_cstr(outstr, GT_VERSION);
+  gt_str_append_char(outstr, '\n');
+  gt_str_append_cstr(outstr, ":man manual:   GenomeTools Manual\n");
+  gt_str_append_char(outstr, '\n');
+
+  /* name */
+  print_asciidoc_header("NAME", outstr);
+  print_toolname(toolname, outstr, false);
+  gt_str_append_cstr(outstr, " - ");
+  gt_str_append_cstr(outstr, op->one_liner);
+  gt_str_append_cstr(outstr, "\n\n");
+
+  /* synopsis */
+  print_asciidoc_header("SYNOPSIS", outstr);
+  gt_str_append_cstr(outstr, "*");
+  gt_str_append_cstr(outstr, toolname);
+  gt_str_append_cstr(outstr, "* ");
+  gt_str_append_cstr(outstr, op->synopsis);
+  gt_str_append_cstr(outstr, "\n\n");
+
+  /* description */
+  if (gt_array_size(op->options)) {
+    print_asciidoc_header("DESCRIPTION", outstr);
+    default_string = gt_str_new();
+    for (i = 0; i < gt_array_size(op->options); i++) {
+      option = *(GtOption**) gt_array_get(op->options, i);
+      /* skip dev options */
+      if (option->is_development_option) continue;
+      gt_str_append_cstr(outstr, "*-");
+      gt_str_append_cstr(outstr, gt_str_get(option->option_str));
+      gt_str_append_cstr(outstr, "* ");
+      if (option->option_type == OPTION_BOOL) {
+        gt_str_append_cstr(outstr, "['yes|no']");
+        gt_str_append_cstr(default_string,
+                              option->default_value.b ? "yes" : "no");
+      }
+      else if (option->option_type == OPTION_CHOICE) {
+        gt_str_append_cstr(outstr, "['...']");
+        if (!option->default_value.s || !strlen(option->default_value.s))
+          gt_str_append_cstr(default_string, "undefined");
+        else
+          gt_str_append_cstr(default_string, option->default_value.s);
+      }
+      else if (option->option_type == OPTION_DOUBLE) {
+        gt_str_append_cstr(outstr, "['value']");
+        if (option->default_value.d == GT_UNDEF_DOUBLE)
+          gt_str_append_cstr(default_string, "undefined");
+        else
+          gt_str_append_double(default_string, option->default_value.d, 6);
+      }
+      else if (option->option_type == OPTION_FILENAME) {
+        gt_str_append_cstr(outstr, "['filename']");
+        if (!option->default_value.s || !strlen(option->default_value.s))
+          gt_str_append_cstr(default_string, "undefined");
+        else
+          gt_str_append_cstr(default_string, option->default_value.s);
+      }
+      else if (option->option_type == OPTION_INT) {
+        gt_str_append_cstr(outstr, "['value']");
+        if (option->default_value.i == GT_UNDEF_INT)
+          gt_str_append_cstr(default_string, "undefined");
+        else
+          gt_str_append_int(default_string, option->default_value.i);
+      }
+      else if (option->option_type == OPTION_UINT) {
+        gt_str_append_cstr(outstr, "['value']");
+        if (option->default_value.ui == GT_UNDEF_UINT)
+          gt_str_append_cstr(default_string, "undefined");
+        else
+          gt_str_append_uint(default_string, option->default_value.ui);
+      }
+      else if (option->option_type == OPTION_LONG) {
+        gt_str_append_cstr(outstr, "['value']");
+      }
+      else if (option->option_type == OPTION_ULONG) {
+        gt_str_append_cstr(outstr, "['value']");
+        if (option->default_value.ul == GT_UNDEF_UWORD)
+          gt_str_append_cstr(default_string, "undefined");
+        else
+          gt_str_append_ulong(default_string, option->default_value.ul);
+      }
+      else if (option->option_type == OPTION_RANGE) {
+        gt_str_append_cstr(outstr, "['start' 'end']");
+        if (option->default_value.r.start == GT_UNDEF_UWORD)
+          gt_str_append_cstr(default_string, "undefined");
+        else {
+          gt_str_append_char(default_string, '[');
+          gt_str_append_ulong(default_string, option->default_value.r.start);
+          gt_str_append_cstr(default_string, "..");
+          gt_str_append_ulong(default_string, option->default_value.r.end);
+          gt_str_append_char(default_string, ']');
+        }
+      }
+      else if (option->option_type == OPTION_STRING) {
+        gt_str_append_cstr(outstr, "['string']");
+        if (!option->default_value.s || !strlen(option->default_value.s))
+          gt_str_append_cstr(default_string, "undefined");
+        else
+          gt_str_append_cstr(default_string, option->default_value.s);
+      }
+      gt_str_append_cstr(outstr, "::\n");
+      gt_str_append_cstr(outstr, gt_str_get(option->description));
+      if (gt_str_length(default_string) > 0) {
+        gt_str_append_cstr(outstr, " (default: ");
+        gt_str_append_cstr(outstr, gt_str_get(default_string));
+        gt_str_append_cstr(outstr, ")");
+        }
+      gt_str_append_cstr(outstr, "\n\n");
+      gt_str_reset(default_string);
+    }
+    gt_str_delete(default_string);
+  }
+
+  if (op->comment_func) {
+    int old_stdout, out_pipe[2];
+#ifndef _WIN32
+    int rval;
+    GtWord flags;
+#endif
+    char c,
+         prognamebuf[BUFSIZ];
+
+    /* Lua docu scripts print to stdout by themselves, so temporarily
+       redirect stdout to a pipe. */
+#ifndef _WIN32
+    fflush(stdout);
+    old_stdout = dup(STDOUT_FILENO);
+    if ((rval = pipe(out_pipe)) == -1) {
+      perror("pipe");
+      exit(EXIT_FAILURE);  /* XXX */
+    }
+
+    flags = fcntl(out_pipe[0], F_GETFL);
+    flags |= O_NONBLOCK;
+    (void) fcntl(out_pipe[0], F_SETFL, flags);
+
+    dup2(out_pipe[1], STDOUT_FILENO);
+    close(out_pipe[1]);
+#else
+    /* XXX */
+    fprintf(stderr, "pipe() stuff not implemented\n");
+    exit(EXIT_FAILURE);
+#endif
+
+    if (!strcmp(toolname, "gt"))
+      (void) snprintf(prognamebuf, BUFSIZ, "%s", gt_error_get_progname(err));
+    else {
+      (void) snprintf(prognamebuf, BUFSIZ, "%s %s",
+                      gt_error_get_progname(err),
+                      toolname + gt_cstr_length_up_to_char(toolname, ' '));
+    }
+    had_err = op->comment_func(prognamebuf, op->comment_func_data, err);
+    fflush(stdout);
+
+    while (read(out_pipe[0], &c, sizeof (char)) > 0)
+      gt_str_append_char(outstr, c);
+
+    dup2(old_stdout, STDOUT_FILENO);
+    close(old_stdout);
+  }
+
+  gt_str_append_cstr(outstr, "\n");
+  if (!had_err) {
+    if (op->refer_to_manual) {
+      print_asciidoc_header("ADDITIONAL INFORMATION", outstr);
+      gt_str_append_cstr(outstr, "For detailed information, please refer to "
+                                 "the manual of");
+      gt_str_append_cstr(outstr, toolname +
+                                 gt_cstr_length_up_to_char(toolname, ' '));
+      gt_str_append_cstr(outstr, ".\n\n");
+    }
+    print_asciidoc_header("REPORTING BUGS", outstr);
+    gt_str_append_cstr(outstr, "Report bugs to ");
+    gt_str_append_cstr(outstr,
+                       op->mail_address ? op->mail_address : GT_MAIL_ADDRESS);
+    gt_str_append_cstr(outstr, ".\n");
+  }
+  return had_err;
+}
+
 static bool optional_arg(GtOption *o, int argnum, int argc, const char **argv)
 {
   gt_assert(o);
@@ -459,7 +774,7 @@ static int check_missing_argument_and_minus_sign(int argnum, int argc,
 
 static int check_mandatory_options(GtOptionParser *op, GtError *err)
 {
-  unsigned long i;
+  GtUword i;
   GtOption *o;
   gt_error_check(err);
   gt_assert(op);
@@ -476,7 +791,7 @@ static int check_mandatory_options(GtOptionParser *op, GtError *err)
 
 static int check_option_implications(GtOptionParser *op, GtError *err)
 {
-  unsigned long i, j, k, l;
+  GtUword i, j, k, l;
   GtArray *implied_option_array;
   GtOption *o, *implied_option;
   unsigned int option_set;
@@ -546,7 +861,7 @@ static int check_option_implications(GtOptionParser *op, GtError *err)
 
 static int check_option_exclusions(GtOptionParser *op, GtError *err)
 {
-  unsigned long i, j;
+  GtUword i, j;
   GtOption *o, *excluded_option;
   gt_error_check(err);
 
@@ -569,7 +884,7 @@ static int check_option_exclusions(GtOptionParser *op, GtError *err)
 
 static int check_mandatory_either_options(GtOptionParser *op, GtError *err)
 {
-  unsigned long i;
+  GtUword i;
   GtOption *o, *meo_a, *meo_b, *meo_c;
   gt_error_check(err);
 
@@ -620,19 +935,6 @@ static int check_mandatory_either_options(GtOptionParser *op, GtError *err)
   return 0;
 }
 
-static bool has_extended_option(GtArray *options)
-{
-  unsigned long i;
-  GtOption *option;
-  gt_assert(options);
-  for (i = 0; i < gt_array_size(options); i++) {
-    option = *(GtOption**) gt_array_get(options, i);
-    if (option->is_extended_option)
-      return true;
-  }
-  return false;
-}
-
 void gt_option_parser_set_min_args(GtOptionParser *op,
                                    unsigned int min_additional_arguments)
 {
@@ -656,42 +958,55 @@ void gt_option_parser_set_min_max_args(GtOptionParser *op,
   op->max_additional_arguments = max_additional_arguments;
 }
 
+static void gt_option_parser_warn_on_nonascii(const char *str)
+{
+  GtUword j = 1;
+  while (*str != '\0') {
+    if (!isprint(*str)) {
+      gt_warning("option '%s' contains non-ASCII character at "
+                 "offset "GT_WU" -- possible copy&paste from "
+                 "non-ASCII context?",
+                 str, j);
+      break;
+    }
+    str++;
+    j++;
+  }
+}
+
 GtOPrval gt_option_parser_parse(GtOptionParser *op, int *parsed_args, int argc,
                                 const char **argv,
                                 GtShowVersionFunc version_func, GtError *err)
 {
   int argnum, int_value;
   unsigned int uint_value;
-  unsigned long i;
+  GtUword i;
   double double_value;
   HookInfo *hookinfo;
   GtOption *option;
-  bool has_extended_options, option_parsed;
-  long long_value;
-  unsigned long ulong_value;
+  bool option_parsed;
+  GtWord long_value;
+  GtUword ulong_value;
   int minus_offset, had_err = 0;
   GtStr *gt_error_str;
 
   gt_error_check(err);
   gt_assert(op);
-  /* to avoid multiple adding of common options */
-  gt_assert(!op->parser_called);
 
+  /* add common options, if necessary */
+  if (!op->common_options_added) {
+    op->common_options_added = true;
+    add_common_options(op);
+  }
+
+  /* set progname */
+  if (op->progname)
+    gt_free(op->progname);
   op->progname = gt_cstr_dup(argv[0]);
 
-  /* add common options */
-  has_extended_options = has_extended_option(op->options);
-  option = gt_option_new_help(has_extended_options);
-  gt_option_parser_add_option(op, option);
-  if (has_extended_options) {
-    option = gt_option_new_helpplus();
-    gt_option_parser_add_option(op, option);
+  for (argnum = 1; argnum < argc; argnum++) {
+    gt_option_parser_warn_on_nonascii(argv[argnum]);
   }
-  option = gt_option_new_helpdev();
-  gt_option_parser_add_option(op, option);
-  option = gt_option_new_version(op->version_func ? op->version_func
-                                                  : version_func);
-  gt_option_parser_add_option(op, option);
 
   for (argnum = 1; argnum < argc; argnum++) {
     if (!(argv[argnum] && argv[argnum][0] == '-' && strlen(argv[argnum]) > 1) ||
@@ -923,7 +1238,7 @@ GtOPrval gt_option_parser_parse(GtOptionParser *op, int *parsed_args, int argc,
                 }
               }
               if (!had_err) {
-                *(long*) option->value = long_value;
+                *(GtWord*) option->value = long_value;
                 option_parsed = true;
               }
               break;
@@ -949,7 +1264,8 @@ GtOPrval gt_option_parser_parse(GtOptionParser *op, int *parsed_args, int argc,
                 if (option->min_value_set &&
                     ulong_value < option->min_value.ul) {
                   gt_error_set(err, "argument to option \"-%s\" must be an "
-                               "integer >= %lu", gt_str_get(option->option_str),
+                               "integer >= "GT_WU"",
+                               gt_str_get(option->option_str),
                                option->min_value.ul);
                   had_err = -1;
                 }
@@ -959,13 +1275,14 @@ GtOPrval gt_option_parser_parse(GtOptionParser *op, int *parsed_args, int argc,
                 if (option->max_value_set &&
                     ulong_value > option->max_value.ul) {
                   gt_error_set(err, "argument to option \"-%s\" must be an "
-                               "integer <= %lu", gt_str_get(option->option_str),
+                               "integer <= "GT_WU"",
+                               gt_str_get(option->option_str),
                                option->max_value.ul);
                   had_err = -1;
                 }
               }
               if (!had_err) {
-                *(unsigned long*) option->value = ulong_value;
+                *(GtUword*) option->value = ulong_value;
                 option_parsed = true;
               }
               break;
@@ -994,7 +1311,7 @@ GtOPrval gt_option_parser_parse(GtOptionParser *op, int *parsed_args, int argc,
                 if (option->min_value_set &&
                     long_value < option->min_value.ul) {
                   gt_error_set(err, "first argument to option \"-%s\" must be "
-                               "an integer >= %lu",
+                               "an integer >= "GT_WU"",
                                gt_str_get(option->option_str),
                                option->min_value.ul);
                   had_err = -1;
@@ -1024,7 +1341,7 @@ GtOPrval gt_option_parser_parse(GtOptionParser *op, int *parsed_args, int argc,
                 if (option->max_value_set &&
                     long_value > option->max_value.ul) {
                   gt_error_set(err, "second argument to option \"-%s\" must be "
-                               "an integer <= %lu",
+                               "an integer <= "GT_WU"",
                                gt_str_get(option->option_str),
                                option->max_value.ul);
                   had_err = -1;
@@ -1035,8 +1352,9 @@ GtOPrval gt_option_parser_parse(GtOptionParser *op, int *parsed_args, int argc,
               /* check arguments */
               if (!had_err && (((GtRange*) option->value)->start >
                                ((GtRange*) option->value)->end)) {
-                gt_error_set(err, "first argument %lu to option \"-%s\" must "
-                             "be <= than second argument %lu",
+                gt_error_set(err,
+                             "first argument "GT_WU" to option \"-%s\" must "
+                             "be <= than second argument "GT_WU"",
                              ((GtRange*) option->value)->start,
                              gt_str_get(option->option_str),
                              ((GtRange*) option->value)->end);
@@ -1045,6 +1363,7 @@ GtOPrval gt_option_parser_parse(GtOptionParser *op, int *parsed_args, int argc,
               if (!had_err)
                 option_parsed = true;
               break;
+            case OPTION_FILENAME:
             case OPTION_STRING:
               if (optional_arg(option, argnum, argc, argv)) {
                 option_parsed = true;
@@ -1085,7 +1404,10 @@ GtOPrval gt_option_parser_parse(GtOptionParser *op, int *parsed_args, int argc,
               }
               break;
             case OPTION_VERSION:
-              ((GtShowVersionFunc) option->value)(op->progname);
+              if (op->version_func)
+                op->version_func(op->progname);
+              else
+                version_func(op->progname);
               return GT_OPTION_PARSER_REQUESTS_EXIT;
             default: gt_assert(0);
           }
@@ -1144,7 +1466,6 @@ GtOPrval gt_option_parser_parse(GtOptionParser *op, int *parsed_args, int argc,
     had_err = hookinfo->hook(hookinfo->data, err);
   }
 
-  op->parser_called = true;
   if (parsed_args)
     *parsed_args = argnum;
 
@@ -1155,7 +1476,7 @@ GtOPrval gt_option_parser_parse(GtOptionParser *op, int *parsed_args, int argc,
 
 void gt_option_parser_delete(GtOptionParser *op)
 {
-  unsigned long i;
+  GtUword i;
   if (!op) return;
   gt_free(op->progname);
   gt_free(op->synopsis);
@@ -1181,9 +1502,9 @@ GtOption* gt_option_new_verbose(bool *value)
   return gt_option_new_bool("v", "be verbose", value, false);
 }
 
-GtOption* gt_option_new_width(unsigned long *value)
+GtOption* gt_option_new_width(GtUword *value)
 {
-  return gt_option_new_ulong("width", "set output width for FASTA sequence "
+  return gt_option_new_uword("width", "set output width for FASTA sequence "
                              "printing\n(0 disables formatting)", value, 0);
 }
 
@@ -1337,8 +1658,8 @@ GtOption *gt_option_new_uint_min_max(const char *option_str,
   return o;
 }
 
-GtOption* gt_option_new_long(const char *option_str, const char *description,
-                             long *value, long default_value)
+GtOption* gt_option_new_word(const char *option_str, const char *description,
+                             GtWord *value, GtWord default_value)
 {
   GtOption *o = gt_option_new(option_str, description, value);
   o->option_type = OPTION_LONG;
@@ -1347,8 +1668,8 @@ GtOption* gt_option_new_long(const char *option_str, const char *description,
   return o;
 }
 
-GtOption* gt_option_new_ulong(const char *option_str, const char *description,
-                              unsigned long *value, unsigned long default_value)
+GtOption* gt_option_new_uword(const char *option_str, const char *description,
+                              GtUword *value, GtUword default_value)
 {
   GtOption *o = gt_option_new(option_str, description, value);
   o->option_type = OPTION_ULONG;
@@ -1357,27 +1678,27 @@ GtOption* gt_option_new_ulong(const char *option_str, const char *description,
   return o;
 }
 
-GtOption* gt_option_new_ulong_min(const char *option_str,
+GtOption* gt_option_new_uword_min(const char *option_str,
                                   const char *description,
-                                  unsigned long *value,
-                                  unsigned long default_value,
-                                  unsigned long min_value)
+                                  GtUword *value,
+                                  GtUword default_value,
+                                  GtUword min_value)
 {
-  GtOption *o = gt_option_new_ulong(option_str, description, value,
+  GtOption *o = gt_option_new_uword(option_str, description, value,
                                     default_value);
   o->min_value_set = true;
   o->min_value.ul = min_value;
   return o;
 }
 
-GtOption *gt_option_new_ulong_min_max(const char *option_str,
+GtOption *gt_option_new_uword_min_max(const char *option_str,
                                       const char *description,
-                                      unsigned long *value,
-                                      unsigned long default_value,
-                                      unsigned long min_value,
-                                      unsigned long max_value)
+                                      GtUword *value,
+                                      GtUword default_value,
+                                      GtUword min_value,
+                                      GtUword max_value)
 {
-  GtOption *o = gt_option_new_ulong(option_str, description, value,
+  GtOption *o = gt_option_new_uword(option_str, description, value,
                                     default_value);
   o->min_value_set = true;
   o->min_value.ul = min_value;
@@ -1386,15 +1707,55 @@ GtOption *gt_option_new_ulong_min_max(const char *option_str,
   return o;
 }
 
+GtOption *gt_option_new_long(const char *option_str,
+                             const char *description,
+                             GtWord *value,
+                             GtWord default_value)
+{
+  return gt_option_new_word(option_str, description, value,
+                            default_value);
+}
+
+GtOption *gt_option_new_ulong(const char *option_str,
+                              const char *description,
+                              GtUword *value,
+                              GtUword default_value)
+{
+  return gt_option_new_uword(option_str, description, value,
+                             default_value);
+}
+
+GtOption *gt_option_new_ulong_min(const char *option_str,
+                                  const char *description,
+                                  GtUword *value,
+                                  GtUword default_value,
+                                  GtUword min_value)
+{
+  return gt_option_new_uword_min(option_str, description, value,
+                                 default_value, min_value);
+}
+
+GtOption *gt_option_new_ulong_min_max(const char *option_str,
+                                      const char *description,
+                                      GtUword *value,
+                                      GtUword default_value,
+                                      GtUword min_value,
+                                      GtUword max_value)
+{
+  return gt_option_new_uword_min_max(option_str, description, value,
+                                     default_value, min_value,
+                                     max_value);
+}
+
 GtOption* gt_option_new_range(const char *option_str, const char *description,
                               GtRange *value, GtRange *default_value)
 {
   GtOption *o = gt_option_new(option_str, description, value);
   o->option_type = OPTION_RANGE;
   o->default_value.r.start = default_value ? default_value->start
-                                           : GT_UNDEF_ULONG;
+                                           : GT_UNDEF_UWORD;
   o->default_value.r.end   = default_value ? default_value->end
-                                           : GT_UNDEF_ULONG;
+                                           : GT_UNDEF_UWORD;
   value->start = o->default_value.r.start;
   value->end   = o->default_value.r.end;
   return o;
@@ -1403,8 +1764,8 @@ GtOption* gt_option_new_range(const char *option_str, const char *description,
 GtOption* gt_option_new_range_min_max(const char *option_str,
                                       const char *description, GtRange *value,
                                       GtRange *default_value,
-                                      unsigned long min_value,
-                                      unsigned long max_value)
+                                      GtUword min_value,
+                                      GtUword max_value)
 {
    GtOption *o = gt_option_new_range(option_str, description, value,
                                      default_value);
@@ -1440,7 +1801,11 @@ GtOption* gt_option_new_filename(const char *option_str,
                                  const char *description,
                                  GtStr *filename)
 {
-  return gt_option_new_string(option_str, description, filename, NULL);
+  GtOption *o = gt_option_new(option_str, description, filename);
+  o->option_type = OPTION_FILENAME;
+  o->default_value.s = NULL;
+  gt_str_reset(filename);
+  return o;
 }
 
 /* the following function would allow to handle file arrays differently from
@@ -1459,7 +1824,7 @@ GtOption* gt_option_new_choice(const char *option_str, const char *description,
 {
   GtOption *o;
 #ifndef NDEBUG
-  unsigned long in_domain = 1;
+  GtUword in_domain = 1;
   if (default_value) {
     while (domain[in_domain - 1] != NULL) {
       if (domain[in_domain - 1] == default_value) {
@@ -1604,7 +1969,7 @@ bool gt_option_is_set(const GtOption *o)
 
 void gt_option_delete(GtOption *o)
 {
-  unsigned long i;
+  GtUword i;
   if (!o) return;
   if (o->reference_count) {
     o->reference_count--;
@@ -1620,7 +1985,7 @@ void gt_option_delete(GtOption *o)
   gt_free(o);
 }
 
-int gt_option_parse_spacespec(unsigned long *maximumspace,
+int gt_option_parse_spacespec(GtUword *maximumspace,
                               const char *optname,
                               const GtStr *memlimit,
                               GtError *err)
@@ -1642,10 +2007,10 @@ int gt_option_parse_spacespec(unsigned long *maximumspace,
     char buffer[2+1];
 
     (void) sscanf(gt_str_get(memlimit), "%d%s", &readint, buffer);
-    *maximumspace = (unsigned long) readint;
+    *maximumspace = (GtUword) readint;
     if (strcmp(buffer, "GB") == 0)
     {
-      if (sizeof (unsigned long) == (size_t) 4 && *maximumspace > 3UL)
+      if (sizeof (GtUword) == (size_t) 4 && *maximumspace > 3UL)
       {
         gt_error_set(err,"option -%s: for 32bit binaries one cannot "
                          "specify more than 3 GB as maximum space",optname);
@@ -1659,7 +2024,7 @@ int gt_option_parse_spacespec(unsigned long *maximumspace,
     {
       if (strcmp(buffer, "MB") == 0)
       {
-        if (sizeof (unsigned long) == (size_t) 4 && *maximumspace > 4095UL)
+        if (sizeof (GtUword) == (size_t) 4 && *maximumspace > 4095UL)
         {
           gt_error_set(err,"option -%s: for 32bit binaries one cannot "
                            "specify more than 4095 MB as maximum space",
@@ -1675,3 +2040,15 @@ int gt_option_parse_spacespec(unsigned long *maximumspace,
   }
   return had_err;
 }
+
+const char *gt_option_parser_synopsis(const GtOptionParser *option_parser)
+{
+  gt_assert(option_parser);
+  return option_parser->synopsis;
+}
+
+const char *gt_option_parser_one_liner(const GtOptionParser *option_parser)
+{
+  gt_assert(option_parser);
+  return option_parser->one_liner;
+}
