@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2008 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2007-2008 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2007-2008 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -23,6 +23,6 @@
 
 GtStrArray* gt_str_array_new_file(const char *path);
 /* Returns an internal GtStr pointer (i.e., _not_ a new reference!). */
-GtStr*      gt_str_array_get_str(const GtStrArray*, unsigned long strnum);
+GtStr*      gt_str_array_get_str(const GtStrArray*, GtUword strnum);
 
 #endif
