@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2008-2010 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2008-2010 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2008      Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -18,8 +18,8 @@
 #include <string.h>
 #include "core/cstr_table.h"
 #include "core/mathsupport.h"
+#include "core/multithread_api.h"
 #include "core/symbol.h"
-#include "core/thread_api.h"
 #include "core/unused_api.h"
 
 static GtCstrTable *symbols = NULL;
@@ -60,7 +60,7 @@ void gt_symbol_clean(void)
 static void* test_symbol(GT_UNUSED void *data)
 {
   GtStr *symbol;
-  unsigned long i;
+  GtUword i;
   symbol = gt_str_new();
   for (i = 0; i < NUMBER_OF_SYMBOLS; i++) {
     gt_str_reset(symbol);
