@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2008 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2006-2008 Gordon Gremme <gordon@gremme.org>
   Copyright (c)      2012 Sascha Steinbiss <steinbiss@zbh.uni-hamburg.de>
   Copyright (c) 2006-2012 Center for Bioinformatics, University of Hamburg
 
@@ -19,7 +19,7 @@
 #include <sys/time.h>
 #include "core/cstr_api.h"
 #include "core/ma.h"
-#include "core/timer.h"
+#include "core/timer_api.h"
 #include "core/unused_api.h"
 #include "core/xposix.h"
 
@@ -29,12 +29,14 @@ typedef enum {
 } Timerstate;
 
 struct GtTimer {
+#ifndef _WIN32
   struct timeval gstart_tv,
                  start_tv,
                  stop_tv;
   struct rusage  gstart_ru,
                  start_ru,
                  stop_ru;
+#endif
   Timerstate state;
   char *statedesc;
   bool has_desc;
@@ -61,26 +63,39 @@ GtTimer* gt_timer_new_with_progress_description(const char* desc)
   return t;
 }
 
-void gt_timer_start(GtTimer *t)
+void gt_timer_start(GT_UNUSED GtTimer *t)
 {
+#ifndef _WIN32
   gt_assert(t);
   gettimeofday(&t->gstart_tv, NULL);
   gettimeofday(&t->start_tv, NULL);
   gt_xgetrusage(RUSAGE_SELF, &t->start_ru);
   gt_xgetrusage(RUSAGE_SELF, &t->gstart_ru);
   t->state = TIMER_RUNNING;
+#else
+  /* XXX */
+  fprintf(stderr, "gt_timer_start() not implemented\n");
+  exit(EXIT_FAILURE);
+#endif
 }
 
 void gt_timer_stop(GtTimer *t)
 {
   gt_assert(t);
+#ifndef _WIN32
   if (t->state == TIMER_RUNNING) {
     gettimeofday(&t->stop_tv, NULL);
     gt_xgetrusage(RUSAGE_SELF, &t->stop_ru);
     t->state = TIMER_STOPPED;
   }
+#else
+  /* XXX */
+  fprintf(stderr, "gt_timer_stop() not implemented\n");
+  exit(EXIT_FAILURE);
+#endif
 }
 
+#ifndef _WIN32
 static int timeval_subtract(struct timeval *result,
                             struct timeval *x,
                             struct timeval *y)
@@ -113,51 +128,70 @@ static int timeval_add(struct timeval *result,
   }
   return 0;
 }
+#endif
 
-void gt_timer_show_formatted(GtTimer *t, const char *fmt, FILE *fp)
+void gt_timer_show_formatted(GT_UNUSED GtTimer *t, GT_UNUSED const char *fmt,
+                             GT_UNUSED FILE *fp)
 {
+#ifndef _WIN32
   struct timeval elapsed_tv;
   if (t->state == TIMER_RUNNING)
     gt_timer_stop(t);
   gt_assert(t->state == TIMER_STOPPED);
   timeval_subtract(&elapsed_tv, &t->stop_tv, &t->gstart_tv);
   fprintf(fp, fmt,
-          (long)(elapsed_tv.tv_sec),
-          (long)(elapsed_tv.tv_usec),
-          (long)(t->stop_ru.ru_utime.tv_sec - t->start_ru.ru_utime.tv_sec),
-          (long)(t->stop_ru.ru_stime.tv_sec - t->start_ru.ru_stime.tv_sec));
+          (GtWord)(elapsed_tv.tv_sec),
+          (GtWord)(elapsed_tv.tv_usec),
+          (GtWord)(t->stop_ru.ru_utime.tv_sec - t->start_ru.ru_utime.tv_sec),
+          (GtWord)(t->stop_ru.ru_stime.tv_sec - t->start_ru.ru_stime.tv_sec));
+#else
+  /* XXX */
+  fprintf(stderr, "gt_timer_show_formatted() not implemented\n");
+  exit(EXIT_FAILURE);
+#endif
 }
 
 void gt_timer_show(GtTimer *t, FILE *fp)
 {
-  gt_timer_show_formatted(t, "%ld.%06lds real %lds user %lds system\n", fp);
+  gt_timer_show_formatted(t, GT_WD ".%06lds real " GT_WD "s user " GT_WD
+                          "s system\n", fp);
 }
 
+#ifndef _WIN32
 static void gt_timer_print_progress_report(GtTimer *t,
     struct timeval *elapsed_tv, struct timeval *elapsed_user_tv,
     struct timeval *elapsed_sys_tv, const char *desc, FILE *fp)
 {
-  fprintf(fp,"# TIME %s %ld.%02ld",
+  fprintf(fp,"# TIME %s "GT_WD".%02ld",
           desc,
-          (long)(elapsed_tv->tv_sec),
-          (long)(elapsed_tv->tv_usec)/10000);
+          (GtWord)(elapsed_tv->tv_sec),
+          (GtWord)(elapsed_tv->tv_usec)/10000);
   if (t->show_cpu_time) {
-    fprintf(fp, " (user: %ld.%02ld; sys: %ld.%02ld)\n",
-            (long)(elapsed_user_tv->tv_sec),
-            (long)(elapsed_user_tv->tv_usec)/10000,
-            (long)(elapsed_sys_tv->tv_sec),
-            (long)(elapsed_sys_tv->tv_usec)/10000);
+    fprintf(fp, " (user: "GT_WD".%02ld; sys: "GT_WD".%02ld)\n",
+            (GtWord)(elapsed_user_tv->tv_sec),
+            (GtWord)(elapsed_user_tv->tv_usec)/10000,
+            (GtWord)(elapsed_sys_tv->tv_sec),
+            (GtWord)(elapsed_sys_tv->tv_usec)/10000);
   }
   else {
     fprintf(fp, "\n");
   }
 }
+#endif
 
-void gt_timer_show_progress(GtTimer *t, const char *desc, FILE *fp)
+void gt_timer_show_progress(GT_UNUSED GtTimer *t, GT_UNUSED const char *desc,
+                            GT_UNUSED FILE *fp)
 {
+#ifndef _WIN32
   gt_timer_show_progress_formatted(t, fp, "%s", desc);
+#else
+  /* XXX */
+  fprintf(stderr, "gt_timer_show_progress() not implemented\n");
+  exit(EXIT_FAILURE);
+#endif
 }
 
+#ifndef _WIN32
 void gt_timer_show_progress_formatted(GtTimer *t, FILE *fp,
                                       const char *desc, ...)
 {
@@ -191,9 +225,11 @@ void gt_timer_show_progress_va(GtTimer *t, FILE *fp, const char *desc,
   gettimeofday(&t->start_tv, NULL);
   gt_xgetrusage(RUSAGE_SELF, &t->start_ru);
 }
+#endif
 
-void gt_timer_show_progress_final(GtTimer *t, FILE *fp)
+void gt_timer_show_progress_final(GT_UNUSED GtTimer *t, GT_UNUSED FILE *fp)
 {
+#ifndef _WIN32
   struct timeval elapsed_tv, elapsed_user_tv, elapsed_sys_tv;
   const char overall_desc[] = "overall";
 
@@ -214,6 +250,11 @@ void gt_timer_show_progress_final(GtTimer *t, FILE *fp)
     &t->gstart_ru.ru_stime);
   gt_timer_print_progress_report(t, &elapsed_tv, &elapsed_user_tv,
     &elapsed_sys_tv, overall_desc, fp);
+#else
+  /* XXX */
+  fprintf(stderr, "gt_timer_show_progress_final() not implemented\n");
+  exit(EXIT_FAILURE);
+#endif
 }
 
 void gt_timer_show_cpu_time_by_progress(GtTimer *t)
