@@ -21,7 +21,7 @@
 #include "core/ma.h"
 #include "core/trans_table.h"
 
-#define GT_AMINOACIDFAIL            -1
+#define GT_AMINOACIDFAIL ((char) 0)
 
 /* The integer which a T is encoded to. */
 #define GT_T_CODE  0
@@ -37,13 +37,13 @@
 #define GT_UNDEFTRANSNUM GT_NUMOFTRANSSCHEMES
 
 #define GT_INCONSISTENT(BASE)\
-        /*gt_log_log("code=%lu with wildcard %c: inconsistent " \
+        /*gt_log_log("code="GT_WU" with wildcard %c: inconsistent " \
                    "aminoacids %c and %c",\
-                   (unsigned long) codeof2, wildcard, aa, newaa);*/\
+                   (GtUword) codeof2, wildcard, aa, newaa);*/\
         return GT_AMINOACIDFAIL
 
 #define GT_ILLEGALCHAR(V)\
-        gt_error_set(err, "illegal char %s='%c'(%lu)",#V,V,(unsigned long)(V));\
+        gt_error_set(err, "illegal char %s='%c'("GT_WU")",#V,V,(GtUword)(V));\
         return GT_AMINOACIDFAIL
 
 #define GT_T_BIT  ((unsigned char) 1)
@@ -737,12 +737,12 @@ static inline char codon2amino(const char *aminos, bool forward,
 /* 'static' function */
 GtStrArray* gt_trans_table_get_scheme_descriptions()
 {
-  unsigned long i;
+  GtUword i;
   GtTranslationScheme *scheme;
   GtStr *str;
   GtStrArray *sa = gt_str_array_new();
   str = gt_str_new();
-  for (i = 1UL; i < (unsigned long) GT_SIZEOFTRANSRANGE; i++) {
+  for (i = 1UL; i < (GtUword) GT_SIZEOFTRANSRANGE; i++) {
     if (transnum2index[i] == GT_UNDEFTRANSNUM)
       continue;
     scheme = schemetable + transnum2index[i];
@@ -845,21 +845,21 @@ int gt_trans_table_unit_test(GtError *err)
 
   /* check retrieval of table descriptions */
   schemes = gt_trans_table_get_scheme_descriptions();
-  gt_ensure(had_err,
-         gt_str_array_size(schemes) == (unsigned long) GT_NUMOFTRANSSCHEMES);
+  gt_ensure(
+         gt_str_array_size(schemes) == (GtUword) GT_NUMOFTRANSSCHEMES);
 
   /* check switching translation scheme */
   /* test_errnum = gt_translator_set_translation_scheme(tr, 3, test_err);
-  gt_ensure(had_err, !test_errnum && !gt_error_is_set(test_err)); */
+  gt_ensure(!test_errnum && !gt_error_is_set(test_err)); */
 
   /* check switching to invalid translation scheme */
   /* test_errnum = gt_translator_set_translation_scheme(tr, 7, test_err);
-  gt_ensure(had_err, test_errnum && gt_error_is_set(test_err)); */
+  gt_ensure(test_errnum && gt_error_is_set(test_err)); */
 
   /* switch back to default translation scheme */
   /* gt_error_unset(test_err);
   test_errnum = gt_translator_set_translation_scheme(tr, 1, test_err);
-  gt_ensure(had_err, !test_errnum && !gt_error_is_set(test_err)); */
+  gt_ensure(!test_errnum && !gt_error_is_set(test_err)); */
 
   /* check single codon translation */
   /*
@@ -873,10 +873,10 @@ int gt_trans_table_unit_test(GtError *err)
         char c3 = bases[k], ret1, ret2;
         test_errnum = gt_translator_codon2amino(tr, c1, c2, c3, &ret1,
                                                 test_err);
-        gt_ensure(had_err, !test_errnum && !gt_error_is_set(test_err));
+        gt_ensure(!test_errnum && !gt_error_is_set(test_err));
         ret2 = gt_transa(tr->scheme->aminos, true, c1, c2, c3, NULL,
                            test_err);
-        gt_ensure(had_err, ret1 == ret2);
+        gt_ensure(ret1 == ret2);
       }
     }
   } */
