@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2007 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2007 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -22,8 +22,8 @@
 
 /* (globally) align u and v (affine gap costs) and return one optimal
    GtAlignment */
-GtAlignment* gt_affinealign(const char *u, unsigned long ulen,
-                       const char *v, unsigned long vlen, int replacement_cost,
+GtAlignment* gt_affinealign(const char *u, GtUword ulen,
+                       const char *v, GtUword vlen, int replacement_cost,
                        int gap_opening_cost, int gap_extension_cost);
 
 #endif
