@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2008 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2008 Gordon Gremme <gordon@gremme.org>
 
   Permission to use, copy, modify, and distribute this software for any
   purpose with or without fee is hereby granted, provided that the above
@@ -47,7 +47,7 @@ struct GtBEDParser {
   char *feature_type,
        *thick_feature_type,
        *block_type;
-  long offset;
+  GtWord offset;
 };
 
 GtBEDParser* gt_bed_parser_new(void)
@@ -199,9 +199,10 @@ static int skip_blanks(GtIO *bed_file, GtError *err)
 {
   gt_error_check(err);
   if (!bed_separator(bed_file)) {
-    gt_error_set(err, "file \"%s\": line %lu: expected blank or tabulator, got "
-                      "'%c'", gt_io_get_filename(bed_file),
-                      gt_io_get_line_number(bed_file), gt_io_peek(bed_file));
+    gt_error_set(err,
+                 "file \"%s\": line "GT_WU": expected blank or tabulator, got "
+                 "'%c'", gt_io_get_filename(bed_file),
+                 gt_io_get_line_number(bed_file), gt_io_peek(bed_file));
     return -1;
   }
   while (bed_separator(bed_file))
@@ -234,7 +235,8 @@ static int track_rest(GtBEDParser *bed_parser, GtIO *bed_file, GtError *err)
     if (!had_err && !strcmp(gt_str_get(bed_parser->word), OFFSET_KEYWORD)) {
       if (gt_parse_long(&bed_parser->offset,
                          gt_str_get(bed_parser->another_word))) {
-        gt_error_set(err, "file \"%s\": line %lu: could not parse offset value "
+        gt_error_set(err,
+                     "file \"%s\": line "GT_WU": could not parse offset value "
                      "'%s'", gt_io_get_filename(bed_file),
                      gt_io_get_line_number(bed_file),
                      gt_str_get(bed_parser->another_word));
@@ -252,7 +254,7 @@ static int track_rest(GtBEDParser *bed_parser, GtIO *bed_file, GtError *err)
 }
 
 static int parse_bed_range(GtRange *range, GtStr *start, GtStr *end,
-                           long offset, GtIO *bed_file, bool thick,
+                           GtWord offset, GtIO *bed_file, bool thick,
                            GtError *err)
 {
   int had_err;
@@ -268,7 +270,7 @@ static int parse_bed_range(GtRange *range, GtStr *start, GtStr *end,
      handle that case later. */
   if (!thick) {
     if (!had_err && range->start > range->end) {
-      gt_error_set(err, "file \"%s\": line %lu: BED feature has length 0",
+      gt_error_set(err, "file \"%s\": line "GT_WU": BED feature has length 0",
                    gt_io_get_filename(bed_file),
                    gt_io_get_line_number(bed_file));
       had_err = -1;
@@ -304,22 +306,23 @@ static void construct_thick_feature(GtBEDParser *bed_parser, GtFeatureNode *fn,
 }
 
 static int create_block_features(GtBEDParser *bed_parser, GtFeatureNode *fn,
-                                 unsigned long block_count,
+                                 GtUword block_count,
                                  GtSplitter *size_splitter,
                                  GtSplitter *start_splitter, GtIO *bed_file,
                                  GtError *err)
 {
-  unsigned long i;
+  GtUword i;
   int had_err = 0;
   gt_assert(fn && block_count && size_splitter && start_splitter);
   gt_assert(gt_splitter_size(size_splitter) == block_count);
   gt_assert(gt_splitter_size(start_splitter) == block_count);
   for (i = 0; !had_err && i < block_count; i++) {
-    unsigned long block_size, block_start, start, end;
+    GtUword block_size, block_start, start, end;
     GtGenomeNode *block;
     const char *name;
     if (gt_parse_ulong(&block_size, gt_splitter_get_token(size_splitter, i))) {
-      gt_error_set(err, "file \"%s\": line %lu: could not parse blockSize '%s'",
+      gt_error_set(err,
+                   "file \"%s\": line "GT_WU": could not parse blockSize '%s'",
                    gt_io_get_filename(bed_file),
                    gt_io_get_line_number(bed_file),
                    gt_splitter_get_token(size_splitter, i));
@@ -327,7 +330,7 @@ static int create_block_features(GtBEDParser *bed_parser, GtFeatureNode *fn,
     }
     if (!had_err && gt_parse_ulong(&block_start,
                                    gt_splitter_get_token(start_splitter, i))) {
-      gt_error_set(err, "file \"%s\": line %lu: could not parse blockStart "
+      gt_error_set(err, "file \"%s\": line "GT_WU": could not parse blockStart "
                    "'%s'", gt_io_get_filename(bed_file),
                    gt_io_get_line_number(bed_file),
                    gt_splitter_get_token(start_splitter, i));
@@ -363,7 +366,7 @@ static void remove_terminal_comma(GtStr *str)
 }
 
 static int process_blocks(GtBEDParser *bed_parser, GtFeatureNode *fn,
-                          unsigned long block_count, GtStr *block_sizes,
+                          GtUword block_count, GtStr *block_sizes,
                           GtStr *block_starts, GtIO *bed_file, GtError *err)
 {
   GtSplitter *size_splitter = NULL , *start_splitter = NULL;
@@ -372,14 +375,16 @@ static int process_blocks(GtBEDParser *bed_parser, GtFeatureNode *fn,
   gt_assert(fn && block_count && block_sizes && block_starts);
   if (!gt_str_length(block_sizes)) {
     gt_error_set(err,
-                 "file \"%s\": line %lu: blockCount given without blockSizes",
+                 "file \"%s\": line "GT_WU
+                 ": blockCount given without blockSizes",
                  gt_io_get_filename(bed_file),
                  gt_io_get_line_number(bed_file));
     had_err = -1;
   }
   if (!had_err && !gt_str_length(block_starts)) {
     gt_error_set(err,
-                 "file \"%s\": line %lu: blockCount given without blockStarts",
+                 "file \"%s\": line "GT_WU
+                 ": blockCount given without blockStarts",
                  gt_io_get_filename(bed_file),
                  gt_io_get_line_number(bed_file));
     had_err = -1;
@@ -394,8 +399,8 @@ static int process_blocks(GtBEDParser *bed_parser, GtFeatureNode *fn,
     gt_splitter_split(size_splitter, gt_str_get(block_sizes),
                       gt_str_length(block_sizes), ',');
     if (gt_splitter_size(size_splitter) != block_count) {
-      gt_error_set(err, "file \"%s\": line %lu: blockSizes column does not "
-                        "have blockCount=%lu many comma separated fields",
+      gt_error_set(err, "file \"%s\": line "GT_WU": blockSizes column does not "
+                        "have blockCount="GT_WU" many comma separated fields",
                    gt_io_get_filename(bed_file),
                    gt_io_get_line_number(bed_file), block_count);
       had_err = -1;
@@ -406,8 +411,9 @@ static int process_blocks(GtBEDParser *bed_parser, GtFeatureNode *fn,
     gt_splitter_split(start_splitter, gt_str_get(block_starts),
                       gt_str_length(block_starts), ',');
     if (gt_splitter_size(start_splitter) != block_count) {
-      gt_error_set(err, "file \"%s\": line %lu: blockStarts column does not "
-                        "have " "blockCount=%lu many comma separated fields",
+      gt_error_set(err,
+                   "file \"%s\": line "GT_WU": blockStarts column does not "
+                   "have " "blockCount="GT_WU" many comma separated fields",
                    gt_io_get_filename(bed_file),
                    gt_io_get_line_number(bed_file), block_count);
       had_err = -1;
@@ -424,7 +430,7 @@ static int process_blocks(GtBEDParser *bed_parser, GtFeatureNode *fn,
 
 static int bed_rest(GtBEDParser *bed_parser, GtIO *bed_file, GtError *err)
 {
-  unsigned long block_count = 0;
+  GtUword block_count = 0;
   GtGenomeNode *gn = NULL;
   GtRange range;
   GtStr *seqid;
@@ -532,7 +538,8 @@ static int bed_rest(GtBEDParser *bed_parser, GtIO *bed_file, GtError *err)
     word(bed_parser->word, bed_file);
     if (gt_str_length(bed_parser->word)) {
       if (gt_parse_ulong(&block_count, gt_str_get(bed_parser->word))) {
-        gt_error_set(err, "file \"%s\": line %lu: could not parse blockCount",
+        gt_error_set(err,
+                     "file \"%s\": line "GT_WU": could not parse blockCount",
                      gt_io_get_filename(bed_file),
                      gt_io_get_line_number(bed_file));
         had_err = -1;
