@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2009 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2009 Gordon Gremme <gordon@gremme.org>
 
   Permission to use, copy, modify, and distribute this software for any
   purpose with or without fee is hereby granted, provided that the above
@@ -45,7 +45,7 @@ static GtFeatureNode* duplicate_feature(const GtFeatureNode *fn,
 {
   GtFeatureNode *dup;
   GtStrArray *attr;
-  unsigned long i;
+  GtUword i;
   dup = (GtFeatureNode*)
         gt_feature_node_new(gt_genome_node_get_seqid((GtGenomeNode*) fn),
                             dest_type,
