@@ -19,7 +19,6 @@
 #include <errno.h>
 #ifndef S_SPLINT_S
 #include <fcntl.h>
-#include <sys/mman.h>
 #include <sys/stat.h>
 #include <unistd.h>
 #endif
@@ -27,6 +26,7 @@
 #include "core/arraydef.h"
 #include "core/assert_api.h"
 #include "core/bittab_api.h"
+#include "core/compat.h"
 #include "core/cstr_api.h"
 #include "core/disc_distri_api.h"
 #include "core/ensure.h"
@@ -58,33 +58,33 @@ static inline void encdesc_prepare_num_of_fields(GtEncdesc *encdesc,
                                                  EncdescWriteInfo *info);
 
 static void parse_number_out_of_current_field(EncdescWriteInfo *info,
-                                              long *retval);
+                                              GtWord *retval);
 
 static void numeric_field_prepare_zero_padding(GtEncdesc *encdesc,
                                                EncdescWriteInfo *info);
 
 static void numeric_field_sample_prepare_verbose_value(GtEncdesc *encdesc,
                                                        EncdescWriteInfo *info,
-                                                       unsigned long value);
+                                                       GtUword value);
 
 static void numeric_field_prepare_huffman_value(GtEncdesc *encdesc,
                                                 EncdescWriteInfo *info,
-                                                unsigned long value);
+                                                GtUword value);
 
 static void numeric_field_prepare_verbose_value(GtEncdesc *encdesc,
                                                 EncdescWriteInfo *info,
-                                                unsigned long value);
+                                                GtUword value);
 
 static inline void prepare_numeric_field(GtEncdesc *encdesc,
                                          EncdescWriteInfo *info);
 
 static void inline regular_field_prepare_length(GtEncdesc *encdesc,
                                                 EncdescWriteInfo *info,
-                                                unsigned long endpos);
+                                                GtUword endpos);
 
 static void inline regular_field_prepare_char(GtEncdesc *encdesc,
                                               EncdescWriteInfo *info,
-                                              unsigned long char_pos);
+                                              GtUword char_pos);
 
 static inline void prepare_generic(EncdescWriteInfo *info,
                                    unsigned length,
@@ -101,8 +101,8 @@ static inline void reset_info(EncdescWriteInfo *info);
 
 static inline unsigned count_leading_zeros(const char *number);
 
-static unsigned encdesc_digits_per_value(unsigned long value,
-                                         unsigned long base)
+static unsigned encdesc_digits_per_value(GtUword value,
+                                         GtUword base)
 {
   if (value > 0) {
     double log_val, log_base;
@@ -114,13 +114,13 @@ static unsigned encdesc_digits_per_value(unsigned long value,
     return 1U;
 }
 
-static int encdesc_hashmap_distr_add(GtHashtable *hm_distri, long key)
+static int encdesc_hashmap_distr_add(GtHashtable *hm_distri, GtWord key)
 {
-  unsigned long long *valueptr;
+  GtUint64 *valueptr;
   gt_assert(hm_distri != NULL);
   valueptr = li_ull_gt_hashmap_get(hm_distri, key);
   if (!valueptr) {
-    li_ull_gt_hashmap_add(hm_distri, key, (unsigned long long) 1);
+    li_ull_gt_hashmap_add(hm_distri, key, (GtUint64) 1);
     return 1;
   }
   else {
@@ -135,7 +135,7 @@ static int encdesc_analyze_descs(GtEncdesc *encdesc,
 {
   int status, had_err = 0;
   unsigned zero_count;
-  unsigned long cur_desc = 0,
+  GtUword cur_desc = 0,
                 j_idx,
                 k_idx,
                 desc_char_idx,
@@ -147,7 +147,7 @@ static int encdesc_analyze_descs(GtEncdesc *encdesc,
                 tmp_numoffields,
                 chars_len,
                 len_diff;
-  long value,
+  GtWord value,
        value_diff,
        out,
        value_delta;
@@ -173,7 +173,7 @@ static int encdesc_analyze_descs(GtEncdesc *encdesc,
       return status;
     gt_assert(descbuffer != NULL);
 
-    desclength = (unsigned long) strlen(descbuffer);
+    desclength = (GtUword) strlen(descbuffer);
 
     tmp_numoffields = 0;
     for (desc_char_idx = 0; desc_char_idx <= desclength; desc_char_idx++) {
@@ -210,7 +210,7 @@ static int encdesc_analyze_descs(GtEncdesc *encdesc,
 
     /* analyze description with maximum number of fields and initialize fields
      */
-    desclength = (unsigned long) strlen(longest_desc);
+    desclength = (GtUword) strlen(longest_desc);
     start_pos = 0;
 
     for (desc_char_idx = 0; desc_char_idx <= desclength; desc_char_idx++) {
@@ -279,7 +279,7 @@ static int encdesc_analyze_descs(GtEncdesc *encdesc,
       gt_assert(descbuffer != NULL);
 
       gt_free(mutable_desc);
-      desclength = (unsigned long) strlen(descbuffer);
+      desclength = (GtUword) strlen(descbuffer);
       encdesc->total_num_of_chars += desclength;
       mutable_desc = gt_cstr_dup(descbuffer);
 
@@ -316,7 +316,7 @@ static int encdesc_analyze_descs(GtEncdesc *encdesc,
 
           for (k_idx = 0; k_idx < chars_len; k_idx++) {
             (void) encdesc_hashmap_distr_add(cur_field->chars[k_idx],
-                                        (long) mutable_desc[start_pos + k_idx]);
+                                      (GtWord) mutable_desc[start_pos + k_idx]);
           }
 
           if (cur_field->is_cons) {
@@ -343,7 +343,7 @@ static int encdesc_analyze_descs(GtEncdesc *encdesc,
               if (zero_count > cur_field->max_zero)
                 cur_field->max_zero = zero_count;
               gt_disc_distri_add(cur_field->zero_count,
-                                 (unsigned long) zero_count);
+                                 (GtUword) zero_count);
 
               if (cur_desc == 0) {
                 cur_field->global_value =
@@ -453,13 +453,13 @@ static int encdesc_analyze_descs(GtEncdesc *encdesc,
         if (!cur_field->is_cons) {
           len_diff = cur_field->max_len - cur_field->min_len;
           cur_field->bits_per_len =
-            encdesc_digits_per_value((unsigned long) len_diff, 2UL);
+            encdesc_digits_per_value((GtUword) len_diff, 2UL);
         }
       }
       else {
         /* TODO range can be large, but the size of the dist is more important
            for huffman coding */
-        long value_range, delta_range;
+        GtWord value_range, delta_range;
         value_range = labs(cur_field->max_value - cur_field->min_value);
         delta_range = labs(cur_field->max_delta - cur_field->min_delta);
         if (value_range < delta_range || cur_field->delta_values_size == 0) {
@@ -471,9 +471,9 @@ static int encdesc_analyze_descs(GtEncdesc *encdesc,
           value_diff = delta_range;
         }
         cur_field->bits_per_num =
-          encdesc_digits_per_value((unsigned long) value_diff, 2UL);
+          encdesc_digits_per_value((GtUword) value_diff, 2UL);
         cur_field->bits_per_value =
-          encdesc_digits_per_value((unsigned long) value_range, 2UL);
+          encdesc_digits_per_value((GtUword) value_range, 2UL);
       }
     }
     encdesc->bits_per_field =
@@ -488,7 +488,7 @@ static int encdesc_write_encoding(GtEncdesc *encdesc,
 {
   int had_err = 0, striter_err;
   const char *descbuffer;
-  unsigned long desc_counter = 0,
+  GtUword desc_counter = 0,
                 page_counter = 0,
                 idx = 0,
                 bits_left_in_page;
@@ -496,7 +496,7 @@ static int encdesc_write_encoding(GtEncdesc *encdesc,
   EncdescWriteInfo *info = gt_calloc((size_t) 1, sizeof (*info));
   GtBitOutStream *bitstream;
 
-  bits_left_in_page = (unsigned long) encdesc->pagesize * 8UL;
+  bits_left_in_page = (GtUword) encdesc->pagesize * 8UL;
 
   info->codes = gt_malloc(sizeof (*info->codes));
   info->cur_desc = 0;
@@ -543,14 +543,14 @@ static int encdesc_write_encoding(GtEncdesc *encdesc,
 
           desc_counter = 0;
           page_counter = 0;
-          bits_left_in_page = (unsigned long) encdesc->pagesize * 8;
+          bits_left_in_page = (GtUword) encdesc->pagesize * 8;
         }
       }
 
       while (bits_left_in_page < info->total_bits_prepared) {
         page_counter++;
         info->total_bits_prepared -= bits_left_in_page;
-        bits_left_in_page = (unsigned long) encdesc->pagesize * 8;
+        bits_left_in_page = (GtUword) encdesc->pagesize * 8;
       }
       bits_left_in_page -= info->total_bits_prepared;
       /* always set first page as written */
@@ -614,22 +614,22 @@ static void prepare_write_data_and_count_bits(GtEncdesc *encdesc,
         else {
           if (!cur_field->fieldlen_is_const) {
             regular_field_prepare_length(encdesc, info,
-                                         (unsigned long) desc_char_idx);
+                                         (GtUword) desc_char_idx);
           }
           for (field_char_idx = 0;
                field_char_idx < desc_char_idx - info->cur_field_start_pos;
                field_char_idx++) {
             if (field_char_idx >= (size_t) cur_field->len ||
                 !gt_bittab_bit_is_set(cur_field->bittab,
-                                     (unsigned long) field_char_idx)) {
+                                     (GtUword) field_char_idx)) {
               regular_field_prepare_char(encdesc, info,
-                                         (unsigned long) field_char_idx);
+                                         (GtUword) field_char_idx);
             }
           }
 
         }
       }
-      info->cur_field_start_pos = (unsigned long) desc_char_idx + 1;
+      info->cur_field_start_pos = (GtUword) desc_char_idx + 1;
       info->cur_field_num++;
       cur_field = &encdesc->fields[info->cur_field_num];
     }
@@ -639,8 +639,8 @@ static void prepare_write_data_and_count_bits(GtEncdesc *encdesc,
 static inline void prepare_numeric_field(GtEncdesc *encdesc,
                                          EncdescWriteInfo *info)
 {
-  long value = 0;
-  unsigned long to_store;
+  GtWord value = 0;
+  GtUword to_store;
   DescField *cur_field = &encdesc->fields[info->cur_field_num];
 
   parse_number_out_of_current_field(info, &value);
@@ -650,19 +650,19 @@ static inline void prepare_numeric_field(GtEncdesc *encdesc,
   }
 
   if (info->cur_desc == 0 || info->sample) {
-    to_store = (unsigned long) (value - cur_field->min_value);
+    to_store = (GtUword) (value - cur_field->min_value);
     numeric_field_sample_prepare_verbose_value(encdesc, info, to_store);
   }
   else if (!cur_field->is_value_cons || !cur_field->is_delta_cons) {
     if (cur_field->use_delta_coding) {
-      to_store = (unsigned long)
+      to_store = (GtUword)
         ((value - cur_field->prev_value) - cur_field->min_delta);
-      gt_assert(to_store <= (unsigned long) cur_field->max_delta -
+      gt_assert(to_store <= (GtUword) cur_field->max_delta -
                               cur_field->min_delta);
     }
     else {
-      to_store = (unsigned long) (value - cur_field->min_value);
-      gt_assert(to_store <= (unsigned long) cur_field->max_value -
+      to_store = (GtUword) (value - cur_field->min_value);
+      gt_assert(to_store <= (GtUword) cur_field->max_value -
                               cur_field->min_value);
     }
 
@@ -689,7 +689,7 @@ static inline void encdesc_prepare_num_of_fields(GtEncdesc *encdesc,
 }
 
 static void parse_number_out_of_current_field(EncdescWriteInfo *info,
-                                              long *retval)
+                                              GtWord *retval)
 {
   char *cur_field_num = info->descbuffer + info->cur_field_start_pos;
   GT_UNUSED int had_err = gt_parse_long(retval, cur_field_num);
@@ -711,7 +711,7 @@ static void numeric_field_prepare_zero_padding(GtEncdesc *encdesc,
   huffman = cur_field->huffman_zero_count;
   gt_assert(huffman != NULL);
   gt_huffman_encode(huffman,
-                    (unsigned long) zero_count,
+                    (GtUword) zero_count,
                     &code,
                     &length);
   prepare_generic(info, length, code);
@@ -732,7 +732,7 @@ static inline unsigned count_leading_zeros(const char *number)
 
 static void numeric_field_sample_prepare_verbose_value(GtEncdesc *encdesc,
                                                        EncdescWriteInfo *info,
-                                                       unsigned long value)
+                                                       GtUword value)
 {
   DescField *cur_field = &encdesc->fields[info->cur_field_num];
 
@@ -743,7 +743,7 @@ static void numeric_field_sample_prepare_verbose_value(GtEncdesc *encdesc,
 
 static void numeric_field_prepare_huffman_value(GtEncdesc *encdesc,
                                                 EncdescWriteInfo *info,
-                                                unsigned long value)
+                                                GtUword value)
 {
   GtBitsequence code;
   unsigned length;
@@ -762,7 +762,7 @@ static void numeric_field_prepare_huffman_value(GtEncdesc *encdesc,
 
 static void numeric_field_prepare_verbose_value(GtEncdesc *encdesc,
                                                 EncdescWriteInfo *info,
-                                                unsigned long value)
+                                                GtUword value)
 {
   DescField *cur_field = &encdesc->fields[info->cur_field_num];
 
@@ -774,7 +774,7 @@ static void numeric_field_prepare_verbose_value(GtEncdesc *encdesc,
 
 static void inline regular_field_prepare_length(GtEncdesc *encdesc,
                                                 EncdescWriteInfo *info,
-                                                unsigned long endpos)
+                                                GtUword endpos)
 {
   DescField *field = &encdesc->fields[info->cur_field_num];
   GtBitsequence code = (GtBitsequence)
@@ -784,7 +784,7 @@ static void inline regular_field_prepare_length(GtEncdesc *encdesc,
 
 static void inline regular_field_prepare_char(GtEncdesc *encdesc,
                                               EncdescWriteInfo *info,
-                                              unsigned long char_pos)
+                                              GtUword char_pos)
 {
   DescField *field = &encdesc->fields[info->cur_field_num];
   GtBitsequence code;
@@ -794,7 +794,7 @@ static void inline regular_field_prepare_char(GtEncdesc *encdesc,
 
   gt_assert(huffman != NULL);
   gt_huffman_encode(huffman,
-                    (unsigned long) cur_char,
+                    (GtUword) cur_char,
                     &code,
                     &length);
   prepare_generic(info, length, code);
@@ -815,11 +815,11 @@ static inline void prepare_generic(EncdescWriteInfo *info,
   info->total_bits_prepared += this_code->length;
 }
 
-static inline void append_data_to_bitstream_and_reset_info(
-                                                      EncdescWriteInfo *info,
-                                                      GtBitOutStream *bitstream)
+static inline void
+append_data_to_bitstream_and_reset_info(EncdescWriteInfo *info,
+                                        GtBitOutStream *bitstream)
 {
-  unsigned long number_of_codes, idx;
+  GtUword number_of_codes, idx;
   EncdescCode *codes = info->codes->spaceEncdescCode;
 
   number_of_codes = info->codes->nextfreeEncdescCode;
@@ -842,10 +842,11 @@ static GtEncdesc *encdesc_new(void)
   GtEncdesc *encdesc;
   encdesc = gt_calloc((size_t) 1, sizeof (GtEncdesc));
   encdesc->bitinstream = NULL;
+  encdesc->fields = NULL;
   encdesc->num_of_descs = 0;
-  encdesc->total_num_of_chars = 0;
+  encdesc->pagesize = gt_pagesize();
   encdesc->sampling = NULL;
-  encdesc->pagesize = sysconf((int) _SC_PAGESIZE);
+  encdesc->total_num_of_chars = 0;
   return encdesc;
 }
 
@@ -908,24 +909,24 @@ bool gt_encdesc_sampling_is_page(GtEncdescEncoder *ee)
 }
 
 void gt_encdesc_encoder_set_sampling_rate(GtEncdescEncoder *ee,
-                                          unsigned long sampling_rate)
+                                          GtUword sampling_rate)
 {
   gt_assert(ee);
   ee->sampling_rate = sampling_rate;
 }
 
-unsigned long gt_encdesc_encoder_get_sampling_rate(GtEncdescEncoder *ee)
+GtUword gt_encdesc_encoder_get_sampling_rate(GtEncdescEncoder *ee)
 {
   gt_assert(ee);
   return ee->sampling_rate;
 }
 
-unsigned long long encdesc_hashmap_distr_get_corrected(const void *data,
-                                                       unsigned long key)
+GtUint64 encdesc_hashmap_distr_get_corrected(const void *data,
+                                                       GtUword key)
 {
   EncdescHuffDist *dist = (EncdescHuffDist*) data;
-  unsigned long long *valueptr;
-  long corrected_key = (long) key + dist->correction_base;
+  GtUint64 *valueptr;
+  GtWord corrected_key = (GtWord) key + dist->correction_base;
   gt_assert(dist->li_ull_hashmap);
   if (!(valueptr = li_ull_gt_hashmap_get(dist->li_ull_hashmap,
                                          corrected_key)))
@@ -933,20 +934,20 @@ unsigned long long encdesc_hashmap_distr_get_corrected(const void *data,
   return *valueptr;
 }
 
-static unsigned long long encdesc_distri_get_symbol_freq(const void *distri,
-                                                         unsigned long symbol)
+static GtUint64 encdesc_distri_get_symbol_freq(const void *distri,
+                                                         GtUword symbol)
 {
   GtDiscDistri *distr = (GtDiscDistri*) distri;
   return gt_disc_distri_get(distr, symbol);
 }
 
-unsigned long long encdesc_hashmap_distr_get(const void *hm_distri,
-                                             unsigned long key)
+GtUint64 encdesc_hashmap_distr_get(const void *hm_distri,
+                                             GtUword key)
 {
   GtHashtable *hashmap = (GtHashtable*) hm_distri;
-  unsigned long long *valueptr;
+  GtUint64 *valueptr;
   gt_assert(hashmap != NULL);
-  if (!(valueptr = li_ull_gt_hashmap_get(hashmap, (long) key)))
+  if (!(valueptr = li_ull_gt_hashmap_get(hashmap, (GtWord) key)))
     return 0;
   return *valueptr;
 }
@@ -954,10 +955,10 @@ unsigned long long encdesc_hashmap_distr_get(const void *hm_distri,
 static void encdesc_init_huffman(GtEncdesc *encdesc)
 {
   DescField *field;
-  unsigned long field_idx,
+  GtUword field_idx,
                 alphabet_size = 0,
                 char_idx;
-  unsigned long const char_alphabet_size = 256UL;
+  GtUword const char_alphabet_size = 256UL;
   EncdescHuffDist huffdist;
 
   for (field_idx = 0;
@@ -971,14 +972,14 @@ static void encdesc_init_huffman(GtEncdesc *encdesc)
           gt_assert(field->delta_values != NULL);
           huffdist.li_ull_hashmap = field->delta_values;
           alphabet_size =
-            (unsigned long) labs(field->max_delta - field->min_delta) + 1;
+            (GtUword) labs(field->max_delta - field->min_delta) + 1;
         }
         else if (!field->is_value_cons && field->use_hc) {
           huffdist.correction_base = field->min_value;
           gt_assert(field->num_values != NULL);
           huffdist.li_ull_hashmap = field->num_values;
           alphabet_size =
-            (unsigned long) labs(field->max_value - field->min_value) + 1;
+            (GtUword) labs(field->max_value - field->min_value) + 1;
         }
 
         if (field->use_hc) {
@@ -991,7 +992,7 @@ static void encdesc_init_huffman(GtEncdesc *encdesc)
           field->huffman_zero_count =
             gt_huffman_new(field->zero_count,
                            encdesc_distri_get_symbol_freq,
-                           (unsigned long) field->max_zero + 1);
+                           (GtUword) field->max_zero + 1);
         }
       }
       else {
@@ -1019,10 +1020,10 @@ int gt_encdesc_encoder_encode(GtEncdescEncoder *ee,
   bool is_not_at_pageborder;
   FILE *fp = NULL;
   GtStr *name1;
-  long pos = 0,
-       start_of_encoding,
-       pagesize;
-  unsigned long dummy = 0;
+  GtWord pos = 0,
+       start_of_encoding;
+  GtUword dummy = 0,
+                pagesize;
 
   gt_assert(ee != NULL);
   gt_assert(cstr_iterator != NULL);
@@ -1043,8 +1044,9 @@ int gt_encdesc_encoder_encode(GtEncdescEncoder *ee,
       had_err = -1;
   }
 
+  if (!had_err)
+    had_err = encdesc_write_header(ee->encdesc, fp, err);
   if (!had_err) {
-    encdesc_write_header(ee->encdesc, fp);
     if (ee->timer != NULL) {
       gt_timer_show_progress(ee->timer, "calculate huffmans", stdout);
     }
@@ -1054,7 +1056,7 @@ int gt_encdesc_encoder_encode(GtEncdescEncoder *ee,
     }
     gt_error_check(err);
     pos = ftell(fp);
-    gt_xfwrite(&dummy, sizeof (dummy), (size_t) 1, fp);
+    gt_xfwrite_one(&dummy, fp);
 
     pagesize = ee->encdesc->pagesize;
     is_not_at_pageborder = (ftell(fp) % pagesize) != 0;
@@ -1079,8 +1081,8 @@ int gt_encdesc_encoder_encode(GtEncdescEncoder *ee,
       gt_xfwrite(&ee->encdesc->start_of_samplingtab,
                  sizeof (ee->encdesc->start_of_samplingtab), (size_t) 1, fp);
     else {
-      const long null = 0;
-      gt_xfwrite(&null, sizeof (null), (size_t) 1, fp);
+      const GtWord null = 0;
+      gt_xfwrite_one(&null, fp);
     }
   }
 
@@ -1091,7 +1093,7 @@ int gt_encdesc_encoder_encode(GtEncdescEncoder *ee,
                              "description encoding finished", stdout);
     }
     if (gt_log_enabled()) {
-      unsigned long rate;
+      GtUword rate;
       name1 = gt_str_new_cstr(name);
       gt_str_append_cstr(name1, GT_ENCDESC_FILESUFFIX);
       gt_log_log("description encoding overview:");
@@ -1100,12 +1102,12 @@ int gt_encdesc_encoder_encode(GtEncdescEncoder *ee,
         rate = gt_sampling_get_rate(ee->encdesc->sampling);
         if (gt_sampling_is_regular(ee->encdesc->sampling)) {
           gt_log_log("applied sampling technique:"
-                     " sampling every %luth description",
+                     " sampling every "GT_WU"th description",
                      rate);
         }
         else {
           gt_log_log("applied sampling technique:"
-                     " sampling every %luth page",
+                     " sampling every "GT_WU"th page",
                      rate);
         }
       }
@@ -1113,9 +1115,9 @@ int gt_encdesc_encoder_encode(GtEncdescEncoder *ee,
         gt_log_log("applied sampling technique: none");
       }
 
-      gt_log_log("total number of encoded descriptions: %lu",
+      gt_log_log("total number of encoded descriptions: "GT_WU"",
                  ee->encdesc->num_of_descs);
-      gt_log_log("total number of encoded characters: %llu",
+      gt_log_log("total number of encoded characters: "GT_LLU"",
                  ee->encdesc->total_num_of_chars);
       gt_log_log("bits per character encoding: %f",
                  (gt_file_estimate_size(gt_str_get(name1)) * 8.0) /
@@ -1152,11 +1154,12 @@ static void encdesc_read_samplingtab(GtEncdesc *encdesc,
 GtEncdesc* gt_encdesc_load(const char *name,
                            GtError *err)
 {
+  int had_err = 0;
   GtEncdesc *encdesc = NULL;
   FILE *fp;
   GtStr *filename;
   int fd;
-  unsigned long const pages_to_map = 5UL;
+  GtUword const pages_to_map = 5UL;
 
   gt_assert(name);
   encdesc = encdesc_new();
@@ -1166,27 +1169,36 @@ GtEncdesc* gt_encdesc_load(const char *name,
   fp = gt_fa_fopen_with_suffix(name, GT_ENCDESC_FILESUFFIX, "rb", err);
   if (fp == NULL) {
     gt_assert(gt_error_is_set(err));
-    return NULL;
+    had_err = 1;
   }
 
-  fd = open(gt_str_get(filename), O_RDONLY);
-  if (fd == -1) {
-    gt_error_set(err, "open(): cannot read file %s, error: %s",
-                 gt_str_get(filename), strerror(errno));
-    return NULL;
+  if (!had_err) {
+    fd = open(gt_str_get(filename), O_RDONLY);
+    if (fd == -1) {
+      gt_error_set(err, "open(): cannot read file %s, error: %s",
+                   gt_str_get(filename), strerror(errno));
+      had_err = 1;
+    }
   }
-  encdesc_read_header(encdesc, fp);
+  if (!had_err)
+    had_err = encdesc_read_header(encdesc, fp, err);
 
-  encdesc_init_huffman(encdesc);
+  if (!had_err) {
+    encdesc_init_huffman(encdesc);
 
-  encdesc_read_samplingtab(encdesc, fp);
-  gt_fa_fclose(fp);
+    encdesc_read_samplingtab(encdesc, fp);
+    gt_fa_fclose(fp);
 
-  encdesc->bitinstream = gt_bitinstream_new(gt_str_get(filename),
-                                            (size_t) encdesc->start_of_encoding,
-                                            pages_to_map);
-  gt_str_delete(filename);
+    encdesc->bitinstream =
+      gt_bitinstream_new(gt_str_get(filename),
+                         (size_t) encdesc->start_of_encoding, pages_to_map);
+    gt_str_delete(filename);
 
+  }
+  else {
+    gt_encdesc_delete(encdesc);
+    encdesc = NULL;
+  }
   return encdesc;
 }
 
@@ -1198,19 +1210,19 @@ static int encdesc_next_desc(GtEncdesc *encdesc, GtStr *desc, GtError *err)
        sampled = false;
   unsigned readbits,
            bits_to_read;
-  long tmp = 0;
-  unsigned long cur_field_num,
-                fieldlen = 0,
-                idx,
-                numoffields,
-                nearestsample,
-                zero_count,
-                tmp_symbol = 0;
+  GtWord tmp = 0;
+  GtUword cur_field_num,
+          fieldlen = 0,
+          idx,
+          numoffields,
+          nearestsample,
+          zero_count = 0,
+          tmp_symbol = 0;
   size_t startofnearestsample;
   GtBitsequence bitseq;
   GtHuffmanBitwiseDecoder *huff_bitwise_decoder;
 
-  gt_log_log("current_desc: %lu", encdesc->cur_desc);
+  gt_log_log("current_desc: "GT_WU"", encdesc->cur_desc);
   if (encdesc->cur_desc == encdesc->num_of_descs) {
     gt_error_set(err,"nothing done, eof?");
     return had_err;
@@ -1220,11 +1232,10 @@ static int encdesc_next_desc(GtEncdesc *encdesc, GtStr *desc, GtError *err)
       encdesc->cur_desc == gt_sampling_get_next_elementnum(encdesc->sampling)) {
     int sample_status;
     sample_status = gt_sampling_get_next_sample(encdesc->sampling,
-                                    &nearestsample,
-                                    &startofnearestsample);
+                                                &nearestsample,
+                                                &startofnearestsample);
     if (sample_status == 1) {
-      gt_bitinstream_reinit(encdesc->bitinstream,
-                            startofnearestsample);
+      gt_bitinstream_reinit(encdesc->bitinstream, startofnearestsample);
       sampled = true;
     }
     else
@@ -1248,7 +1259,7 @@ static int encdesc_next_desc(GtEncdesc *encdesc, GtStr *desc, GtError *err)
       else if (bit)
         bitseq = bitseq | (GtBitsequence) 1;
     }
-    numoffields = (unsigned long) bitseq;
+    numoffields = (GtUword) bitseq;
   }
   else
     numoffields = encdesc->num_of_fields;
@@ -1259,6 +1270,7 @@ static int encdesc_next_desc(GtEncdesc *encdesc, GtStr *desc, GtError *err)
     DescField *cur_field = &encdesc->fields[cur_field_num];
     if (cur_field->is_cons) {
       if (desc != NULL) {
+        gt_assert(cur_field->data != NULL);
         gt_str_append_cstr(desc, cur_field->data);
         gt_str_append_char(desc, cur_field->sep);
       }
@@ -1267,7 +1279,7 @@ static int encdesc_next_desc(GtEncdesc *encdesc, GtStr *desc, GtError *err)
     if (cur_field->is_numeric) {
       if (cur_field->has_zero_padding && !cur_field->fieldlen_is_const) {
         huff_bitwise_decoder = gt_huffman_bitwise_decoder_new(
-                                           cur_field->huffman_zero_count, err);
+                                            cur_field->huffman_zero_count, err);
         stat = -1;
         while (!had_err && stat != 0) {
           if (gt_bitinstream_get_next_bit(encdesc->bitinstream, &bit) != 1) {
@@ -1306,7 +1318,7 @@ static int encdesc_next_desc(GtEncdesc *encdesc, GtStr *desc, GtError *err)
 
         }
         if (!had_err) {
-          tmp = (long) bitseq + cur_field->min_value;
+          tmp = (GtWord) bitseq + cur_field->min_value;
           cur_field->prev_value = tmp;
         }
       }
@@ -1315,7 +1327,7 @@ static int encdesc_next_desc(GtEncdesc *encdesc, GtStr *desc, GtError *err)
           if (cur_field->bits_per_num) {
             if (cur_field->use_hc) {
               huff_bitwise_decoder = gt_huffman_bitwise_decoder_new(
-                                                  cur_field->huffman_num, err);
+                                                   cur_field->huffman_num, err);
               stat = 1;
               while (!had_err && stat != 0) {
                 if (gt_bitinstream_get_next_bit(encdesc->bitinstream,
@@ -1331,7 +1343,7 @@ static int encdesc_next_desc(GtEncdesc *encdesc, GtStr *desc, GtError *err)
                     gt_assert(gt_error_is_set(err));
                   }
                   else
-                    tmp = (long) tmp_symbol;
+                    tmp = (GtWord) tmp_symbol;
                 }
               }
               gt_huffman_bitwise_decoder_delete(huff_bitwise_decoder);
@@ -1352,7 +1364,7 @@ static int encdesc_next_desc(GtEncdesc *encdesc, GtStr *desc, GtError *err)
                   bitseq = bitseq | (GtBitsequence) 1;
               }
               if (!had_err)
-                tmp = (long) bitseq;
+                tmp = (GtWord) bitseq;
             }
           }
           else
@@ -1373,14 +1385,14 @@ static int encdesc_next_desc(GtEncdesc *encdesc, GtStr *desc, GtError *err)
         cur_field->prev_value = tmp;
         if (cur_field->has_zero_padding && cur_field->fieldlen_is_const) {
           zero_count = cur_field->len -
-                       encdesc_digits_per_value((unsigned long) tmp, 10UL);
+            encdesc_digits_per_value((GtUword) tmp, 10UL);
           for (idx = 0;
                desc != NULL && idx < zero_count;
                idx++)
             gt_str_append_char(desc, '0');
         }
         if (desc != NULL) {
-          gt_str_append_ulong(desc, (unsigned long) tmp);
+          gt_str_append_ulong(desc, (GtUword) tmp);
           gt_str_append_char(desc, cur_field->sep);
         }
         continue;
@@ -1403,7 +1415,7 @@ static int encdesc_next_desc(GtEncdesc *encdesc, GtStr *desc, GtError *err)
 
       }
       if (!had_err)
-        fieldlen = (unsigned long) bitseq + cur_field->min_len;
+        fieldlen = (GtUword) bitseq + cur_field->min_len;
     }
     else
       fieldlen = cur_field->len;
@@ -1416,7 +1428,7 @@ static int encdesc_next_desc(GtEncdesc *encdesc, GtStr *desc, GtError *err)
       }
       else {
         huff_bitwise_decoder = gt_huffman_bitwise_decoder_new(
-                                           cur_field->huffman_chars[idx], err);
+                                            cur_field->huffman_chars[idx], err);
         stat = -1;
         while (!had_err && stat != 0) {
           if (gt_bitinstream_get_next_bit(encdesc->bitinstream, &bit) != 1) {
@@ -1431,7 +1443,7 @@ static int encdesc_next_desc(GtEncdesc *encdesc, GtStr *desc, GtError *err)
               had_err = stat;
             }
             else
-              tmp = (long) tmp_symbol;
+              tmp = (GtWord) tmp_symbol;
           }
         }
         if (!had_err && desc != NULL) {
@@ -1455,21 +1467,21 @@ static int encdesc_next_desc(GtEncdesc *encdesc, GtStr *desc, GtError *err)
     return success;
 }
 
-unsigned long gt_encdesc_num_of_descriptions(GtEncdesc *encdesc)
+GtUword gt_encdesc_num_of_descriptions(GtEncdesc *encdesc)
 {
   gt_assert(encdesc);
   return encdesc->num_of_descs;
 }
 
 int gt_encdesc_decode(GtEncdesc *encdesc,
-                      unsigned long num,
+                      GtUword num,
                       GtStr *desc,
                       GtError *err)
 {
   int had_err = 0;
-  unsigned long descs2read = 0,
-                nearestsample = 0,
-                idx;
+  GtUword descs2read = 0,
+          nearestsample = 0,
+          idx;
   size_t startofnearestsample = 0;
 
   gt_assert(encdesc);
@@ -1523,9 +1535,9 @@ int gt_encdesc_decode(GtEncdesc *encdesc,
 }
 
 static void encdesc_delete_desc_fields(DescField *fields,
-                                      unsigned long numoffields)
+                                      GtUword numoffields)
 {
-  unsigned long idx,
+  GtUword idx,
                 j_idx;
 
   if (!fields)
@@ -1585,35 +1597,35 @@ int gt_encdesc_unit_test(GtError *err)
   /* test count_leading_zeros */
   if (!had_err) {
     char *test = "000156";
-    gt_ensure(had_err, count_leading_zeros(test) == 3U);
+    gt_ensure(count_leading_zeros(test) == 3U);
 
     test = "x";
-    gt_ensure(had_err, count_leading_zeros(test) == 0);
+    gt_ensure(count_leading_zeros(test) == 0);
 
     test = "0000";
-    gt_ensure(had_err, count_leading_zeros(test) == 3U);
+    gt_ensure(count_leading_zeros(test) == 3U);
 
     test = "";
-    gt_ensure(had_err, count_leading_zeros(test) == 0U);
+    gt_ensure(count_leading_zeros(test) == 0U);
   }
 
   /* test parse_number_out_of_current_field */
   if (!had_err) {
-    long retval = 0;
+    GtWord retval = 0;
     info->descbuffer = "abc00666";
     info->cur_field_start_pos = 3UL;
     parse_number_out_of_current_field(info, &retval);
-    gt_ensure(had_err, retval == 666L);
+    gt_ensure(retval == 666L);
 
     info->descbuffer = "abc\000666\000abc";
     info->cur_field_start_pos = 4UL;
     parse_number_out_of_current_field(info, &retval);
-    gt_ensure(had_err, retval == 666L);
+    gt_ensure(retval == 666L);
 
     info->descbuffer = "aaa-123\000aaa";
     info->cur_field_start_pos = 3UL;
     parse_number_out_of_current_field(info, &retval);
-    gt_ensure(had_err, retval == -123L);
+    gt_ensure(retval == -123L);
   }
 
   GT_FREEARRAY(info->codes, EncdescCode);
