@@ -32,94 +32,94 @@
 
 #define GT_ENCDESC_MAX_NUM_VAL_HUF 512UL
 
-DECLARE_HASHMAP(long int, li, unsigned long long, ull, static, inline)
-DEFINE_HASHMAP(long int, li, unsigned long long, ull, gt_ht_ul_elem_hash,
+DECLARE_HASHMAP(GtWord, li, GtUint64, ull, static, inline)
+DEFINE_HASHMAP(GtWord, li, GtUint64, ull, gt_ht_ul_elem_hash,
                gt_ht_ul_elem_cmp, NULL_DESTRUCTOR, NULL_DESTRUCTOR, static,
                inline)
 
 typedef struct {
   GtHashtable *li_ull_hashmap;
-  long correction_base;
+  GtWord       correction_base;
 } EncdescHuffDist;
 
 typedef struct {
-  char *data,
-       sep;
-  bool is_numeric,
-       is_cons,
-       fieldlen_is_const,
-       use_delta_coding,
-       is_delta_cons,
-       is_value_cons,
-       use_hc,
-       has_zero_padding;
-  unsigned bits_per_num,
-           bits_per_value,
-           bits_per_len,
-           max_zero;
-  long max_delta,
-       min_delta,
-       global_delta,
-       min_value,
-       max_value,
-       global_value,
-       prev_value;
-  unsigned long max_len,
-                min_len,
-                num_values_size,
-                len,
-                delta_values_size;
-  GtBittab *bittab;
-  GtHashtable *num_values,
-              *delta_values,
+  GtHuffman   **huffman_chars,
+               *huffman_num,
+               *huffman_zero_count;
+  GtBittab     *bittab;
+  GtHashtable  *num_values,
+               *delta_values,
               **chars;
   /* TODO: test if this can be a GtHashtable, too */
   GtDiscDistri *zero_count;
-  GtHuffman **huffman_chars,
-            *huffman_num,
-            *huffman_zero_count;
+  char         *data;
+  GtUword       delta_values_size,
+                len,
+                min_len,
+                num_values_size,
+                max_len;
+  GtWord        global_delta,
+                global_value,
+                max_delta,
+                max_value,
+                min_delta,
+                min_value,
+                prev_value;
+  unsigned int  bits_per_len,
+                bits_per_num,
+                bits_per_value,
+                max_zero;
+  char          sep;
+  bool          fieldlen_is_const,
+                has_zero_padding,
+                is_cons,
+                is_delta_cons,
+                is_numeric,
+                is_value_cons,
+                use_delta_coding,
+                use_hc;
 } DescField;
 
 struct GtEncdesc {
-  bool num_of_fields_is_cons;
-  unsigned bits_per_field;
-  long start_of_encoding,
-       start_of_samplingtab;
-  unsigned long num_of_descs,
-                num_of_fields,
-                cur_desc;
-  unsigned long long total_num_of_chars;
-  DescField *fields;
-  GtBitInStream *bitinstream;
-  GtArrayGtUlong num_of_fields_tab;
-  GtSampling *sampling;
-  long pagesize;
+  GtArrayGtUlong  num_of_fields_tab;
+  DescField      *fields;
+  GtBitInStream  *bitinstream;
+  GtSampling     *sampling;
+  GtUint64        total_num_of_chars;
+  GtUword         num_of_descs,
+                  num_of_fields,
+                  cur_desc,
+                  pagesize;
+  GtWord          start_of_samplingtab,
+                  start_of_encoding;
+  unsigned int    bits_per_field;
+  bool            num_of_fields_is_cons;
 };
 
 struct GtEncdescEncoder {
-  GtTimer *timer;
+  GtTimer   *timer;
   GtEncdesc *encdesc;
-  bool regular_sampling,
-       page_sampling;
-  unsigned long sampling_rate;
+  GtUword    sampling_rate;
+  bool       regular_sampling,
+             page_sampling;
 };
 
 typedef struct {
   GtBitsequence code;
-  unsigned length;
+  unsigned      length;
 } EncdescCode;
 
 GT_DECLAREARRAYSTRUCT(EncdescCode);
 
 typedef struct {
   GtArrayEncdescCode *codes;
-  unsigned long total_bits_prepared,
-                bits_to_write,
-                cur_field_start_pos,
-                cur_field_num,
-                cur_desc;
-  char *descbuffer;
-  bool sample;
+  char               *descbuffer;
+  GtUword             total_bits_prepared,
+                      bits_to_write,
+                      cur_field_start_pos,
+                      cur_field_num,
+                      cur_desc;
+  bool                sample;
 } EncdescWriteInfo;
 
 #endif
