@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2011 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2006-2011 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2006-2008 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -32,8 +32,9 @@ struct GtExtractFeatureVisitor {
   bool join,
        translate,
        seqid,
-       target;
-  unsigned long fastaseq_counter,
+       target,
+       retain_ids;
+  GtUword fastaseq_counter,
                 width;
   GtRegionMapping *region_mapping;
   GtFile *outfp;
@@ -50,14 +51,15 @@ static void extract_feature_visitor_free(GtNodeVisitor *nv)
 }
 
 static void construct_description(GtStr *description, const char *type,
-                                  unsigned long counter, bool join,
+                                  GtUword counter, bool join,
                                   bool translate, GtStr *seqid,
                                   GtStrArray *target_ids)
 {
-  gt_assert(!gt_str_length(description));
-  gt_str_append_cstr(description, type);
-  gt_str_append_char(description, '_');
-  gt_str_append_ulong(description, counter);
+  if (!gt_str_length(description)) {
+    gt_str_append_cstr(description, type);
+    gt_str_append_char(description, '_');
+    gt_str_append_ulong(description, counter);
+  }
   if (join)
     gt_str_append_cstr(description, " (joined)");
   if (translate)
@@ -69,7 +71,7 @@ static void construct_description(GtStr *description, const char *type,
     gt_str_append_char(description, ']');
   }
   if (target_ids && gt_str_array_size(target_ids)) {
-    unsigned long i;
+    GtUword i;
     gt_str_append_cstr(description, " [target IDs ");
     gt_str_append_cstr(description, gt_str_array_get(target_ids, 0));
     for (i = 1; i < gt_str_array_size(target_ids); i++) {
@@ -81,7 +83,7 @@ static void construct_description(GtStr *description, const char *type,
 }
 
 static int show_entry(GtStr *description, GtStr *sequence, bool translate,
-                      unsigned long width, GtFile *outfp)
+                      GtUword width, GtFile *outfp)
 {
   int had_err = 0;
   if (translate) {
@@ -149,6 +151,11 @@ static int extract_feature_visitor_feature_node(GtNodeVisitor *nv,
 
     if (!had_err && gt_str_length(sequence)) {
       efv->fastaseq_counter++;
+      if (efv->retain_ids && gt_feature_node_get_attribute(child, "ID")) {
+        gt_assert(!gt_str_length(description));
+        gt_str_append_cstr(description, gt_feature_node_get_attribute(child,
+                                                                      "ID"));
+      }
       construct_description(description, efv->type, efv->fastaseq_counter,
                             efv->join, efv->translate, seqid, target_ids);
       had_err = show_entry(description, sequence, efv->translate, efv->width,
@@ -186,7 +193,7 @@ const GtNodeVisitorClass* gt_extract_feature_visitor_class()
 GtNodeVisitor* gt_extract_feature_visitor_new(GtRegionMapping *rm,
                                               const char *type, bool join,
                                               bool translate, bool seqid,
-                                              bool target, unsigned long width,
+                                              bool target, GtUword width,
                                               GtFile *outfp)
 {
   GtNodeVisitor *nv;
@@ -203,5 +210,14 @@ GtNodeVisitor* gt_extract_feature_visitor_new(GtRegionMapping *rm,
   efv->region_mapping = rm;
   efv->width = width;
   efv->outfp = outfp;
+  /* XXX */
+  efv->retain_ids = getenv("GT_RETAINIDS") ? true : false;
   return nv;
 }
+
+void gt_extract_feature_visitor_retain_id_attributes(GtExtractFeatureVisitor
+                                                                          *efv)
+{
+  gt_assert(efv);
+  efv->retain_ids = true;
+}
