@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2013 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2006-2013 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2006-2008 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -77,7 +77,7 @@ typedef struct {
 
 typedef struct {
   const char *type;
-  unsigned long number;
+  GtUword number;
 } GtTypeTraverseInfo;
 
 static void feature_node_free(GtGenomeNode *gn)
@@ -155,7 +155,9 @@ static void feature_node_change_seqid(GtGenomeNode *gn, GtStr *seqid)
 
 void gt_feature_node_set_source(GtFeatureNode *fn, GtStr *source)
 {
-  gt_assert(fn && source && !fn->source);
+  gt_assert(fn && source);
+  if (fn->source)
+    gt_str_delete(fn->source);
   fn->source = gt_str_ref(source);
   if (fn->observer && fn->observer->source_changed)
     fn->observer->source_changed(fn, source, fn->observer->data);
@@ -229,7 +231,7 @@ static void set_tree_status(unsigned int *bit_field, TreeStatus tree_status)
 }
 
 GtGenomeNode* gt_feature_node_new(GtStr *seqid, const char *type,
-                                  unsigned long start, unsigned long end,
+                                  GtUword start, GtUword end,
                                   GtStrand strand)
 {
   GtGenomeNode *gn;
@@ -258,8 +260,8 @@ GtGenomeNode* gt_feature_node_new(GtStr *seqid, const char *type,
   return gn;
 }
 
-GtGenomeNode* gt_feature_node_new_pseudo(GtStr *seqid, unsigned long start,
-                                         unsigned long end, GtStrand strand)
+GtGenomeNode* gt_feature_node_new_pseudo(GtStr *seqid, GtUword start,
+                                         GtUword end, GtStrand strand)
 {
   GtFeatureNode *pf;
   GtGenomeNode *pn;
@@ -344,7 +346,7 @@ GtFeatureNode* gt_feature_node_clone(const GtFeatureNode *template)
   GtFeatureNode *fn;
   GtStr *seqid;
   const char *type;
-  unsigned long i, start, end;
+  GtUword i, start, end;
   GtStrand strand;
   GtStrArray *attributes;
   gt_assert(template && !gt_feature_node_has_children(template));
@@ -493,6 +495,13 @@ float gt_feature_node_get_score(const GtFeatureNode *fn)
   return fn->score;
 }
 
+void gt_feature_node_get_score_p(const GtFeatureNode *fn, float *val)
+{
+  gt_assert(fn);
+  gt_assert(gt_feature_node_score_is_defined(fn));
+  *val = fn->score;
+}
+
 GtStrand gt_feature_node_get_strand(const GtFeatureNode *fn)
 {
   gt_assert(fn);
@@ -552,7 +561,7 @@ static int save_exons_and_cds(GtFeatureNode *fn, void *data,
 static void set_transcript_types(GtArray *features, GtStrand parent_strand)
 {
   GtFeatureNode *fn;
-  unsigned long i;
+  GtUword i;
   gt_assert(features);
   if (gt_array_size(features)) {
     if (gt_array_size(features) == 1) {
@@ -620,7 +629,7 @@ GtTranscriptFeatureType gt_feature_node_get_transcriptfeaturetype(GtFeatureNode
          TRANSCRIPT_FEATURE_TYPE_MASK;
 }
 
-void gt_feature_node_set_end(GtFeatureNode *fn, unsigned long end)
+void gt_feature_node_set_end(GtFeatureNode *fn, GtUword end)
 {
   gt_assert(fn && fn->range.start <= end);
   fn->range.end = end;
@@ -637,6 +646,15 @@ void gt_feature_node_set_score(GtFeatureNode *fn, float score)
     fn->observer->score_changed(fn, score, fn->observer->data);
 }
 
+void gt_feature_node_set_score_p(GtFeatureNode *fn, float* score)
+{
+  gt_assert(fn);
+  fn->bit_field |= 1 << SCORE_IS_DEFINED_OFFSET;
+  fn->score = *score;
+  if (fn->observer && fn->observer->score_changed)
+    fn->observer->score_changed(fn, *score, fn->observer->data);
+}
+
 void gt_feature_node_unset_score(GtFeatureNode *fn)
 {
   gt_assert(fn);
@@ -693,7 +711,8 @@ void gt_feature_node_remove_attribute(GtFeatureNode *fn,
 }
 
 void gt_feature_node_foreach_attribute(GtFeatureNode *fn,
-                                      AttributeIterFunc iterfunc, void *data)
+                                       GtFeatureNodeAttributeIterFunc iterfunc,
+                                       void *data)
 {
   gt_assert(fn && iterfunc);
   if (fn->attributes) {
@@ -711,7 +730,7 @@ static bool feature_node_has_gft(const GtFeatureNode *fn, const char **fnts)
   gt_assert(fn && fnts && fnts[0] != NULL);
   fni = gt_feature_node_iterator_new(fn);
   while ((child = gt_feature_node_iterator_next(fni))) {
-    unsigned long i = 0;
+    GtUword i = 0;
     while (fnts[i] != NULL) {
       if (gt_feature_node_has_type((GtFeatureNode*) child, fnts[i])) {
         has_gft = true;
@@ -743,11 +762,11 @@ bool gt_feature_node_has_splice_site(const GtFeatureNode *fn)
 }
 
 double gt_feature_node_average_splice_site_prob(const GtFeatureNode *fn,
-                                                unsigned long *num_ss)
+                                                GtUword *num_ss)
 {
   GtFeatureNodeIterator *fni;
   GtFeatureNode *child;
-  unsigned long num_of_splice_sites = 0;
+  GtUword num_of_splice_sites = 0;
   double averagessp = 0.0;
   gt_assert(fn);
   fni = gt_feature_node_iterator_new(fn);
@@ -799,7 +818,7 @@ int gt_feature_node_unit_test(GtError *err)
   seqid = gt_str_new_cstr("seqid");
   fn = gt_feature_node_new(seqid, gt_ft_gene, 1, 1000, GT_STRAND_FORWARD);
 
-  gt_ensure(had_err, !gt_feature_node_score_is_defined((GtFeatureNode*) fn));
+  gt_ensure(!gt_feature_node_score_is_defined((GtFeatureNode*) fn));
 
   gt_genome_node_delete(fn);
   gt_str_delete(seqid);
@@ -852,7 +871,7 @@ int gt_feature_node_traverse_children(GtFeatureNode *feature_node, void *data,
   GtArray *node_stack = NULL, *list_of_children;
   GtFeatureNode *fn, *fn_ref, *child_feature;
   GtDlistelem *dlistelem;
-  unsigned long i;
+  GtUword i;
   GtHashtable *traversed_nodes = NULL;
   bool has_node_with_multiple_parents = false;
   int had_err = 0;
@@ -1047,13 +1066,13 @@ int gt_feature_node_traverse_direct_children(GtFeatureNode *fn,
   return had_err;
 }
 
-unsigned long gt_feature_node_number_of_children(const GtFeatureNode *fn)
+GtUword gt_feature_node_number_of_children(const GtFeatureNode *fn)
 {
   gt_assert(fn);
   return gt_dlist_size(fn->children);
 }
 
-unsigned long gt_feature_node_number_of_children_of_type(const GtFeatureNode
+GtUword gt_feature_node_number_of_children_of_type(const GtFeatureNode
                                                          *parent,
                                                          const GtFeatureNode
                                                          *node)
@@ -1089,17 +1108,26 @@ void gt_feature_node_add_child(GtFeatureNode *parent, GtFeatureNode *child)
     parent->observer->child_added(parent, child, parent->observer->data);
 }
 
+typedef struct {
+  GtFeatureNode *leaf,
+                *parent;
+  bool deleted;
+} GtFeatureNodeLeafDeleteInfo;
+
 static int remove_leaf(GtFeatureNode *node, void *data, GT_UNUSED GtError *err)
 {
-  GtFeatureNode *child, *leaf = (GtFeatureNode*) data;
+  GtFeatureNode *child;
+  GtFeatureNodeLeafDeleteInfo* info = (GtFeatureNodeLeafDeleteInfo*) data;
   GtDlistelem *dlistelem;
   gt_error_check(err);
-  if (node != leaf && node->children) {
+  if (node != info->leaf && node->children) {
     for (dlistelem = gt_dlist_first(node->children); dlistelem != NULL;
          dlistelem = gt_dlistelem_next(dlistelem)) {
       child = (GtFeatureNode*) gt_dlistelem_get_data(dlistelem);
-      if (child == leaf) {
+      if (child == info->leaf) {
         gt_dlist_remove(node->children, dlistelem);
+        gt_genome_node_delete((GtGenomeNode*) child);
+        info->deleted = true;
         break;
       }
     }
@@ -1110,10 +1138,24 @@ static int remove_leaf(GtFeatureNode *node, void *data, GT_UNUSED GtError *err)
 void gt_feature_node_remove_leaf(GtFeatureNode *tree, GtFeatureNode *leafn)
 {
   GT_UNUSED int had_err;
+  GtFeatureNodeLeafDeleteInfo info;
   gt_assert(tree && leafn);
-  gt_assert(!gt_feature_node_number_of_children(leafn));
-  had_err = gt_feature_node_traverse_children(tree, leafn, remove_leaf, true,
+
+  info.leaf = leafn;
+  info.parent = tree;
+  info.deleted = false;
+
+  /* ref child node to enable traversal */
+  gt_genome_node_ref((GtGenomeNode*) leafn);
+  gt_assert(gt_feature_node_number_of_children(leafn) == 0);
+  had_err = gt_feature_node_traverse_children(tree, &info, remove_leaf, true,
                                               NULL);
+  /* unref child node, traversal done */
+  gt_genome_node_delete((GtGenomeNode*) leafn);
+
+  if (info.deleted)
+    set_tree_status(&tree->bit_field, TREE_STATUS_UNDETERMINED);
+
   gt_assert(!had_err); /* cannot happen, remove_leaf() is sane */
 }
 
@@ -1247,7 +1289,7 @@ bool gt_feature_node_overlaps_nodes(GtFeatureNode *fn, GtArray *nodes)
 bool gt_feature_node_overlaps_nodes_mark(GtFeatureNode *fn, GtArray *nodes,
                                          GtBittab *b)
 {
-  unsigned long i;
+  GtUword i;
   GtGenomeNode *node;
   GtRange fn_range, node_range;
   bool rval = false;
@@ -1273,3 +1315,13 @@ bool gt_feature_node_overlaps_nodes_mark(GtFeatureNode *fn, GtArray *nodes,
   }
   return rval;
 }
+
+GtFeatureNode* gt_feature_node_try_cast(GtGenomeNode *gn)
+{
+  return gt_genome_node_try_cast(gt_feature_node_class(), gn);
+}
+
+GtFeatureNode* gt_feature_node_cast(GtGenomeNode *gn)
+{
+  return gt_genome_node_cast(gt_feature_node_class(), gn);
+}
