@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2011 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2006-2011 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2006-2008 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -18,6 +18,7 @@
 #include <stdarg.h>
 #include "core/assert_api.h"
 #include "core/class_alloc.h"
+#include "core/cstr_api.h"
 #include "core/ensure.h"
 #include "core/hashtable.h"
 #include "core/ma.h"
@@ -25,7 +26,7 @@
 #include "core/msort.h"
 #include "core/queue_api.h"
 #include "core/unused_api.h"
-#include "extended/eof_node.h"
+#include "extended/eof_node_api.h"
 #include "extended/genome_node_rep.h"
 #include "extended/gff3_defines.h"
 #include "extended/gff3_visitor_api.h"
@@ -125,9 +126,13 @@ static int compare_genome_node_type(GtGenomeNode *gn_a, GtGenomeNode *gn_b)
   en_a = gt_eof_node_try_cast(gn_a);
   en_b = gt_eof_node_try_cast(gn_b);
 
-  if ((sn_a && !sn_b) || (en_a && !en_b))
+  if (sn_a && !sn_b)
+    return en_b ? -1 : 1;
+  if (!sn_a && sn_b)
+    return en_a ? 1 : -1;
+  if (en_a && !en_b)
     return 1;
-  if ((!sn_a && sn_b) || (!en_a && en_b))
+  if (!en_a && en_b)
     return -1;
 
   return 0;
@@ -156,7 +161,7 @@ int gt_genome_node_cmp(GtGenomeNode *gn_a, GtGenomeNode *gn_b)
 
 static int compare_genome_nodes_with_delta(GtGenomeNode *gn_a,
                                            GtGenomeNode *gn_b,
-                                           unsigned long delta)
+                                           GtUword delta)
 {
   GtRange range_a, range_b;
   int rval;
@@ -189,7 +194,7 @@ GtGenomeNode* gt_genome_node_create(const GtGenomeNodeClass *gnc)
   gn->userdata           = NULL;
   gn->userdata_nof_items = 0;
 #ifdef GT_THREADS_ENABLED
-  gn-> lock              = gt_rwlock_new();
+  gn->lock              = gt_rwlock_new();
 #endif
   return gn;
 }
@@ -246,12 +251,12 @@ GtStr* gt_genome_node_get_idstr(GtGenomeNode *gn)
   return gn->c_class->get_idstr(gn);
 }
 
-unsigned long gt_genome_node_get_start(GtGenomeNode *gn)
+GtUword gt_genome_node_get_start(GtGenomeNode *gn)
 {
   return gt_genome_node_get_range(gn).start;
 }
 
-unsigned long gt_genome_node_get_end(GtGenomeNode *gn)
+GtUword gt_genome_node_get_end(GtGenomeNode *gn)
 {
   return gt_genome_node_get_range(gn).end;
 }
@@ -262,7 +267,7 @@ GtRange gt_genome_node_get_range(GtGenomeNode *gn)
   return gn->c_class->get_range(gn);
 }
 
-unsigned long gt_genome_node_get_length(GtGenomeNode *gn)
+GtUword gt_genome_node_get_length(GtGenomeNode *gn)
 {
   GtRange range;
   gt_assert(gn && gn->c_class && gn->c_class->get_range);
@@ -304,7 +309,7 @@ int gt_genome_node_compare_with_data(GtGenomeNode **gn_a, GtGenomeNode **gn_b,
 int gt_genome_node_compare_delta(GtGenomeNode **gn_a, GtGenomeNode **gn_b,
                                  void *delta)
 {
-  unsigned long *deltaptr = delta;
+  GtUword *deltaptr = delta;
   gt_assert(delta);
   return compare_genome_nodes_with_delta(*gn_a, *gn_b, *deltaptr);
 }
@@ -324,7 +329,7 @@ void gt_genome_nodes_sort_stable(GtArray *nodes)
 void gt_genome_nodes_show(GtArray *nodes, GtFile *outfp)
 {
   GtNodeVisitor *gff3_visitor;
-  unsigned long i;
+  GtUword i;
   gt_assert(nodes);
   gff3_visitor = gt_gff3_visitor_new(outfp);
   for (i = 0; i < gt_array_size(nodes); i++) {
@@ -353,7 +358,7 @@ bool gt_genome_nodes_are_equal_region_nodes(GtGenomeNode *gn_a,
 
 bool gt_genome_nodes_are_sorted(const GtArray *nodes)
 {
-  unsigned long i;
+  GtUword i;
   gt_assert(nodes);
   for (i = 1; i < gt_array_size(nodes); i++) {
     if (gt_genome_node_compare(gt_array_get(nodes, i-1),
@@ -367,18 +372,23 @@ bool gt_genome_nodes_are_sorted(const GtArray *nodes)
 void gt_genome_node_add_user_data(GtGenomeNode *gn, const char *key, void *data,
                                   GtFree free_func)
 {
-  GtGenomeNodeUserData *ud;
+  GtGenomeNodeUserData *ud, *myud;
   gt_assert(gn && key);
   ud = gt_malloc(sizeof (GtGenomeNodeUserData));
   ud->ptr = data;
   ud->free_func = free_func;
   if (!gn->userdata) {
-    gn->userdata = gt_hashmap_new(GT_HASH_STRING, NULL, userdata_delete);
+    gn->userdata = gt_hashmap_new(GT_HASH_STRING, gt_free_func,
+                                  userdata_delete);
   }
-  else /* free old data if overwriting */
-    gt_genome_node_release_user_data(gn, key);
-  gt_hashmap_add(gn->userdata, (char*) key, ud);
-  gn->userdata_nof_items++;
+  gt_assert(gn->userdata != NULL);
+  /* remove old data entry first if there is one */
+  if ((myud = gt_hashmap_get(gn->userdata, key)) != NULL) {
+    gt_hashmap_remove(gn->userdata, key);
+  } else {
+    gn->userdata_nof_items++;
+  }
+  gt_hashmap_add(gn->userdata, gt_cstr_dup((char*) key), ud);
 }
 
 void* gt_genome_node_get_user_data(const GtGenomeNode *gn, const char *key)
@@ -398,8 +408,7 @@ void gt_genome_node_release_user_data(GtGenomeNode *gn, const char *key)
   if (!gn->userdata)
     return;
   if ((ud = (GtGenomeNodeUserData*) gt_hashmap_get(gn->userdata, key))) {
-    gt_hashmap_add(gn->userdata, (char*) key, NULL);
-    userdata_delete(ud);
+    gt_hashmap_remove(gn->userdata, (char*) key);
     if (--gn->userdata_nof_items == 0) {
       gt_hashmap_delete(gn->userdata);
       gn->userdata = NULL;
@@ -425,35 +434,35 @@ int gt_genome_node_unit_test(GtError *err)
   gnc->size = sizeof (GtGenomeNode);
 
   gn = gt_genome_node_create(gnc);
-  gt_ensure(had_err, gt_genome_node_get_user_data(gn, testkey1) == NULL);
-  gt_ensure(had_err, gt_genome_node_get_user_data(gn, testkey2) == NULL);
-  gt_ensure(had_err, gn->userdata_nof_items == 0);
-  gt_ensure(had_err, gn->userdata == NULL);
+  gt_ensure(gt_genome_node_get_user_data(gn, testkey1) == NULL);
+  gt_ensure(gt_genome_node_get_user_data(gn, testkey2) == NULL);
+  gt_ensure(gn->userdata_nof_items == 0);
+  gt_ensure(gn->userdata == NULL);
 
   gt_genome_node_add_user_data(gn, testkey1, testptr1, NULL);
-  gt_ensure(had_err, gt_genome_node_get_user_data(gn, testkey1) != NULL);
-  gt_ensure(had_err, gt_genome_node_get_user_data(gn, testkey1) == testptr1);
-  gt_ensure(had_err, gn->userdata_nof_items == 1);
-  gt_ensure(had_err, gn->userdata != NULL);
+  gt_ensure(gt_genome_node_get_user_data(gn, testkey1) != NULL);
+  gt_ensure(gt_genome_node_get_user_data(gn, testkey1) == testptr1);
+  gt_ensure(gn->userdata_nof_items == 1);
+  gt_ensure(gn->userdata != NULL);
 
   gt_genome_node_add_user_data(gn, testkey2, testptr2, gt_free_func);
-  gt_ensure(had_err, gt_genome_node_get_user_data(gn, testkey2) != NULL);
-  gt_ensure(had_err, gt_genome_node_get_user_data(gn, testkey2) == testptr2);
-  gt_ensure(had_err, gn->userdata_nof_items == 2);
+  gt_ensure(gt_genome_node_get_user_data(gn, testkey2) != NULL);
+  gt_ensure(gt_genome_node_get_user_data(gn, testkey2) == testptr2);
+  gt_ensure(gn->userdata_nof_items == 2);
 
   gt_genome_node_release_user_data(gn, testkey1);
-  gt_ensure(had_err, gt_genome_node_get_user_data(gn, testkey1) == NULL);
-  gt_ensure(had_err, gn->userdata_nof_items == 1);
+  gt_ensure(gt_genome_node_get_user_data(gn, testkey1) == NULL);
+  gt_ensure(gn->userdata_nof_items == 1);
 
   gt_genome_node_release_user_data(gn, testkey2);
-  gt_ensure(had_err, gt_genome_node_get_user_data(gn, testkey2) == NULL);
-  gt_ensure(had_err, gn->userdata_nof_items == 0);
-  gt_ensure(had_err, gn->userdata == NULL);
+  gt_ensure(gt_genome_node_get_user_data(gn, testkey2) == NULL);
+  gt_ensure(gn->userdata_nof_items == 0);
+  gt_ensure(gn->userdata == NULL);
 
   testptr2 = gt_malloc(sizeof (char)*4);
   gt_genome_node_add_user_data(gn, testkey1, testptr1, NULL);
   gt_genome_node_add_user_data(gn, testkey2, testptr2, gt_free_func);
-  gt_ensure(had_err, gn->userdata != NULL);
+  gt_ensure(gn->userdata != NULL);
   gt_genome_node_delete(gn);
 
   gt_free(gnc);
