@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2012 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2006-2013 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2006-2008 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -21,6 +21,7 @@
 #include <string.h>
 #include "core/array.h"
 #include "core/assert_api.h"
+#include "core/compat.h"
 #include "core/cstr_api.h"
 #include "core/hashmap.h"
 #include "core/ma.h"
@@ -28,6 +29,7 @@
 #include "core/parseutils.h"
 #include "core/queue.h"
 #include "core/splitter.h"
+#include "core/symbol_api.h"
 #include "core/undef_api.h"
 #include "core/unused_api.h"
 #include "core/warning_api.h"
@@ -35,6 +37,8 @@
 #include "extended/feature_info.h"
 #include "extended/feature_node.h"
 #include "extended/feature_node_iterator_api.h"
+#include "extended/feature_type.h"
+#include "extended/gap_str.h"
 #include "extended/genome_node.h"
 #include "extended/gff3_defines.h"
 #include "extended/gff3_escaping.h"
@@ -42,6 +46,7 @@
 #include "extended/mapping.h"
 #include "extended/orphanage.h"
 #include "extended/region_node.h"
+#include "extended/xrf_checker_api.h"
 
 struct GtGFF3Parser {
   GtFeatureInfo *feature_info;
@@ -56,10 +61,11 @@ struct GtGFF3Parser {
        eof_emitted,
        gvf_mode;
   GtGenomeNode *gff3_pragma;
-  long offset;
+  GtWord offset;
   GtMapping *offset_mapping;
   GtOrphanage *orphanage;
   GtTypeChecker *type_checker;
+  GtXRFChecker *xrf_checker;
   unsigned int last_terminator; /* line number of the last terminator */
 };
 
@@ -99,13 +105,22 @@ GtGFF3Parser* gt_gff3_parser_new(GtTypeChecker *type_checker)
                                         (GtFree) simple_sequence_region_delete);
   parser->source_to_str_mapping = gt_hashmap_new(GT_HASH_STRING, NULL,
                                                  (GtFree) gt_str_delete);
-  parser->offset = GT_UNDEF_LONG;
+  parser->offset = GT_UNDEF_WORD;
   parser->orphanage = gt_orphanage_new();
   parser->type_checker = type_checker ? gt_type_checker_ref(type_checker)
                                       : NULL;
+  parser->xrf_checker = NULL;
   return parser;
 }
 
+void gt_gff3_parser_set_xrf_checker(GtGFF3Parser *parser,
+                                    GtXRFChecker *xrf_checker)
+{
+  gt_assert(parser && xrf_checker);
+  gt_xrf_checker_delete(parser->xrf_checker);
+  parser->xrf_checker = gt_xrf_checker_ref(xrf_checker);
+}
+
 void gt_gff3_parser_check_id_attributes(GtGFF3Parser *parser)
 {
   gt_assert(parser);
@@ -124,7 +139,7 @@ void gt_gff3_parser_do_not_check_region_boundaries(GtGFF3Parser *parser)
   parser->checkregions = false;
 }
 
-void gt_gff3_parser_set_offset(GtGFF3Parser *parser, long offset)
+void gt_gff3_parser_set_offset(GtGFF3Parser *parser, GtWord offset)
 {
   gt_assert(parser);
   gt_assert(!parser->offset_mapping);
@@ -144,7 +159,7 @@ int gt_gff3_parser_set_offsetfile(GtGFF3Parser *parser, GtStr *offsetfile,
 {
   gt_error_check(err);
   gt_assert(parser);
-  gt_assert(parser->offset == GT_UNDEF_LONG);
+  gt_assert(parser->offset == GT_UNDEF_WORD);
   parser->offset_mapping = gt_mapping_new(offsetfile, "offsets",
                                           GT_MAPPINGTYPE_INTEGER, err);
   if (parser->offset_mapping)
@@ -164,17 +179,50 @@ void gt_gff3_parser_enable_tidy_mode(GtGFF3Parser *parser)
   parser->tidy = true;
 }
 
-static int add_offset_if_necessary(GtRange *range, GtGFF3Parser *parser,
-                                   const char *seqid, GtError *err)
+static int offset_possible(const GtRange *range, GtWord offset,
+                           const char *filename, unsigned int line_number,
+                           GtError *err)
 {
-  long offset;
   int had_err = 0;
   gt_error_check(err);
-  if (parser->offset != GT_UNDEF_LONG)
-    *range = gt_range_offset(range, parser->offset);
+  if (offset < 0) {
+    /* check for underflow */
+    GtUword result = range->start + offset;
+    if (result == 0) {
+      gt_error_set(err, "==0");
+      gt_error_set(err, "adding offset "GT_WD" to node on line %u in file "
+                   "\"%s\" leads to start 0 (GFF3 files are 1-based)",
+                   offset, line_number, filename);
+      had_err = -1;
+    }
+    else if (result > range->start) {
+      gt_error_set(err, "adding offset "GT_WD" to node on line %u in file "
+                   "\"%s\" leads to underflow",
+                   offset, line_number, filename);
+      had_err = -1;
+    }
+  }
+  return had_err;
+}
+
+static int add_offset_if_necessary(GtRange *range, GtGFF3Parser *parser,
+                                   const char *seqid, const char *filename,
+                                   GtUword line_number, GtError *err)
+{
+  int had_err = 0;
+  gt_error_check(err);
+  if (parser->offset != GT_UNDEF_WORD) {
+    had_err = offset_possible(range, parser->offset, filename, line_number,
+                              err);
+    if (!had_err)
+      *range = gt_range_offset(range, parser->offset);
+  }
   else if (parser->offset_mapping) {
+    GtWord offset;
     had_err = gt_mapping_map_integer(parser->offset_mapping, &offset, seqid,
                                      err);
+    if (!had_err)
+      had_err = offset_possible(range, offset, filename, line_number, err);
     if (!had_err)
       *range = gt_range_offset(range, offset);
   }
@@ -224,7 +272,7 @@ static int parse_target_attribute(const char *value, bool tidy,
                                   const char *filename,
                                   unsigned int line_number, GtError *err)
 {
-  unsigned long num_of_tokens;
+  GtUword num_of_tokens;
   GtStr *unescaped_target;
   char *escaped_target;
   GtStrand parsed_strand;
@@ -302,7 +350,7 @@ static int parse_target_attribute(const char *value, bool tidy,
 }
 
 static int parse_target_attributes(const char *values, bool tidy,
-                                   unsigned long *num_of_targets,
+                                   GtUword *num_of_targets,
                                    GtStr *first_target_id,
                                    GtRange *first_target_range,
                                    GtStrand *first_target_strand,
@@ -314,7 +362,7 @@ static int parse_target_attributes(const char *values, bool tidy,
                                    GtError *err)
 {
   GtSplitter *splitter;
-  unsigned long i;
+  GtUword i;
   char *targets;
   int had_err = 0;
   gt_error_check(err);
@@ -338,7 +386,7 @@ static int parse_target_attributes(const char *values, bool tidy,
 }
 
 int gt_gff3_parser_parse_target_attributes(const char *values,
-                                           unsigned long *num_of_targets,
+                                           GtUword *num_of_targets,
                                            GtStr *first_target_id,
                                            GtRange *first_target_range,
                                            GtStrand *first_target_strand,
@@ -385,10 +433,11 @@ static int get_seqid_str(GtStr **seqid_str, const char *seqid, GtRange range,
   }
   else if (parser->checkregions && !ssr->is_circular &&
            !gt_range_contains(&ssr->range, &range) && parser->checkregions) {
-    gt_error_set(err, "range (%lu,%lu) of feature on line %u in file \"%s\" is "
-                 "not contained in range (%lu,%lu) of corresponding sequence "
-                 "region on line %u", range.start, range.end, line_number,
-                 filename, ssr->range.start, ssr->range.end, ssr->line_number);
+    gt_error_set(err, "range ("GT_WU","GT_WU") of feature on line %u in file "
+                 "\"%s\" is not contained in range ("GT_WU","GT_WU") of "
+                 "corresponding sequence region on line %u",
+                 range.start, range.end, line_number, filename,
+                 ssr->range.start, ssr->range.end, ssr->line_number);
     had_err = -1;
   }
 
@@ -546,7 +595,7 @@ static int store_id(const char *id, GtFeatureNode *feature_node,
 static GtArray* find_roots(GtStrArray *parents, GtFeatureInfo *feature_info)
 {
   GtArray *roots;
-  unsigned long i;
+  GtUword i;
   gt_assert(parents);
   roots = gt_array_new(sizeof (GtGenomeNode*));
   for (i = 0; i < gt_str_array_size(parents); i++) {
@@ -560,7 +609,7 @@ static GtArray* find_roots(GtStrArray *parents, GtFeatureInfo *feature_info)
 static bool roots_differ(GtArray *roots)
 {
   GtGenomeNode *first_root;
-  unsigned long i;
+  GtUword i;
   gt_assert(roots);
   first_root = *(GtGenomeNode**) gt_array_get(roots, 0);
   for (i = 1; i < gt_array_size(roots); i++) {
@@ -659,7 +708,7 @@ static void join_roots(GtArray *roots, GtFeatureInfo *feature_info,
                        GtQueue *genome_nodes)
 {
   GtFeatureNode *master_root;
-  unsigned long i;
+  GtUword i;
   gt_assert(roots && feature_info && genome_nodes);
   master_root = *(GtFeatureNode**) gt_array_get(roots, 0);
   for (i = 1; i < gt_array_size(roots); i++) {
@@ -677,7 +726,7 @@ static int process_child(GtGenomeNode *child, GtSplitter *parent_splitter,
 {
   GtStrArray *valid_parents;
   GtGenomeNode* parent_gf;
-  unsigned long i;
+  GtUword i;
   int had_err = 0;
   gt_error_check(err);
   gt_assert(child && parent_splitter && feature_info && genome_nodes);
@@ -769,7 +818,7 @@ static int process_parent_attr(char *parent_attr, GtGenomeNode *feature_node,
   bool orphaned_parent = false;
   GtGenomeNode* parent_gf;
   const char *parent;
-  unsigned long i;
+  GtUword i;
   int had_err = 0;
 
   gt_error_check(err);
@@ -857,19 +906,22 @@ static int check_missing_attributes(GtGenomeNode *this_feature,
                                     const char *id, const char *filename,
                                     GtError *err)
 {
-  unsigned long i;
+  GtUword i;
   int had_err = 0;
   gt_error_check(err);
   gt_assert(this_feature && this_attributes && other_feature);
   for (i = 0; !had_err && i < gt_str_array_size(this_attributes); i++) {
-    if (!gt_feature_node_get_attribute(other_feature,
-                                      gt_str_array_get(this_attributes, i))) {
+    const char *attrkey = gt_str_array_get(this_attributes, i);
+    if (strcmp(attrkey, "ID") != 0 && strcmp(attrkey, "Parent"))
+      continue;
+
+    if (!gt_feature_node_get_attribute(other_feature, attrkey)) {
       gt_error_set(err, "the multi-feature with %s \"%s\" on line %u in file "
                    "\"%s\" does not have a '%s' attribute which is present in "
                    "its counterpart on line %u", GT_GFF_ID, id,
                    gt_genome_node_get_line_number((GtGenomeNode*)
                                                   other_feature),
-                   filename, gt_str_array_get(this_attributes, i),
+                   filename, attrkey,
                    gt_genome_node_get_line_number(this_feature));
       had_err = -1;
       break;
@@ -882,7 +934,7 @@ static int compare_target_attribute(GtFeatureNode *new_gf,
                                     GtFeatureNode *old_gf,
                                     const char *id, GtError *err)
 {
-  unsigned long new_target_num, old_target_num;
+  GtUword new_target_num, old_target_num;
   GtStr *new_target_str, *old_target_str;
   const char *new_target, *old_target;
   int had_err;
@@ -1030,16 +1082,17 @@ static int check_multi_feature_constrains(GtGenomeNode *new_gf,
                                          err);
     }
     if (!had_err) {
-      unsigned long i;
-      gt_assert(gt_str_array_size(new_attributes) ==
-             gt_str_array_size(old_attributes));
+      GtUword i;
       for (i = 0; !had_err && i < gt_str_array_size(new_attributes); i++) {
         const char *attr_name = gt_str_array_get(new_attributes, i);
         if (!strcmp(attr_name, GT_GFF_TARGET)) {
           had_err = compare_target_attribute((GtFeatureNode*) new_gf,
                                              (GtFeatureNode*) old_gf, id, err);
         }
-        else {
+        else if (!strcmp(attr_name, GT_GFF_PARENT) ||
+                 !strcmp(attr_name, GT_GFF_NAME)) {
+          /* we relaxed the check and now only require the 'Parent' and the
+             'Name' attribute to match*/
           had_err = compare_other_attribute(attr_name, (GtFeatureNode*) new_gf,
                                             (GtFeatureNode*) old_gf, id, parser,
                                             err);
@@ -1056,7 +1109,7 @@ void gt_gff3_parser_build_target_str(GtStr *target, GtStrArray *target_ids,
                                      GtArray *target_ranges,
                                      GtArray *target_strands)
 {
-  unsigned long i;
+  GtUword i;
   gt_assert(target && target_ids && target_ranges && target_strands);
   for (i = 0; i < gt_str_array_size(target_ids); i++) {
     GtRange *range;
@@ -1079,39 +1132,41 @@ void gt_gff3_parser_build_target_str(GtStr *target, GtStrArray *target_ids,
 
 static bool invalid_uppercase_gff3_attribute(const char *attr_tag)
 {
-return (strcmp(attr_tag, GT_GFF_ID) &&
-        strcmp(attr_tag, GT_GFF_NAME) &&
-        strcmp(attr_tag, GT_GFF_ALIAS) &&
-        strcmp(attr_tag, GT_GFF_PARENT) &&
-        strcmp(attr_tag, GT_GFF_TARGET) &&
-        strcmp(attr_tag, GT_GFF_GAP) &&
-        strcmp(attr_tag, GT_GFF_DERIVES_FROM) &&
-        strcmp(attr_tag, GT_GFF_NOTE) &&
-        strcmp(attr_tag, GT_GFF_DBXREF) &&
-        strcmp(attr_tag, GT_GFF_ONTOLOGY_TERM) &&
-        strcmp(attr_tag, GT_GFF_IS_CIRCULAR));
+  return (strcmp(attr_tag, GT_GFF_ID) &&
+          strcmp(attr_tag, GT_GFF_NAME) &&
+          strcmp(attr_tag, GT_GFF_ALIAS) &&
+          strcmp(attr_tag, GT_GFF_PARENT) &&
+          strcmp(attr_tag, GT_GFF_TARGET) &&
+          strcmp(attr_tag, GT_GFF_GAP) &&
+          strcmp(attr_tag, GT_GFF_DERIVES_FROM) &&
+          strcmp(attr_tag, GT_GFF_NOTE) &&
+          strcmp(attr_tag, GT_GFF_DBXREF) &&
+          strcmp(attr_tag, GT_GFF_ONTOLOGY_TERM) &&
+          strcmp(attr_tag, GT_GFF_START_RANGE) &&
+          strcmp(attr_tag, GT_GFF_END_RANGE) &&
+          strcmp(attr_tag, GT_GFF_IS_CIRCULAR));
 }
 
 static bool invalid_uppercase_gvf_attribute(const char *attr_tag)
 {
-return (strcmp(attr_tag, GT_GVF_GENOTYPE) &&
-        strcmp(attr_tag, GT_GVF_REFERENCE_SEQ) &&
-        strcmp(attr_tag, GT_GVF_VARIANT_SEQ) &&
-        strcmp(attr_tag, GT_GVF_VARIANT_FREQ) &&
-        strcmp(attr_tag, GT_GVF_VARIANT_EFFECT) &&
-        strcmp(attr_tag, GT_GVF_VARIANT_READS) &&
-        strcmp(attr_tag, GT_GVF_TOTAL_READS) &&
-        strcmp(attr_tag, GT_GVF_PHASED) &&
-        strcmp(attr_tag, GT_GVF_START_RANGE) &&
-        strcmp(attr_tag, GT_GVF_END_RANGE) &&
-        strcmp(attr_tag, GT_GVF_INDIVIDUAL) &&
-        strcmp(attr_tag, GT_GVF_REFERENCE_CODON) &&
-        strcmp(attr_tag, GT_GVF_VARIANT_CODON) &&
-        strcmp(attr_tag, GT_GVF_REFERENCE_AA) &&
-        strcmp(attr_tag, GT_GVF_VARIANT_AA) &&
-        strcmp(attr_tag, GT_GVF_BREAKPOINT_DETAIL) &&
-        strcmp(attr_tag, GT_GVF_SEQUENCE_CONTEXT) &&
-        strcmp(attr_tag, GT_GVF_ZYGOSITY));
+  return (strcmp(attr_tag, GT_GVF_GENOTYPE) &&
+          strcmp(attr_tag, GT_GVF_REFERENCE_SEQ) &&
+          strcmp(attr_tag, GT_GVF_VARIANT_SEQ) &&
+          strcmp(attr_tag, GT_GVF_VARIANT_FREQ) &&
+          strcmp(attr_tag, GT_GVF_VARIANT_EFFECT) &&
+          strcmp(attr_tag, GT_GVF_VARIANT_READS) &&
+          strcmp(attr_tag, GT_GVF_TOTAL_READS) &&
+          strcmp(attr_tag, GT_GVF_PHASED) &&
+          strcmp(attr_tag, GT_GVF_START_RANGE) &&
+          strcmp(attr_tag, GT_GVF_END_RANGE) &&
+          strcmp(attr_tag, GT_GVF_INDIVIDUAL) &&
+          strcmp(attr_tag, GT_GVF_REFERENCE_CODON) &&
+          strcmp(attr_tag, GT_GVF_VARIANT_CODON) &&
+          strcmp(attr_tag, GT_GVF_REFERENCE_AA) &&
+          strcmp(attr_tag, GT_GVF_VARIANT_AA) &&
+          strcmp(attr_tag, GT_GVF_BREAKPOINT_DETAIL) &&
+          strcmp(attr_tag, GT_GVF_SEQUENCE_CONTEXT) &&
+          strcmp(attr_tag, GT_GVF_ZYGOSITY));
 }
 
 static int parse_attributes(char *attributes, GtGenomeNode *feature_node,
@@ -1122,7 +1177,7 @@ static int parse_attributes(char *attributes, GtGenomeNode *feature_node,
 {
   GtSplitter *attribute_splitter, *tmp_splitter, *parent_splitter;
   char *id_value = NULL, *parent_value = NULL;
-  unsigned long i;
+  GtUword i;
   int had_err = 0;
 
   gt_error_check(err);
@@ -1287,7 +1342,6 @@ static int parse_attributes(char *attributes, GtGenomeNode *feature_node,
           GtStrArray *target_ids;
           GtArray *target_ranges, *target_strands;
           /* try to tidy up the ``Target'' attributes */
-          had_err = 0;
           gt_error_unset(err);
           target_ids = gt_str_array_new();
           target_ranges = gt_array_new(sizeof (GtRange));
@@ -1313,6 +1367,44 @@ static int parse_attributes(char *attributes, GtGenomeNode *feature_node,
           gt_str_array_delete(target_ids);
         }
       }
+      else if (!strcmp(attr_tag, GT_GFF_DBXREF)
+                 || !strcmp(attr_tag, GT_GFF_ONTOLOGY_TERM)) {
+        if (parser->xrf_checker) {
+          if (!gt_xrf_checker_is_valid(parser->xrf_checker, attr_value, err)) {
+            had_err = -1;
+          }
+        }
+      }
+      else if (parser->type_checker && !strcmp(attr_tag, GT_GFF_GAP)) {
+        GtGapStr *gs = NULL;
+        GtRange rng = gt_genome_node_get_range(feature_node);
+        if (gt_type_checker_is_a(parser->type_checker,
+                                 gt_symbol("protein_match"),
+                                 gt_feature_node_get_type((GtFeatureNode*)
+                                                          feature_node))) {
+          gs = gt_gap_str_new_protein(attr_value, err);
+        } else {
+          gs = gt_gap_str_new_nucleotide(attr_value, err);
+        }
+        if (!gs) {
+          gt_assert(gt_error_is_set(err));
+          had_err = -1;
+        }
+        if (!had_err) {
+          if (gt_range_length(&rng) != gt_gap_str_length_reference(gs)) {
+            gt_error_set(err, "length of aligned reference in %s attribute on "
+                              "line %u in file \"%s\" (" GT_WU ") does not "
+                              "match the length of its %s feature (" GT_WU ")",
+                         GT_GFF_GAP, line_number, filename,
+                         gt_gap_str_length_reference(gs),
+                         gt_feature_node_get_type((GtFeatureNode*)
+                                                  feature_node),
+                         gt_range_length(&rng));
+            had_err = -1;
+          }
+        }
+        gt_gap_str_delete(gs);
+      }
     }
   }
 
@@ -1357,6 +1449,20 @@ static void set_source(GtFeatureNode *feature_node, const char *source,
   gt_feature_node_set_source(feature_node, source_str);
 }
 
+void chomp_seqid(char *seqid, const char *filename, unsigned int line_number)
+{
+  GtUword len;
+  if (!seqid) return;
+  len = strlen(seqid);
+  if (len > 0) {
+    if (seqid[len-1] == ' ') {
+      gt_warning("seqid \"%s\" on line %u in file \"%s\" ends with a blank, "
+                 "removing it", seqid, line_number, filename);
+      (void) gt_cstr_rtrim(seqid, ' ');
+    }
+  }
+}
+
 static int parse_gff3_feature_line(GtGFF3Parser *parser,
                                    GtQueue *genome_nodes,
                                    GtCstrTable *used_types, char *line,
@@ -1448,8 +1554,10 @@ static int parse_gff3_feature_line(GtGFF3Parser *parser,
                    "(GFF3 files are 1-based)", line_number, filename);
       had_err = -1;
   }
-  if (!had_err)
-    had_err = add_offset_if_necessary(&range, parser, seqid, err);
+  if (!had_err) {
+    had_err = add_offset_if_necessary(&range, parser, seqid, filename,
+                                      line_number, err);
+  }
 
   /* parse the score */
   if (!had_err) {
@@ -1467,6 +1575,9 @@ static int parse_gff3_feature_line(GtGFF3Parser *parser,
   if (!had_err)
     had_err = gt_parse_phase(&phase_value, phase, line_number, filename, err);
 
+  if (!had_err)
+    chomp_seqid(seqid, filename, line_number);
+
   /* get seqid */
   if (!had_err) {
     had_err = get_seqid_str(&seqid_str, seqid, range, parser, filename,
@@ -1517,7 +1628,7 @@ static int parse_gff3_feature_line(GtGFF3Parser *parser,
 
 static int parse_first_gff3_line(const char *line, const char *filename,
                                  GtQueue *genome_nodes, GtStr *filenamestr,
-                                 unsigned long long *line_number,
+                                 GtUint64 *line_number,
                                  bool *gvf_mode,
                                  bool tidy, GtError *err)
 {
@@ -1636,7 +1747,7 @@ static int process_orphans(GtOrphanage *orphanage, GtFeatureInfo *feature_info,
     const char *parent_attr;
     char *parent_attr_dup;
     GtSplitter *splitter;
-    unsigned long i;
+    GtUword i;
     parent_attr = gt_feature_node_get_attribute((GtFeatureNode*) orphan,
                                                 GT_GFF_PARENT);
     gt_assert(parent_attr);
@@ -1766,7 +1877,7 @@ static int parse_meta_gff3_line(GtGFF3Parser *parser, GtQueue *genome_nodes,
     tmplineend = line + line_length - 1;
 
     /* skip blanks */
-    while (tmpline[0] == ' ')
+    while (tmpline[0] == ' ' || tmpline[0] == '\t')
       tmpline++;
     if (tmpline > tmplineend) {
       gt_error_set(err, "missing sequence region name on line %u in file "
@@ -1828,8 +1939,10 @@ static int parse_meta_gff3_line(GtGFF3Parser *parser, GtQueue *genome_nodes,
                    "(GFF3 files are 1-based)", line_number, filename);
       had_err = -1;
     }
-    if (!had_err)
-      had_err = add_offset_if_necessary(&range, parser, seqid, err);
+    if (!had_err) {
+      had_err = add_offset_if_necessary(&range, parser, seqid, filename,
+                                        line_number, err);
+    }
     if (!had_err) {
       /* now we can create a sequence region node */
       gt_assert(seqid);
@@ -1967,7 +2080,7 @@ int gt_gff3_parser_parse_genome_nodes(GtGFF3Parser *parser, int *status_code,
                                       GtQueue *genome_nodes,
                                       GtCstrTable *used_types,
                                       GtStr *filenamestr,
-                                      unsigned long long *line_number,
+                                      GtUint64 *line_number,
                                       GtFile *fpin, GtError *err)
 {
   size_t line_length;
@@ -2003,7 +2116,7 @@ int gt_gff3_parser_parse_genome_nodes(GtGFF3Parser *parser, int *status_code,
       gt_assert(had_err == 0); /* line not processed */
     }
     if (line_length == 0) {
-      gt_warning("skipping blank line %llu in file \"%s\"", *line_number,
+      gt_warning("skipping blank line "GT_LLU" in file \"%s\"", *line_number,
                  filename);
     }
     else if (parser->fasta_parsing || line[0] == '>') {
@@ -2031,8 +2144,12 @@ int gt_gff3_parser_parse_genome_nodes(GtGFF3Parser *parser, int *status_code,
   }
 
   if (!had_err && rval == EOF && *line_number == 0) {
-    gt_error_set(err, "GFF3 file \"%s\" is empty", gt_str_get(filenamestr));
-    had_err = -1;
+    if (parser->tidy) {
+      gt_warning("GFF3 file \"%s\" is empty", gt_str_get(filenamestr));
+    } else {
+      gt_error_set(err, "GFF3 file \"%s\" is empty", gt_str_get(filenamestr));
+      had_err = -1;
+    }
   }
 
   if (!had_err && !parser->strict) {
@@ -2081,5 +2198,6 @@ void gt_gff3_parser_delete(GtGFF3Parser *parser)
   gt_mapping_delete(parser->offset_mapping);
   gt_orphanage_delete(parser->orphanage);
   gt_type_checker_delete(parser->type_checker);
+  gt_xrf_checker_delete(parser->xrf_checker);
   gt_free(parser);
 }
