@@ -21,7 +21,6 @@
 #ifndef S_SPLINT_S
 #include <ctype.h>
 #include <fcntl.h>
-#include <sys/mman.h>
 #include <sys/stat.h>
 #include <unistd.h>
 #endif
@@ -31,6 +30,7 @@
 #include "core/arraydef.h"
 #include "core/assert_api.h"
 #include "core/chardef.h"
+#include "core/compat.h"
 #include "core/fa.h"
 #include "core/fileutils_api.h"
 #include "core/intbits.h"
@@ -43,11 +43,12 @@
 #include "core/unused_api.h"
 #include "core/xansi_api.h"
 #include "extended/bitoutstream.h"
+#include "extended/cstr_iterator.h"
 #include "extended/encdesc.h"
 #include "extended/fasta_header_iterator.h"
 #include "extended/hcr.h"
 #include "extended/rbtree.h"
-#include "extended/cstr_iterator.h"
+#include "extended/sampling.h"
 
 #define HCR_LOWESTQUALVALUE 0
 #define HCR_HIGHESTQUALVALUE 127U
@@ -57,96 +58,96 @@
 #define HCR_PAGES_PER_CHUNK 10UL
 
 typedef struct GtBaseQualDistr {
-  unsigned ncols,
-           nrows,
-           max_qual,
-           min_qual,
-           wildcard_indx,
-           qrange_start,
-           qual_offset,
-           qrange_end;
-  unsigned long long **distr;
-  GtAlphabet *alpha;
+  GtUint64 **distr;
+  GtAlphabet          *alpha;
+  unsigned int         ncols,
+                       nrows,
+                       max_qual,
+                       min_qual,
+                       wildcard_indx,
+                       qrange_start,
+                       qual_offset,
+                       qrange_end;
 } GtBaseQualDistr;
 
 typedef struct FastqFileInfo {
-  unsigned long readlength,
+  GtUword readlength,
                 readnum;
 } FastqFileInfo;
 
 typedef struct GtHcrSeqEncoder {
-  GtHuffman *huffman;
-  unsigned qual_offset;
-  unsigned long num_of_files;
-  long startofsamplingtab,
-       start_of_encoding;
-  unsigned long long total_num_of_symbols;
-  GtAlphabet *alpha;
-  FastqFileInfo *fileinfos;
-  GtQualRange qrange;
-  GtSampling *sampling;
+  GtQualRange        qrange;
+  FastqFileInfo     *fileinfos;
+  GtAlphabet        *alpha;
+  GtHuffman         *huffman;
+  GtSampling        *sampling;
+  GtUint64 total_num_of_symbols;
+  GtUword      num_of_files;
+  GtWord               startofsamplingtab,
+                     start_of_encoding;
+  unsigned int       qual_offset;
 } GtHcrSeqEncoder;
 
 struct GtHcrEncoder {
-  GtHcrSeqEncoder *seq_encoder;
   GtEncdescEncoder *encdesc_encoder;
-  unsigned long num_of_reads,
-                num_of_files,
-                sampling_rate;
-  GtStrArray *files;
-  bool page_sampling,
-       regular_sampling;
-  long pagesize;
+  GtHcrSeqEncoder  *seq_encoder;
+  GtStrArray       *files;
+  GtUword     num_of_reads,
+                    num_of_files,
+                    sampling_rate,
+                    pagesize;
+  bool              page_sampling,
+                    regular_sampling;
 };
 
 typedef struct hcr_huff_mem_info {
-  char *path;
-  size_t start,
-         end,
-         pos;
-  unsigned long pages_per_chunk,
-                bitseq_per_chunk;
-  long pagesize,
-       blocksize;
-  bool first;
-  void *data;
+  char         *path;
+  void         *data;
+  size_t        start,
+                end,
+                pos;
+  GtUword pages_per_chunk,
+                bitseq_per_chunk,
+                pagesize,
+                blocksize;
+  bool          first;
 } HcrHuffDataIterator;
 
 typedef struct GtHcrSeqDecoder {
-  unsigned alphabet_size,
-           qual_offset;
-  long start_of_encoding;
-  unsigned long readlength,
-                cur_read,
-                num_of_reads,
-                num_of_files;
-  FastqFileInfo *fileinfos;
-  GtAlphabet *alpha;
-  GtArray *symbols;
-  GtBitsequence *bitseq_buffer;
-  GtHuffman *huffman;
-  GtHuffmanDecoder *huff_dec;
-  GtRBTree *file_info_rbt;
-  GtSampling *sampling;
-  GtStr *filename;
+  FastqFileInfo       *fileinfos;
+  GtAlphabet          *alpha;
+  GtArray             *symbols;
+  GtBitsequence       *bitseq_buffer;
+  GtHuffman           *huffman;
+  GtHuffmanDecoder    *huff_dec;
+  GtRBTree            *file_info_rbt;
+  GtSampling          *sampling;
+  GtStr               *filename;
   HcrHuffDataIterator *data_iter;
+  GtUword        readlength,
+                       cur_read,
+                       num_of_reads,
+                       num_of_files;
+  GtWord                 start_of_encoding;
+  unsigned int         alphabet_size,
+                       qual_offset;
 } GtHcrSeqDecoder;
 
 struct GtHcrDecoder {
-  GtEncdesc *encdesc;
+  GtEncdesc       *encdesc;
   GtHcrSeqDecoder *seq_dec;
 };
 
 typedef struct WriteNodeInfo {
+  FILE       *output;
   GtAlphabet *alpha;
-  unsigned qual_offset;
-  FILE *output;
+  unsigned    qual_offset;
 } WriteNodeInfo;
 
-static unsigned long long hcr_base_qual_distr_func(const void *distr,
-                                                   unsigned long symbol)
+static GtUint64 hcr_base_qual_distr_func(const void *distr,
+                                                   GtUword symbol)
 {
-  unsigned long long value;
+  GtUint64 value;
   GtBaseQualDistr *bqd = (GtBaseQualDistr*)distr;
   value = bqd->distr[symbol / bqd->ncols][symbol % bqd->ncols];
   return value;
@@ -155,13 +156,13 @@ static unsigned long long hcr_base_qual_distr_func(const void *distr,
 static void hcr_base_qual_distr_trim(GtBaseQualDistr *bqd)
 {
   if (bqd->min_qual != 0) {
-    unsigned long long **distr_trimmed;
+    GtUint64 **distr_trimmed;
     unsigned nrows_new,
              i,
              j;
 
     nrows_new = bqd->max_qual - bqd->min_qual + 1;
-    gt_array2dim_calloc(distr_trimmed, (unsigned long) nrows_new, bqd->ncols);
+    gt_array2dim_calloc(distr_trimmed, (GtUword) nrows_new, bqd->ncols);
 
     for (i = 0; i < nrows_new; i++)
       for (j = 0; j < bqd->ncols; j++)
@@ -183,9 +184,9 @@ static GtBaseQualDistr* hcr_base_qual_distr_new_from_file(FILE *fp,
   unsigned alpha_size,
            min_qual = HCR_HIGHESTQUALVALUE,
            max_qual = HCR_LOWESTQUALVALUE;
-  unsigned long numofleaves,
+  GtUword numofleaves,
                 i;
-  unsigned long long cur_freq;
+  GtUint64 cur_freq;
   GT_UNUSED size_t read,
             one = (size_t) 1;
 
@@ -243,9 +244,9 @@ static GtBaseQualDistr* hcr_base_qual_distr_new(GtAlphabet *alpha,
 }
 
 static int hcr_base_qual_distr_add(GtBaseQualDistr *bqd, const GtUchar *qual,
-                                   const GtUchar *seq, unsigned long len)
+                                   const GtUchar *seq, GtUword len)
 {
-  unsigned long i;
+  GtUword i;
   unsigned cur_char_code,
            cur_qual;
 
@@ -299,10 +300,10 @@ static int hcr_cmp_FastqFileInfo(const void *node1, const void *node2,
   return 0;
 }
 
-static unsigned long hcr_write_seq(GtHcrSeqEncoder *seq_encoder,
+static GtUword hcr_write_seq(GtHcrSeqEncoder *seq_encoder,
                                    const GtUchar *seq,
                                    const GtUchar *qual,
-                                   unsigned long len,
+                                   GtUword len,
                                    GtBitOutStream *bitstream,
                                    bool dry)
 {
@@ -310,7 +311,7 @@ static unsigned long hcr_write_seq(GtHcrSeqEncoder *seq_encoder,
            cur_char_code,
            cur_qual,
            symbol;
-  unsigned long i,
+  GtUword i,
                 written_bits = 0;
   GtBitsequence code;
 
@@ -335,7 +336,7 @@ static unsigned long hcr_write_seq(GtHcrSeqEncoder *seq_encoder,
     cur_qual = cur_qual - seq_encoder->qual_offset;
 
     symbol = gt_alphabet_size(seq_encoder->alpha) * cur_qual + cur_char_code;
-    gt_huffman_encode(seq_encoder->huffman, (unsigned long) symbol,
+    gt_huffman_encode(seq_encoder->huffman, (GtUword) symbol,
                       &code, &bits_to_write);
     written_bits += bits_to_write;
     if (!dry) {
@@ -348,13 +349,13 @@ static unsigned long hcr_write_seq(GtHcrSeqEncoder *seq_encoder,
 static int hcr_write_seqs(FILE *fp, GtHcrEncoder *hcr_enc, GtError *err)
 {
   int had_err = 0, seqit_err;
-  unsigned long bits_to_write = 0,
+  GtUword bits_to_write = 0,
                 len,
                 read_counter = 0,
                 page_counter = 0,
                 bits_left_in_page,
                 cur_read = 0;
-  long filepos;
+  GtWord filepos;
   GtSeqIterator *seqit;
   const GtUchar *seq,
                 *qual;
@@ -450,7 +451,7 @@ static int hcr_write_seqs(FILE *fp, GtHcrEncoder *hcr_enc, GtError *err)
     }
     else {
     hcr_enc->seq_encoder->startofsamplingtab = filepos;
-    gt_log_log("start of samplingtab: %lu",
+    gt_log_log("start of samplingtab: "GT_WU"",
                hcr_enc->seq_encoder->startofsamplingtab);
     if (hcr_enc->seq_encoder->sampling != NULL)
       gt_sampling_write(hcr_enc->seq_encoder->sampling, fp);
@@ -461,8 +462,8 @@ static int hcr_write_seqs(FILE *fp, GtHcrEncoder *hcr_enc, GtError *err)
   return had_err;
 }
 
-static int hcr_huffman_write_base_qual_freq(unsigned long symbol,
-                                            unsigned long long freq,
+static int hcr_huffman_write_base_qual_freq(GtUword symbol,
+                                            GtUint64 freq,
                                             GT_UNUSED GtBitsequence code,
                                             GT_UNUSED unsigned code_length,
                                             void *pt)
@@ -490,7 +491,7 @@ static int hcr_write_seqdistrtab(FILE *fp, GtHcrEncoder *hcr_enc)
 {
   WriteNodeInfo *info;
   int had_err = 0;
-  unsigned long numofleaves;
+  GtUword numofleaves;
 
   info = gt_calloc((size_t) 1, sizeof (WriteNodeInfo));
   info->alpha = hcr_enc->seq_encoder->alpha;
@@ -509,7 +510,7 @@ static int hcr_write_seqdistrtab(FILE *fp, GtHcrEncoder *hcr_enc)
 
 static void hcr_write_file_info(FILE *fp, GtHcrEncoder *hcr_enc)
 {
-  unsigned long i;
+  GtUword i;
 
   gt_xfwrite_one(&hcr_enc->num_of_files, fp);
 
@@ -524,8 +525,8 @@ static int hcr_write_seq_qual_data(const char *name, GtHcrEncoder *hcr_enc,
 {
   int had_err = 0;
   FILE *fp;
-  unsigned long dummy = 0;
-  long pos;
+  GtUword dummy = 0;
+  GtWord pos;
 
   gt_error_check(err);
 
@@ -578,7 +579,7 @@ static int hcr_write_seq_qual_data(const char *name, GtHcrEncoder *hcr_enc,
 
 static void hcr_read_file_info(GtHcrSeqDecoder *seq_dec, FILE *fp)
 {
-  unsigned long i;
+  GtUword i;
   GT_UNUSED size_t read,
             one = (size_t) 1;
 
@@ -597,8 +598,8 @@ static void hcr_read_file_info(GtHcrSeqDecoder *seq_dec, FILE *fp)
 }
 
 static HcrHuffDataIterator *decoder_init_data_iterator(
-                                                long start_of_encoding,
-                                                long end_of_encoding,
+                                                GtWord start_of_encoding,
+                                                GtWord end_of_encoding,
                                                 const GtStr *filename)
 {
   HcrHuffDataIterator *data_iter = gt_malloc(sizeof (*data_iter));
@@ -606,7 +607,7 @@ static HcrHuffDataIterator *decoder_init_data_iterator(
   data_iter->pos = data_iter->start = (size_t) start_of_encoding;
   data_iter->end = (size_t) end_of_encoding;
   data_iter->pages_per_chunk = HCR_PAGES_PER_CHUNK;
-  data_iter->pagesize = sysconf((int) _SC_PAGESIZE);
+  data_iter->pagesize = gt_pagesize();
   gt_assert(data_iter->start % data_iter->pagesize == 0);
   data_iter->blocksize = data_iter->pagesize * data_iter->pages_per_chunk;
   gt_safe_assign(data_iter->bitseq_per_chunk,
@@ -616,9 +617,9 @@ static HcrHuffDataIterator *decoder_init_data_iterator(
 }
 
 static int get_next_file_chunk_for_huffman(GtBitsequence **bits,
-                                           unsigned long *length,
-                                           unsigned long *offset,
-                                           unsigned long *pad_length,
+                                           GtUword *length,
+                                           GtUword *offset,
+                                           GtUword *pad_length,
                                            void *meminfo)
 {
   const int empty = 0,
@@ -628,7 +629,7 @@ static int get_next_file_chunk_for_huffman(GtBitsequence **bits,
   gt_assert(bits && length && offset && pad_length);
   data_iter = (HcrHuffDataIterator*) meminfo;
 
-  gt_log_log("pos in iter: %lu", (unsigned long) data_iter->pos);
+  gt_log_log("pos in iter: "GT_WU"", (GtUword) data_iter->pos);
   if (data_iter->pos < data_iter->end) {
     gt_fa_xmunmap(data_iter->data);
     data_iter->data = NULL;
@@ -665,7 +666,7 @@ static void reset_data_iterator_to_pos(HcrHuffDataIterator *data_iter,
   gt_assert(pos < data_iter->end);
   gt_assert(data_iter->start <= pos);
   gt_fa_xmunmap(data_iter->data);
-  gt_log_log("reset to pos: %lu", (unsigned long) pos);
+  gt_log_log("reset to pos: "GT_WU"", (GtUword) pos);
   data_iter->data = NULL;
   data_iter->pos = pos;
 }
@@ -684,11 +685,11 @@ static void data_iterator_delete(HcrHuffDataIterator *data_iter)
 }
 
 static GtRBTree *seq_decoder_init_file_info(FastqFileInfo *fileinfos,
-                                            unsigned long num_off_files)
+                                            GtUword num_off_files)
 {
   GtRBTree *tree;
-  bool nodecreated;
-  unsigned long i;
+  bool nodecreated = false;
+  GtUword i;
 
   tree = gt_rbtree_new(hcr_cmp_FastqFileInfo, NULL, NULL);
   for (i = 0; i < num_off_files; i++) {
@@ -698,10 +699,10 @@ static GtRBTree *seq_decoder_init_file_info(FastqFileInfo *fileinfos,
   return tree;
 }
 
-static inline long decoder_calc_start_of_encoded_data(FILE *fp)
+static inline GtWord decoder_calc_start_of_encoded_data(FILE *fp)
 {
   bool is_not_at_pageborder;
-  long pagesize = sysconf((int) _SC_PAGESIZE);
+  GtUword pagesize = gt_pagesize();
 
   is_not_at_pageborder = (ftell(fp) % pagesize) != 0;
 
@@ -712,7 +713,7 @@ static inline long decoder_calc_start_of_encoded_data(FILE *fp)
 }
 
 static void seq_decoder_init_huffman(GtHcrSeqDecoder *seq_dec,
-                                     long end_of_encoding,
+                                     GtWord end_of_encoding,
                                      GtBaseQualDistr *bqd,
                                      GtError *err)
 {
@@ -722,7 +723,7 @@ static void seq_decoder_init_huffman(GtHcrSeqDecoder *seq_dec,
 
   gt_assert(seq_dec->data_iter);
   seq_dec->huffman = gt_huffman_new(bqd, hcr_base_qual_distr_func,
-                                    (unsigned long) bqd->ncols * bqd->nrows);
+                                    (GtUword) bqd->ncols * bqd->nrows);
 
   seq_dec->huff_dec = gt_huffman_decoder_new_from_memory(seq_dec->huffman,
                                                 get_next_file_chunk_for_huffman,
@@ -749,7 +750,7 @@ static GtHcrSeqDecoder *hcr_seq_decoder_new(GtAlphabet *alpha, const char *name,
 {
   GtHcrSeqDecoder *seq_dec = gt_malloc(sizeof (GtHcrSeqDecoder));
   GtBaseQualDistr *bqd = NULL;
-  long end_enc_start_sampling = 0;
+  GtWord end_enc_start_sampling = 0;
   FILE *fp = NULL;
   GT_UNUSED size_t read,
             one = (size_t) 1;
@@ -843,13 +844,13 @@ bool gt_hcr_decoder_has_descs_support(GtHcrDecoder *hcr_dec)
 }
 
 static inline char get_qual_from_symbol(GtHcrSeqDecoder *seq_dec,
-                                        unsigned long symbol)
+                                        GtUword symbol)
 {
   return (char) (symbol / seq_dec->alphabet_size + seq_dec->qual_offset);
 }
 
 static unsigned char get_base_from_symbol(GtHcrSeqDecoder *seq_dec,
-                                 unsigned long symbol)
+                                 GtUword symbol)
 {
   unsigned char base = (unsigned char) symbol % seq_dec->alphabet_size;
   if (base == (unsigned char) seq_dec->alphabet_size)
@@ -861,15 +862,15 @@ static int hcr_next_seq_qual(GtHcrSeqDecoder *seq_dec, char *seq, char *qual,
                              GtError *err)
 {
   enum state {
-    ERROR = -1,
+    HCR_ERROR = -1,
     END,
     SUCCESS
   };
   unsigned char base;
-  unsigned long i,
+  GtUword i,
                 nearestsample,
                 *symbol;
-  size_t startofnearestsample;
+  size_t startofnearestsample = 0;
   enum state status = END;
   FastqFileInfo cur_read;
   FastqFileInfo *fileinfo = NULL;
@@ -877,12 +878,12 @@ static int hcr_next_seq_qual(GtHcrSeqDecoder *seq_dec, char *seq, char *qual,
   if (seq_dec->cur_read <= seq_dec->num_of_reads) {
     status = SUCCESS;
     if (seq_dec->symbols == NULL)
-      seq_dec->symbols = gt_array_new(sizeof (unsigned long));
+      seq_dec->symbols = gt_array_new(sizeof (GtUword));
     else
       gt_array_reset(seq_dec->symbols);
 
     cur_read.readnum = seq_dec->cur_read;
-    gt_log_log("cur_read: %lu",seq_dec->cur_read);
+    gt_log_log("cur_read: "GT_WU"",seq_dec->cur_read);
     fileinfo = (FastqFileInfo *)gt_rbtree_next_key(seq_dec->file_info_rbt,
                                                    &cur_read,
                                                    hcr_cmp_FastqFileInfo,
@@ -899,21 +900,21 @@ static int hcr_next_seq_qual(GtHcrSeqDecoder *seq_dec, char *seq, char *qual,
       reset_data_iterator_to_pos(seq_dec->data_iter, startofnearestsample);
       (void) gt_huffman_decoder_get_new_mem_chunk(seq_dec->huff_dec, err);
       if (gt_error_is_set(err))
-        status = ERROR;
+        status = HCR_ERROR;
     }
-    if (status != ERROR) {
+    if (status != HCR_ERROR) {
       int ret;
       ret =  gt_huffman_decoder_next(seq_dec->huff_dec, seq_dec->symbols,
                                      fileinfo->readlength, err);
       if (ret != 1)
-        status = ERROR;
+        status = HCR_ERROR;
       if (ret == 0)
         gt_error_set(err, "reached end of file");
     }
     if (qual || seq) {
       gt_log_log("set strings");
       for (i = 0; i < gt_array_size(seq_dec->symbols); i++) {
-        symbol = (unsigned long*) gt_array_get(seq_dec->symbols, i);
+        symbol = (GtUword*) gt_array_get(seq_dec->symbols, i);
         if (qual != NULL)
           qual[i] = get_qual_from_symbol(seq_dec, *symbol);
         if (seq != NULL) {
@@ -932,10 +933,10 @@ static int hcr_next_seq_qual(GtHcrSeqDecoder *seq_dec, char *seq, char *qual,
   return (int) status;
 }
 
-int gt_hcr_decoder_decode(GtHcrDecoder *hcr_dec, unsigned long readnum,
+int gt_hcr_decoder_decode(GtHcrDecoder *hcr_dec, GtUword readnum,
                           char *seq, char *qual, GtStr *desc, GtError *err)
 {
-  unsigned long nearestsample = 0,
+  GtUword nearestsample = 0,
                 reads_to_read = 0,
                 idx,
                 current_read = hcr_dec->seq_dec->cur_read ;
@@ -976,9 +977,9 @@ int gt_hcr_decoder_decode(GtHcrDecoder *hcr_dec, unsigned long readnum,
         reads_to_read = readnum - nearestsample;
         hcr_dec->seq_dec->cur_read = nearestsample;
       }
-      gt_log_log("reads to read: %lu, nearest sample: %lu",
+      gt_log_log("reads to read: "GT_WU", nearest sample: "GT_WU"",
                  reads_to_read,nearestsample);
-      gt_log_log("start of nearest: %lu", (unsigned long) startofnearestsample);
+      gt_log_log("start of nearest: "GT_WU"", (GtUword) startofnearestsample);
     }
     else {
       if (current_read <= readnum)
@@ -1009,7 +1010,7 @@ int gt_hcr_decoder_decode(GtHcrDecoder *hcr_dec, unsigned long readnum,
 
   if (hcr_dec->encdesc != NULL) {
     if (gt_encdesc_decode(hcr_dec->encdesc, readnum, desc, err) == -1) {
-      gt_error_set(err, "cannot retrieve description with number %lu."
+      gt_error_set(err, "cannot retrieve description with number " GT_WU "."
                    "(%d)", readnum, __LINE__);
       return -1;
     }
@@ -1018,14 +1019,14 @@ int gt_hcr_decoder_decode(GtHcrDecoder *hcr_dec, unsigned long readnum,
 }
 
 int gt_hcr_decoder_decode_range(GtHcrDecoder *hcr_dec, const char *name,
-                                unsigned long start, unsigned long end,
+                                GtUword start, GtUword end,
                                 GtTimer *timer, GtError *err)
 {
   char qual[BUFSIZ] = {0},
        seq[BUFSIZ] = {0};
   GtStr *desc = gt_str_new();
   int had_err = 0;
-  unsigned long cur_width,
+  GtUword cur_width,
                 cur_read;
   size_t i;
   FILE *output;
@@ -1050,7 +1051,7 @@ int gt_hcr_decoder_decode_range(GtHcrDecoder *hcr_dec, const char *name,
       if (hcr_dec->encdesc != NULL)
         gt_xfputs(gt_str_get(desc), output);
       else
-        fprintf(output, "%lu", cur_read);
+        fprintf(output, ""GT_WU"", cur_read);
       gt_xfputc('\n', output);
       for (i = 0, cur_width = 0; i < strlen(seq); i++, cur_width++) {
         if (cur_width == HCR_LINEWIDTH) {
@@ -1077,14 +1078,14 @@ int gt_hcr_decoder_decode_range(GtHcrDecoder *hcr_dec, const char *name,
   return had_err;
 }
 
-unsigned long gt_hcr_decoder_num_of_reads(GtHcrDecoder *hcr_dec)
+GtUword gt_hcr_decoder_num_of_reads(GtHcrDecoder *hcr_dec)
 {
   gt_assert(hcr_dec);
   return hcr_dec->seq_dec->num_of_reads;
 }
 
-unsigned long gt_hcr_decoder_readlength(GtHcrDecoder *hcr_dec,
-                                        unsigned long filenum)
+GtUword gt_hcr_decoder_readlength(GtHcrDecoder *hcr_dec,
+                                        GtUword filenum)
 {
   gt_assert(hcr_dec);
   gt_assert(hcr_dec->seq_dec->num_of_files > filenum);
@@ -1101,7 +1102,7 @@ GtHcrEncoder *gt_hcr_encoder_new(GtStrArray *files, GtAlphabet *alpha,
   GtStrArray *file;
   int had_err = 0,
       status;
-  unsigned long len1,
+  GtUword len1,
                 len2,
                 i,
                 num_of_reads = 0;
@@ -1128,7 +1129,7 @@ GtHcrEncoder *gt_hcr_encoder_new(GtStrArray *files, GtAlphabet *alpha,
   hcr_enc->page_sampling = false;
   hcr_enc->regular_sampling = false;
   hcr_enc->sampling_rate = 0;
-  hcr_enc->pagesize = sysconf((int) _SC_PAGESIZE);
+  hcr_enc->pagesize = gt_pagesize();
   if (descs) {
     hcr_enc->encdesc_encoder = gt_encdesc_encoder_new();
     if (timer != NULL)
@@ -1205,7 +1206,7 @@ GtHcrEncoder *gt_hcr_encoder_new(GtStrArray *files, GtAlphabet *alpha,
     hcr_enc->seq_encoder->huffman =
       gt_huffman_new(bqd,
                      hcr_base_qual_distr_func,
-                     (unsigned long) bqd->ncols * bqd->nrows);
+                     (GtUword) bqd->ncols * bqd->nrows);
   }
   if (!had_err) {
     hcr_enc->seq_encoder->qual_offset = bqd->qual_offset;
@@ -1251,7 +1252,7 @@ void gt_hcr_encoder_set_sampling_page(GtHcrEncoder *hcr_enc)
 }
 
 void gt_hcr_encoder_set_sampling_rate(GtHcrEncoder *hcr_enc,
-                                      unsigned long srate)
+                                      GtUword srate)
 {
   gt_assert(hcr_enc);
   hcr_enc->sampling_rate = srate;
@@ -1260,7 +1261,7 @@ void gt_hcr_encoder_set_sampling_rate(GtHcrEncoder *hcr_enc,
     gt_encdesc_encoder_set_sampling_rate(hcr_enc->encdesc_encoder, srate);
 }
 
-unsigned long gt_hcr_encoder_get_sampling_rate(GtHcrEncoder *hcr_enc)
+GtUword gt_hcr_encoder_get_sampling_rate(GtHcrEncoder *hcr_enc)
 {
   gt_assert(hcr_enc);
   return hcr_enc->sampling_rate;
@@ -1291,17 +1292,17 @@ int gt_hcr_encoder_encode(GtHcrEncoder *hcr_enc, const char *name,
     gt_log_log("sequences with qualities encoding overview:");
     gt_log_log("**>");
     if (hcr_enc->page_sampling)
-        gt_log_log("applied sampling technique: sampling every %luth page",
+        gt_log_log("applied sampling technique: sampling every "GT_WU"th page",
                    hcr_enc->sampling_rate);
     else if (hcr_enc->regular_sampling)
-        gt_log_log("applied sampling technique: sampling every %luth read",
+        gt_log_log("applied sampling technique: sampling every "GT_WU"th read",
                    hcr_enc->sampling_rate);
     else
         gt_log_log("applied sampling technique: none");
 
     gt_log_log("total number of encoded nucleotide sequences with qualities: "
-               "%lu", hcr_enc->num_of_reads);
-    gt_log_log("total number of encoded nucleotides: %llu",
+               ""GT_WU"", hcr_enc->num_of_reads);
+    gt_log_log("total number of encoded nucleotides: "GT_LLU"",
                hcr_enc->seq_encoder->total_num_of_symbols);
     gt_log_log("bits per nucleotide encoding: %f",
                (gt_file_estimate_size(gt_str_get(name1)) * 8.0) /
