@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2007 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2005-2007 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2005-2007 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -27,6 +27,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
+#include <float.h>
 #include "core/array2dim_api.h"
 #include "core/assert_api.h"
 #include "core/chardef.h"
@@ -345,7 +346,7 @@ void gt_hmm_decode(const GtHMM *hmm,
         tmp_prob = max_probabilities[previous_row][precolidx] +
                    hmm->transition_prob[previous_row][row] +
                    hmm->emission_prob[row][emission];
-        if (tmp_prob > max_probabilities[row][colidx]) {
+        if (tmp_prob - max_probabilities[row][colidx] < -DBL_EPSILON) {
           max_probabilities[row][colidx] = tmp_prob;
           backtrace[row][column] = previous_row;
         }
@@ -358,7 +359,7 @@ void gt_hmm_decode(const GtHMM *hmm,
   tmp_prob = max_probabilities[0][colidx];
   state_sequence[num_of_columns - 1] = 0;
   for (row = 1; row < num_of_rows; row++) {
-    if (max_probabilities[row][colidx] > tmp_prob)
+    if (max_probabilities[row][colidx] - tmp_prob > DBL_EPSILON)
       state_sequence[num_of_columns - 1] = row;
   }
 
@@ -374,7 +375,7 @@ void gt_hmm_decode(const GtHMM *hmm,
 /* [DEKM98, p. 58] */
 static void compute_forward_table(double **f, const GtHMM *hmm,
                                   const unsigned int *emissions,
-                                  unsigned long num_of_emissions)
+                                  GtUword num_of_emissions)
 {
   int row, column, previous_row;
   double tmp_prob;
@@ -431,7 +432,7 @@ double gt_hmm_forward(const GtHMM* hmm, const unsigned int *emissions,
 /* [DEKM98, p. 59] */
 static void compute_backward_table(double **b, const GtHMM *hmm,
                                    const unsigned int *emissions,
-                                   unsigned long num_of_emissions)
+                                   GtUword num_of_emissions)
 {
   int row, column, next_row;
   double tmp_prob;
@@ -486,11 +487,11 @@ double gt_hmm_backward(const GtHMM* hmm, const unsigned int *emissions,
   return P;
 }
 
-void gt_hmm_emit(GtHMM *hmm, unsigned long num_of_emissions,
+void gt_hmm_emit(GtHMM *hmm, GtUword num_of_emissions,
               void (*proc_emission)(unsigned int symbol, void *data),
               void *data)
 {
-  unsigned long i;
+  GtUword i;
   unsigned int state, symbol, next_state;
   double random_value, cumulative_prob;
   gt_assert(hmm);
@@ -500,7 +501,7 @@ void gt_hmm_emit(GtHMM *hmm, unsigned long num_of_emissions,
   cumulative_prob = 0.0;
   for (state = 0; state < hmm->num_of_states - 1; state++) {
     cumulative_prob += gt_hmm_get_initial_state_probability(hmm, state);
-    if (cumulative_prob > random_value)
+    if (cumulative_prob - random_value > DBL_EPSILON)
       break;
   }
 
@@ -511,10 +512,10 @@ void gt_hmm_emit(GtHMM *hmm, unsigned long num_of_emissions,
     cumulative_prob = 0.0;
     for (symbol = 0; symbol < hmm->num_of_symbols - 1; symbol++) {
       cumulative_prob += gt_hmm_get_emission_probability(hmm, state, symbol);
-      if (cumulative_prob > random_value)
+      if (cumulative_prob - random_value > DBL_EPSILON)
         break;
     }
-    if (proc_emission)
+    if (proc_emission != NULL)
       proc_emission(symbol, data);
     /* go to next state */
     random_value = gt_rand_0_to_1();
@@ -522,7 +523,7 @@ void gt_hmm_emit(GtHMM *hmm, unsigned long num_of_emissions,
     for (next_state = 0; next_state < hmm->num_of_states - 1; next_state++) {
       cumulative_prob += gt_hmm_get_transition_probability(hmm,
                                                            state, next_state);
-      if (cumulative_prob > random_value)
+      if (cumulative_prob - random_value > DBL_EPSILON)
         break;
     }
     state = next_state;
@@ -532,7 +533,7 @@ void gt_hmm_emit(GtHMM *hmm, unsigned long num_of_emissions,
 double gt_hmm_rmsd(const GtHMM *hmm_a, const GtHMM* hmm_b)
 {
   unsigned int i, j;
-  double difference = 0.0, rmsd = 0.0;
+  double difference = 0.0, rmsd = 0.0, a_prob, b_prob;
   gt_assert(hmm_a && hmm_b);
   gt_assert(hmm_a->num_of_states == hmm_b->num_of_states);
   gt_assert(hmm_a->num_of_symbols == hmm_b->num_of_symbols);
@@ -541,16 +542,26 @@ double gt_hmm_rmsd(const GtHMM *hmm_a, const GtHMM* hmm_b)
   /* add transitions probabilities */
   for (i = 0; i < hmm_a->num_of_states; i++) {
     for (j = 0; j < hmm_a->num_of_states; j++) {
-      difference = gt_hmm_get_transition_probability(hmm_a, i, j) -
-                   gt_hmm_get_transition_probability(hmm_b, i, j);
+      a_prob = gt_hmm_get_transition_probability(hmm_a,i,j);
+      b_prob = gt_hmm_get_transition_probability(hmm_b,i,j);
+
+      if (gt_double_equals_double(a_prob, b_prob))
+        difference = 0.0;
+      else
+        difference = a_prob - b_prob;
       rmsd += difference * difference;
     }
   }
   /* add emission probabilities */
   for (i = 0; i < hmm_a->num_of_states; i++) {
     for (j = 0; j < hmm_a->num_of_symbols; j++) {
-      difference = gt_hmm_get_emission_probability(hmm_a, i, j) -
-                   gt_hmm_get_emission_probability(hmm_b, i, j);
+      a_prob = gt_hmm_get_emission_probability(hmm_a,i,j);
+      b_prob = gt_hmm_get_emission_probability(hmm_b,i,j);
+
+      if (gt_double_equals_double(a_prob, b_prob))
+        difference = 0.0;
+      else
+        difference = a_prob - b_prob;
       rmsd += difference * difference;
     }
   }
@@ -626,12 +637,12 @@ int gt_hmm_unit_test(GtError *err)
     for (j = 0; j < len; j++)
       encoded_seq[j] = gt_alphabet_encode(alpha, coin_tosses[i][j]);
     /* XXX: remove exp() calls */
-    gt_ensure(had_err,
+    gt_ensure(
            gt_double_equals_double(exp(gt_hmm_forward(fair_hmm, encoded_seq,
                                                       len)),
                                    exp(gt_hmm_backward(fair_hmm, encoded_seq,
                                                     len))));
-    gt_ensure(had_err,
+    gt_ensure(
            gt_double_equals_double(exp(gt_hmm_forward(loaded_hmm, encoded_seq,
                                                    len)),
                                    exp(gt_hmm_backward(loaded_hmm, encoded_seq,
@@ -640,9 +651,9 @@ int gt_hmm_unit_test(GtError *err)
 
   gt_free(encoded_seq);
   gt_alphabet_delete(alpha);
-  gt_ensure(had_err,
+  gt_ensure(
             gt_double_equals_double(gt_hmm_rmsd(fair_hmm, fair_hmm), 0.0));
-  gt_ensure(had_err,
+  gt_ensure(
             gt_double_equals_double(gt_hmm_rmsd(loaded_hmm, loaded_hmm), 0.0));
   gt_hmm_delete(loaded_hmm);
   gt_hmm_delete(fair_hmm);
@@ -660,12 +671,12 @@ int gt_hmm_unit_test(GtError *err)
       encoded_seq[j] = gt_alphabet_encode(alpha, dice_rolls[i][j]);
     }
     /* XXX: remove exp() calls */
-    gt_ensure(had_err,
+    gt_ensure(
            gt_double_equals_double(exp(gt_hmm_forward(fair_hmm, encoded_seq,
                                                       len)),
                                    exp(gt_hmm_backward(fair_hmm, encoded_seq,
                                                        len))));
-    gt_ensure(had_err,
+    gt_ensure(
            gt_double_equals_double(exp(gt_hmm_forward(loaded_hmm, encoded_seq,
                                                       len)),
                                    exp(gt_hmm_backward(loaded_hmm, encoded_seq,
@@ -674,9 +685,9 @@ int gt_hmm_unit_test(GtError *err)
 
   gt_free(encoded_seq);
   gt_alphabet_delete(alpha);
-  gt_ensure(had_err,
+  gt_ensure(
             gt_double_equals_double(gt_hmm_rmsd(fair_hmm, fair_hmm), 0.0));
-  gt_ensure(had_err,
+  gt_ensure(
             gt_double_equals_double(gt_hmm_rmsd(loaded_hmm, loaded_hmm), 0.0));
   gt_hmm_delete(loaded_hmm);
   gt_hmm_delete(fair_hmm);
