@@ -33,25 +33,25 @@
 struct GtHpolProcessor
 {
   GtEncseq *encseq;
-  unsigned long hmin, clenmax, read_hmin, mapqmin, covmin;
+  GtUword hmin, clenmax, read_hmin, mapqmin, covmin, qmax;
   bool allow_partial, allow_multiple;
   double altmax, refmin;
   GtDiscDistri *hdist, *hdist_e;
   GtSeqposClassifier *cds_oracle;
   GtAlignedSegmentsPile *asp;
-  unsigned long nof_complete_edited, nof_complete_not_edited,
+  GtUword nof_complete_edited, nof_complete_not_edited,
                 nof_skipped, nof_unmapped, nof_h, nof_h_e, hlen_max,
                 nof_multihits, nof_replaced;
   bool adjust_s_hlen;
   GtFile *outfp_segments, *outfp_stats, **outfiles;
   GtSeqIterator **reads_iters;
-  unsigned long nfiles;
+  GtUword nfiles;
   GtHashmap *processed_segments;
   GtAlphabet *alpha;
   bool output_segments, output_stats, output_multihit_stats;
 };
 
-GtHpolProcessor *gt_hpol_processor_new(GtEncseq *encseq, unsigned long hmin)
+GtHpolProcessor *gt_hpol_processor_new(GtEncseq *encseq, GtUword hmin)
 {
   GtHpolProcessor *hpp;
   hpp = gt_malloc(sizeof (GtHpolProcessor));
@@ -60,6 +60,7 @@ GtHpolProcessor *gt_hpol_processor_new(GtEncseq *encseq, unsigned long hmin)
   hpp->encseq = encseq;
   hpp->hmin = hmin;
   hpp->read_hmin = 0;
+  hpp->qmax = 0;
   hpp->mapqmin = 0;
   hpp->covmin = 0;
   hpp->allow_partial = false;
@@ -77,7 +78,7 @@ GtHpolProcessor *gt_hpol_processor_new(GtEncseq *encseq, unsigned long hmin)
   hpp->nof_unmapped = 0;
   hpp->nof_multihits = 0;
   hpp->nof_replaced = 0;
-  hpp->clenmax = GT_UNDEF_ULONG;
+  hpp->clenmax = GT_UNDEF_UWORD;
   hpp->altmax = (double) 1.0;
   hpp->refmin = (double) 0.0;
   hpp->alpha = gt_alphabet_new_dna();
@@ -105,23 +106,23 @@ void gt_hpol_processor_restrict_to_feature_type(GtHpolProcessor *hpp,
 static void gt_hpol_processor_output_segment(GtAlignedSegment *as,
     bool may_be_gapped, GtFile *outfp, const char *desc)
 {
-  unsigned long slen;
+  GtUword slen;
   if (may_be_gapped)
     gt_aligned_segment_ungap_seq_and_qual(as);
-  slen = (unsigned long)strlen(gt_aligned_segment_seq(as));
-  gt_assert(slen == (unsigned long)strlen(gt_aligned_segment_qual(as)));
+  slen = (GtUword)strlen(gt_aligned_segment_seq(as));
+  gt_assert(slen == (GtUword)strlen(gt_aligned_segment_qual(as)));
   if (gt_aligned_segment_is_reverse(as))
   {
     GtError *err = gt_error_new();
     char *q = gt_aligned_segment_qual(as), tmp;
-    unsigned long i;
+    GtUword i;
     for (i = 0; i < (slen + 1UL) >> 1; i++)
     {
       tmp = q[i];
       q[i] = q[slen - i - 1UL];
       q[slen - i - 1UL] = tmp;
     }
-    gt_assert((unsigned long)strlen(gt_aligned_segment_qual(as)) == slen);
+    gt_assert((GtUword)strlen(gt_aligned_segment_qual(as)) == slen);
     if (gt_reverse_complement(gt_aligned_segment_seq(as), slen, err) != 0)
     {
       fprintf(stderr, "error: %s", gt_error_get(err));
@@ -241,14 +242,14 @@ static void gt_hpol_processor_refregioncheck(
     GtAlignedSegment *as, void *data)
 {
   GtHpolProcessor *hpp = data;
-  unsigned long rlen, i, startpos;
+  GtUword rlen, i, startpos;
   char *r;
   bool haserr = false;
   gt_assert(hpp != NULL);
   gt_aligned_segment_ungap_refregion(as);
   gt_aligned_segment_assign_refregion_chars(as, hpp->encseq);
   r = gt_aligned_segment_refregion(as);
-  rlen = (unsigned long)strlen(r);
+  rlen = (GtUword)strlen(r);
   startpos = gt_aligned_segment_refregion_startpos(as);
   for (i = 0; i < rlen; i++)
   {
@@ -275,14 +276,14 @@ static void gt_hpol_processor_refregioncheck(
         fprintf(stderr, " ");
     }
     fprintf(stderr, "\n");
-    fprintf(stderr, "reference = ");
+    fprintf(stderr, "cognate = ");
     for (i = 0; i < rlen; i++)
     {
       fprintf(stderr, "%c", gt_encseq_get_decoded_char(hpp->encseq,
             startpos + i, GT_READMODE_FORWARD));
     }
     fprintf(stderr, "\n");
-    fprintf(stderr, "[startpos = %lu]\n", startpos);
+    fprintf(stderr, "[startpos = "GT_WU"]\n", startpos);
     exit(EXIT_FAILURE);
   }
 }
@@ -301,9 +302,9 @@ void gt_hpol_processor_enable_aligned_segments_refregionscheck(
 }
 
 void gt_hpol_processor_enable_segments_hlen_adjustment(GtHpolProcessor *hpp,
-    GtAlignedSegmentsPile *asp, unsigned long read_hmin, double altmax,
-    double refmin, unsigned long mapqmin, unsigned long covmin,
-    bool allow_partial, bool allow_multiple, unsigned long clenmax)
+    GtAlignedSegmentsPile *asp, GtUword read_hmin, GtUword qmax,
+    double altmax, double refmin, GtUword mapqmin, GtUword covmin,
+    bool allow_partial, bool allow_multiple, GtUword clenmax)
 {
   gt_assert(hpp != NULL);
   gt_assert(asp != NULL);
@@ -311,6 +312,7 @@ void gt_hpol_processor_enable_segments_hlen_adjustment(GtHpolProcessor *hpp,
   hpp->adjust_s_hlen = true;
   hpp->asp = asp;
   hpp->read_hmin = read_hmin;
+  hpp->qmax = qmax;
   hpp->altmax = altmax;
   hpp->refmin = refmin;
   hpp->mapqmin = mapqmin;
@@ -335,7 +337,7 @@ void gt_hpol_processor_enable_direct_segments_output(GtHpolProcessor *hpp,
 }
 
 void gt_hpol_processor_enable_sorted_segments_output(GtHpolProcessor *hpp,
-    unsigned long nfiles, GtSeqIterator **reads_iters, GtFile **outfiles)
+    GtUword nfiles, GtSeqIterator **reads_iters, GtFile **outfiles)
 {
   gt_assert(hpp != NULL);
   gt_aligned_segments_pile_disable_segment_deletion(hpp->asp);
@@ -349,16 +351,16 @@ void gt_hpol_processor_enable_sorted_segments_output(GtHpolProcessor *hpp,
 static void gt_hpol_processor_output_stats_header(GtFile *outfp)
 {
   gt_file_xprintf(outfp, "# correction statistics\n");
-  gt_file_xprintf(outfp, "# r_hpos =    start pos of hpol on reference\n");
+  gt_file_xprintf(outfp, "# r_hpos =    start pos of hpol on cognate\n");
   gt_file_xprintf(outfp, "# edit =      edit operation on the read (I or D)\n");
   gt_file_xprintf(outfp, "# s_hpos =    first pos of hpol on read\n");
   gt_file_xprintf(outfp, "# s_hend =    last pos of hpol on read\n");
   gt_file_xprintf(outfp, "# s_char =    hpol character in read\n");
   gt_file_xprintf(outfp, "# s_or =      orientation of read "
-      "(+ or -; + = same as reference)\n");
+      "(+ or -; + = same as cognate)\n");
   gt_file_xprintf(outfp, "# c_len =     correction length\n");
   gt_file_xprintf(outfp, "# coverage =  number of reads over entire hpol\n");
-  gt_file_xprintf(outfp, "# r_hlen =    length of hpol on reference\n");
+  gt_file_xprintf(outfp, "# r_hlen =    length of hpol on cognate\n");
   gt_file_xprintf(outfp, "# r_supp =    %% reads with ref hpol length\n");
   gt_file_xprintf(outfp, "# s_hlen =    length of hpol in read\n");
   gt_file_xprintf(outfp, "# a_hlen =    alt consensus hpol length in reads\n");
@@ -386,18 +388,17 @@ static void gt_hpol_processor_output_stats_header(GtFile *outfp)
 
 #define GT_HPOL_PROCESSOR_PHREDOFFSET 33UL
 #define GT_HPOL_PROCESSOR_QUAL(QCHAR) \
-  (unsigned long)(QCHAR) - GT_HPOL_PROCESSOR_PHREDOFFSET;
+  (GtUword)(QCHAR) - GT_HPOL_PROCESSOR_PHREDOFFSET;
 
 static void gt_hpol_processor_output_stats(GtAlignedSegment *as,
-    unsigned long r_hpos, unsigned long coverage, unsigned long r_hlen,
-    unsigned long r_supp, unsigned long s_hlen, unsigned long a_hlen,
-    unsigned long a_supp, char s_char, unsigned long s_q_sum,
-    unsigned long c_len, GtFile *outfp)
+    GtUword r_hpos, GtUword coverage, GtUword r_hlen,
+    GtUword r_supp, GtUword s_hlen, GtUword a_hlen,
+    GtUword a_supp, char s_char, double s_q_ave,
+    GtUword c_len, GtFile *outfp)
 {
-  unsigned long i, pos, s_hpos = 0, s_offset, s_q_bef, s_q_aft, s_q_value,
+  GtUword i, pos, s_hpos = 0, s_offset, s_q_bef, s_q_aft, s_q_value,
                 s_q_min, s_q_max, s_q_range, s_q_first, s_q_last = 0, s_hend,
                 s_mapq;
-  double s_q_ave;
   char *s_qual, *q, edit, s_or;
   const char *s_id;
   gt_assert(r_hlen != s_hlen);
@@ -409,13 +410,10 @@ static void gt_hpol_processor_output_stats(GtAlignedSegment *as,
   s_mapq = gt_aligned_segment_mapping_quality(as);
   q = gt_aligned_segment_qual(as);
   gt_assert(s_hlen > 0);
-  gt_assert(s_q_sum >= GT_HPOL_PROCESSOR_PHREDOFFSET * s_hlen);
-  s_q_ave = (double)(s_q_sum - GT_HPOL_PROCESSOR_PHREDOFFSET * s_hlen)
-    / (double)s_hlen;
   s_hpos = gt_aligned_segment_orig_seqpos_for_refpos(as, r_hpos);
   s_offset = gt_aligned_segment_offset_for_refpos(as, r_hpos);
   s_qual = gt_malloc(sizeof (*s_qual) * (s_hlen + 1UL));
-  s_q_bef = GT_UNDEF_ULONG;
+  s_q_bef = GT_UNDEF_UWORD;
   for (i = s_offset; i > 0; /**/)
   {
     i--;
@@ -425,10 +423,10 @@ static void gt_hpol_processor_output_stats(GtAlignedSegment *as,
       break;
     }
   }
-  gt_assert(s_q_bef != GT_UNDEF_ULONG);
+  gt_assert(s_q_bef != GT_UNDEF_UWORD);
   s_q_min = ULONG_MAX;
   s_q_max = 0;
-  s_q_first = GT_UNDEF_ULONG;
+  s_q_first = GT_UNDEF_UWORD;
   if (!gt_aligned_segment_is_reverse(as))
   {
     for (i = s_offset, pos = 0; pos < s_hlen; i++)
@@ -442,7 +440,7 @@ static void gt_hpol_processor_output_stats(GtAlignedSegment *as,
           s_q_min = s_q_value;
         if (s_q_value > s_q_max)
           s_q_max = s_q_value;
-        if (s_q_first == GT_UNDEF_ULONG)
+        if (s_q_first == GT_UNDEF_UWORD)
           s_q_first = s_q_value;
         s_q_last = s_q_value;
       }
@@ -461,14 +459,14 @@ static void gt_hpol_processor_output_stats(GtAlignedSegment *as,
           s_q_min = s_q_value;
         if (s_q_value > s_q_max)
           s_q_max = s_q_value;
-        if (s_q_first == GT_UNDEF_ULONG)
+        if (s_q_first == GT_UNDEF_UWORD)
           s_q_first = s_q_value;
         s_q_last = s_q_value;
       }
     }
   }
   s_qual[s_hlen] = '\0';
-  s_q_aft = GT_UNDEF_ULONG;
+  s_q_aft = GT_UNDEF_UWORD;
   for (/**/; i < gt_aligned_segment_length(as); i++)
   {
     if (q[i] != GT_UNDEF_CHAR)
@@ -477,7 +475,7 @@ static void gt_hpol_processor_output_stats(GtAlignedSegment *as,
       break;
     }
   }
-  gt_assert(s_q_aft != GT_UNDEF_ULONG);
+  gt_assert(s_q_aft != GT_UNDEF_UWORD);
   gt_assert(s_q_min < ULONG_MAX);
   gt_assert(s_q_max >= s_q_min);
   s_q_range = s_q_max - s_q_min + 1UL;
@@ -509,11 +507,14 @@ static void gt_hpol_processor_output_stats(GtAlignedSegment *as,
     s_or = '+';
   }
   gt_file_xprintf(outfp,
-      "%lu\t%c\t%lu\t%lu\t%c\t%c\t%lu\t%lu\t%lu\t%lu\t%lu\t%lu\t%lu\t%lu\t"
-      "%lu\t%lu\t%lu\t%.2f\t%lu\t%lu\t%lu\t%lu\t%s\t%s\n",
-      r_hpos, edit, s_hpos, s_hend, s_char, s_or, c_len, coverage, r_hlen,
-      r_supp, s_hlen, a_hlen, a_supp, s_mapq, s_q_bef, s_q_first, s_q_min,
-      s_q_ave, s_q_max, s_q_range, s_q_last, s_q_aft, s_qual, s_id);
+                  GT_WU "\t%c\t" GT_WU "\t" GT_WU "\t%c\t%c\t" GT_WU "\t" GT_WU
+                  "\t" GT_WU "\t" GT_WU "\t" GT_WU "\t" GT_WU "\t" GT_WU "\t"
+                  GT_WU "\t" GT_WU "\t" GT_WU "\t" GT_WU "\t%.2f\t" GT_WU "\t"
+                  GT_WU "\t" GT_WU "\t" GT_WU "\t%s\t%s\n",
+                  r_hpos, edit, s_hpos, s_hend, s_char, s_or, c_len, coverage,
+                  r_hlen, r_supp, s_hlen, a_hlen, a_supp, s_mapq, s_q_bef,
+                  s_q_first, s_q_min, s_q_ave, s_q_max, s_q_range, s_q_last,
+                  s_q_aft, s_qual, s_id);
   gt_free(s_qual);
 }
 
@@ -529,11 +530,11 @@ void gt_hpol_processor_enable_statistics_output(GtHpolProcessor *hpp,
 }
 
 #ifdef GG_DEBUG
-static unsigned long gt_hpol_processor_determine_hlen_backwards(char *s,
-    char *q, unsigned long pos, char c, unsigned long *q_sum,
-    unsigned long *gaps)
+static GtUword gt_hpol_processor_determine_hlen_backwards(char *s,
+    char *q, GtUword pos, char c, GtUword *q_sum,
+    GtUword *gaps)
 {
-  unsigned long s_hlen = 0;
+  GtUword s_hlen = 0;
   pos++;
   while (pos > 0)
   {
@@ -556,11 +557,11 @@ static unsigned long gt_hpol_processor_determine_hlen_backwards(char *s,
 }
 #endif
 
-static unsigned long gt_hpol_processor_determine_hlen_forwards(char *s, char *q,
-    unsigned long pos, unsigned long maxpos, char c, unsigned long *q_sum,
-    unsigned long *gaps)
+static GtUword gt_hpol_processor_determine_hlen_forwards(char *s, char *q,
+    GtUword pos, GtUword maxpos, char c, GtUword *q_sum,
+    GtUword *gaps)
 {
-  unsigned long s_hlen = 0;
+  GtUword s_hlen = 0;
   while (pos <= maxpos)
   {
     if (s[pos] == c)
@@ -582,10 +583,10 @@ static unsigned long gt_hpol_processor_determine_hlen_forwards(char *s, char *q,
 }
 
 static void gt_hpol_processor_subst_in_range(char *s, char *q,
-    unsigned long left, unsigned long right, unsigned long length, char old,
+    GtUword left, GtUword right, GtUword length, char old,
     char new, char qual)
 {
-  unsigned long pos;
+  GtUword pos;
   for (pos = right + 1UL; pos > left && length > 0; /**/)
   {
     pos--;
@@ -599,33 +600,34 @@ static void gt_hpol_processor_subst_in_range(char *s, char *q,
   gt_assert(length == 0);
 }
 
-static void gt_hpol_processor_shrink_hpol(char *s, char *q, unsigned long left,
-    unsigned long right, unsigned long length, char c)
+static void gt_hpol_processor_shrink_hpol(char *s, char *q, GtUword left,
+    GtUword right, GtUword length, char c)
 {
   gt_hpol_processor_subst_in_range(s, q, left, right, length, c, '-',
       GT_UNDEF_CHAR);
 }
 
-static void gt_hpol_processor_enlarge_hpol(char *s, char *q, unsigned long left,
-    unsigned long right, unsigned long length, char c, char qual)
+static void gt_hpol_processor_enlarge_hpol(char *s, char *q, GtUword left,
+    GtUword right, GtUword length, char c, char qual)
 {
   gt_hpol_processor_subst_in_range(s, q, left, right, length, '-', c, qual);
 }
 
 static bool gt_hpol_processor_adjust_hlen_of_a_segment(GtAlignedSegment *as,
-    char c, unsigned long r_hstart, unsigned long coverage,
-    unsigned long r_hlen, unsigned long r_supp, unsigned long a_hlen,
-    unsigned long a_supp, unsigned long clenmax, bool allow_partial,
-    bool allow_multiple, unsigned long s_hmin, bool output_stats,
-    GtFile *outfp_stats)
+    char c, GtUword r_hstart, GtUword coverage,
+    GtUword r_hlen, GtUword r_supp, GtUword a_hlen,
+    GtUword a_supp, GtUword clenmax, bool allow_partial,
+    bool allow_multiple, GtUword s_hmin, GtUword qmax,
+    bool output_stats, GtFile *outfp_stats)
 {
-  unsigned long left, right, s_hlen = 0, q_sum = 0, s_free = 0;
+  GtUword left, right, s_hlen = 0, q_sum = 0, s_free = 0;
   char *s, *q;
   bool edited = false;
+  double q_ave = 0.0;
   left = gt_aligned_segment_offset_for_refpos(as, r_hstart);
   right = gt_aligned_segment_offset_for_refpos(as, r_hstart + r_hlen);
-  if (left == GT_UNDEF_ULONG || left == 0 ||
-      right == GT_UNDEF_ULONG || right == gt_aligned_segment_length(as))
+  if (left == GT_UNDEF_UWORD || left == 0 ||
+      right == GT_UNDEF_UWORD || right == gt_aligned_segment_length(as))
     return edited;
   right--;
   s = gt_aligned_segment_seq(as);
@@ -635,7 +637,7 @@ static bool gt_hpol_processor_adjust_hlen_of_a_segment(GtAlignedSegment *as,
     s_hlen = gt_hpol_processor_determine_hlen_backwards(s, q, left - 1UL,
           c, &q_sum, &s_free);
   if (s_hlen > 0)
-    printf("backwards_hlen = %lu\n", s_hlen);
+    printf("backwards_hlen = "GT_WU"\n", s_hlen);
   s_free = 0;
   q_sum = 0;
 #endif
@@ -646,7 +648,7 @@ static bool gt_hpol_processor_adjust_hlen_of_a_segment(GtAlignedSegment *as,
 #ifdef GG_DEBUG
   if (s_hlen != r_hlen)
   {
-    unsigned long i;
+    GtUword i;
     gt_aligned_segment_show(as, NULL);
     printf("   ");
     for (i = 0; i < left; i++)
@@ -655,28 +657,32 @@ static bool gt_hpol_processor_adjust_hlen_of_a_segment(GtAlignedSegment *as,
     for (/**/; i < right - 1UL; i++)
       printf(".");
     printf("|\n");
-    printf("[s_hlen=%lu, r_hlen=%lu]\n", s_hlen, r_hlen);
+    printf("[s_hlen="GT_WU", r_hlen="GT_WU"]\n", s_hlen, r_hlen);
     printf("\n");
   }
   else
   {
-    printf("s_hlen == r_hlen = %lu\n\n", s_hlen);
+    printf("s_hlen == r_hlen = "GT_WU"\n\n", s_hlen);
   }
 #endif
   /* do the editing if necessary and possible */
+  gt_assert(q_sum > GT_HPOL_PROCESSOR_PHREDOFFSET * s_hlen);
+  q_ave = (double)(q_sum - GT_HPOL_PROCESSOR_PHREDOFFSET * s_hlen)
+    / (double)s_hlen;
   if (s_hlen < r_hlen)
   {
     if (s_free > 0)
     {
-      unsigned long hlen_diff = r_hlen - s_hlen;
-      if (hlen_diff < clenmax &&
+      GtUword hlen_diff = r_hlen - s_hlen;
+      if (hlen_diff <= clenmax &&
+          (q_ave <= (double)qmax) &&
           (s_free >= hlen_diff || allow_partial) &&
           (!gt_aligned_segment_seq_edited(as) || allow_multiple))
       {
         if (output_stats)
         {
           gt_hpol_processor_output_stats(as, r_hstart, coverage, r_hlen, r_supp,
-              s_hlen, a_hlen, a_supp, c, q_sum, MIN(s_free, hlen_diff),
+              s_hlen, a_hlen, a_supp, c, q_ave, MIN(s_free, hlen_diff),
               outfp_stats);
         }
         gt_aligned_segment_seq_set_edited(as);
@@ -688,14 +694,15 @@ static bool gt_hpol_processor_adjust_hlen_of_a_segment(GtAlignedSegment *as,
   }
   else if (s_hlen > r_hlen)
   {
-    unsigned long hlen_diff = s_hlen - r_hlen;
-    if (hlen_diff < clenmax &&
+    GtUword hlen_diff = s_hlen - r_hlen;
+    if (hlen_diff <= clenmax &&
+       (q_ave <= (double)qmax) &&
        (!gt_aligned_segment_seq_edited(as) || allow_multiple))
     {
       if (output_stats)
       {
         gt_hpol_processor_output_stats(as, r_hstart, coverage, r_hlen, r_supp,
-            s_hlen, a_hlen, a_supp, c, q_sum, hlen_diff, outfp_stats);
+            s_hlen, a_hlen, a_supp, c, q_ave, hlen_diff, outfp_stats);
       }
       gt_aligned_segment_seq_set_edited(as);
       gt_hpol_processor_shrink_hpol(s, q, left, right, hlen_diff, c);
@@ -706,12 +713,13 @@ static bool gt_hpol_processor_adjust_hlen_of_a_segment(GtAlignedSegment *as,
 }
 
 static bool gt_hpol_processor_adjust_hlen_of_all_segments(
-    GtAlignedSegmentsPile *asp, char c, unsigned long r_hstart,
-    unsigned long coverage, unsigned long r_hlen, unsigned long r_supp,
-    unsigned long a_hlen, unsigned long a_supp, unsigned long clenmax,
-    bool allow_partial, bool allow_multiple, unsigned long s_hmin,
-    unsigned long mapqmin, bool output_stats, GtFile *outfp_stats,
-    GtHashmap *processed_segments, bool output_multihit_stats)
+    GtAlignedSegmentsPile *asp, char c, GtUword r_hstart,
+    GtUword coverage, GtUword r_hlen, GtUword r_supp,
+    GtUword a_hlen, GtUword a_supp, GtUword clenmax,
+    bool allow_partial, bool allow_multiple, GtUword s_hmin,
+    GtUword qmax, GtUword mapqmin, bool output_stats,
+    GtFile *outfp_stats, GtHashmap *processed_segments,
+    bool output_multihit_stats)
 {
   GtDlistelem *dlistelem;
   bool any_edited = false, edited;
@@ -737,7 +745,7 @@ static bool gt_hpol_processor_adjust_hlen_of_all_segments(
       }
       edited = gt_hpol_processor_adjust_hlen_of_a_segment(as, c, r_hstart,
           coverage, r_hlen, r_supp, a_hlen, a_supp, clenmax, allow_partial,
-          allow_multiple, s_hmin, output_stats_for_as, outfp_stats);
+          allow_multiple, s_hmin, qmax, output_stats_for_as, outfp_stats);
       if (edited)
         any_edited = true;
     }
@@ -746,13 +754,13 @@ static bool gt_hpol_processor_adjust_hlen_of_all_segments(
 }
 
 static void gt_hpol_processor_determine_alternative_consensus(
-    GtHpolProcessor *hpp, char c, unsigned long r_hstart, unsigned long r_hlen,
-    unsigned long *c_s_hlen, unsigned long *c_support, unsigned long *piled,
-    unsigned long *r_hlen_support)
+    GtHpolProcessor *hpp, char c, GtUword r_hstart, GtUword r_hlen,
+    GtUword *c_s_hlen, GtUword *c_support, GtUword *piled,
+    GtUword *r_hlen_support)
 {
-  unsigned long *occ;
+  GtUword *occ;
   GtDlistelem *dlistelem;
-  unsigned long s_hlen_max = r_hlen << 1, i;
+  GtUword s_hlen_max = r_hlen << 1, i;
   *c_support = 0;
   *piled = 0;
   occ = gt_calloc((size_t)(s_hlen_max + 1UL), sizeof (*occ));
@@ -760,7 +768,7 @@ static void gt_hpol_processor_determine_alternative_consensus(
       dlistelem != NULL; dlistelem = gt_dlistelem_next(dlistelem))
   {
     GtAlignedSegment *as;
-    unsigned long left, right, s_hlen;
+    GtUword left, right, s_hlen;
     char *s;
     as = gt_dlistelem_get_data(dlistelem);
 #ifdef GG_DEBUG
@@ -769,7 +777,7 @@ static void gt_hpol_processor_determine_alternative_consensus(
 #endif
     left = gt_aligned_segment_offset_for_refpos(as, r_hstart);
     right = gt_aligned_segment_offset_for_refpos(as, r_hstart + r_hlen);
-    if (left == GT_UNDEF_ULONG || right == GT_UNDEF_ULONG)
+    if (left == GT_UNDEF_UWORD || right == GT_UNDEF_UWORD)
       continue;
     (*piled)++;
     right--;
@@ -793,7 +801,7 @@ static void gt_hpol_processor_determine_alternative_consensus(
 }
 
 static void gt_hpol_processor_process_hpol_end(GtHpolProcessor *hpp,
-    GtUchar c, unsigned long endpos, unsigned long hlen)
+    GtUchar c, GtUword endpos, GtUword hlen)
 {
   bool edited = false;
   gt_disc_distri_add(hpp->hdist, hlen);
@@ -803,7 +811,7 @@ static void gt_hpol_processor_process_hpol_end(GtHpolProcessor *hpp,
   if (hpp->adjust_s_hlen)
   {
     char ch = gt_alphabet_decode(hpp->alpha, c);
-    unsigned long a_supp_max = ULONG_MAX, a_supp = 0, piled, r_supp = 0, a_hlen,
+    GtUword a_supp_max = ULONG_MAX, a_supp = 0, piled, r_supp = 0, a_hlen,
                   r_supp_min = 0;
     gt_aligned_segments_pile_move_over_position(hpp->asp, endpos + 1UL);
     piled = gt_aligned_segments_pile_size(hpp->asp);
@@ -812,15 +820,16 @@ static void gt_hpol_processor_process_hpol_end(GtHpolProcessor *hpp,
       gt_hpol_processor_determine_alternative_consensus(hpp, ch,
           endpos + 1UL - hlen, hlen, &a_hlen, &a_supp, &piled,
           &r_supp);
-      a_supp_max = (unsigned long)(hpp->altmax * (double)piled);
-      r_supp_min = (unsigned long)(hpp->refmin * (double)piled);
+      a_supp_max = (GtUword)(hpp->altmax * (double)piled);
+      r_supp_min = (GtUword)(hpp->refmin * (double)piled);
       if (r_supp < piled && r_supp >= r_supp_min && a_supp <= a_supp_max)
       {
         edited = gt_hpol_processor_adjust_hlen_of_all_segments(hpp->asp, ch,
             endpos + 1UL - hlen, piled, hlen, r_supp, a_hlen, a_supp,
             hpp->clenmax, hpp->allow_partial, hpp->allow_multiple,
-            hpp->read_hmin, hpp->mapqmin, hpp->output_stats, hpp->outfp_stats,
-            hpp->processed_segments, hpp->output_multihit_stats);
+            hpp->read_hmin, hpp->qmax, hpp->mapqmin, hpp->output_stats,
+            hpp->outfp_stats, hpp->processed_segments,
+            hpp->output_multihit_stats);
       }
     }
   }
@@ -833,56 +842,56 @@ static void gt_hpol_processor_process_hpol_end(GtHpolProcessor *hpp,
 
 static void gt_hpol_processor_show_hdist(GtHpolProcessor *hpp, GtLogger *logger)
 {
-  unsigned long i;
+  GtUword i;
   gt_assert(hpp != NULL);
   gt_assert(hpp->hdist != NULL);
-  gt_logger_log(logger, "Distribution of homopolymers of length >= %lu %s",
+  gt_logger_log(logger, "Distribution of homopolymers of length >= "GT_WU" %s",
       hpp->hmin, (hpp->cds_oracle != NULL ?  "in coding sequences" :
-        "in reference sequence"));
+        "in cognate sequence"));
   gt_logger_log(logger, "length\toccurrences\tedited");
   for (i = hpp->hmin; i <= hpp->hlen_max; i++)
   {
-    unsigned long n = (unsigned long)gt_disc_distri_get(hpp->hdist, i);
+    GtUword n = (GtUword)gt_disc_distri_get(hpp->hdist, i);
     if (n > 0)
     {
-      gt_logger_log(logger, "%-6lu\t%-11lu\t%-6lu\t(%.2f%%)", i, n,
-          (unsigned long)gt_disc_distri_get(hpp->hdist_e, i),
-          (double)gt_disc_distri_get(hpp->hdist_e, i) * 100 / n);
+      gt_logger_log(logger, "%-6"GT_WUS"\t%-11"GT_WUS"\t%-6"GT_WUS"\t(%.2f%%)",
+                    i, n, (GtUword)gt_disc_distri_get(hpp->hdist_e, i),
+                    (double)gt_disc_distri_get(hpp->hdist_e, i) * 100 / n);
     }
   }
-  gt_logger_log(logger, "total \t%-11lu\t%-6lu\t(%.2f%%)",
+  gt_logger_log(logger, "total \t%-11"GT_WUS"\t%-6"GT_WUS"\t(%.2f%%)",
       hpp->nof_h, hpp->nof_h_e, (double)hpp->nof_h_e * 100 /
       (double)hpp->nof_h);
   if (hpp->cds_oracle != NULL)
   {
-    gt_logger_log(logger, "coding sequences: %lu",
+    gt_logger_log(logger, "coding sequences: "GT_WU"",
         gt_seqpos_classifier_nof_features_found(hpp->cds_oracle));
   }
   if (hpp->adjust_s_hlen)
   {
-    unsigned long nof_complete = hpp->nof_complete_edited +
+    GtUword nof_complete = hpp->nof_complete_edited +
       hpp->nof_complete_not_edited;
-    unsigned long total_segments =
+    GtUword total_segments =
       nof_complete + hpp->nof_skipped + hpp->nof_unmapped;
-    gt_logger_log(logger, "segments in SAM file:       %lu",
+    gt_logger_log(logger, "segments in SAM file:       "GT_WU"",
         total_segments);
-    gt_logger_log(logger, "- processed:                %-7lu (%.2f%%)",
+    gt_logger_log(logger, "- processed:                %-7"GT_WUS" (%.2f%%)",
         nof_complete, (double)nof_complete * 100 / total_segments);
-    gt_logger_log(logger, "  ... and not edited:       %-7lu (%.2f%%)",
+    gt_logger_log(logger, "  ... and not edited:       %-7"GT_WUS" (%.2f%%)",
         hpp->nof_complete_not_edited,
         (double)hpp->nof_complete_not_edited * 100 / total_segments);
-    gt_logger_log(logger, "  ... and edited:           %-7lu (%.2f%%)",
+    gt_logger_log(logger, "  ... and edited:           %-7"GT_WUS" (%.2f%%)",
         hpp->nof_complete_edited,
         (double)hpp->nof_complete_edited * 100 / total_segments);
-    gt_logger_log(logger, "- not processed:            %-7lu (%.2f%%)",
+    gt_logger_log(logger, "- not processed:            %-7"GT_WUS" (%.2f%%)",
         hpp->nof_skipped, (double)hpp->nof_skipped * 100 / total_segments);
-    gt_logger_log(logger, "- not mapping:              %-7lu (%.2f%%)",
+    gt_logger_log(logger, "- not mapping:              %-7"GT_WUS" (%.2f%%)",
         hpp->nof_unmapped, (double)hpp->nof_unmapped * 100 / total_segments);
     if (hpp->processed_segments != NULL)
     {
-      gt_logger_log(logger, "- multiple hits:            %-7lu",
+      gt_logger_log(logger, "- multiple hits:            %-7"GT_WUS"",
           hpp->nof_multihits);
-      gt_log_log("replacements in hashmap: %lu", hpp->nof_replaced);
+      gt_log_log("replacements in hashmap: "GT_WU"", hpp->nof_replaced);
     }
   }
 }
@@ -893,7 +902,7 @@ static int gt_hpol_processor_output_sorted_segments(GtHpolProcessor *hpp,
   const GtUchar *s;
   char *d;
   int next_rval;
-  unsigned long len, i;
+  GtUword len, i;
   GtStr *d_str = NULL;
   GtAlignedSegment *as;
   gt_assert(hpp != NULL);
@@ -904,7 +913,7 @@ static int gt_hpol_processor_output_sorted_segments(GtHpolProcessor *hpp,
       > 0)
   {
     gt_str_set(d_str, d);
-    for (i = 0; i < (unsigned long)strlen(d); i++)
+    for (i = 0; i < (GtUword)strlen(d); i++)
     {
       if (d[i] == ' ')
         d[i] = '\0';
@@ -925,7 +934,7 @@ static int gt_hpol_processor_output_sorted_segments(GtHpolProcessor *hpp,
 int gt_hpol_processor_run(GtHpolProcessor *hpp, GtLogger *logger, GtError *err)
 {
   int had_err = 0;
-  unsigned long i, hlen, tlen;
+  GtUword i, hlen, tlen;
   GtUchar prev, c;
   bool coding = false;
   bool end_of_annotation = true;
