@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2009 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2007-2009 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2007-2008 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -54,8 +54,8 @@ static int inter_feature_in_children(GtFeatureNode *current_feature, void *data,
                                                 aiv->previous_feature);
       current_range = gt_genome_node_get_range((GtGenomeNode*) current_feature);
       if (previous_range.end >= current_range.start) {
-        gt_warning("overlapping boundary features %lu-%lu and %lu-%lu, "
-                   "not placing '%s' inter-feature",
+        gt_warning("overlapping boundary features " GT_WU "-" GT_WU " and "
+                   GT_WU "-" GT_WU ", " "not placing '%s' inter-feature",
                    previous_range.start,
                    previous_range.end,
                    current_range.start,
@@ -64,7 +64,8 @@ static int inter_feature_in_children(GtFeatureNode *current_feature, void *data,
         return 0;
       }
       if (current_range.start - previous_range.end < 2) {
-        gt_warning("no space for inter-feature '%s' between %lu and %lu",
+        gt_warning("no space for inter-feature '%s' between " GT_WU " and "
+                   GT_WU,
                    aiv->inter_type,
                    previous_range.end,
                    current_range.start);
