@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2007 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2006-2007 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2006-2007 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -21,7 +21,7 @@
 #include "core/error.h"
 
 /* Compute the edit distance of sequences u and v in O(max{|u|,|v|}) space */
-unsigned long gt_calc_linearedist(const char *u, unsigned long n,
-                                  const char *v, unsigned long m);
+GtUword gt_calc_linearedist(const char *u, GtUword n,
+                                  const char *v, GtUword m);
 
 #endif
