@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2010      Sascha Kastens <sascha.kastens@studium.uni-hamburg.de>
+  Copyright (c) 2010      Sascha Kastens <mail@skastens.de>
   Copyright (c)      2011 Sascha Steinbiss <steinbiss@zbh.uni-hamburg.de>
   Copyright (c) 2010-2011 Center for Bioinformatics, University of Hamburg
 
@@ -36,18 +36,18 @@
 #define READVALUES 10
 
 #define GT_MATCHER_BLAST_CANNOTPARSECOLUMN(S)\
-        gt_error_set(err,"file %s, line %lu, column %lu: %s", \
+        gt_error_set(err, "file %s, line " GT_WU ", column " GT_WU ": %s", \
                      m->pvt->matchfile, m->pvt->curpos, columncount + 1, S)
 
 #define GT_MATCHER_BLAST_CANNOTPARSELINE(S)\
-        gt_error_set(err,"file %s, line %lu: %s", \
+        gt_error_set(err, "file %s, line " GT_WU ": %s", \
                      m->pvt->matchfile, m->pvt->curpos, S)
 
 #define gt_match_iterator_blast_cast(M)\
         gt_match_iterator_cast(gt_match_iterator_blast_class(), M)
 
 typedef struct {
-  unsigned long curpos;
+  GtUword curpos;
   FILE *matchfilep;
   GtFile *gtmatchfilep;
   const char *matchfile;
@@ -66,9 +66,9 @@ static GtMatchIteratorStatus gt_match_iterator_blast_next(GtMatchIterator *gm,
                                                           GtError *err)
 {
   gt_assert(gm);
-  unsigned long columncount = 0;
-  long storeinteger[READNUMS], tmp;
-  long double e_value;
+  GtUword columncount = 0;
+  GtWord storeinteger[READNUMS], tmp;
+  double e_value;
   float bitscore, identity;
   bool reverse = false;
   char query_seq[BUFSIZ], db_seq[BUFSIZ], buffer[BUFSIZ];
@@ -87,8 +87,8 @@ static GtMatchIteratorStatus gt_match_iterator_blast_next(GtMatchIterator *gm,
     if (!m->pvt->process)
       fseek(m->pvt->matchfilep, -1, SEEK_CUR);
     readvalues = fscanf(m->pvt->matchfilep,
-                        "%s %s %f %ld %*d %*d %ld %ld %ld %ld "
-                        "%Lg %f\n", query_seq, db_seq, &identity,
+                        "%s %s %f " GT_WD " %*d %*d " GT_WD " " GT_WD " " GT_WD
+                        " " GT_WD " %lg %f\n", query_seq, db_seq, &identity,
                         &storeinteger[0],
                         &storeinteger[1], &storeinteger[2], &storeinteger[3],
                         &storeinteger[4], &e_value, &bitscore);
@@ -112,8 +112,9 @@ static GtMatchIteratorStatus gt_match_iterator_blast_next(GtMatchIterator *gm,
         i = 0;
       } else break;
     }
-    if ((readvalues = sscanf(buffer,"%s %s %f %ld %*d %*d %ld %ld %ld %ld %Lg "
-                             "%f\n", query_seq, db_seq, &identity,
+    if ((readvalues = sscanf(buffer, "%s %s %f " GT_WD " %*d %*d " GT_WD " "
+                             GT_WD " " GT_WD " " GT_WD " %lg " "%f\n",
+                             query_seq, db_seq, &identity,
                              &storeinteger[0],
                              &storeinteger[1], &storeinteger[2],
                              &storeinteger[3], &storeinteger[4], &e_value,
@@ -123,7 +124,7 @@ static GtMatchIteratorStatus gt_match_iterator_blast_next(GtMatchIterator *gm,
     }
   }
 
-  for (columncount = 0; columncount < (unsigned long) (READNUMS);
+  for (columncount = 0; !had_err && columncount < (GtUword) (READNUMS);
        columncount++) {
     if (storeinteger[columncount] < 0) {
          GT_MATCHER_BLAST_CANNOTPARSECOLUMN("non-negative integer expected");
@@ -288,7 +289,7 @@ GtMatchIterator* gt_match_iterator_blastallp_process_new(const char *query,
     sprintf(blast_call, "blastall -p blastp");
   }
   if (evalue != GT_UNDEF_DOUBLE)
-    sprintf(blast_call, "%s -e %.6f",blast_call, evalue);
+    sprintf(blast_call, "%s -e %.6f", blast_call, evalue);
   if (word_size != GT_UNDEF_INT)
     sprintf(blast_call, "%s -W %d", blast_call, word_size);
   if (gapopen != GT_UNDEF_INT)
@@ -403,7 +404,7 @@ GtMatchIterator* gt_match_iterator_blastp_process_new(const char *query,
     sprintf(blast_call, "blastp");
   }
   if (evalue != GT_UNDEF_DOUBLE)
-    sprintf(blast_call, "%s -evalue %.6f",blast_call, evalue);
+    sprintf(blast_call, "%s -evalue %.6f", blast_call, evalue);
   if (word_size != GT_UNDEF_INT)
     sprintf(blast_call, "%s -word_size %d", blast_call, word_size);
   if (gapopen != GT_UNDEF_INT)
