@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2012 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2006-2012 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2006-2008 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -96,7 +96,7 @@ static int merge_feature_visitor_feature_node(GtNodeVisitor *nv,
 {
   GtMergeFeatureVisitor *v;
   GtFeatureNode *leaf;
-  unsigned long i;
+  GtUword i;
   int had_err = 0;
   gt_error_check(err);
   v = gt_merge_feature_visitor_cast(nv);
@@ -107,7 +107,6 @@ static int merge_feature_visitor_feature_node(GtNodeVisitor *nv,
     for (i = 0; i < gt_array_size(v->nodes_to_remove); i++) {
       leaf = *(GtFeatureNode**) gt_array_get(v->nodes_to_remove, i);
       gt_feature_node_remove_leaf(fn, leaf);
-      gt_genome_node_delete((GtGenomeNode*) leaf);
     }
   }
   return had_err;
