@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2011 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2006-2011 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2006-2008 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -19,7 +19,7 @@
 #include "core/class_alloc_lock.h"
 #include "core/ma.h"
 #include "core/undef_api.h"
-#include "extended/eof_node.h"
+#include "extended/eof_node_api.h"
 #include "extended/genome_node.h"
 #include "extended/merge_stream.h"
 #include "extended/node_stream_api.h"
@@ -38,7 +38,7 @@ static int merge_stream_next(GtNodeStream *ns, GtGenomeNode **gn, GtError *err)
 {
   GtMergeStream *ms;
   GtGenomeNode *min_node = NULL;
-  unsigned long i, j, min_i = GT_UNDEF_ULONG;
+  GtUword i, j, min_i = GT_UNDEF_UWORD;
   unsigned int gt_genome_node_consolidated;
   int had_err = 0;
 
@@ -87,14 +87,14 @@ static int merge_stream_next(GtNodeStream *ns, GtGenomeNode **gn, GtError *err)
   if (!had_err) {
     for (i = 0; i < gt_array_size(ms->node_streams); i++) {
       if (ms->buffer[i]) {
-        if (min_i != GT_UNDEF_ULONG) {
+        if (min_i != GT_UNDEF_UWORD) {
           if (gt_genome_node_compare(ms->buffer + i, ms->buffer + min_i) < 0)
             min_i = i;
         }
         else min_i = i;
       }
     }
-    if (min_i != GT_UNDEF_ULONG) {
+    if (min_i != GT_UNDEF_UWORD) {
       min_node = ms->buffer[min_i];
       ms->buffer[min_i] = NULL;
     }
@@ -107,7 +107,7 @@ static int merge_stream_next(GtNodeStream *ns, GtGenomeNode **gn, GtError *err)
 static void merge_stream_free(GtNodeStream *ns)
 {
   GtMergeStream *ms = gt_merge_stream_cast(ns);
-  unsigned long i;
+  GtUword i;
   for (i = 0; i < gt_array_size(ms->node_streams); i++)
     gt_node_stream_delete(*(GtNodeStream**) gt_array_get(ms->node_streams, i));
   gt_array_delete(ms->node_streams);
@@ -132,7 +132,7 @@ GtNodeStream* gt_merge_stream_new(const GtArray *node_streams)
   GtNodeStream *in_stream,
                *ns = gt_node_stream_create(gt_merge_stream_class(), true);
   GtMergeStream *ms = gt_merge_stream_cast(ns);
-  unsigned long i;
+  GtUword i;
 #ifndef NDEBUG
   gt_assert(gt_array_size(node_streams)); /* at least on input stream given */
   /* each input stream is sorted */
