@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2012 Gordon Gremme <gordon@gremme.org>
 
   Permission to use, copy, modify, and distribute this software for any
   purpose with or without fee is hereby granted, provided that the above
@@ -105,3 +105,13 @@ const char* gt_meta_node_get_data(const GtMetaNode *m)
   gt_assert(m && m->meta_data);
   return m->meta_data;
 }
+
+GtMetaNode* gt_meta_node_try_cast(GtGenomeNode *gn)
+{
+  return gt_genome_node_try_cast(gt_meta_node_class(), gn);
+}
+
+GtMetaNode* gt_meta_node_cast(GtGenomeNode *gn)
+{
+  return gt_genome_node_cast(gt_meta_node_class(), gn);
+}
