@@ -21,7 +21,6 @@
 #include <string.h>
 #include <ctype.h>
 #include <fcntl.h>
-#include <sys/mman.h>
 #include <sys/stat.h>
 #include <unistd.h>
 #endif
@@ -31,8 +30,8 @@
 #include "core/fa.h"
 #include "core/bittab_api.h"
 #include "core/chardef.h"
+#include "core/compat.h"
 #include "core/disc_distri_api.h"
-#include "core/hashmap-generic.h"
 #include "core/log_api.h"
 #include "core/ma.h"
 #include "core/mathsupport.h"
@@ -63,7 +62,7 @@
 #define PHREDOFFSET 33
 
 #ifndef PAGESIZE
-#define PAGESIZE sysconf((int) _SC_PAGESIZE)
+#define PAGESIZE gt_pagesize()
 #endif
 #define NUMOFPAGES2MAP 100
 
@@ -79,99 +78,94 @@
 #define DEFAULTMQUAL 0
 #define DEFAULTQUAL '-'
 
-DECLARE_HASHMAP(long int, rcr_li, unsigned long long, ull, static, inline)
-DEFINE_HASHMAP(long int, rcr_li, unsigned long long, ull, gt_ht_ul_elem_hash,
-               gt_ht_ul_elem_cmp, NULL_DESTRUCTOR, NULL_DESTRUCTOR, static,
-               inline)
-
 /* TODO: use ONE struct for both, this is duplicating code and stupid */
 struct GtRcrEncoder {
-  bool cons_readlength,
-       store_all_qual,
-       store_var_qual,
-       store_mapping_qual,
-       store_unmmaped_reads,
-       is_num_fields_cons,
-       is_verbose;
-  unsigned long numofreads,
-                numofunmappedreads,
-                prev_readpos,
-                readlength,
-                max_read_length,
-                cur_read,
-                cur_seq_startpos;
-  unsigned long long present_cigar_ops[ENDOFRECORD + 1],
-                     *ins_bases,
-                     all_bits,
-                     qual_bits,
-                     mapqual_bits,
-                     dellen_bits,
-                     ins_bases_bits,
-                     vartype_bits,
-                     readlen_bits,
-                     pos_bits,
-                     varpos_bits,
-                     strand_bits,
-                     subs_bits,
-                     skiplen_bits,
-                     sclip_bits,
-                     exact_match_flag_bits,
-                     encodedbases;
-  const char *samfilename;
-  const GtEncseq *encseq;
-  GtDiscDistri *readlength_distr,
-               *readpos_distr,
-               *varpos_distr,
-               *qual_distr,
-               *qual_mapping_distr;
-  GtHuffman *readlenghts_huff,
-            *qual_huff,
-            *qual_mapping_huff,
-            *cigar_ops_huff,
-            *bases_huff;
-  GtGolomb *readpos_golomb,
-           *varpos_golomb;
-  GtSamfileIterator *sam_iter;
-  GtBitOutStream *bitstream;
-  GtCstrIterator *cstr_iterator;
-  bam1_t *sam_align;
-  GtEncdescEncoder *encdesc_enc;
-  FILE *output,
-       *unmapped_reads_ptr;
-  GtQueue *not_exact_matches;
+  FILE               *output,
+                     *unmapped_reads_ptr;
+  GtBitOutStream     *bitstream;
+  GtCstrIterator     *cstr_iterator;
+  GtDiscDistri       *readlength_distr,
+                     *readpos_distr,
+                     *varpos_distr,
+                     *qual_distr,
+                     *qual_mapping_distr;
+  GtEncdescEncoder   *encdesc_enc;
+  GtGolomb           *readpos_golomb,
+                     *varpos_golomb;
+  GtHuffman          *readlenghts_huff,
+                     *qual_huff,
+                     *qual_mapping_huff,
+                     *cigar_ops_huff,
+                     *bases_huff;
+  GtSamfileIterator  *sam_iter;
+  bam1_t             *sam_align;
+  const GtEncseq     *encseq;
+  const char         *samfilename;
+  GtUint64 *ins_bases;
+  GtQueue            *not_exact_matches;
+  GtUint64  all_bits,
+                      dellen_bits,
+                      encodedbases,
+                      exact_match_flag_bits,
+                      ins_bases_bits,
+                      mapqual_bits,
+                      pos_bits,
+                      present_cigar_ops[ENDOFRECORD + 1],
+                      qual_bits,
+                      readlen_bits,
+                      sclip_bits,
+                      skiplen_bits,
+                      strand_bits,
+                      subs_bits,
+                      varpos_bits,
+                      vartype_bits;
+  GtUword       cur_read,
+                      cur_seq_startpos,
+                      max_read_length,
+                      numofreads,
+                      numofunmappedreads,
+                      prev_readpos,
+                      readlength;
+  bool                cons_readlength,
+                      is_num_fields_cons,
+                      is_verbose,
+                      store_all_qual,
+                      store_mapping_qual,
+                      store_unmmaped_reads,
+                      store_var_qual;
 };
 
 struct GtRcrDecoder {
-  bool cons_readlength,
-       store_all_qual,
-       store_var_qual,
-       store_mapping_qual,
-       is_num_fields_cons;
-  unsigned long numofreads,
-                cur_bit,
-                cur_bitseq,
-                readlength,
-                startofencoding;
-  const char *basename;
-  GtStr *inputname;
-  unsigned long long present_cigar_ops[ENDOFRECORD + 1],
-                     *ins_bases;
-  GtHuffman *readlenghts_huff,
-            *qual_huff,
-            *qual_mapping_huff,
-            *cigar_ops_huff,
-            *bases_huff;
-  GtGolomb *readpos_golomb,
-           *varpos_golomb;
-  FILE *fp;
-  const GtEncseq *encseq;
-  GtEncdesc *encdesc;
+  FILE               *fp;
+  GtEncdesc          *encdesc;
+  GtGolomb           *readpos_golomb,
+                     *varpos_golomb;
+  GtHuffman          *readlenghts_huff,
+                     *qual_huff,
+                     *qual_mapping_huff,
+                     *cigar_ops_huff,
+                     *bases_huff;
+  GtStr              *inputname;
+  const GtEncseq     *encseq;
+  const char         *basename;
+  GtUint64 *ins_bases;
+  GtUint64  present_cigar_ops[ENDOFRECORD + 1];
+  GtUword       numofreads,
+                      cur_bit,
+                      cur_bitseq,
+                      readlength,
+                      startofencoding;
+  bool                cons_readlength,
+                      store_all_qual,
+                      store_var_qual,
+                      store_mapping_qual,
+                      is_num_fields_cons;
 };
 
 typedef struct MedianData {
-  unsigned long long n,
+  GtUint64 n,
                      x;
-  unsigned long median;
+  GtUword      median;
 } MedianData;
 
 static inline char rcr_bambase2char(uint8_t base)
@@ -254,7 +248,7 @@ static GtBitsequence rcr_transencode(GtUchar ref, GtUchar base,
     if (base == code_t)
       return (GtBitsequence) 3;
   }
-  return (GtBitsequence) GT_UNDEF_ULONG;
+  return (GtBitsequence) GT_UNDEF_UWORD;
 }
 
 static GtUchar rcr_transdecode(GtUchar ref, GtBitsequence transcode,
@@ -326,7 +320,7 @@ static GtUchar rcr_transdecode(GtUchar ref, GtBitsequence transcode,
 
 static void rcr_convert_cigar_string(GtStr *cigar_str)
 {
-  unsigned long i,
+  GtUword i,
                 cur_cigar_len = 1UL;
   char cur_cigar_op = gt_str_get(cigar_str)[0];
   GtStr *new_cigar_str = gt_str_new();
@@ -355,9 +349,9 @@ static void rcr_convert_cigar_string(GtStr *cigar_str)
 }
 
 static void rcr_write_read_to_file(FILE *fp, uint8_t *seq, uint8_t *qual,
-                                  const char *desc, unsigned long seq_l)
+                                  const char *desc, GtUword seq_l)
 {
-  unsigned long i,
+  GtUword i,
                 cur_width;
   gt_xfputc(DESCSEPSEQ, fp);
   gt_xfputs(desc, fp);
@@ -386,7 +380,7 @@ static void rcr_write_read_to_file(FILE *fp, uint8_t *seq, uint8_t *qual,
 
 static void rcr_huff_encode_write(GtRcrEncoder *rcr_enc,
                                   GtHuffman *huff,
-                                  unsigned long val)
+                                  GtUword val)
 {
   GtBitsequence code;
   unsigned bits_to_write;
@@ -399,10 +393,10 @@ static void rcr_huff_encode_write(GtRcrEncoder *rcr_enc,
 
 static void rcr_golomb_encode_write(GtRcrEncoder *rcr_enc,
                                     GtGolomb *gol,
-                                    unsigned long val)
+                                    GtUword val)
 {
   GtBittab *code = gt_golomb_encode(gol, val);
-  unsigned long size = gt_bittab_size(code);
+  GtUword size = gt_bittab_size(code);
   rcr_enc->all_bits += size;
   rcr_enc->varpos_bits += size;
   gt_bitoutstream_append_bittab(rcr_enc->bitstream, code);
@@ -410,10 +404,10 @@ static void rcr_golomb_encode_write(GtRcrEncoder *rcr_enc,
 }
 
 static void rcr_elias_encode_write(GtRcrEncoder *rcr_enc,
-                                   unsigned long val)
+                                   GtUword val)
 {
   GtBittab *code = gt_elias_gamma_encode(val);
-  unsigned long size = gt_bittab_size(code);
+  GtUword size = gt_bittab_size(code);
   rcr_enc->all_bits += size;
   rcr_enc->dellen_bits += size;
   gt_bitoutstream_append_bittab(rcr_enc->bitstream, code);
@@ -421,13 +415,13 @@ static void rcr_elias_encode_write(GtRcrEncoder *rcr_enc,
 }
 
 static void rcr_encode_write_var_type(GtRcrEncoder *rcr_enc,
-                                      unsigned long cigar_op)
+                                      GtUword cigar_op)
 {
   rcr_huff_encode_write(rcr_enc, rcr_enc->cigar_ops_huff, cigar_op);
 }
 
 static void rcr_encode_write_var_pos(GtRcrEncoder *rcr_enc,
-                                     unsigned long rel_varpos)
+                                     GtUword rel_varpos)
 {
   rcr_golomb_encode_write(rcr_enc, rcr_enc->varpos_golomb, rel_varpos);
 }
@@ -443,11 +437,11 @@ static int rcr_write_read_encoding(const bam1_t *alignment,
   int had_err = 0;
   GtUchar ref,
           base;
-  unsigned long cigar_op,
+  GtUword cigar_op,
                 cigar_len;
   unsigned bits_to_write,
            one_bit = 1U;
-  unsigned long alpha_size,
+  GtUword alpha_size,
                 i,
                 j,
                 prev_varpos,
@@ -468,7 +462,7 @@ static int rcr_write_read_encoding(const bam1_t *alignment,
   const bam1_core_t *core;
   GtAlphabet *encseq_alpha = gt_encseq_alphabet(rcr_enc->encseq);
 
-  alpha_size = (unsigned long) gt_alphabet_size(encseq_alpha);
+  alpha_size = (GtUword) gt_alphabet_size(encseq_alpha);
 
   core = &alignment->core;
   qual_string = bam1_qual(alignment);
@@ -485,7 +479,7 @@ static int rcr_write_read_encoding(const bam1_t *alignment,
                              seq_string,
                              qual_string,
                              bam1_qname(alignment),
-                             (unsigned long) core->l_qseq);
+                             (GtUword) core->l_qseq);
     gt_bitoutstream_append(rcr_enc->bitstream, one, one_bit);
     return 0;
   }
@@ -494,7 +488,7 @@ static int rcr_write_read_encoding(const bam1_t *alignment,
 
   /* encode read length */
   if (!rcr_enc->cons_readlength) {
-    readlength = (unsigned long) core->l_qseq;
+    readlength = (GtUword) core->l_qseq;
     rcr_huff_encode_write(rcr_enc, rcr_enc->readlenghts_huff, readlength);
   }
   else
@@ -516,13 +510,13 @@ static int rcr_write_read_encoding(const bam1_t *alignment,
 
   /* write mapping qual */
   if (rcr_enc->store_mapping_qual) {
-    qual = (unsigned long) core->qual;
+    qual = (GtUword) core->qual;
     rcr_huff_encode_write(rcr_enc, rcr_enc->qual_mapping_huff, qual);
   }
   /* encode qual string */
   if (rcr_enc->store_all_qual) {
     for (i = 0; i < readlength; i++) {
-      qual = ((unsigned long) qual_string[i]) + PHREDOFFSET;
+      qual = ((GtUword) qual_string[i]) + PHREDOFFSET;
       rcr_huff_encode_write(rcr_enc, rcr_enc->qual_huff, qual);
     }
   }
@@ -546,12 +540,12 @@ static int rcr_write_read_encoding(const bam1_t *alignment,
 
     prev_varpos = 0;
 
-    for (i = 0; i < (unsigned long) core->n_cigar; i++) {
+    for (i = 0; i < (GtUword) core->n_cigar; i++) {
       gt_safe_assign(cigar_op, (cigar[i] & 0xf));
       gt_safe_assign(cigar_len, (cigar[i]>>4));
 
-      if (cigar_op == (unsigned long) BAM_CEQUAL ||
-          cigar_op == (unsigned long) BAM_CDIFF)
+      if (cigar_op == (GtUword) BAM_CEQUAL ||
+          cigar_op == (GtUword) BAM_CDIFF)
         cigar_op = BAM_CMATCH;
 
       switch (cigar_op) {
@@ -564,7 +558,7 @@ static int rcr_write_read_encoding(const bam1_t *alignment,
               rcr_bambase2gtbase((uint8_t) bam1_seqi(seq_string, read_i + j),
                                  encseq_alpha);
             if (ref != base) {
-              rcr_encode_write_var_type(rcr_enc, (unsigned long) cigar_op);
+              rcr_encode_write_var_type(rcr_enc, (GtUword) cigar_op);
 
               /* encode variation position */
               varpos = read_i + j;
@@ -582,7 +576,7 @@ static int rcr_write_read_encoding(const bam1_t *alignment,
               gt_bitoutstream_append(rcr_enc->bitstream, code, bits_to_write);
 
               if (rcr_enc->store_var_qual) {
-                qual = ((unsigned long) qual_string[varpos]) + PHREDOFFSET;
+                qual = ((GtUword) qual_string[varpos]) + PHREDOFFSET;
                 rcr_huff_encode_write(rcr_enc, rcr_enc->qual_huff, qual);
               }
             }
@@ -593,7 +587,7 @@ static int rcr_write_read_encoding(const bam1_t *alignment,
 
         case BAM_CDEL:
         case BAM_CREF_SKIP:
-          rcr_encode_write_var_type(rcr_enc, (unsigned long) cigar_op);
+          rcr_encode_write_var_type(rcr_enc, (GtUword) cigar_op);
 
           /* encode variation position */
           varpos = read_i;
@@ -608,7 +602,7 @@ static int rcr_write_read_encoding(const bam1_t *alignment,
 
         case BAM_CINS:
         case BAM_CSOFT_CLIP:
-          rcr_encode_write_var_type(rcr_enc, (unsigned long) cigar_op);
+          rcr_encode_write_var_type(rcr_enc, (GtUword) cigar_op);
 
           /* encode varation position */
           varpos = read_i;
@@ -628,7 +622,7 @@ static int rcr_write_read_encoding(const bam1_t *alignment,
               base = (GtUchar) (alpha_size - 1);
 
             rcr_huff_encode_write(rcr_enc, rcr_enc->bases_huff,
-                                  (unsigned long) base);
+                                  (GtUword) base);
           }
 
           /* append end symbol */
@@ -636,7 +630,7 @@ static int rcr_write_read_encoding(const bam1_t *alignment,
 
           if (rcr_enc->store_var_qual) {
             for (j = 0; j < cigar_len; j++) {
-              qual = ((unsigned long) qual_string[read_i + j]) + PHREDOFFSET;
+              qual = ((GtUword) qual_string[read_i + j]) + PHREDOFFSET;
               rcr_huff_encode_write(rcr_enc, rcr_enc->qual_huff, qual);
             }
           }
@@ -644,16 +638,16 @@ static int rcr_write_read_encoding(const bam1_t *alignment,
           break;
         default:
           /* XXX gt_error nutzen */
-          gt_log_log("encountered funny cigar_op: %lu", cigar_op);
+          gt_log_log("encountered funny cigar_op: "GT_WU"", cigar_op);
           return -1;
           ;
       }
     }
     /* end symbol of a record */
-    rcr_encode_write_var_type(rcr_enc, (unsigned long) ENDOFRECORD);
+    rcr_encode_write_var_type(rcr_enc, (GtUword) ENDOFRECORD);
     if (readlength != read_i) {
       /* XXX gt_error nutzen */
-      gt_log_log("readlength: %lu, read_i: %lu", readlength, read_i);
+      gt_log_log("readlength: "GT_WU", read_i: "GT_WU"", readlength, read_i);
       return -1;
     }
   }
@@ -666,31 +660,31 @@ static int rcr_write_read_encoding(const bam1_t *alignment,
   return 0;
 }
 
-static void rcr_get_m(unsigned long key, unsigned long long value,
+static void rcr_get_m(GtUword key, GtUint64 value,
                       void *data)
 {
   MedianData *md = (MedianData*) data;
   md->x = md->x + value;
-  if (md->x > (md->n) / 2 && (md->median == GT_UNDEF_ULONG))
+  if (md->x > (md->n) / 2 && (md->median == GT_UNDEF_UWORD))
     md->median = key;
 }
 
-static void rcr_get_n(GT_UNUSED unsigned long key, unsigned long long value,
+static void rcr_get_n(GT_UNUSED GtUword key, GtUint64 value,
                       void *data)
 {
   MedianData *md = (MedianData*) data;
   md->n = md->n + value;
 }
 
-static unsigned long rcr_get_median(GtDiscDistri *distr)
+static GtUword rcr_get_median(GtDiscDistri *distr)
 {
-  unsigned long median;
+  GtUword median;
   MedianData *md;
 
   md = gt_malloc(sizeof (MedianData));
   md->n = 0;
   md->x = 0;
-  md->median = GT_UNDEF_ULONG;
+  md->median = GT_UNDEF_UWORD;
   gt_disc_distri_foreach(distr, rcr_get_n, md);
   gt_disc_distri_foreach(distr, rcr_get_m, md);
   median = md->median;
@@ -698,17 +692,17 @@ static unsigned long rcr_get_median(GtDiscDistri *distr)
   return median;
 }
 
-static unsigned long long rcr_disc_distri_func(const void *data,
-                                               unsigned long symbol)
+static GtUint64 rcr_disc_distri_func(const void *data,
+                                               GtUword symbol)
 {
   GtDiscDistri *distr = (GtDiscDistri*)data;
   return gt_disc_distri_get(distr, symbol);
 }
 
-static unsigned long long rcr_array_func(const void *data, unsigned long symbol)
+static GtUint64 rcr_array_func(const void *data, GtUword symbol)
 {
-  unsigned long *distr = (unsigned long*)data;
-  return (unsigned long long) distr[symbol];
+  GtUword *distr = (GtUword*)data;
+  return (GtUint64) distr[symbol];
 }
 
 static int rcr_initialize_encoders(GtRcrEncoder *rcr_enc,
@@ -716,13 +710,13 @@ static int rcr_initialize_encoders(GtRcrEncoder *rcr_enc,
                                    GtError *err)
 {
   bool has_var = true;
-  unsigned long median;
+  GtUword median;
 
   if (timer != NULL)
     gt_timer_show_progress(timer, "initializing encoders", stdout);
 
   median = rcr_get_median(rcr_enc->readpos_distr);
-  if (median == GT_UNDEF_ULONG) {
+  if (median == GT_UNDEF_UWORD) {
     gt_error_set(err, "no mapped reads present in %s",rcr_enc->samfilename);
     return -1;
   }
@@ -735,7 +729,7 @@ static int rcr_initialize_encoders(GtRcrEncoder *rcr_enc,
   median = rcr_get_median(rcr_enc->varpos_distr);
 
   /* no variations present -> have only exact matches */
-  if (median == GT_UNDEF_ULONG)
+  if (median == GT_UNDEF_UWORD)
     has_var = false;
 
   if (median == 0)
@@ -773,7 +767,7 @@ static int rcr_initialize_encoders(GtRcrEncoder *rcr_enc,
   rcr_enc->bases_huff =
     gt_huffman_new(rcr_enc->ins_bases,
                    rcr_array_func,
-                   (unsigned long)
+                   (GtUword)
                      gt_alphabet_size(gt_encseq_alphabet(rcr_enc->encseq)) + 1);
   if (!(rcr_enc->bases_huff)) {
     gt_error_set(err, "unable to initialize GtHuffmanCoding object");
@@ -787,7 +781,7 @@ static int rcr_get_read_infos(const bam1_t *alignment, GtRcrEncoder *rcr_enc)
 {
   uint32_t *cigar;
   const bam1_core_t *bam_core;
-  unsigned long i,
+  GtUword i,
                 j,
                 rel_readpos,
                 readpos,
@@ -815,9 +809,9 @@ static int rcr_get_read_infos(const bam1_t *alignment, GtRcrEncoder *rcr_enc)
     return 0;
   if (rcr_enc->store_mapping_qual)
     gt_disc_distri_add(rcr_enc->qual_mapping_distr,
-                       (unsigned long) bam_core->qual);
+                       (GtUword) bam_core->qual);
 
-  readlength = (unsigned long) bam_core->l_qseq;
+  readlength = (GtUword) bam_core->l_qseq;
   gt_disc_distri_add(rcr_enc->readlength_distr, readlength);
   if (rcr_enc->readlength == 0) {
     rcr_enc->readlength = readlength;
@@ -833,12 +827,12 @@ static int rcr_get_read_infos(const bam1_t *alignment, GtRcrEncoder *rcr_enc)
 
   if (rcr_enc->store_all_qual) {
     for (j = 0; j < readlength; j++) {
-      q = ((unsigned long) qual_string[j]) + PHREDOFFSET;
+      q = ((GtUword) qual_string[j]) + PHREDOFFSET;
       gt_disc_distri_add(rcr_enc->qual_distr, q);
     }
   }
 
-  readpos = (unsigned long) bam_core->pos;
+  readpos = (GtUword) bam_core->pos;
   ref_i = readpos;
   read_i = 0;
 
@@ -849,7 +843,7 @@ static int rcr_get_read_infos(const bam1_t *alignment, GtRcrEncoder *rcr_enc)
   varpos = 0;
   prev_varpos = 0;
 
-  for (i = 0; i < (unsigned long) bam_core->n_cigar; i++) {
+  for (i = 0; i < (GtUword) bam_core->n_cigar; i++) {
     GtAlphabet *alpha = gt_encseq_alphabet(rcr_enc->encseq);
     unsigned int alpha_size = gt_alphabet_size(alpha);
 
@@ -861,7 +855,7 @@ static int rcr_get_read_infos(const bam1_t *alignment, GtRcrEncoder *rcr_enc)
       cigar_op = BAM_CMATCH;
     switch (cigar_op) {
       case BAM_CMATCH:
-        for (j = 0; j < (unsigned long) cigar_len; j++) {
+        for (j = 0; j < (GtUword) cigar_len; j++) {
           base = rcr_bambase2gtbase((uint8_t) bam1_seqi(seq_string, read_i + j),
                                 alpha);
           ref = gt_encseq_get_encoded_char(rcr_enc->encseq,
@@ -873,7 +867,7 @@ static int rcr_get_read_infos(const bam1_t *alignment, GtRcrEncoder *rcr_enc)
             varpos = read_i + j;
 
             if (rcr_enc->store_var_qual) {
-              q = ((unsigned long) qual_string[read_i + j]) + PHREDOFFSET;
+              q = ((GtUword) qual_string[read_i + j]) + PHREDOFFSET;
               gt_disc_distri_add(rcr_enc->qual_distr, q);
             }
           }
@@ -887,7 +881,7 @@ static int rcr_get_read_infos(const bam1_t *alignment, GtRcrEncoder *rcr_enc)
         exact_match = false;
         varpos = read_i;
 
-        for (j = 0; j < (unsigned long) cigar_len; j++) {
+        for (j = 0; j < (GtUword) cigar_len; j++) {
           base = rcr_bambase2gtbase((uint8_t) bam1_seqi(seq_string, read_i + j),
                                    alpha);
 
@@ -900,8 +894,8 @@ static int rcr_get_read_infos(const bam1_t *alignment, GtRcrEncoder *rcr_enc)
         }
 
         if (rcr_enc->store_var_qual) {
-          for (j = 0; j < (unsigned long) cigar_len; j++) {
-            q = ((unsigned long) qual_string[read_i + j]) + PHREDOFFSET;
+          for (j = 0; j < (GtUword) cigar_len; j++) {
+            q = ((GtUword) qual_string[read_i + j]) + PHREDOFFSET;
             gt_disc_distri_add(rcr_enc->qual_distr, q);
           }
         }
@@ -927,7 +921,7 @@ static int rcr_get_read_infos(const bam1_t *alignment, GtRcrEncoder *rcr_enc)
         exact_match = false;
         varpos = read_i;
 
-        for (j = 0; j < (unsigned long) cigar_len; j++) {
+        for (j = 0; j < (GtUword) cigar_len; j++) {
           base = rcr_bambase2gtbase((uint8_t) bam1_seqi(seq_string, read_i + j),
                                    alpha);
 
@@ -941,8 +935,8 @@ static int rcr_get_read_infos(const bam1_t *alignment, GtRcrEncoder *rcr_enc)
         rcr_enc->ins_bases[alpha_size]++;
 
         if (rcr_enc->store_var_qual) {
-          for (j = 0; j < (unsigned long) cigar_len; j++) {
-            q = ((unsigned long) qual_string[read_i + j]) + PHREDOFFSET;
+          for (j = 0; j < (GtUword) cigar_len; j++) {
+            q = ((GtUword) qual_string[read_i + j]) + PHREDOFFSET;
             gt_disc_distri_add(rcr_enc->qual_distr, q);
           }
         }
@@ -970,7 +964,7 @@ static inline GtRcrEncoder *gt_rcr_encoder_init(const char *filename,
                                                 const GtEncseq *ref)
 {
   unsigned alpha_size= gt_alphabet_size(gt_encseq_alphabet(ref));
-  unsigned long i;
+  GtUword i;
 
   GtRcrEncoder *rcr_enc = gt_malloc(sizeof (*rcr_enc));
 
@@ -1008,11 +1002,11 @@ static inline GtRcrEncoder *gt_rcr_encoder_init(const char *filename,
   rcr_enc->readlength = 0;
 
   rcr_enc->ins_bases = gt_calloc((size_t) (alpha_size + 1),
-                              sizeof (unsigned long long));
-  for (i = 0; i < (unsigned long) (alpha_size + 1); i ++)
+                              sizeof (GtUint64));
+  for (i = 0; i < (GtUword) (alpha_size + 1); i ++)
     rcr_enc->ins_bases[i] = 0;
 
-  for (i = 0; i <= (unsigned long) ENDOFRECORD; i++)
+  for (i = 0; i <= (GtUword) ENDOFRECORD; i++)
     rcr_enc->present_cigar_ops[i] = 0;
 
   return rcr_enc;
@@ -1044,9 +1038,9 @@ static inline int gt_rcr_analyse_alignment_data(GtRcrEncoder *rcr_enc,
       rcr_enc->prev_readpos = 0;
       seq_id = rcr_enc->sam_align->core.tid;
       rcr_enc->cur_seq_startpos = gt_encseq_seqstartpos(rcr_enc->encseq,
-                                                        (unsigned long) seq_id);
+                                                        (GtUword) seq_id);
     }
-    if (rcr_enc->prev_readpos > (unsigned long) rcr_enc->sam_align->core.pos) {
+    if (rcr_enc->prev_readpos > (GtUword) rcr_enc->sam_align->core.pos) {
       gt_error_set(err, "file %s is not sorted", rcr_enc->samfilename);
       had_err = -1;
     }
@@ -1062,7 +1056,7 @@ static inline int gt_rcr_analyse_alignment_data(GtRcrEncoder *rcr_enc,
   }
 
   /* end symbol */
-  rcr_enc->present_cigar_ops[ENDOFRECORD] = (unsigned long long)
+  rcr_enc->present_cigar_ops[ENDOFRECORD] = (GtUint64)
                                               rcr_enc->numofreads;
   samclose(samfile);
 
@@ -1155,8 +1149,8 @@ typedef struct{
   FILE *fp;
 } RcrData;
 
-static int rcr_write_node(unsigned long symbol,
-                          unsigned long long freq,
+static int rcr_write_node(GtUword symbol,
+                          GtUint64 freq,
                           GT_UNUSED GtBitsequence code,
                           GT_UNUSED unsigned length,
                           void *pt)
@@ -1177,7 +1171,7 @@ static int rcr_write_distr_to_file(FILE *fp, GtHuffman *huff)
 
 static int rcr_write_header_to_file(GtRcrEncoder *rcr_enc)
 {
-  unsigned long numofleaves,
+  GtUword numofleaves,
                 m;
   FILE *fp = rcr_enc->output;
 
@@ -1220,14 +1214,14 @@ static int rcr_write_header_to_file(GtRcrEncoder *rcr_enc)
   if (rcr_enc->varpos_golomb != NULL)
     m = gt_golomb_get_m(rcr_enc->varpos_golomb);
   else
-    m = GT_UNDEF_ULONG;
+    m = GT_UNDEF_UWORD;
 
   gt_xfwrite_one(&m, fp);
 
   gt_xfwrite(rcr_enc->present_cigar_ops, sizeof (*rcr_enc->present_cigar_ops),
              (size_t) (ENDOFRECORD + 1), fp);
 
-  gt_xfwrite(rcr_enc->ins_bases, sizeof (unsigned long long),
+  gt_xfwrite(rcr_enc->ins_bases, sizeof (GtUint64),
              (size_t) gt_alphabet_size(gt_encseq_alphabet(rcr_enc->encseq)) + 1,
              fp);
 
@@ -1274,9 +1268,9 @@ static int rcr_write_encoding_to_file(GtRcrEncoder *rcr_enc, GtError *err)
       tid = rcr_enc->sam_align->core.tid;
       rcr_enc->prev_readpos = 0;
       rcr_enc->cur_seq_startpos =
-        gt_encseq_seqstartpos(rcr_enc->encseq, (unsigned long) tid);
+        gt_encseq_seqstartpos(rcr_enc->encseq, (GtUword) tid);
       gt_bitoutstream_append(rcr_enc->bitstream, new_ref, one_bit);
-      gt_log_log("reset pos for new ref %lu", rcr_enc->cur_seq_startpos);
+      gt_log_log("reset pos for new ref "GT_WU"", rcr_enc->cur_seq_startpos);
     }
     else
       gt_bitoutstream_append(rcr_enc->bitstream, old_ref, one_bit);
@@ -1291,10 +1285,11 @@ static int rcr_write_encoding_to_file(GtRcrEncoder *rcr_enc, GtError *err)
 
 #ifndef S_SPLINT_S
   if (rcr_enc->is_verbose) {
-    printf("encoded %lu BAM records, %lu reads(s) unmapped\n",
+    printf("encoded "GT_WU" BAM records, "GT_WU" reads(s) unmapped\n",
            rcr_enc->numofreads, rcr_enc->numofunmappedreads);
-    printf("encoded %llu bases\n",rcr_enc->encodedbases);
-    printf("total number of bits used for encoding: %llu\n", rcr_enc->all_bits);
+    printf("encoded "GT_LLU" bases\n",rcr_enc->encodedbases);
+    printf("total number of bits used for encoding: "GT_LLU"\n",
+           rcr_enc->all_bits);
     printf("%% bits used for quality values: %.3f\n",
            rcr_enc->qual_bits * 100.0 / rcr_enc->all_bits);
     printf("%% bits used for mapping quality values: %.3f\n",
@@ -1331,8 +1326,8 @@ static int rcr_write_data(const char *name, GtRcrEncoder *rcr_enc, GtError *err)
 {
   bool is_not_at_pageborder;
   int had_err = 0;
-  long fpos,
-       pagesize = sysconf((int) _SC_PAGESIZE);
+  GtWord fpos;
+  GtUword pagesize = gt_pagesize();
   GtStr *unmapped_reads_filename;
   gt_error_check(err);
 
@@ -1412,12 +1407,12 @@ void gt_rcr_encoder_disable_verbosity(GtRcrEncoder *rcr_enc)
 static void rcr_read_header(GtRcrDecoder *rcr_dec)
 {
   unsigned alpha_size;
-  unsigned long numofleaves,
+  GtUword numofleaves,
                 m,
                 i,
                 symbol,
                 max_read_length;
-  unsigned long long freq;
+  GtUint64 freq;
   GT_UNUSED size_t read,
             one = (size_t) 1;
 
@@ -1504,7 +1499,7 @@ static void rcr_read_header(GtRcrDecoder *rcr_dec)
 
   read = gt_xfread_one(&m, rcr_dec->fp);
   gt_assert(read == one);
-  if (m != GT_UNDEF_ULONG) {
+  if (m != GT_UNDEF_UWORD) {
     rcr_dec->varpos_golomb = gt_golomb_new(m);
   }
 
@@ -1517,7 +1512,7 @@ static void rcr_read_header(GtRcrDecoder *rcr_dec)
   rcr_dec->cigar_ops_huff =
     gt_huffman_new(rcr_dec->present_cigar_ops,
                    rcr_array_func,
-                   (unsigned long) (ENDOFRECORD + 1));
+                   (GtUword) (ENDOFRECORD + 1));
 
   alpha_size = gt_alphabet_size(gt_encseq_alphabet(rcr_dec->encseq));
   read = gt_xfread(rcr_dec->ins_bases,
@@ -1529,7 +1524,7 @@ static void rcr_read_header(GtRcrDecoder *rcr_dec)
   rcr_dec->bases_huff =
     gt_huffman_new(rcr_dec->ins_bases,
                    rcr_array_func,
-                   (unsigned long) (alpha_size + 1));
+                   (GtUword) (alpha_size + 1));
   gt_assert(rcr_dec->bases_huff != NULL);
 
 }
@@ -1544,23 +1539,23 @@ static void rcr_read_header(GtRcrDecoder *rcr_dec)
    })
 
 typedef struct RcrDecodeInfo {
-  GtStr *base_string,
-        *qual_string,
-        *cigar_string;
-  GtHuffmanBitwiseDecoder *base_hbwd,
-                          *qual_hbwd,
-                          *cigar_hbwd;
-  GtGolombBitwiseDecoder *varpos_gbwd;
+  GtAlphabet                 *alphabet;
   GtEliasGammaBitwiseDecoder *del_len_ebwd;
-  GtAlphabet *alphabet;
-  unsigned long alpha_size,
-                offset,
-                inserted_bases;
+  GtGolombBitwiseDecoder     *varpos_gbwd;
+  GtHuffmanBitwiseDecoder    *base_hbwd,
+                             *qual_hbwd,
+                             *cigar_hbwd;
+  GtStr                      *base_string,
+                             *qual_string,
+                             *cigar_string;
+  GtUword               alpha_size,
+                              offset,
+                              inserted_bases;
 } RcrDecodeInfo;
 
 static int rcr_huff_read(GtHuffmanBitwiseDecoder *hbwd,
                          GtBitInStream *bitstream,
-                         unsigned long *val,
+                         GtUword *val,
                          GtError *err)
 {
   bool bit;
@@ -1578,12 +1573,12 @@ static int rcr_huff_read(GtHuffmanBitwiseDecoder *hbwd,
 
 static int rcr_huff_read_string(GtHuffmanBitwiseDecoder *hbwd,
                                 GtBitInStream *bitstream,
-                                unsigned long length,
+                                GtUword length,
                                 GtStr *str,
                                 GtError *err)
 {
   int had_err = 0;
-  unsigned long symbol,
+  GtUword symbol,
                 read = 0;
   while (!had_err && read < length) {
     had_err = rcr_huff_read(hbwd, bitstream, &symbol, err);
@@ -1597,7 +1592,7 @@ static int rcr_huff_read_string(GtHuffmanBitwiseDecoder *hbwd,
 
 static int rcr_golomb_read(GtGolombBitwiseDecoder *gbwd,
                            GtBitInStream *bitstream,
-                           unsigned long *val,
+                           GtUword *val,
                            GtError *err)
 {
   bool bit;
@@ -1616,11 +1611,11 @@ static int rcr_golomb_read(GtGolombBitwiseDecoder *gbwd,
 /* XXX struct with all strings, and struct with info */
 static void rcr_decode_exact_range(GtRcrDecoder *rcr_dec,
                                    RcrDecodeInfo *info,
-                                   unsigned long start,
-                                   unsigned long end)
+                                   GtUword start,
+                                   GtUword end)
 {
   GtUchar ref;
-  unsigned long i;
+  GtUword i;
   for (i = start; i < end ; i++) {
     ref = (GtUchar) gt_encseq_get_decoded_char(rcr_dec->encseq, i,
                                                GT_READMODE_FORWARD);
@@ -1633,15 +1628,15 @@ static void rcr_decode_exact_range(GtRcrDecoder *rcr_dec,
 
 static void rcr_decode_exact(GtRcrDecoder *rcr_dec,
                              RcrDecodeInfo *info,
-                             unsigned long readlength,
-                             unsigned long seqstart,
-                             unsigned long readpos)
+                             GtUword readlength,
+                             GtUword seqstart,
+                             GtUword readpos)
 {
   rcr_decode_exact_range(rcr_dec, info, seqstart + readpos,
                          seqstart + readpos + readlength);
 }
 
-static int rcr_decode_mismatch(GtRcrDecoder *rcr_dec, unsigned long pos,
+static int rcr_decode_mismatch(GtRcrDecoder *rcr_dec, GtUword pos,
                                RcrDecodeInfo *info, GtBitInStream *bitstream,
                                GtError *err)
 {
@@ -1676,7 +1671,7 @@ static int rcr_decode_mismatch_qual(GtRcrDecoder *rcr_dec,
                                     GtError *err)
 {
   int had_err = 0;
-  unsigned long symbol = 0;
+  GtUword symbol = 0;
 
   if (rcr_dec->store_var_qual) {
     had_err = rcr_huff_read(info->qual_hbwd, bitstream, &symbol, err);
@@ -1696,7 +1691,7 @@ static int rcr_decode_insert_var(GtRcrDecoder *rcr_dec,
                                  GtError *err)
 {
   int had_err = 0;
-  unsigned long symbol = 0, i;
+  GtUword symbol = 0, i;
   GtUchar base;
 
   info->inserted_bases = 0;
@@ -1736,7 +1731,7 @@ static int rcr_decode_insert_var(GtRcrDecoder *rcr_dec,
 
 static inline int rcr_elias_read(GtEliasGammaBitwiseDecoder *ebwd,
                                  GtBitInStream *bitstream,
-                                 unsigned long *symbol,
+                                 GtUword *symbol,
                                  GtError *err)
 {
   bool bit;
@@ -1756,7 +1751,7 @@ static int rcr_decode_delete_var(RcrDecodeInfo *info,
 {
   /* XXX remove loop and just set in as xD */
   int had_err = 0;
-  unsigned long del_length , i;
+  GtUword del_length , i;
   had_err = rcr_elias_read(info->del_len_ebwd, bitstream, &del_length, err);
   if (!had_err) {
     for (i = 0; i < del_length; i++)
@@ -1785,7 +1780,7 @@ static RcrDecodeInfo *rcr_init_decode_info(GtRcrDecoder *rcr_dec, GtError *err)
     info->del_len_ebwd = gt_elias_gamma_bitwise_decoder_new();
 
     info->alphabet = gt_encseq_alphabet(rcr_dec->encseq);
-    info->alpha_size = (unsigned long) gt_alphabet_size(info->alphabet);
+    info->alpha_size = (GtUword) gt_alphabet_size(info->alphabet);
     info->qual_hbwd = NULL;
     info->varpos_gbwd = NULL;
     info->base_string = gt_str_new();
@@ -1826,13 +1821,13 @@ static void rcr_delete_decode_info(RcrDecodeInfo *info)
 static inline int rcr_decode_inexact(GtRcrDecoder *rcr_dec,
                                      GtBitInStream *bitstream,
                                      RcrDecodeInfo *info,
-                                     unsigned long seq_i,
-                                     unsigned long readlength,
+                                     GtUword seq_i,
+                                     GtUword readlength,
                                      GtError *err)
 {
   int had_err = 0,
       cigar_op = GT_UNDEF_INT;
-  unsigned long end,
+  GtUword end,
                 prev_varpos = 0,
                 read_i = 0,
                 rel_varpos = 0,
@@ -1914,7 +1909,7 @@ static int rcr_write_decoding_to_file(GtRcrDecoder *rcr_dec, GtError *err)
        strand;
   int had_err = 0;
   uint32_t mapping_qual = 0;
-  unsigned long
+  GtUword
                 cur_read = 0,
                 i,
                 l,
@@ -1958,11 +1953,11 @@ static int rcr_write_decoding_to_file(GtRcrDecoder *rcr_dec, GtError *err)
 
     for (i = 0; i < gt_encseq_num_of_sequences(rcr_dec->encseq); i++) {
       const char *seqname = gt_encseq_description(rcr_dec->encseq, &l, i);
-      unsigned long len = gt_encseq_seqlength(rcr_dec->encseq, i);
-      fprintf(rcr_dec->fp, "@SQ\tSN:%.*s\tLN:%lu\n", (int) l, seqname, len);
+      GtUword len = gt_encseq_seqlength(rcr_dec->encseq, i);
+      fprintf(rcr_dec->fp, "@SQ\tSN:%.*s\tLN:"GT_WU"\n", (int) l, seqname, len);
     }
 
-    gt_log_log("start to decode %lu reads", rcr_dec->numofreads);
+    gt_log_log("start to decode "GT_WU" reads", rcr_dec->numofreads);
   }
 
   while (!had_err &&
@@ -1972,7 +1967,7 @@ static int rcr_write_decoding_to_file(GtRcrDecoder *rcr_dec, GtError *err)
     if (RCR_NEXT_BIT(bit)) {
       if (bit) {
         seqstart = gt_encseq_seqstartpos(rcr_dec->encseq, refnum);
-        gt_log_log("get start for new ref %lu: %lu", refnum, seqstart);
+        gt_log_log("get start for new ref "GT_WU": "GT_WU"", refnum, seqstart);
         refnum++;
         prev_readpos = 0;
       }
@@ -2033,7 +2028,7 @@ static int rcr_write_decoding_to_file(GtRcrDecoder *rcr_dec, GtError *err)
     }
     if (!had_err) {
       /* exact match? */
-      unsigned long seq_i = seqstart + readpos;
+      GtUword seq_i = seqstart + readpos;
       if (RCR_NEXT_BIT(bit)) {
         if (bit)
           rcr_decode_exact(rcr_dec, info, readlength, seqstart, readpos);
@@ -2043,14 +2038,14 @@ static int rcr_write_decoding_to_file(GtRcrDecoder *rcr_dec, GtError *err)
 
         /* write read to file */
         if (readlength != gt_str_length(info->base_string)) {
-          gt_log_log("readlen: %lu, stringlen: %lu, read: %lu",
+          gt_log_log("readlen: "GT_WU", stringlen: "GT_WU", read: "GT_WU"",
                      readlength, gt_str_length(info->base_string), cur_read);
         }
         gt_assert(readlength == gt_str_length(info->base_string));
         gt_assert(readlength == gt_str_length(info->qual_string));
         fprintf(rcr_dec->fp, "%s", gt_str_get(qname));
         fprintf(rcr_dec->fp, "\t%c", strand?'-':'+');
-        fprintf(rcr_dec->fp, "\t%lu", readpos + 1);
+        fprintf(rcr_dec->fp, "\t"GT_WU"", readpos + 1);
         if (rcr_dec->store_mapping_qual)
           fprintf(rcr_dec->fp, "\t%u", (unsigned) mapping_qual);
         else
@@ -2073,7 +2068,7 @@ static int rcr_write_decoding_to_file(GtRcrDecoder *rcr_dec, GtError *err)
   gt_golomb_bitwise_decoder_delete(readpos_gbwd);
   gt_bitinstream_delete(bitstream);
   rcr_delete_decode_info(info);
-  gt_log_log("decoded %lu reads", cur_read);
+  gt_log_log("decoded "GT_WU" reads", cur_read);
   return had_err;
 }
 
@@ -2097,7 +2092,7 @@ static GtRcrDecoder *gt_rcr_decoder_init(const char *name,
   rcr_dec->readpos_golomb = NULL;
   rcr_dec->varpos_golomb = NULL;
 
-  rcr_dec->ins_bases = gt_calloc(alpha_size + 1, sizeof (unsigned long long));
+  rcr_dec->ins_bases = gt_calloc(alpha_size + 1, sizeof (GtUint64));
 
   rcr_dec->fp = gt_fa_fopen(gt_str_get(rcr_dec->inputname),
                             "rb", err);
@@ -2112,8 +2107,8 @@ GtRcrDecoder *gt_rcr_decoder_new(const char *name, const GtEncseq *ref,
                                  GtTimer *timer, GtError *err)
 {
   bool is_not_at_pageborder;
-  long pagesize = sysconf((int) _SC_PAGESIZE),
-       filepos;
+  GtUword pagesize = gt_pagesize();
+  GtWord filepos;
   GtRcrDecoder *rcr_dec;
 
   gt_assert(name);
@@ -2129,6 +2124,7 @@ GtRcrDecoder *gt_rcr_decoder_new(const char *name, const GtEncseq *ref,
 
   rcr_read_header(rcr_dec);
 
+  gt_assert(rcr_dec != NULL && rcr_dec->fp != NULL);
   filepos = ftell(rcr_dec->fp);
   is_not_at_pageborder = (filepos % pagesize) != 0;
   if (is_not_at_pageborder)
