@@ -1,6 +1,6 @@
 /*
-  Copyright (c) 2007-2012 Gordon Gremme <gremme@zbh.uni-hamburg.de>
-  Copyright (c) 2012-2013 Sascha Steinbiss <steinbiss@zbh.uni-hamburg.de>
+  Copyright (c) 2007-2012 Gordon Gremme <gordon@gremme.org>
+  Copyright (c) 2012-2014 Sascha Steinbiss <sascha@steinbiss.name>
   Copyright (c) 2007-2013 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -38,14 +38,16 @@ struct GtRegionMapping {
         *sequence_name;  /* the (current) sequence name */
   bool matchdesc,
        usedesc,
-       userawseq;
+       matchdescstart,
+       userawseq,
+       useseqno;
   GtMapping *mapping;
   GtBioseq *bioseq; /* the current bioseq */
   GtEncseq *encseq;
   GtSeqCol *seq_col;
   GtSeqid2SeqnumMapping *seqid2seqnum_mapping;
   const char *rawseq;
-  unsigned long rawlength,
+  GtUword rawlength,
                 rawoffset;
   unsigned int reference_count;
 };
@@ -75,6 +77,7 @@ GtRegionMapping* gt_region_mapping_new_seqfiles(GtStrArray *sequence_filenames,
   rm = gt_calloc(1, sizeof (GtRegionMapping));
   rm->sequence_filenames = gt_str_array_ref(sequence_filenames);
   rm->matchdesc = matchdesc;
+  rm->matchdescstart = false;
   rm->usedesc = usedesc;
   return rm;
 }
@@ -89,12 +92,21 @@ GtRegionMapping* gt_region_mapping_new_encseq(GtEncseq *encseq, bool matchdesc,
   rm->encseq = gt_encseq_ref(encseq);
   rm->matchdesc = matchdesc;
   rm->usedesc = usedesc;
+  rm->matchdescstart = false;
+  return rm;
+}
+
+GtRegionMapping* gt_region_mapping_new_encseq_seqno(GtEncseq *encseq)
+{
+  GtRegionMapping *rm;
+  rm = gt_region_mapping_new_encseq(encseq, false, false);
+  rm->useseqno = true;
   return rm;
 }
 
 GtRegionMapping* gt_region_mapping_new_rawseq(const char *rawseq,
-                                              unsigned long length,
-                                              unsigned long offset)
+                                              GtUword length,
+                                              GtUword offset)
 {
   GtRegionMapping *rm;
   gt_assert(rawseq);
@@ -103,9 +115,16 @@ GtRegionMapping* gt_region_mapping_new_rawseq(const char *rawseq,
   rm->rawseq = rawseq;
   rm->rawlength = length;
   rm->rawoffset = offset;
+  rm->matchdescstart = false;
   return rm;
 }
 
+void gt_region_mapping_enable_match_desc_start(GtRegionMapping *rm)
+{
+  gt_assert(rm);
+  rm->matchdescstart = true;
+}
+
 GtRegionMapping* gt_region_mapping_ref(GtRegionMapping *rm)
 {
   gt_assert(rm);
@@ -183,17 +202,19 @@ static int update_seq_col_if_necessary(GtRegionMapping *rm, GtStr *seqid,
         had_err = -1;
       }
     }
+    if (rm->seq_col && rm->matchdescstart)
+      gt_seq_col_enable_match_desc_start(rm->seq_col);
   }
   return had_err;
 }
 
 int gt_region_mapping_get_sequence(GtRegionMapping *rm, char **seq,
-                                   GtStr *seqid, unsigned long start,
-                                   unsigned long end, GtError *err)
+                                   GtStr *seqid, GtUword start,
+                                   GtUword end, GtError *err)
 {
   int had_err = 0;
-  unsigned long offset = 1;
-  GtRange range = {GT_UNDEF_ULONG, GT_UNDEF_ULONG};
+  GtUword offset = 1;
+  GtRange range = {GT_UNDEF_UWORD, GT_UNDEF_UWORD};
   gt_error_check(err);
   gt_assert(rm && seq && seqid && gt_str_length(seqid) > 0);
 
@@ -212,7 +233,7 @@ int gt_region_mapping_get_sequence(GtRegionMapping *rm, char **seq,
   if (!had_err) {
     if (gt_md5_seqid_has_prefix(gt_str_get(seqid))) {
       had_err = gt_seq_col_md5_to_seq(rm->seq_col, seq, start - offset,
-                                        end - offset, seqid, err);
+                                      end - offset, seqid, err);
       return had_err;
     }
   }
@@ -222,7 +243,7 @@ int gt_region_mapping_get_sequence(GtRegionMapping *rm, char **seq,
     gt_assert(!rm->usedesc || rm->seqid2seqnum_mapping);
     gt_assert(rm->mapping || rm->seq_col);
     if (rm->usedesc) {
-      unsigned long seqnum, filenum;
+      GtUword seqnum, filenum;
       gt_assert(rm->seqid2seqnum_mapping);
       range.start = start;
       range.end = end;
@@ -231,14 +252,15 @@ int gt_region_mapping_get_sequence(GtRegionMapping *rm, char **seq,
                                             &filenum, &offset, err);
 
       if (!had_err) {
-        if (range.end != GT_UNDEF_ULONG && range.start != GT_UNDEF_ULONG &&
+        if (range.end != GT_UNDEF_UWORD && range.start != GT_UNDEF_UWORD &&
               range.end >= gt_seq_col_get_sequence_length(rm->seq_col, filenum,
                                                           seqnum)
               + offset) {
-          gt_error_set(err, "trying to extract range %lu-%lu on sequence "
-                       "``%s''which is not covered by that sequence (with "
-                       "boundaries %lu-%lu). Has the sequence-region "
-                       "to sequence mapping been defined correctly?",
+          gt_error_set(err, "trying to extract range " GT_WU "-" GT_WU " on "
+                       "sequence ``%s'' which is not covered by that sequence "
+                       "(with boundaries " GT_WU "-" GT_WU "). Has the "
+                       "sequence-region to sequence mapping been defined "
+                       "correctly?",
                        start, end, gt_str_get(seqid),
                        range.start, range.end);
           had_err = -1;
@@ -255,22 +277,56 @@ int gt_region_mapping_get_sequence(GtRegionMapping *rm, char **seq,
         had_err = gt_seq_col_grep_desc(rm->seq_col, seq, start - 1, end - 1,
                                        seqid, err);
       }
+    } else if (rm->useseqno) {
+      GtUword seqno = GT_UNDEF_UWORD;
+      gt_assert(rm->encseq);
+      if (1 != sscanf(gt_str_get(seqid), "seq"GT_WU"", &seqno)) {
+        gt_error_set(err, "seqid '%s' does not have the form 'seqX' "
+                          "where X is a sequence number in the encoded "
+                          "sequence", gt_str_get(seqid));
+        had_err = -1;
+      }
+      gt_assert(had_err || seqno != GT_UNDEF_UWORD);
+      if (!had_err && seqno >= gt_encseq_num_of_sequences(rm->encseq)) {
+          gt_error_set(err, "trying to access sequence "GT_WU", but encoded "
+                            "sequence contains only "GT_WU" sequences",
+                            seqno, gt_encseq_num_of_sequences(rm->encseq));
+          had_err = -1;
+      }
+      if (!had_err) {
+        GtUword seqlength = gt_encseq_seqlength(rm->encseq, seqno);
+        if (start > seqlength || end > seqlength) {
+          gt_error_set(err, "trying to extract range " GT_WU "-" GT_WU " on "
+                       "sequence ``%s'' which is not covered by that sequence "
+                       "(only " GT_WU " characters in size). Has the "
+                       "sequence-region to sequence mapping been defined "
+                       "correctly?",
+                       start, end, gt_str_get(seqid), seqlength);
+          had_err = -1;
+        }
+      }
+      if (!had_err) {
+        GtUword seqstartpos;
+        *seq = gt_calloc(end - start + 1, sizeof (char));
+        seqstartpos = gt_encseq_seqstartpos(rm->encseq, seqno);
+        gt_encseq_extract_decoded(rm->encseq, *seq, seqstartpos + start - 1,
+                                  seqstartpos + end - 1);
+      }
     } else if (rm->userawseq) {
       gt_assert(!rm->seqid2seqnum_mapping);
       *seq = gt_calloc(end - start + 1, sizeof (char));
       strncpy(*seq, rm->rawseq + start - 1, (end - start + 1) * sizeof (char));
-    } else {
-      gt_assert(rm->seq_col);
-
+    } else if (rm->mapping) {
       if (!had_err) {
-        unsigned long seqlength = gt_seq_col_get_sequence_length(rm->seq_col,
+        GtUword seqlength = gt_seq_col_get_sequence_length(rm->seq_col,
                                                                  0, 0);
         if (start > seqlength || end > seqlength) {
           had_err = -1;
-          gt_error_set(err, "trying to extract range %lu-%lu on sequence "
-                       "``%s''which is not covered by that sequence (only "
-                       "%lu characters in size). Has the sequence-region "
-                       "to sequence mapping been defined correctly?",
+          gt_error_set(err, "trying to extract range " GT_WU "-" GT_WU " on "
+                       "sequence ``%s'' which is not covered by that sequence "
+                       "(only " GT_WU " characters in size). Has the "
+                       "sequence-region to sequence mapping been defined "
+                       "correctly?",
                        start, end, gt_str_get(seqid), seqlength);
         }
         if (!had_err) {
@@ -278,17 +334,23 @@ int gt_region_mapping_get_sequence(GtRegionMapping *rm, char **seq,
                                          end - offset);
         }
       }
+    } else {
+      gt_assert(!rm->usedesc && !rm->matchdesc);
+      gt_error_set(err, "no mapping rule given and no MD5 tags "
+                        "present in the query seqid \"%s\" -- no mapping can "
+                        "be defined", gt_str_get(seqid));
+      had_err = -1;
     }
   }
   return had_err;
 }
 
 int gt_region_mapping_get_sequence_length(GtRegionMapping *rm,
-                                          unsigned long *length, GtStr *seqid,
+                                          GtUword *length, GtStr *seqid,
                                           GtError *err)
 {
+  GtUword filenum, seqnum;
   int had_err;
-  unsigned long filenum, seqnum, GT_UNUSED offset;
   gt_error_check(err);
   GT_UNUSED GtRange range;
   gt_assert(rm && seqid);
@@ -301,15 +363,11 @@ int gt_region_mapping_get_sequence_length(GtRegionMapping *rm,
       had_err = gt_seq_col_md5_to_sequence_length(rm->seq_col, length, seqid,
                                                   err);
     }
-    return had_err;
-  }
-  if (!had_err) {
-    if (rm->usedesc) {
+    else if (rm->usedesc) {
       gt_assert(rm->seqid2seqnum_mapping);
       had_err = gt_seqid2seqnum_mapping_map(rm->seqid2seqnum_mapping,
                                             gt_str_get(seqid), &range, &seqnum,
-                                            &filenum,
-                                            &offset, err);
+                                            &filenum, NULL, err);
       if (!had_err)
         *length = gt_seq_col_get_sequence_length(rm->seq_col, filenum, seqnum);
     }
@@ -317,9 +375,33 @@ int gt_region_mapping_get_sequence_length(GtRegionMapping *rm,
       had_err = gt_seq_col_grep_desc_sequence_length(rm->seq_col, length,
                                                      seqid, err);
     }
-    else {
-      if (!had_err)
-        *length = gt_seq_col_get_sequence_length(rm->seq_col, 0, 0);
+    else if (rm->useseqno) {
+      GtUword seqno = GT_UNDEF_UWORD;
+      gt_assert(rm->encseq);
+      if (1 != sscanf(gt_str_get(seqid), "seq"GT_WU"", &seqno)) {
+        gt_error_set(err, "seqid '%s' does not have the form 'seqX' "
+                          "where X is a sequence number in the encoded "
+                          "sequence", gt_str_get(seqid));
+        had_err = -1;
+      }
+      gt_assert(had_err || seqno != GT_UNDEF_UWORD);
+      if (!had_err && seqno >= gt_encseq_num_of_sequences(rm->encseq)) {
+          gt_error_set(err, "trying to access sequence "GT_WU", but encoded "
+                            "sequence contains only "GT_WU" sequences",
+                            seqno, gt_encseq_num_of_sequences(rm->encseq));
+          had_err = -1;
+      }
+      if (!had_err) {
+        *length = gt_encseq_seqlength(rm->encseq, seqno);
+      }
+    } else if (rm->mapping) {
+      *length = gt_seq_col_get_sequence_length(rm->seq_col, 0, 0);
+    } else {
+      gt_assert(!rm->usedesc && !rm->matchdesc);
+      gt_error_set(err, "no mapping rule given and no MD5 tags "
+                        "present in the query seqid \"%s\" -- no mapping can "
+                        "be defined", gt_str_get(seqid));
+      had_err = -1;
     }
   }
   return had_err;
@@ -345,12 +427,11 @@ int gt_region_mapping_get_description(GtRegionMapping *rm, GtStr *desc,
   }
   if (!had_err) {
     if (rm->usedesc) {
-      unsigned long filenum, seqnum;
+      GtUword filenum, seqnum;
       gt_assert(rm->seqid2seqnum_mapping);
       had_err = gt_seqid2seqnum_mapping_map(rm->seqid2seqnum_mapping,
                                             gt_str_get(seqid), NULL, &seqnum,
-                                            &filenum,
-                                            NULL, err);
+                                            &filenum, NULL, err);
       if (!had_err) {
         char *cdesc;
         cdesc = gt_seq_col_get_description(rm->seq_col, filenum, seqnum);
@@ -358,6 +439,29 @@ int gt_region_mapping_get_description(GtRegionMapping *rm, GtStr *desc,
         gt_str_append_cstr(desc, cdesc);
         gt_free(cdesc);
       }
+    }
+    else if (rm->useseqno) {
+      GtUword seqno = GT_UNDEF_UWORD;
+      gt_assert(rm->encseq);
+      if (1 != sscanf(gt_str_get(seqid), "seq"GT_WU"", &seqno)) {
+        gt_error_set(err, "seqid '%s' does not have the form 'seqX' "
+                          "where X is a sequence number in the encoded "
+                          "sequence", gt_str_get(seqid));
+        had_err = -1;
+      }
+      gt_assert(had_err || seqno != GT_UNDEF_UWORD);
+      if (!had_err && seqno >= gt_encseq_num_of_sequences(rm->encseq)) {
+          gt_error_set(err, "trying to access sequence "GT_WU", but encoded"
+                            "sequence contains only "GT_WU" sequences",
+                            seqno, gt_encseq_num_of_sequences(rm->encseq));
+          had_err = -1;
+      }
+      if (!had_err) {
+        GtUword desclen;
+        const char *edesc;
+        edesc = gt_encseq_description(rm->encseq, &desclen, seqno);
+        gt_str_append_cstr_nt(desc, edesc, desclen);
+      }
     } else if (rm->matchdesc) {
       const char *md5;
       /* XXX: not beautiful, but works -- this may be LOTS faster */
@@ -368,13 +472,19 @@ int gt_region_mapping_get_description(GtRegionMapping *rm, GtStr *desc,
                                                 err);
         gt_str_delete(md5_seqid);
       }
+    } else if (rm->mapping) {
+      char *cdesc;
+      cdesc = gt_seq_col_get_description(rm->seq_col, 0, 0);
+      gt_assert(cdesc);
+      gt_str_append_cstr(desc, cdesc);
+      gt_free(cdesc);
     } else {
+      gt_assert(!rm->usedesc && !rm->matchdesc);
       if (!had_err) {
-        char *cdesc;
-        cdesc = gt_seq_col_get_description(rm->seq_col, 0, 0);
-        gt_assert(cdesc);
-        gt_str_append_cstr(desc, cdesc);
-        gt_free(cdesc);
+        gt_error_set(err, "no mapping rule given and no MD5 tags "
+                          "present in the query seqid \"%s\" -- no mapping can "
+                          "be defined", gt_str_get(seqid));
+        had_err = -1;
       }
     }
   }
@@ -384,12 +494,12 @@ int gt_region_mapping_get_description(GtRegionMapping *rm, GtStr *desc,
 const char* gt_region_mapping_get_md5_fingerprint(GtRegionMapping *rm,
                                                   GtStr *seqid,
                                                   const GtRange *range,
-                                                  unsigned long *offset,
+                                                  GtUword *offset,
                                                   GtError *err)
 {
   const char *md5 = NULL;
   int had_err;
-  unsigned long filenum, seqnum;
+  GtUword filenum, seqnum;
   gt_error_check(err);
   gt_assert(rm && seqid);
   gt_assert(!rm->userawseq); /* not implemented */
@@ -400,8 +510,7 @@ const char* gt_region_mapping_get_md5_fingerprint(GtRegionMapping *rm,
       gt_assert(rm->seqid2seqnum_mapping);
       had_err = gt_seqid2seqnum_mapping_map(rm->seqid2seqnum_mapping,
                                             gt_str_get(seqid), range, &seqnum,
-                                            &filenum,
-                                            offset, err);
+                                            &filenum, offset, err);
       if (!had_err)
         md5 = gt_seq_col_get_md5_fingerprint(rm->seq_col, filenum, seqnum);
     }
@@ -416,13 +525,48 @@ const char* gt_region_mapping_get_md5_fingerprint(GtRegionMapping *rm,
         }
       }
       if (!had_err)
-        had_err = gt_seq_col_grep_desc_md5(rm->seq_col, &md5, seqid, err);
+        (void) gt_seq_col_grep_desc_md5(rm->seq_col, &md5, seqid, err);
       *offset = 1;
     }
-    else {
+    else if (rm->useseqno) {
+      GtMD5Tab *tab = NULL;
+      GtUword seqno = GT_UNDEF_UWORD;
+      gt_assert(rm->encseq);
+      if (1 != sscanf(gt_str_get(seqid), "seq"GT_WU"", &seqno)) {
+        gt_error_set(err, "seqid '%s' does not have the form 'seqX' "
+                          "where X is a sequence number in the encoded "
+                          "sequence", gt_str_get(seqid));
+        had_err = -1;
+      }
+      gt_assert(had_err || seqno != GT_UNDEF_UWORD);
+      if (!had_err && seqno >= gt_encseq_num_of_sequences(rm->encseq)) {
+          gt_error_set(err, "trying to access sequence "GT_WU", but encoded"
+                            "sequence contains only "GT_WU" sequences",
+                            seqno, gt_encseq_num_of_sequences(rm->encseq));
+          had_err = -1;
+      }
+      if (!had_err) {
+        tab = gt_encseq_get_md5_tab(rm->encseq, err);
+        if (!tab)
+          had_err = -1;
+      }
+      *offset = 1;
+      if (!had_err)
+        return gt_md5_tab_get(tab, seqno);
+      else
+        return NULL;
+    } else if (rm->mapping) {
       if (!had_err)
         md5 = gt_seq_col_get_md5_fingerprint(rm->seq_col, 0, 0);
       *offset = 1;
+    } else {
+      if (!had_err) {
+        gt_assert(!rm->usedesc && !rm->matchdesc);
+        gt_error_set(err, "no mapping rule given and no MD5 tags "
+                          "present in the query seqid \"%s\" -- no mapping can "
+                          "be defined", gt_str_get(seqid));
+        had_err = -1;
+      }
     }
   }
   return md5;
