@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2010      Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2010      Gordon Gremme <gordon@gremme.org>
   Copyright (c)      2013 Sascha Steinbiss <steinbiss@zbh.uni-hamburg.de>
   Copyright (c)      2013 Center for Bioinformatics, University of Hamburg
 
@@ -28,11 +28,11 @@
 typedef GtArray SeqidInfo;
 
 typedef struct {
-  unsigned long seqnum, filenum;
+  GtUword seqnum, filenum;
   GtRange descrange;
 } SeqidInfoElem;
 
-static SeqidInfo* seqid_info_new(unsigned long seqnum, unsigned long filenum,
+static SeqidInfo* seqid_info_new(GtUword seqnum, GtUword filenum,
                                  const GtRange *descrange)
 {
   SeqidInfoElem seqid_info_elem;
@@ -52,19 +52,20 @@ static void seqid_info_delete(SeqidInfo *seqid_info)
   gt_array_delete(seqid_info);
 }
 
-static int seqid_info_add(SeqidInfo *seqid_info, unsigned long seqnum,
-                          unsigned long filenum, const GtRange *range,
-                          const char *filename, const char *seqid, GtError *err)
+static int seqid_info_add(SeqidInfo *seqid_info, GtUword seqnum,
+                          GtUword filenum, const GtRange *range,
+                          GT_UNUSED const char *filename,
+                          const char *seqid, GtError *err)
 {
   SeqidInfoElem *seqid_info_elem_ptr, seqid_info_elem;
   gt_error_check(err);
   gt_assert(range);
   seqid_info_elem_ptr = gt_array_get_first(seqid_info);
-  if (range->end == GT_UNDEF_ULONG ||
-      seqid_info_elem_ptr->descrange.end == GT_UNDEF_ULONG) {
-    gt_error_set(err, "sequence file \"%s\" does contain multiple sequences "
-                  "with ID \"%s\" and not all of them have description ranges",
-                  filename, seqid);
+  if (range->end == GT_UNDEF_UWORD ||
+      seqid_info_elem_ptr->descrange.end == GT_UNDEF_UWORD) {
+    gt_error_set(err, "input sequence(s) contain multiple sequences "
+                 "with ID \"%s\" and not all of them have description ranges",
+                 seqid);
     return -1;
   }
   seqid_info_elem.seqnum = seqnum;
@@ -74,18 +75,19 @@ static int seqid_info_add(SeqidInfo *seqid_info, unsigned long seqnum,
   return 0;
 }
 
-static int seqid_info_get(SeqidInfo *seqid_info, unsigned long *seqnum,
-                          unsigned long *filenum, GtRange *outrange,
-                          const GtRange *inrange, const char *filename,
+static int seqid_info_get(SeqidInfo *seqid_info, GtUword *seqnum,
+                          GtUword *filenum, GtRange *outrange,
+                          const GtRange *inrange,
+                          GT_UNUSED const char *filename,
                           const char *seqid, GtError *err)
 {
   SeqidInfoElem *seqid_info_elem;
-  unsigned long i;
+  GtUword i;
   gt_error_check(err);
   gt_assert(seqid_info && seqnum && outrange && inrange);
   for (i = 0; i < gt_array_size(seqid_info); i++) {
     seqid_info_elem = gt_array_get(seqid_info, i);
-    if (seqid_info_elem->descrange.end == GT_UNDEF_ULONG ||
+    if (seqid_info_elem->descrange.end == GT_UNDEF_UWORD ||
         gt_range_contains(&seqid_info_elem->descrange, inrange)) {
       *seqnum = seqid_info_elem->seqnum;
       *filenum = seqid_info_elem->filenum;
@@ -93,9 +95,10 @@ static int seqid_info_get(SeqidInfo *seqid_info, unsigned long *seqnum,
       return 0;
     }
   }
-  gt_error_set(err, "cannot find sequence ID \"%s\" (with range %lu,%lu) in "
-               "sequence file \"%s\"", seqid, inrange->start, inrange->end,
-               filename);
+  gt_error_set(err,
+               "cannot find a sequence with ID \"%s\" "
+               "{range " GT_WU "," GT_WU ")",
+               seqid, inrange->start, inrange->end);
   return -1;
 }
 
@@ -103,23 +106,23 @@ struct GtSeqid2SeqnumMapping {
   char *filename;
   GtHashmap *map;
   const char *cached_seqid;
-  unsigned long cached_seqnum,
+  GtUword cached_seqnum,
                 cached_filenum;
   GtRange cached_range;
 };
 
 static int handle_description(GtSeqid2SeqnumMapping *mapping, const char *desc,
-                              unsigned long seqnum, unsigned long filenum,
+                              GtUword seqnum, GtUword filenum,
                               GtError *err)
 {
   GtRange descrange;
-  unsigned long j;
+  GtUword j;
   int had_err = 0;
   SeqidInfo *seqid_info;
   if (gt_parse_description_range(desc, &descrange)) {
     /* no offset could be parsed -> store description as sequence id */
     descrange.start = 1;
-    descrange.end = GT_UNDEF_ULONG;
+    descrange.end = GT_UNDEF_UWORD;
     if ((seqid_info = gt_hashmap_get(mapping->map, desc))) {
       had_err = seqid_info_add(seqid_info, seqnum, filenum,
                                &descrange, mapping->filename, desc, err);
@@ -154,7 +157,7 @@ static int handle_description(GtSeqid2SeqnumMapping *mapping, const char *desc,
 static int fill_mapping(GtSeqid2SeqnumMapping *mapping, GtBioseq *bioseq,
                         GtSeqCol *seqcol, GT_UNUSED GtError *err)
 {
-  unsigned long i, j, nof_sequences, nof_files;
+  GtUword i, j, nof_sequences, nof_files;
   int had_err = 0;
   gt_error_check(err);
   gt_assert(mapping && (bioseq || seqcol) && !(bioseq && seqcol));
@@ -230,26 +233,27 @@ void gt_seqid2seqnum_mapping_delete(GtSeqid2SeqnumMapping *mapping)
 
 int gt_seqid2seqnum_mapping_map(GtSeqid2SeqnumMapping *mapping,
                                 const char *seqid, const GtRange *inrange,
-                                unsigned long *seqnum, unsigned long *filenum,
-                                unsigned long *offset, GtError *err)
+                                GtUword *seqnum, GtUword *filenum,
+                                GtUword *offset, GtError *err)
 {
   SeqidInfo *seqid_info;
   GtRange outrange;
   gt_error_check(err);
-  gt_assert(mapping && seqid && seqnum && offset);
+  gt_assert(mapping && seqid && seqnum);
   /* try to answer request from cache */
   if (mapping->cached_seqid && !strcmp(seqid, mapping->cached_seqid) &&
-      (mapping->cached_range.end == GT_UNDEF_ULONG ||
+      (mapping->cached_range.end == GT_UNDEF_UWORD ||
        gt_range_contains(&mapping->cached_range, inrange))) {
     *seqnum = mapping->cached_seqnum;
     *filenum = mapping->cached_filenum;
-    *offset = mapping->cached_range.start;
+    if (offset)
+      *offset = mapping->cached_range.start;
     return 0;
   }
   /* cache miss -> regular mapping */
   if (!(seqid_info = gt_hashmap_get(mapping->map, seqid))) {
-    gt_error_set(err, "sequence file \"%s\" does not contain a sequence with "
-                      "ID \"%s\"", mapping->filename, seqid);
+    gt_error_set(err, "no sequence with ID \"%s\" found in input sequence(s)",
+                 seqid);
     return -1;
   }
   /* get results from seqid info */
@@ -258,7 +262,8 @@ int gt_seqid2seqnum_mapping_map(GtSeqid2SeqnumMapping *mapping,
     return -1;
   }
   /* report offset */
-  *offset = outrange.start;
+  if (offset)
+    *offset = outrange.start;
   /* store result in cache */
   mapping->cached_seqid = gt_hashmap_get_key(mapping->map, seqid);
   gt_assert(mapping->cached_seqid);
