@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2003-2011 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2003-2013 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2003-2005 Michael E Sparks <mespar1@iastate.edu>
   Copyright (c) 2003-2008 Center for Bioinformatics, University of Hamburg
 
@@ -18,6 +18,7 @@
 
 #include "lauxlib.h"
 #include "core/bioseq.h"
+#include "core/compat.h"
 #include "core/fa.h"
 #include "core/fileutils_api.h"
 #include "core/ma_api.h"
@@ -69,7 +70,7 @@ static char *filenames[] =
 static void write_model(GtStr *str, const char *model_cstr,
                         const GthBSSMModel *model)
 {
-  unsigned long i, j, k, l;
+  GtUword i, j, k, l;
   gt_assert(str && model_cstr && model);
   gt_assert(model->hypothesis_num == 2 || model->hypothesis_num == 7);
   gt_str_append_cstr(str, "  ");
@@ -139,7 +140,7 @@ static int read_bssm_model(GthBSSMModel *bssm_model, lua_State *L, GtError *err)
 #ifndef NDEBUG
   int stack_size;
 #endif
-  unsigned long i, j, k, l;
+  GtUword i, j, k, l;
   int had_err = 0;
   gt_error_check(err);
   gt_assert(bssm_model && L);
@@ -354,15 +355,15 @@ static int bssm_model_read(GthBSSMModel *bssm_model, FILE *file, GtError *err)
 {
   int had_err = 0;
   gt_error_check(err);
-  gt_xfread(&bssm_model->hypothesis_num, sizeof (unsigned long), 1, file);
+  gt_xfread(&bssm_model->hypothesis_num, sizeof (GtUword), 1, file);
   if (bssm_model->hypothesis_num != HYPOTHESIS7 &&
       bssm_model->hypothesis_num != HYPOTHESIS2) {
     gt_error_set(err, "BSSM model contains unknown hypothesis number");
     had_err = -1;
   }
   if (!had_err) {
-    gt_xfread(&bssm_model->window_size_left, sizeof (unsigned long), 1, file);
-    gt_xfread(&bssm_model->window_size_right, sizeof (unsigned long), 1, file);
+    gt_xfread(&bssm_model->window_size_left, sizeof (GtUword), 1, file);
+    gt_xfread(&bssm_model->window_size_right, sizeof (GtUword), 1, file);
     switch (bssm_model->hypothesis_num) {
       case HYPOTHESIS2:
         gt_xfread(&bssm_model->hypotables.hypo2table, sizeof (Hypo2table), 1,
@@ -450,24 +451,42 @@ GthBSSMParam* gth_bssm_param_load(const char *filename, GtError *err)
   if (gt_file_exists(filename))
     gt_str_append_cstr(path, filename);
   else {
-    if (strchr(filename, '/')) {
-      gt_error_set(err, "filename \"%s\" contains illegal symbol '/': the path "
-                        "list specified by environment variable \"%s\" cannot "
-                        "be searched for it", filename, BSSMENVNAME);
+    if (strchr(filename, GT_PATH_SEPARATOR)) {
+      gt_error_set(err, "filename \"%s\" contains illegal symbol '%c': the "
+                        "path list specified by environment variable \"%s\" "
+                        "cannot be searched for it", filename,
+                        GT_PATH_SEPARATOR, BSSMENVNAME);
       had_err = -1;
     }
+    /* check for file path in environment variable */
     if (!had_err)
       had_err = gt_file_find_in_env(path, filename, BSSMENVNAME, err);
     if (!had_err && !gt_str_length(path)) {
-      gt_error_set(err, "file \"%s\" not found in directory list specified by "
-                        "environment variable %s", filename, BSSMENVNAME);
+      gt_error_set(err, "file \"%s\" not found in directory list specified "
+                        "by environment variable %s", filename, BSSMENVNAME);
       had_err = -1;
     }
     if (!had_err) {
       /* path found -> append filename */
-      gt_str_append_char(path, '/');
+      gt_str_append_char(path, GT_PATH_SEPARATOR);
       gt_str_append_cstr(path, filename);
     }
+    else {
+      /* check for file path relative to binary */
+      int new_err = gt_file_find_exec_in_path(path, gt_error_get_progname(err),
+                                              NULL);
+      if (!new_err) {
+        gt_assert(gt_str_length(path));
+        gt_str_append_char(path, GT_PATH_SEPARATOR);
+        gt_str_append_cstr(path, "bssm");
+        gt_str_append_char(path, GT_PATH_SEPARATOR);
+        gt_str_append_cstr(path, filename);
+        if (gt_file_exists(gt_str_get(path))) {
+          gt_error_unset(err);
+          had_err = 0;
+        }
+      }
+    }
   }
 
   if (!had_err) {
@@ -492,10 +511,10 @@ GthBSSMParam* gth_bssm_param_load(const char *filename, GtError *err)
   return bssm_param;
 }
 
-GthBSSMParam* gth_bssm_param_extract(unsigned long speciesnum, GtError *err)
+GthBSSMParam* gth_bssm_param_extract(GtUword speciesnum, GtError *err)
 {
   GthBSSMParam *bssm_param;
-  unsigned long i, j, k, l;
+  GtUword i, j, k, l;
 
   gt_error_check(err);
 
@@ -540,7 +559,7 @@ GthBSSMParam* gth_bssm_param_extract(unsigned long speciesnum, GtError *err)
     }
   }
   else {
-    gt_error_set(err, "illegal speciesnum (speciesnum == %lu)", speciesnum);
+    gt_error_set(err, "illegal speciesnum (speciesnum == "GT_WU")", speciesnum);
     gth_bssm_param_delete(bssm_param);
     return NULL;
   }
@@ -608,49 +627,56 @@ bool gth_bssm_param_is_seven_class(const GthBSSMParam  *bssm_param)
    It is assumed that the Hypo7table is used. */
 static void bssm_model_echo(const GthBSSMModel *bssm_model, FILE *outfp)
 {
-  unsigned long i, j, k, l;
+  GtUword i, j, k, l;
 
   gt_assert(bssm_model_is_seven_class(bssm_model));
 
   for (i = 0; i < HYPOTHESIS7; i++) {
-    fprintf(outfp,"\n\nHypothesis: %lu", i);
+    fprintf(outfp, "\n\nHypothesis: "GT_WU"", i);
     for (j = 0; j < STRINGSIZE; j++) {
-      fprintf(outfp,"\n");
+      fprintf(outfp, "\n");
       for (k = 0; k < ALPHSIZE; k++) {
-        fprintf(outfp,"\n");
+        fprintf(outfp, "\n");
         for (l = 0; l < ALPHSIZE; l++) {
-          fprintf(outfp,"%.4f ", bssm_model->hypotables.hypo7table[i][j][k][l]);
+          fprintf(outfp, "%.4f ",
+                  bssm_model->hypotables.hypo7table[i][j][k][l]);
         }
       }
     }
   }
-  fprintf(outfp,"\n\n");
+  fprintf(outfp, "\n\n");
 }
 
 void gth_bssm_param_echo(const GthBSSMParam *bssm_param, FILE *outfp)
 {
   gt_assert(bssm_param && outfp);
-  fprintf(outfp,"BSSMPARAMVERSION is %u\n\n", bssm_param->version_num);
-  fprintf(outfp,"Is the GT donor model set? -> %s\n",
+  fprintf(outfp, "BSSMPARAMVERSION is %u\n\n", bssm_param->version_num);
+  fprintf(outfp, "Is the GT donor model set? -> %s\n",
           GTH_SHOWBOOL(bssm_param->gt_donor_model_set));
-  fprintf(outfp,"Is the GC donor model set? -> %s\n\n",
+  fprintf(outfp, "Is the GC donor model set? -> %s\n\n",
           GTH_SHOWBOOL(bssm_param->gc_donor_model_set));
-  fprintf(outfp,"Is the AG acceptor model set? -> %s\n\n",
+  fprintf(outfp, "Is the AG acceptor model set? -> %s\n\n",
           GTH_SHOWBOOL(bssm_param->ag_acceptor_model_set));
 
-  if (bssm_param->gt_donor_model_set) {
-    fprintf(outfp,"reporting GT donor model parameterization");
-    bssm_model_echo(&bssm_param->gt_donor_model, outfp);
-  }
+  if (gth_bssm_param_is_seven_class(bssm_param)) {
+    if (bssm_param->gt_donor_model_set) {
+      fprintf(outfp, "reporting GT donor model parameterization");
+      bssm_model_echo(&bssm_param->gt_donor_model, outfp);
+    }
 
-  if (bssm_param->gc_donor_model_set) {
-    fprintf(outfp,"reporting GC donor model parameterization");
-    bssm_model_echo(&bssm_param->gc_donor_model, outfp);
-  }
+    if (bssm_param->gc_donor_model_set) {
+      fprintf(outfp, "reporting GC donor model parameterization");
+      bssm_model_echo(&bssm_param->gc_donor_model, outfp);
+    }
 
-  if (bssm_param->ag_acceptor_model_set) {
-    fprintf(outfp,"reporting AG acceptor model parameterization");
-    bssm_model_echo(&bssm_param->ag_acceptor_model, outfp);
+    if (bssm_param->ag_acceptor_model_set) {
+      fprintf(outfp, "reporting AG acceptor model parameterization");
+      bssm_model_echo(&bssm_param->ag_acceptor_model, outfp);
+    }
+  }
+  else {
+    fprintf(outfp,
+            "Cannot report model parameterization for two-class BSSMs.\n");
   }
 }
 
@@ -698,11 +724,11 @@ static void set_window_sizes_in_Bssmmodel(GthBSSMModel *bssm_model)
 static void build_bssm(GtBioseq *bioseq, GthBSSMModel *bssm_model,
                        unsigned int hypothesisnum)
 {
-  unsigned long mono_ct[STRINGSIZE-1][ALPHSIZE],         /* Mononuc freq */
+  GtUword mono_ct[STRINGSIZE-1][ALPHSIZE],         /* Mononuc freq */
                 di_ct[STRINGSIZE-1][ALPHSIZE][ALPHSIZE]; /* Dinuc freq */
   double mono_freq,      /* Mononuc relative freq */
          di_freq;        /* Dinuc relative freq */
-  unsigned long i, j, k, /* Iterator variables */
+  GtUword i, j, k, /* Iterator variables */
                 len, curlen = 0,
                 num_entries = gt_bioseq_number_of_sequences(bioseq);
   GtUchar *encoded_seq = NULL;
@@ -811,7 +837,7 @@ int gth_bssm_param_parameterize(GthBSSMParam *bssm_param, const char *path,
   GtAlphabet *alphabet = NULL;
   GtBioseq *bioseq;
   GtStr *file2proc;
-  unsigned long i, j;
+  GtUword i, j;
   int had_err = 0;
   gt_error_check(err);
 
@@ -871,7 +897,8 @@ int gth_bssm_param_parameterize(GthBSSMParam *bssm_param, const char *path,
       GtUchar encoded_seq[2];
       /* check length */
       if (gt_bioseq_get_sequence_length(bioseq, j) != STRINGSIZE) {
-        gt_error_set(err, "sequence %lu in file \"%s\" does not have length %u",
+        gt_error_set(err,
+                     "sequence "GT_WU" in file \"%s\" does not have length %u",
                      j, gt_str_get(file2proc), STRINGSIZE);
         had_err = -1;
       }
@@ -883,7 +910,7 @@ int gth_bssm_param_parameterize(GthBSSMParam *bssm_param, const char *path,
           case GT_DONOR_TYPE:
             if (encoded_seq[0] != gt_alphabet_encode(alphabet, 'G') ||
                 encoded_seq[1] != gt_alphabet_encode(alphabet, 'T')) {
-              gt_error_set(err, "sequence %lu in file \"%s\" is not a GT "
+              gt_error_set(err, "sequence "GT_WU" in file \"%s\" is not a GT "
                                 "sequence", j, gt_str_get(file2proc));
               had_err = -1;
             }
@@ -891,7 +918,7 @@ int gth_bssm_param_parameterize(GthBSSMParam *bssm_param, const char *path,
           case GC_DONOR_TYPE:
             if (encoded_seq[0] != gt_alphabet_encode(alphabet, 'G') ||
                 encoded_seq[1] != gt_alphabet_encode(alphabet, 'C')) {
-              gt_error_set(err, "sequence %lu in file \"%s\" is not a GC "
+              gt_error_set(err, "sequence "GT_WU" in file \"%s\" is not a GC "
                                 "sequence", j, gt_str_get(file2proc));
               had_err = -1;
             }
@@ -899,7 +926,7 @@ int gth_bssm_param_parameterize(GthBSSMParam *bssm_param, const char *path,
           case AG_ACCEPTOR_TYPE:
             if (encoded_seq[0] != gt_alphabet_encode(alphabet, 'A') ||
                 encoded_seq[1] != gt_alphabet_encode(alphabet, 'G')) {
-              gt_error_set(err, "sequence %lu in file \"%s\" is not a AG "
+              gt_error_set(err, "sequence "GT_WU" in file \"%s\" is not a AG "
                                 "sequence", j, gt_str_get(file2proc));
               had_err = -1;
             }
