@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2003-2011 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2003-2011 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2003-2008 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -34,7 +34,7 @@
 #define SHOW_COMPUTE_MATCHES_STATUS_BUF_SIZE    160
 
 typedef struct {
-  unsigned long call_number;
+  GtUword call_number;
   bool significant_match_found,
        max_call_number_reached,
        stop_amino_acid_warning;
@@ -44,13 +44,13 @@ static void show_matrix_calculation_status(GthShowVerbose showverbose,
                                            bool gen_strand_forward,
                                            bool ref_strand_forward,
                                            bool introncutout,
-                                           unsigned long chainctr,
-                                           unsigned long num_of_chains,
-                                           unsigned long icdelta,
-                                           unsigned long gen_file_num,
-                                           unsigned long num_of_gen_files,
-                                           unsigned long ref_file_num,
-                                           unsigned long num_of_ref_files,
+                                           GtUword chainctr,
+                                           GtUword num_of_chains,
+                                           GtUword icdelta,
+                                           GtUword gen_file_num,
+                                           GtUword num_of_gen_files,
+                                           GtUword ref_file_num,
+                                           GtUword num_of_ref_files,
                                            bool directmatches,
                                            bool verboseseqs,
                                            const char *gen_id,
@@ -61,7 +61,7 @@ static void show_matrix_calculation_status(GthShowVerbose showverbose,
   GT_UNUSED int rval;
 
   if (introncutout) {
-    rval =  snprintf(icdeltastring, ICDELTASTRINGLENGTH, ", icdelta=%lu",
+    rval =  snprintf(icdeltastring, ICDELTASTRINGLENGTH, ", icdelta=" GT_WU ,
                      icdelta);
     /* buffer icdeltastring[ICDELTASTRINGLENGTH] is large enough */
     gt_assert(rval <  ICDELTASTRINGLENGTH);
@@ -70,19 +70,20 @@ static void show_matrix_calculation_status(GthShowVerbose showverbose,
   if (num_of_gen_files == 1 && num_of_ref_files == 1) {
     rval = snprintf(buf, SHOW_MATRIX_CALCULATION_STATUS_BUF_SIZE,
                     "d=%c, compute spliced alignment, genseq=%c, "
-                    "chain=%lu/%lu, refseq=%c%s", SHOWSTRAND(directmatches),
-                    SHOWSTRAND(gen_strand_forward),  chainctr + 1,
-                    num_of_chains, SHOWSTRAND(ref_strand_forward),
+                    "chain=" GT_WU "/" GT_WU ", refseq=%c%s",
+                    SHOWSTRAND(directmatches), SHOWSTRAND(gen_strand_forward),
+                    chainctr + 1, num_of_chains, SHOWSTRAND(ref_strand_forward),
                     introncutout ? icdeltastring : "");
   }
   else {
     rval = snprintf(buf, SHOW_MATRIX_CALCULATION_STATUS_BUF_SIZE,
-                    "gf=%lu/%lu, d=%c, rf=%lu/%lu, compute spliced alignment, "
-                    "gs=%c, chain=%lu/%lu, rs=%c%s", gen_file_num + 1,
-                    num_of_gen_files, SHOWSTRAND(directmatches),
-                    ref_file_num + 1, num_of_ref_files,
-                    SHOWSTRAND(gen_strand_forward), chainctr + 1,
-                    num_of_chains, SHOWSTRAND(ref_strand_forward),
+                    "gf=" GT_WU "/" GT_WU ", d=%c, rf=" GT_WU "/" GT_WU
+                    ", compute spliced alignment, gs=%c, chain=" GT_WU "/"
+                    GT_WU ", rs=%c%s",
+                    gen_file_num + 1, num_of_gen_files,
+                    SHOWSTRAND(directmatches), ref_file_num + 1,
+                    num_of_ref_files, SHOWSTRAND(gen_strand_forward),
+                    chainctr + 1, num_of_chains, SHOWSTRAND(ref_strand_forward),
                     introncutout ? icdeltastring : "");
   }
   /* buf[SHOW_MATRIX_CALCULATION_STATUS_BUF_SIZE] is large enough */
@@ -101,23 +102,23 @@ static void show_matrix_calculation_status(GthShowVerbose showverbose,
 static int callsahmt(bool call_dna_dp,
                      GthSA *sa,
                      bool forward,
-                     unsigned long gen_file_num,
-                     unsigned long ref_file_num,
+                     GtUword gen_file_num,
+                     GtUword ref_file_num,
                      GthChain *raw_chain,
-                     unsigned long gen_total_length,
-                     unsigned long gen_offset,
+                     GtUword gen_total_length,
+                     GtUword gen_offset,
                      const GtRange *gen_seq_bounds,
                      const GtRange *gen_seq_bounds_rc,
                      const unsigned char *ref_seq_tran,
                      const unsigned char *ref_seq_orig,
-                     unsigned long ref_total_length,
-                     unsigned long ref_offset,
+                     GtUword ref_total_length,
+                     GtUword ref_offset,
                      GthInput *input,
                      Introncutoutinfo *introncutoutinfo,
                      GthStat *stat,
-                     unsigned long chainctr,
-                     unsigned long num_of_chains,
-                     unsigned long translationtable,
+                     GtUword chainctr,
+                     GtUword num_of_chains,
+                     GtUword translationtable,
                      bool directmatches,
                      bool proteinexonpenal,
                      GthSpliceSiteModel *splice_site_model,
@@ -131,7 +132,7 @@ static int callsahmt(bool call_dna_dp,
 {
   int rval;
   GthChain *actual_chain, *contracted_chain, *used_chain;
-  unsigned long icdelta = introncutoutinfo->icinitialdelta,
+  GtUword icdelta = introncutoutinfo->icinitialdelta,
                 iciterations = introncutoutinfo->iciterations;
   bool useintroncutout = introncutoutinfo->introncutout;
   /* initially useintron is set to the value of introncutoutinfo->introncutout,
@@ -357,15 +358,15 @@ static bool isunsuccessfulalignment(GthSA *sa,
 static int call_dna_DP(bool directmatches, GthCallInfo *call_info,
                        GthInput *input, GthStat *stat,
                        GthSACollection *sa_collection, GthSA *saA,
-                       unsigned long gen_file_num,
-                       unsigned long ref_file_num,
-                       unsigned long gen_total_length,
-                       unsigned long gen_offset,
+                       GtUword gen_file_num,
+                       GtUword ref_file_num,
+                       GtUword gen_total_length,
+                       GtUword gen_offset,
                        const GtRange *gen_seq_bounds,
                        const GtRange *gen_seq_bounds_rc,
-                       unsigned long ref_total_length, unsigned long ref_offset,
-                       unsigned long chainctr,
-                       unsigned long num_of_chains, GthMatchInfo *match_info,
+                       GtUword ref_total_length, GtUword ref_offset,
+                       GtUword chainctr,
+                       GtUword num_of_chains, GthMatchInfo *match_info,
                        const unsigned char *ref_seq_tran,
                        const unsigned char *ref_seq_orig,
                        const unsigned char *ref_seq_tran_rc,
@@ -505,16 +506,16 @@ static int call_protein_DP(bool directmatches,
                            GthStat *stat,
                            GthSACollection *sa_collection,
                            GthSA *saA,
-                           unsigned long gen_file_num,
-                           unsigned long ref_file_num,
-                           unsigned long gen_total_length,
-                           unsigned long gen_offset,
+                           GtUword gen_file_num,
+                           GtUword ref_file_num,
+                           GtUword gen_total_length,
+                           GtUword gen_offset,
                            const GtRange *gen_seq_bounds,
                            const GtRange *gen_seq_bounds_rc,
-                           unsigned long ref_total_length,
-                           unsigned long ref_offset,
-                           unsigned long chainctr,
-                           unsigned long num_of_chains,
+                           GtUword ref_total_length,
+                           GtUword ref_offset,
+                           GtUword chainctr,
+                           GtUword num_of_chains,
                            GthMatchInfo *match_info,
                            const unsigned char *ref_seq_tran,
                            const unsigned char *ref_seq_orig,
@@ -586,8 +587,8 @@ static void show_no_match_line(GthAlphatype overallalphatype, GtFile *outfp)
 static GthChainCollection* match_and_chain(GthCallInfo *call_info,
                                            GthInput *input,
                                            GthStat *stat,
-                                           unsigned long gen_file_num,
-                                           unsigned long ref_file_num,
+                                           GtUword gen_file_num,
+                                           GtUword ref_file_num,
                                            bool directmatches,
                                            GthMatchInfo *match_info,
                                            const GthPlugins *plugins)
@@ -630,8 +631,8 @@ static int calc_spliced_alignments(GthSACollection *sa_collection,
                                    GthCallInfo *call_info,
                                    GthInput *input,
                                    GthStat *stat,
-                                   unsigned long gen_file_num,
-                                   unsigned long ref_file_num,
+                                   GtUword gen_file_num,
+                                   GtUword ref_file_num,
                                    bool directmatches,
                                    GthMatchInfo *match_info,
                                    GthDNACompletePathMatrixJT
@@ -641,7 +642,7 @@ static int calc_spliced_alignments(GthSACollection *sa_collection,
 {
   const unsigned char *ref_seq_tran, *ref_seq_orig, *ref_seq_tran_rc = NULL,
                       *ref_seq_orig_rc = NULL;
-  unsigned long chainctr, gen_offset = GT_UNDEF_ULONG, gen_total_length,
+  GtUword chainctr, gen_offset = GT_UNDEF_UWORD, gen_total_length,
                 ref_total_length;
   GtFile *outfp = call_info->out->outfp;
   GtRange gen_seq_bounds, gen_seq_bounds_rc;
@@ -721,12 +722,12 @@ static int calc_spliced_alignments(GthSACollection *sa_collection,
       GtStr *ref_id = gt_str_new();
       gth_input_save_ref_id(input, ref_id, chain->ref_file_num,
                             chain->ref_seq_num);
-      gt_warning("protein sequence '%s' (#%lu in file %s) does not end with a "
-                 "stop amino acid ('%c'). If it is not a protein fragment you "
-                 "should add a stop amino acid to improve the prediction. "
-                 "For example with `gt seqtransform -addstopaminos` (see "
-                 "http://genometools.org for details).", gt_str_get(ref_id),
-                 chain->ref_seq_num,
+      gt_warning("protein sequence '%s' (#" GT_WU " in file %s) does not end "
+                 "with a stop amino acid ('%c'). If it is not a protein "
+                 "fragment you should add a stop amino acid to improve the "
+                 "prediction. For example with `gt seqtransform "
+                 "-addstopaminos` (see http://genometools.org for details).",
+                 gt_str_get(ref_id), chain->ref_seq_num,
                  gth_input_get_reference_filename(input, chain->ref_file_num),
                  GT_STOP_AMINO);
       match_info->stop_amino_acid_warning = true;
@@ -793,10 +794,10 @@ static int calc_spliced_alignments(GthSACollection *sa_collection,
 }
 
 static void show_compute_matches_status(bool direct, GthShowVerbose showverbose,
-                                        unsigned long gen_file_num,
-                                        unsigned long num_of_gen_files,
-                                        unsigned long ref_file_num,
-                                        unsigned long num_of_ref_files)
+                                        GtUword gen_file_num,
+                                        GtUword num_of_gen_files,
+                                        GtUword ref_file_num,
+                                        GtUword num_of_ref_files)
 {
   char buf[SHOW_COMPUTE_MATCHES_STATUS_BUF_SIZE];
   GT_UNUSED int rval;
@@ -810,15 +811,15 @@ static void show_compute_matches_status(bool direct, GthShowVerbose showverbose,
   else {
     if (direct) {
       rval = snprintf(buf, SHOW_MATRIX_CALCULATION_STATUS_BUF_SIZE,
-                      "compute direct matches for genomic file (gf) %lu/%lu "
-                      "and reference file (rf) %lu/%lu",
+                      "compute direct matches for genomic file (gf) " GT_WU "/"
+                      GT_WU " and reference file (rf) " GT_WU "/" GT_WU,
                       gen_file_num + 1, num_of_gen_files,
                       ref_file_num + 1, num_of_ref_files);
     }
     else {
       rval = snprintf(buf, SHOW_MATRIX_CALCULATION_STATUS_BUF_SIZE,
-                      "compute palindromic matches for genomic file (gf) "
-                      "%lu/%lu and reference file (rf) %lu/%lu",
+                      "compute palindromic matches for genomic file (gf) " GT_WU
+                      "/" GT_WU " and reference file (rf) " GT_WU "/" GT_WU,
                       gen_file_num + 1,  num_of_gen_files,
                       ref_file_num + 1,  num_of_ref_files);
     }
@@ -836,7 +837,7 @@ static int compute_sa_collection(GthSACollection *sa_collection,
 {
   GthChainCollection *chain_collection;
   GthMatchInfo match_info;
-  unsigned long g, r;
+  GtUword g, r;
   int rval = 0;
 
   match_info.call_number = 0;
