@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2003-2011 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2003-2011 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2003-2008 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -26,6 +26,8 @@
 #include "lpeg.h"
 #include "md5.h"
 #include "ldes56.h"
+#include "core/compat.h"
+#include "core/cstr.h"
 #include "core/cstr_array.h"
 #include "core/ensure.h"
 #include "core/fa.h"
@@ -33,14 +35,20 @@
 #include "core/gtdatapath.h"
 #include "core/log.h"
 #include "core/ma.h"
-#include "core/thread_api.h"
+#include "core/multithread_api.h"
+#include "core/option.h"
+#include "core/parseutils.h"
+#include "core/tool.h"
+#include "core/toolbox.h"
+#include "core/tool_iterator.h"
+#include "core/types_api.h"
 #include "core/unit_testing.h"
 #include "core/versionfunc.h"
 #include "core/xansi_api.h"
+#include "core/xposix.h"
 #include "core/yarandom.h"
 #include "extended/gtdatahelp.h"
 #include "extended/luahelper.h"
-#include "extended/toolbox.h"
 #include "gtlua/gt_lua.h"
 
 #ifndef WITHOUT_CAIRO
@@ -52,13 +60,15 @@ struct GtR {
   bool test,
        interactive,
        debug,
+       list,
        check64bit;
   unsigned int seed;
   GtStr *debugfp,
       *testspacepeak;
   GtToolbox *tools;
   GtHashmap *unit_tests;
-  GtStr *test_only;
+  GtStr *manoutdir,
+        *test_only;
   lua_State *L;
 #ifndef WITHOUT_CAIRO
   GtStyle *style;
@@ -69,18 +79,29 @@ struct GtR {
 GtR* gtr_new(GtError *err)
 {
   GtR *gtr;
+  char *seedstr = NULL;
   int had_err = 0;
 #ifndef WITHOUT_CAIRO
   GtStr *style_file = NULL;
 #endif
   gtr = gt_calloc(1, sizeof (GtR));
-  gtr->debugfp = gt_str_new();
-  gtr->testspacepeak = gt_str_new();
-  gtr->test_only = gt_str_new();
-  gtr->L = luaL_newstate();
-  if (!gtr->L) {
-    gt_error_set(err, "out of memory (cannot create new lua state)");
-    had_err = -1;
+  if ((seedstr = getenv("GT_SEED"))) {
+    if (gt_parse_uint(&gtr->seed, seedstr) != 0) {
+      gt_error_set(err, "invalid seed in GT_SEED environment variable: %s",
+                   seedstr);
+      had_err = -1;
+    }
+  } else gtr->seed = 0;
+  if (!had_err) {
+    gtr->debugfp = gt_str_new();
+    gtr->testspacepeak = gt_str_new();
+    gtr->test_only = gt_str_new();
+    gtr->manoutdir = gt_str_new();
+    gtr->L = luaL_newstate();
+    if (!gtr->L) {
+      gt_error_set(err, "out of memory (cannot create new lua state)");
+      had_err = -1;
+    }
   }
   if (!had_err) {
     luaL_openlibs(gtr->L);    /* open the standard libraries */
@@ -136,18 +157,13 @@ static int show_gtr_help(const char *progname, void *data, GtError *err)
   return had_err;
 }
 
-GtOPrval gtr_parse(GtR *gtr, int *parsed_args, int argc, const char **argv,
-                   GtError *err)
+static GtOptionParser* gtr_option_parser_new(GtR *gtr)
 {
   GtOptionParser *op;
   GtOption *o, *only_option, *debug_option, *debugfp_option;
-  GtOPrval oprval;
-
-  gt_error_check(err);
   gt_assert(gtr);
   op = gt_option_parser_new("[option ...] [tool | script] [argument ...]",
-                            "The GenomeTools (gt) genome analysis system "
-                            "(http://genometools.org).");
+                            "The GenomeTools genome analysis system.");
   gt_option_parser_set_comment_func(op, show_gtr_help, gtr->tools);
   o = gt_option_new_bool("i",
                          "enter interactive mode after executing 'tool' or "
@@ -184,17 +200,36 @@ GtOPrval gtr_parse(GtR *gtr, int *parsed_args, int argc, const char **argv,
   o = gt_option_new_uint("seed",
                          "set seed for random number generator manually\n"
                          "0 generates a seed from current time and process id",
-                         &gtr->seed, 0);
-  gt_option_is_development_option(o);
+                         &gtr->seed, gtr->seed);
   gt_option_parser_add_option(op, o);
   o = gt_option_new_bool("64bit", "exit with code 0 if this is a 64bit binary, "
                          "with 1 otherwise", &gtr->check64bit, false);
   gt_option_is_development_option(o);
   gt_option_parser_add_option(op, o);
+  o = gt_option_new_bool("list", "list all tools and exit", &gtr->list, false);
+  gt_option_is_development_option(o);
+  gt_option_hide_default(o);
+  gt_option_parser_add_option(op, o);
   o = gt_option_new_filename("testspacepeak", "alloc 64 MB and mmap the given "
                              "file", gtr->testspacepeak);
   gt_option_is_development_option(o);
   gt_option_parser_add_option(op, o);
+
+  o = gt_option_new_string("createman", "create man page sources in directory",
+                           gtr->manoutdir, "");
+  gt_option_is_development_option(o);
+  gt_option_parser_add_option(op, o);
+  return op;
+}
+
+GtOPrval gtr_parse(GtR *gtr, int *parsed_args, int argc, const char **argv,
+                   GtError *err)
+{
+  GtOptionParser *op;
+  GtOPrval oprval;
+  gt_error_check(err);
+  gt_assert(gtr);
+  op = gtr_option_parser_new(gtr);
   oprval = gt_option_parser_parse(op, parsed_args, argc, argv, gt_versionfunc,
                                   err);
   gt_option_parser_delete(op);
@@ -212,9 +247,109 @@ void gtr_register_components(GtR *gtr)
   gtr->unit_tests = gtt_unit_tests();
 }
 
+static int list_tools(GtR *gtr)
+{
+  GtToolIterator *ti;
+  GtOptionParser *op;
+  const char *name;
+  char fulltoolname[BUFSIZ],
+       *utoolname;
+  GtTool *tool;
+  GtStr *prefix = gt_str_new();
+  gt_assert(gtr);
+  /* list 'gt' itself */
+  printf("\n"),
+  printf("- link:tools/gt.html[gt]\n");
+  op = gtr_option_parser_new(gtr);
+  printf("  %s\n", gt_option_parser_one_liner(op));
+  gt_option_parser_delete(op);
+  /* list all tools in 'gt' */
+  ti = gt_tool_iterator_new(gtr->tools);
+  gt_tool_iterator_set_prefix_target(ti, prefix, ' ');
+  while (gt_tool_iterator_next(ti, &name, &tool)) {
+    op = gt_tool_get_option_parser(tool);
+    (void) snprintf(fulltoolname, BUFSIZ, "gt%c%s%s", ' ',
+                    gt_str_get(prefix), name);
+    utoolname = gt_cstr_dup(fulltoolname);
+    gt_cstr_rep(utoolname, ' ', '_');
+    printf("\n"),
+    printf("- link:tools/%s.html[%s]\n", utoolname, fulltoolname);
+    printf("  %s\n", gt_option_parser_one_liner(op));
+    gt_free(utoolname);
+  }
+  gt_tool_iterator_delete(ti);
+  gt_str_delete(prefix);
+  return EXIT_SUCCESS;
+}
+
+static int create_manpage(const char *outdir, const char *toolname,
+                          GtOptionParser *option_parser, GtError *err)
+{
+  GtFile *outfile = NULL;
+  GtStr *man, *pathbuf;
+  char *utoolname;
+  int had_err = 0;
+  gt_error_check(err);
+  gt_assert(outdir && toolname && option_parser);
+  man = gt_str_new();
+  pathbuf = gt_str_new_cstr(outdir);
+  utoolname = gt_cstr_dup(toolname);
+  gt_cstr_rep(utoolname, ' ', '_');
+  if (!gt_file_exists(gt_str_get(pathbuf)))
+    gt_xmkdir(gt_str_get(pathbuf));
+  gt_str_append_char(pathbuf, GT_PATH_SEPARATOR);
+  gt_str_append_cstr(pathbuf, utoolname);
+  gt_str_append_cstr(pathbuf, ".mansrc");
+  gt_free(utoolname);
+  if (!(outfile = gt_file_new(gt_str_get(pathbuf), "w+", err)))
+    had_err = -1;
+  if (!had_err)
+    had_err = gt_option_parser_manpage(option_parser, toolname, man, err);
+  if (!had_err)
+    gt_file_xprintf(outfile, "%s", gt_str_get(man));
+  gt_file_delete(outfile);
+  gt_str_delete(pathbuf);
+  gt_str_delete(man);
+  return had_err;
+}
+
+static int create_manpages(GtR *gtr, const char *outdir, GtError *err)
+{
+  GtOptionParser *op;
+  const char *name;
+  char fulltoolname[BUFSIZ];
+  GtTool *tool;
+  GtStr *prefix = gt_str_new();
+  int had_err = 0;
+  gt_error_check(err);
+  gt_assert(gtr);
+  gt_createman = true;
+  /* create man page for 'gt' itself */
+  op = gtr_option_parser_new(gtr);
+  had_err = create_manpage(outdir, "gt", op, err);
+  gt_option_parser_delete(op);
+  /* create man pages for all tools in 'gt' */
+  if (!had_err) {
+    GtToolIterator *ti = gt_tool_iterator_new(gtr->tools);
+    gt_tool_iterator_set_prefix_target(ti, prefix, ' ');
+    while (!had_err && gt_tool_iterator_next(ti, &name, &tool)) {
+      op = gt_tool_get_option_parser(tool);
+      (void) snprintf(fulltoolname, BUFSIZ, "gt%c%s%s", ' ',
+                      gt_str_get(prefix), name);
+      had_err = create_manpage(outdir, fulltoolname, op, err);
+    }
+    gt_tool_iterator_delete(ti);
+  }
+  gt_str_delete(prefix);
+  gt_createman = false;
+  if (had_err)
+    return EXIT_FAILURE;
+  return EXIT_SUCCESS;
+}
+
 static int check64bit(void)
 {
-  if (sizeof (unsigned long) == 8)
+  if (sizeof (GtUword) == 8)
     return EXIT_SUCCESS;
   return EXIT_FAILURE;
 }
@@ -228,18 +363,17 @@ static int run_tests(GtR *gtr, GtError *err)
   gt_assert(gtr);
 
   /* The following type assumptions are made in the GenomeTools library. */
-  gt_ensure(had_err, sizeof (char) == 1);
-  gt_ensure(had_err, sizeof (unsigned char) == 1);
-  gt_ensure(had_err, sizeof (short) == 2);
-  gt_ensure(had_err, sizeof (unsigned short) == 2);
-  gt_ensure(had_err, sizeof (int) == 4);
-  gt_ensure(had_err, sizeof (unsigned int) == 4);
-  gt_ensure(had_err, sizeof (long) == 4 || sizeof (long) == 8);
-  gt_ensure(had_err, sizeof (unsigned long) == 4 ||
-                     sizeof (unsigned long) == 8);
-  gt_ensure(had_err, sizeof (unsigned long) >= sizeof (size_t));
-  gt_ensure(had_err, sizeof (long long) == 8);
-  gt_ensure(had_err, sizeof (unsigned long long) == 8);
+  gt_ensure(sizeof (char) == 1);
+  gt_ensure(sizeof (unsigned char) == 1);
+  gt_ensure(sizeof (short) == 2);
+  gt_ensure(sizeof (unsigned short) == 2);
+  gt_ensure(sizeof (int) == 4);
+  gt_ensure(sizeof (unsigned int) == 4);
+  gt_ensure(sizeof (GtWord) == 4 || sizeof (GtWord) == 8);
+  gt_ensure(sizeof (GtUword) == 4 || sizeof (GtUword) == 8);
+  gt_ensure(sizeof (GtUword) >= sizeof (size_t));
+  gt_ensure(sizeof (GtInt64) == 8);
+  gt_ensure(sizeof (GtUint64) == 8);
 
   /* show seed */
   printf("seed=%u\n", gtr->seed);
@@ -295,6 +429,10 @@ int gtr_run(GtR *gtr, int argc, const char **argv, GtError *err)
     enable_logging(gt_str_get(gtr->debugfp), &gtr->logfp);
   gtr->seed = gt_ya_rand_init(gtr->seed);
   gt_log_log("seed=%u", gtr->seed);
+  if (gtr->list)
+    return list_tools(gtr);
+  if (gt_str_length(gtr->manoutdir) > 0)
+    return create_manpages(gtr, gt_str_get(gtr->manoutdir), err);
   if (gtr->check64bit)
     return check64bit();
   if (gtr->test)
@@ -365,6 +503,7 @@ void gtr_delete(GtR *gtr)
   gt_str_delete(gtr->testspacepeak);
   gt_str_delete(gtr->debugfp);
   gt_str_delete(gtr->test_only);
+  gt_str_delete(gtr->manoutdir);
   gt_toolbox_delete(gtr->tools);
   gt_hashmap_delete(gtr->unit_tests);
   if (gtr->L) lua_close(gtr->L);
