@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2003-2013 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2003-2013 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2003-2013 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -54,9 +54,12 @@
 #include "core/translator.h"
 #include "extended/alignment.h"
 #include "extended/anno_db_gfflike_api.h"
+#include "extended/compressed_bitsequence.h"
+#include "extended/editscript.h"
 #include "extended/elias_gamma.h"
 #include "extended/encdesc.h"
 #include "extended/evaluator.h"
+#include "extended/feature_in_stream.h"
 #include "extended/feature_index.h"
 #include "extended/feature_index_memory.h"
 #include "extended/feature_node.h"
@@ -66,8 +69,11 @@
 #include "extended/golomb.h"
 #include "extended/hmm.h"
 #include "extended/huffcode.h"
+#include "extended/intset.h"
 #include "extended/luaserialize.h"
+#include "extended/n_r_encseq.h"
 #include "extended/popcount_tab.h"
+#include "extended/priority_queue.h"
 #include "extended/ranked_list.h"
 #include "extended/rbtree.h"
 #include "extended/rmq.h"
@@ -78,18 +84,19 @@
 #include "ltr/gt_ltrclustering.h"
 #include "ltr/gt_ltrdigest.h"
 #include "ltr/gt_ltrharvest.h"
-#include "ltr/ltrelement.h"
-#include "ltr/pbs.h"
-#include "ltr/ppt.h"
+#include "ltr/ltrdigest_pbs_visitor.h"
 #include "match/rdj-spmlist.h"
 #include "match/rdj-strgraph.h"
 #include "match/shu-encseq-gc.h"
+#include "match/xdrop.h"
 #include "tools/gt_bed_to_gff3.h"
 #include "tools/gt_cds.h"
 #include "tools/gt_chain2dim.h"
 #include "tools/gt_chseqids.h"
 #include "tools/gt_clean.h"
 #include "tools/gt_compreads.h"
+#include "tools/gt_compressedbits.h"
+#include "tools/gt_condenser.h"
 #include "tools/gt_congruence.h"
 #include "tools/gt_convertseq.h"
 #include "tools/gt_csa.h"
@@ -101,6 +108,7 @@
 #include "tools/gt_eval.h"
 #include "tools/gt_extractfeat.h"
 #include "tools/gt_extractseq.h"
+#include "tools/gt_fastq_sample.h"
 #include "tools/gt_featureindex.h"
 #include "tools/gt_fingerprint.h"
 #include "tools/gt_genomediff.h"
@@ -111,9 +119,9 @@
 #include "tools/gt_hop.h"
 #include "tools/gt_id_to_md5.h"
 #include "tools/gt_interfeat.h"
+#include "tools/gt_loccheck.h"
 #include "tools/gt_matchtool.h"
 #include "tools/gt_matstat.h"
-#include "tools/gt_maxpairs.h"
 #include "tools/gt_md5_to_id.h"
 #include "tools/gt_merge.h"
 #include "tools/gt_mergefeat.h"
@@ -125,6 +133,7 @@
 #include "tools/gt_packedindex.h"
 #include "tools/gt_prebwt.h"
 #include "tools/gt_readjoiner.h"
+#include "tools/gt_repfind.h"
 #include "tools/gt_script_filter.h"
 #include "tools/gt_select.h"
 #include "tools/gt_seq.h"
@@ -140,6 +149,7 @@
 #include "tools/gt_shulen.h"
 #include "tools/gt_simreads.h"
 #include "tools/gt_snpper.h"
+#include "tools/gt_speck.h"
 #include "tools/gt_splicesiteinfo.h"
 #include "tools/gt_splitfasta.h"
 #include "tools/gt_stat.h"
@@ -147,8 +157,10 @@
 #include "tools/gt_tagerator.h"
 #include "tools/gt_tallymer.h"
 #include "tools/gt_template.h"
+#include "tools/gt_tir.h"
 #include "tools/gt_uniq.h"
 #include "tools/gt_uniquesub.h"
+#include "tools/gt_wtree.h"
 #ifndef WITHOUT_CAIRO
 #include "annotationsketch/block.h"
 #include "annotationsketch/diagram.h"
@@ -165,18 +177,9 @@ GtToolbox* gtt_tools(void)
   GtToolbox *tools = gt_toolbox_new();
 
   /* add tools */
-  gt_toolbox_add_tool(tools, "orffinder", gt_orffinder());
-  gt_toolbox_add(tools, "chseqids", gt_chseqids);
-  gt_toolbox_add(tools, "clean", gt_clean);
-  gt_toolbox_add(tools, "convertseq", gt_convertseq);
-  gt_toolbox_add(tools, "matstat", gt_matstat);
-  gt_toolbox_add(tools, "merge", gt_merge);
   gt_toolbox_add(tools, "mgth", gt_mgth);
   gt_toolbox_add(tools, "mkfmindex", gt_mkfmindex);
-  gt_toolbox_add(tools, "mmapandread", gt_mmapandread);
-  gt_toolbox_add(tools, "seqstat", gt_seqstat);
   gt_toolbox_add(tools, "suffixerator", gt_suffixerator);
-  gt_toolbox_add(tools, "uniquesub", gt_uniquesub);
   gt_toolbox_add_hidden_tool(tools, "dev", gt_dev());
   gt_toolbox_add_hidden_tool(tools, "filter", gt_select());
   /* hidden "link from the mutate to the seqmutate tool for backward
@@ -186,8 +189,12 @@ GtToolbox* gtt_tools(void)
   gt_toolbox_add_tool(tools, "bed_to_gff3", gt_bed_to_gff3());
   gt_toolbox_add_tool(tools, "cds", gt_cds());
   gt_toolbox_add_tool(tools, "chain2dim", gt_chain2dim());
+  gt_toolbox_add_tool(tools, "chseqids", gt_chseqids());
+  gt_toolbox_add_tool(tools, "clean", gt_clean());
   gt_toolbox_add_tool(tools, "compreads", gt_compreads());
+  gt_toolbox_add_tool(tools, "condenser", gt_condenser());
   gt_toolbox_add_tool(tools, "congruence", gt_congruence());
+  gt_toolbox_add_tool(tools, "convertseq", gt_convertseq());
   gt_toolbox_add_tool(tools, "csa", gt_csa());
   gt_toolbox_add_tool(tools, "dot", gt_dot());
   gt_toolbox_add_tool(tools, "dupfeat", gt_dupfeat());
@@ -196,7 +203,7 @@ GtToolbox* gtt_tools(void)
   gt_toolbox_add_tool(tools, "eval", gt_eval());
   gt_toolbox_add_tool(tools, "extractfeat", gt_extractfeat());
   gt_toolbox_add_tool(tools, "extractseq", gt_extractseq());
-  gt_toolbox_add_tool(tools, "featureindex", gt_featureindex());
+  gt_toolbox_add_tool(tools, "fastq_sample", gt_fastq_sample());
   gt_toolbox_add_tool(tools, "fingerprint", gt_fingerprint());
   gt_toolbox_add_tool(tools, "genomediff", gt_genomediff());
   gt_toolbox_add_tool(tools, "gff3", gt_gff3());
@@ -206,13 +213,17 @@ GtToolbox* gtt_tools(void)
   gt_toolbox_add_tool(tools, "hop", gt_hop());
   gt_toolbox_add_tool(tools, "id_to_md5", gt_id_to_md5());
   gt_toolbox_add_tool(tools, "interfeat", gt_interfeat());
+  gt_toolbox_add_tool(tools, "loccheck", gt_loccheck());
   gt_toolbox_add_tool(tools, "ltrclustering", gt_ltrclustering());
   gt_toolbox_add_tool(tools, "ltrdigest", gt_ltrdigest());
   gt_toolbox_add_tool(tools, "ltrharvest", gt_ltrharvest());
   gt_toolbox_add_tool(tools, "matchtool", gt_matchtool());
+  gt_toolbox_add_tool(tools, "matstat", gt_matstat());
   gt_toolbox_add_tool(tools, "md5_to_id", gt_md5_to_id());
+  gt_toolbox_add_tool(tools, "merge", gt_merge());
   gt_toolbox_add_tool(tools, "mergefeat", gt_mergefeat());
-  gt_toolbox_add_tool(tools, "mkfeatureindex", gt_mkfeatureindex());
+  gt_toolbox_add_tool(tools, "mmapandread", gt_mmapandread());
+  gt_toolbox_add_tool(tools, "orffinder", gt_orffinder());
   gt_toolbox_add_tool(tools, "packedindex", gt_packedindex());
   gt_toolbox_add_tool(tools, "prebwt", gt_prebwt());
   gt_toolbox_add_tool(tools, "readjoiner", gt_readjoiner());
@@ -224,6 +235,7 @@ GtToolbox* gtt_tools(void)
   gt_toolbox_add_tool(tools, "seqids", gt_seqids());
   gt_toolbox_add_tool(tools, "seqmutate", gt_seqmutate());
   gt_toolbox_add_tool(tools, "seqorder", gt_seqorder());
+  gt_toolbox_add_tool(tools, "seqstat", gt_seqstat());
   gt_toolbox_add_tool(tools, "seqtransform", gt_seqtransform());
   gt_toolbox_add_tool(tools, "seqtranslate", gt_seqtranslate());
   gt_toolbox_add_tool(tools, "sequniq", gt_sequniq());
@@ -231,16 +243,25 @@ GtToolbox* gtt_tools(void)
   gt_toolbox_add_tool(tools, "shulengthdist", gt_shulengthdist());
   gt_toolbox_add_tool(tools, "simreads", gt_simreads());
   gt_toolbox_add_tool(tools, "snpper", gt_snpper());
+  gt_toolbox_add_tool(tools, "speck", gt_speck());
   gt_toolbox_add_tool(tools, "splicesiteinfo", gt_splicesiteinfo());
   gt_toolbox_add_tool(tools, "splitfasta", gt_splitfasta());
   gt_toolbox_add_tool(tools, "stat", gt_stat());
   gt_toolbox_add_tool(tools, "tagerator", gt_tagerator());
   gt_toolbox_add_tool(tools, "tallymer", gt_tallymer());
+  gt_toolbox_add_tool(tools, "tirvish", gt_tir());
   gt_toolbox_add_tool(tools, "uniq", gt_uniq());
+  gt_toolbox_add_tool(tools, "uniquesub", gt_uniquesub());
+  gt_toolbox_add_tool(tools, "wtree", gt_wtree());
 #ifndef WITHOUT_CAIRO
-  gt_toolbox_add(tools, "sketch", gt_sketch);
+  gt_toolbox_add_tool(tools, "sketch", gt_sketch());
   gt_toolbox_add_tool(tools, "sketch_page", gt_sketch_page());
 #endif
+#if defined (HAVE_MYSQL) || defined (HAVE_SQLITE)
+  gt_toolbox_add_tool(tools, "featureindex", gt_featureindex());
+  gt_toolbox_add_tool(tools, "mkfeatureindex", gt_mkfeatureindex());
+#endif
+
   return tools;
 }
 
@@ -250,8 +271,6 @@ GtHashmap* gtt_unit_tests(void)
 
   /* add unit tests */
 
-  gt_hashmap_add(unit_tests, "compactulongstore class",
-                                              gt_compact_ulong_store_unit_test);
   gt_hashmap_add(unit_tests, "alphabet class", gt_alphabet_unit_test);
   gt_hashmap_add(unit_tests, "alignment class", gt_alignment_unit_test);
   gt_hashmap_add(unit_tests, "array class", gt_array_unit_test);
@@ -273,6 +292,10 @@ GtHashmap* gtt_unit_tests(void)
                                             gt_codon_iterator_encseq_unit_test);
   gt_hashmap_add(unit_tests, "color space module", gt_colorspace_unit_test);
   gt_hashmap_add(unit_tests, "combinatorics", gt_combinatorics_unit_test);
+  gt_hashmap_add(unit_tests, "compactulongstore class",
+                                              gt_compact_ulong_store_unit_test);
+  gt_hashmap_add(unit_tests, "compressed bitsequence",
+                                           gt_compressed_bitsequence_unit_test);
   gt_hashmap_add(unit_tests, "countingsort module", gt_countingsort_unit_test);
   gt_hashmap_add(unit_tests, "cstr module", gt_cstr_unit_test);
   gt_hashmap_add(unit_tests, "cstr table class", gt_cstr_table_unit_test);
@@ -282,6 +305,7 @@ GtHashmap* gtt_unit_tests(void)
   gt_hashmap_add(unit_tests, "dlist class", gt_dlist_unit_test);
   gt_hashmap_add(unit_tests, "dlist example", gt_dlist_example);
   gt_hashmap_add(unit_tests, "dynamic bittab class", gt_dyn_bittab_unit_test);
+  gt_hashmap_add(unit_tests, "editscript class", gt_editscript_unit_test);
   gt_hashmap_add(unit_tests, "elias gamma class", gt_elias_gamma_unit_test);
   gt_hashmap_add(unit_tests, "encdesc class", gt_encdesc_unit_test);
   gt_hashmap_add(unit_tests, "encseq builder class",
@@ -291,6 +315,8 @@ GtHashmap* gtt_unit_tests(void)
   gt_hashmap_add(unit_tests, "feature node iterator example",
                                              gt_feature_node_iterator_example);
   gt_hashmap_add(unit_tests, "feature node class", gt_feature_node_unit_test);
+  gt_hashmap_add(unit_tests, "feature in stream class",
+                                                gt_feature_in_stream_unit_test);
   gt_hashmap_add(unit_tests, "genome node class", gt_genome_node_unit_test);
   gt_hashmap_add(unit_tests, "gff3 escaping module",
                                                     gt_gff3_escaping_unit_test);
@@ -301,16 +327,17 @@ GtHashmap* gtt_unit_tests(void)
   gt_hashmap_add(unit_tests, "hmm class", gt_hmm_unit_test);
   gt_hashmap_add(unit_tests, "huffman coding class", gt_huffman_unit_test);
   gt_hashmap_add(unit_tests, "interval tree class", gt_interval_tree_unit_test);
+  gt_hashmap_add(unit_tests, "intset classes", gt_intset_unit_test);
   gt_hashmap_add(unit_tests, "Lua serializer module",
                                                    gt_lua_serializer_unit_test);
-  gt_hashmap_add(unit_tests, "ltrelement module", gt_ltrelement_unit_test);
   gt_hashmap_add(unit_tests, "mathsupport module", gt_mathsupport_unit_test);
   gt_hashmap_add(unit_tests, "memory allocator module", gt_ma_unit_test);
   gt_hashmap_add(unit_tests, "MD5 seqid module", gt_md5_seqid_unit_test);
+  gt_hashmap_add(unit_tests, "n_r_encseq", gt_n_r_encseq_unit_test);
   gt_hashmap_add(unit_tests, "rdj: suffix-prefix matches list module",
                                                           gt_spmlist_unit_test);
-  gt_hashmap_add(unit_tests, "PBS finder module", gt_pbs_unit_test);
-  gt_hashmap_add(unit_tests, "PPT finder module", gt_ppt_unit_test);
+  gt_hashmap_add(unit_tests, "PBS finder module",
+                                            gt_ltrdigest_pbs_visitor_unit_test);
   gt_hashmap_add(unit_tests, "popcount sorted tab", gt_popcount_tab_unit_test);
   gt_hashmap_add(unit_tests, "quality module", gt_quality_unit_test);
   gt_hashmap_add(unit_tests, "queue class", gt_queue_unit_test);
@@ -319,7 +346,8 @@ GtHashmap* gtt_unit_tests(void)
   gt_hashmap_add(unit_tests, "red-black tree class", gt_rbtree_unit_test);
   gt_hashmap_add(unit_tests, "range minimum query class", gt_rmq_unit_test);
   gt_hashmap_add(unit_tests, "rdj: string graph class", gt_strgraph_unit_test);
-  gt_hashmap_add(unit_tests, "red-black tree class", gt_rbtree_unit_test);
+  gt_hashmap_add(unit_tests, "priority queue class",
+                             gt_priority_queue_unit_test);
   gt_hashmap_add(unit_tests, "safearith example", gt_safearith_example);
   gt_hashmap_add(unit_tests, "safearith module", gt_safearith_unit_test);
   gt_hashmap_add(unit_tests, "sequence buffer class",
@@ -335,6 +363,7 @@ GtHashmap* gtt_unit_tests(void)
   gt_hashmap_add(unit_tests, "tokenizer class", gt_tokenizer_unit_test);
   gt_hashmap_add(unit_tests, "translator class", gt_translator_unit_test);
   gt_hashmap_add(unit_tests, "uint64hashtable", gt_uint64hashtable_unit_test);
+  gt_hashmap_add(unit_tests, "xdrop", gt_xdrop_unit_test);
 #ifndef WITHOUT_CAIRO
   gt_hashmap_add(unit_tests, "block class", gt_block_unit_test);
   gt_hashmap_add(unit_tests, "diagram class", gt_diagram_unit_test);
@@ -342,12 +371,14 @@ GtHashmap* gtt_unit_tests(void)
   gt_hashmap_add(unit_tests, "element class", gt_element_unit_test);
   gt_hashmap_add(unit_tests, "memory feature index class",
                                              gt_feature_index_memory_unit_test);
-  gt_hashmap_add(unit_tests, "database feature index class (GFF-like)",
-                                                  gt_anno_db_gfflike_unit_test);
   gt_hashmap_add(unit_tests, "imageinfo class", gt_image_info_unit_test);
   gt_hashmap_add(unit_tests, "line class", gt_line_unit_test);
   gt_hashmap_add(unit_tests, "track class", gt_track_unit_test);
 #endif
+#if defined (HAVE_MYSQL) || defined (HAVE_SQLITE)
+  gt_hashmap_add(unit_tests, "database feature index class (GFF-like)",
+                                                  gt_anno_db_gfflike_unit_test);
+#endif
 
   return unit_tests;
 }
