@@ -42,7 +42,7 @@ typedef struct {
         *str_fastaoutputfilenameinnerregion,
         *str_gff3filename;
   GtRange searchrange;
-  unsigned long minseedlength,
+  GtUword minseedlength,
                 minltrlength,
                 maxltrlength,
                 mindistance,
@@ -63,7 +63,10 @@ typedef struct {
        gff3output,
        longoutput,
        scan,
-       verbosemode;
+       verbosemode,
+       tabout,
+       md5,
+       seqids;
   GtOption *optionmotif,
            *optionmotifmis,
            *optionoverlaps,
@@ -101,15 +104,15 @@ static void gt_ltrharvest_showopts(const LTRharvestArguments *lo)
   }
   printf("#   xdropbelowscore: %d\n", lo->xdropbelowscore);
   printf("#   similaritythreshold: %.2f\n", lo->similaritythreshold);
-  printf("#   minseedlength: %lu\n", lo->minseedlength);
+  printf("#   minseedlength: "GT_WU"\n", lo->minseedlength);
   printf("#   matchscore: %d\n", lo->arbitscores.mat);
   printf("#   mismatchscore: %d\n", lo->arbitscores.mis);
   printf("#   insertionscore: %d\n", lo->arbitscores.ins);
   printf("#   deletionscore: %d\n", lo->arbitscores.del);
-  printf("#   minLTRlength: %lu\n",  lo->minltrlength);
-  printf("#   maxLTRlength: %lu\n",  lo->maxltrlength);
-  printf("#   minLTRdistance: %lu\n",  lo->mindistance);
-  printf("#   maxLTRdistance: %lu\n",  lo->maxdistance);
+  printf("#   minLTRlength: "GT_WU"\n",  lo->minltrlength);
+  printf("#   maxLTRlength: "GT_WU"\n",  lo->maxltrlength);
+  printf("#   minLTRdistance: "GT_WU"\n",  lo->mindistance);
+  printf("#   maxLTRdistance: "GT_WU"\n",  lo->maxdistance);
   if (lo->nooverlaps)
   {
     printf("#   overlaps: no\n");
@@ -133,7 +136,7 @@ static void gt_ltrharvest_showopts(const LTRharvestArguments *lo)
   if (lo->searchrange.start != 0 ||
       lo->searchrange.end != 0)
   {
-    printf("# ltrsearchseqrange=(%lu,%lu)\n",
+    printf("# ltrsearchseqrange=("GT_WU","GT_WU")\n",
           lo->searchrange.start,
           lo->searchrange.end);
   }
@@ -199,6 +202,9 @@ static GtOptionParser* gt_ltrharvest_option_parser_new(void *tool_arguments)
            *optionins,
            *optiondel,
            *optionv,
+           *optiontabout,
+           *optionmd5,
+           *optionseqids,
            *optionoffset,
            *optionlongoutput,
            *optionout,
@@ -236,7 +242,7 @@ static GtOptionParser* gt_ltrharvest_option_parser_new(void *tool_arguments)
   gt_option_parser_add_option(op, optionltrsearchseqrange);
 
   /* -seed */
-  optionseed = gt_option_new_ulong_min("seed",
+  optionseed = gt_option_new_uword_min("seed",
                                "specify minimum seed length for"
                                " exact repeats",
                                &arguments->minseedlength,
@@ -245,41 +251,41 @@ static GtOptionParser* gt_ltrharvest_option_parser_new(void *tool_arguments)
   gt_option_parser_add_option(op, optionseed);
 
   /* -minlenltr */
-  optionminlenltr = gt_option_new_ulong_min_max("minlenltr",
+  optionminlenltr = gt_option_new_uword_min_max("minlenltr",
                                "specify minimum length for each LTR",
                                &arguments->minltrlength,
                                100UL,
                                1UL,
-                               GT_UNDEF_ULONG);
+                               GT_UNDEF_UWORD);
   gt_option_parser_add_option(op, optionminlenltr);
 
   /* -maxlenltr */
-  optionmaxlenltr = gt_option_new_ulong_min_max("maxlenltr",
+  optionmaxlenltr = gt_option_new_uword_min_max("maxlenltr",
                                "specify maximum length for each LTR",
                                &arguments->maxltrlength,
                                1000UL,
                                1UL,
-                               GT_UNDEF_ULONG);
+                               GT_UNDEF_UWORD);
   gt_option_parser_add_option(op, optionmaxlenltr);
 
   /* -mindistltr */
-  optionmindistltr = gt_option_new_ulong_min_max("mindistltr",
+  optionmindistltr = gt_option_new_uword_min_max("mindistltr",
                                "specify minimum distance of "
                                "LTR startpositions",
                                &arguments->mindistance,
                                1000UL,
                                1UL,
-                               GT_UNDEF_ULONG);
+                               GT_UNDEF_UWORD);
   gt_option_parser_add_option(op, optionmindistltr);
 
   /* -maxdistltr */
-  optionmaxdistltr = gt_option_new_ulong_min_max("maxdistltr",
+  optionmaxdistltr = gt_option_new_uword_min_max("maxdistltr",
                                "specify maximum distance of "
                                "LTR startpositions",
                                &arguments->maxdistance,
                                15000UL,
                                1UL,
-                               GT_UNDEF_ULONG);
+                               GT_UNDEF_UWORD);
   gt_option_parser_add_option(op, optionmaxdistltr);
 
   /* -similar */
@@ -396,6 +402,29 @@ static GtOptionParser* gt_ltrharvest_option_parser_new(void *tool_arguments)
                            false);
   gt_option_parser_add_option(op, optionv);
 
+  /* -tabout */
+  optiontabout = gt_option_new_bool("tabout",
+                                    "show 'old' tabular output instead "
+                                    "of GFF3 on stdout",
+                                    &arguments->tabout,
+                                    true);
+  gt_option_parser_add_option(op, optiontabout);
+
+  /* -seqids */
+  optionseqids = gt_option_new_bool("seqids",
+                                    "use sequence descriptions instead of "
+                                    "sequence numbers in GFF3 output",
+                                    &arguments->seqids,
+                                    false);
+  gt_option_parser_add_option(op, optionseqids);
+
+  /* -md5 */
+  optionmd5 = gt_option_new_bool("md5",
+                                 "add MD5 hashes to seqids in GFF3 output",
+                                 &arguments->md5,
+                                 false);
+  gt_option_parser_add_option(op, optionmd5);
+
   /* -longoutput */
   optionlongoutput = gt_option_new_bool("longoutput",
                            "additional motif/TSD output",
@@ -429,7 +458,7 @@ static GtOptionParser* gt_ltrharvest_option_parser_new(void *tool_arguments)
   arguments->optiongff3 = gt_option_ref(optiongff3);
 
   /* -offset */
-  optionoffset = gt_option_new_ulong("offset",
+  optionoffset = gt_option_new_uword("offset",
                                      "offset added to GFF3 coordinates",
                                      &arguments->offset,
                                      0UL);
@@ -453,8 +482,6 @@ static GtOptionParser* gt_ltrharvest_option_parser_new(void *tool_arguments)
 
   gt_option_parser_refer_to_manual(op);
 
-  /* gt_output_file_register_options(op, &arguments->outfp, arguments->ofi); */
-
   return op;
 }
 
@@ -565,11 +592,10 @@ static int gt_ltrharvest_runner(GT_UNUSED int argc,
 {
   GtNodeStream *ltrh_stream,
                *gff3_out_stream = NULL,
-               *tabout_stream = NULL,
+               *out_stream = NULL,
                *fasta_out_stream = NULL,
                *fasta_inner_out_stream = NULL,
                *last_stream;
-  GtNodeVisitor *tabout_visitor = NULL;
   GtFile *gff3file = NULL,
          *fastaoutfile = NULL,
          *fastainneroutfile = NULL;
@@ -599,24 +625,37 @@ static int gt_ltrharvest_runner(GT_UNUSED int argc,
                                          arguments->offset,
                                          arguments->minlengthTSD,
                                          arguments->maxlengthTSD,
-                                         (unsigned long) arguments->vicinity,
+                                         (GtUword) arguments->vicinity,
                                          err);
   if (ltrh_stream == NULL)
     return -1;
+  if (!arguments->md5)
+    gt_ltrharvest_stream_disable_md5_seqids((GtLTRharvestStream*) ltrh_stream);
+  else
+    gt_ltrharvest_stream_enable_md5_seqids((GtLTRharvestStream*) ltrh_stream);
+  if (!arguments->seqids)
+    gt_ltrharvest_stream_disable_seqids((GtLTRharvestStream*) ltrh_stream);
+  else
+    gt_ltrharvest_stream_enable_seqids((GtLTRharvestStream*) ltrh_stream);
   last_stream = ltrh_stream;
 
   encseq = gt_ltrharvest_stream_get_encseq(ltrh_stream);
 
-  /* set visitors according to output parameter */
-  if (!had_err && arguments->longoutput) {
-    tabout_visitor = gt_ltrharvest_tabout_visitor_new_longoutput(encseq);
-  } else {
-    tabout_visitor = gt_ltrharvest_tabout_visitor_new();
-  }
+  if (arguments->tabout) {
+    GtNodeVisitor *tabout_visitor = NULL;
+    /* set visitors according to output parameter */
+    if (!had_err && arguments->longoutput) {
+      tabout_visitor = gt_ltrharvest_tabout_visitor_new_longoutput(encseq);
+    } else {
+      tabout_visitor = gt_ltrharvest_tabout_visitor_new();
+    }
 
-  /* create tabular output stream (traditional LTRharvest format) */
-  tabout_stream = gt_ltrharvest_tabout_stream_new(last_stream, tabout_visitor);
-  last_stream = tabout_stream;
+    /* create tabular output stream (traditional LTRharvest format) */
+    out_stream = gt_ltrharvest_tabout_stream_new(last_stream, tabout_visitor);
+  } else {
+    out_stream = gt_gff3_out_stream_new(last_stream, NULL);
+  }
+  last_stream = out_stream;
 
   /* attach GFF3 output stream if requested */
   if (!had_err && arguments->gff3output) {
@@ -668,14 +707,15 @@ static int gt_ltrharvest_runner(GT_UNUSED int argc,
   }
 
   /* output arguments line */
-  gt_ltrharvest_showargsline(argc, argv);
+  if (!had_err && arguments->tabout)
+    gt_ltrharvest_showargsline(argc, argv);
 
   /* show long parameters */
-  if (arguments->verbosemode)
+  if (!had_err && arguments->tabout && arguments->verbosemode)
     gt_ltrharvest_showopts(arguments);
 
   /* print tabular output header */
-  if (!had_err) {
+  if (!had_err && arguments->tabout) {
     if (arguments->longoutput) {
       gt_ltrharvest_tabout_stream_printlongheader(arguments->minlengthTSD > 1U,
                                              arguments->allowedmismatches < 4U);
@@ -690,7 +730,7 @@ static int gt_ltrharvest_runner(GT_UNUSED int argc,
 
   /* free */
   gt_node_stream_delete(gff3_out_stream);
-  gt_node_stream_delete(tabout_stream);
+  gt_node_stream_delete(out_stream);
   gt_node_stream_delete(fasta_out_stream);
   gt_node_stream_delete(fasta_inner_out_stream);
   gt_node_stream_delete(ltrh_stream);
