@@ -60,8 +60,7 @@ static int scanprjfileuintkeysviafileptr(Suffixarray *suffixarray,
 {
   uint32_t integersize, littleendian, readmodeint, mirrored;
   unsigned int linenum;
-  unsigned long currentlinelength;
-  Definedunsignedlong maxbranchdepth;
+  GtUword currentlinelength;
   size_t dbfilelen = strlen(DBFILEKEY);
   bool haserr = false;
   GtScannedprjkeytable *scannedprjkeytable;
@@ -69,7 +68,7 @@ static int scanprjfileuintkeysviafileptr(Suffixarray *suffixarray,
   /* the following five variables are local as the parsed values are
      not required: they are determined by reading the encseq */
   GtSpecialcharinfo specialcharinfo;
-  unsigned long totallength,
+  GtUword totallength,
                 numofsequences,
                 numofdbsequences,
                 numofquerysequences;
@@ -114,8 +113,9 @@ static int scanprjfileuintkeysviafileptr(Suffixarray *suffixarray,
                        sizeof (suffixarray->averagelcp.valuedouble),
                        true,
                        &suffixarray->averagelcp.defined);
-  GT_SCANNEDPRJKEY_ADD("maxbranchdepth",&maxbranchdepth.valueunsignedlong,
-                       &maxbranchdepth.defined);
+  GT_SCANNEDPRJKEY_ADD("maxbranchdepth",
+                       &suffixarray->maxbranchdepth.valueunsignedlong,
+                       &suffixarray->maxbranchdepth.defined);
   GT_SCANNEDPRJKEY_ADD("integersize",&integersize,NULL);
   GT_SCANNEDPRJKEY_ADD("littleendian",&littleendian,NULL);
   GT_SCANNEDPRJKEY_ADD("readmode",&readmodeint,NULL);
@@ -131,7 +131,7 @@ static int scanprjfileuintkeysviafileptr(Suffixarray *suffixarray,
     } else
     {
       if (gt_scannedprjkey_analyze(indexname,
-                                   PROJECTFILESUFFIX,
+                                   GT_PROJECTFILESUFFIX,
                                    linenum,
                                    gt_str_get(currentline),
                                    currentlinelength,
@@ -145,7 +145,7 @@ static int scanprjfileuintkeysviafileptr(Suffixarray *suffixarray,
     gt_str_reset(currentline);
   }
   gt_str_delete(currentline);
-  if (!haserr && gt_scannedprjkey_allkeysdefined(indexname,PROJECTFILESUFFIX,
+  if (!haserr && gt_scannedprjkey_allkeysdefined(indexname,GT_PROJECTFILESUFFIX,
                                                  scannedprjkeytable,
                                                  logger,err) != 0)
   {
@@ -154,15 +154,15 @@ static int scanprjfileuintkeysviafileptr(Suffixarray *suffixarray,
   if (!haserr && integersize != (uint32_t) 32 && integersize != (uint32_t) 64)
   {
     gt_error_set(err,"%s%s contains illegal line defining the integer size",
-                 indexname,PROJECTFILESUFFIX);
+                 indexname,GT_PROJECTFILESUFFIX);
     haserr = true;
   }
-  if (!haserr && integersize != (uint32_t) (sizeof (unsigned long) * CHAR_BIT))
+  if (!haserr && integersize != (uint32_t) (sizeof (GtUword) * CHAR_BIT))
   {
     gt_error_set(err,"index was generated for %u-bit integers while "
                       "this program uses %u-bit integers",
                       (unsigned int) integersize,
-                      (unsigned int) (sizeof (unsigned long) * CHAR_BIT));
+                      (unsigned int) (sizeof (GtUword) * CHAR_BIT));
     haserr = true;
   }
   if (!haserr)
@@ -222,7 +222,7 @@ static void initsuffixarray(Suffixarray *suffixarray)
   suffixarray->bwttabstream.bufferedfilespace = NULL;
   suffixarray->suftabstream_GtUlong.fp = NULL;
   suffixarray->suftabstream_GtUlong.bufferedfilespace = NULL;
-#ifdef _LP64
+#if defined (_LP64) || defined (_WIN64)
   suffixarray->suftabstream_uint32_t.fp = NULL;
   suffixarray->suftabstream_uint32_t.bufferedfilespace = NULL;
 #endif
@@ -242,7 +242,7 @@ static bool scanprjfileuintkeys(Suffixarray *suffixarray,
   FILE *fp;
 
   gt_error_check(err);
-  fp = gt_fa_fopen_with_suffix(indexname,PROJECTFILESUFFIX,"rb",err);
+  fp = gt_fa_fopen_with_suffix(indexname,GT_PROJECTFILESUFFIX,"rb",err);
   if (fp == NULL)
   {
     haserr = true;
@@ -270,7 +270,7 @@ void gt_freesuffixarray(Suffixarray *suffixarray)
   gt_fa_xfclose(suffixarray->suftabstream_GtUlong.fp);
   suffixarray->suftabstream_GtUlong.fp = NULL;
   gt_free(suffixarray->suftabstream_GtUlong.bufferedfilespace);
-#ifdef _LP64
+#if defined (_LP64) || defined (_WIN64)
   gt_fa_xfclose(suffixarray->suftabstream_uint32_t.fp);
   suffixarray->suftabstream_uint32_t.fp = NULL;
   gt_free(suffixarray->suftabstream_uint32_t.bufferedfilespace);
@@ -302,7 +302,7 @@ static int inputsuffixarray(bool map,
 {
   bool haserr = false;
   GtEncseqLoader *el;
-  unsigned long totallength = 0;
+  GtUword totallength = 0;
 
   gt_error_check(err);
   initsuffixarray(suffixarray);
@@ -349,7 +349,7 @@ static int inputsuffixarray(bool map,
       {
         suffixarray->suftab
           = gt_fa_mmap_check_size_with_suffix(indexname,
-                                       SUFTABSUFFIX,
+                                       GT_SUFTABSUFFIX,
                                        suffixarray->numberofallsortedsuffixes,
                                        sizeof (*suffixarray->suftab),
                                        err);
@@ -360,25 +360,25 @@ static int inputsuffixarray(bool map,
       }
     } else
     {
-#ifdef _LP64
-      off_t filesize = gt_file_size_with_suffix(indexname,SUFTABSUFFIX);
+#if defined (_LP64) || defined (_WIN64)
+      off_t filesize = gt_file_size_with_suffix(indexname,GT_SUFTABSUFFIX);
 
       if (filesize == (off_t) sizeof (uint32_t) *
                               suffixarray->numberofallsortedsuffixes)
       {
         gt_logger_log(logger,"read suftab in units of 4 bytes");
         INITBufferedfile(indexname,&suffixarray->suftabstream_uint32_t,uint32_t,
-                         SUFTABSUFFIX);
+                         GT_SUFTABSUFFIX);
       } else
       {
         gt_logger_log(logger,"read suftab in units of 8 bytes");
         INITBufferedfile(indexname,&suffixarray->suftabstream_GtUlong,GtUlong,
-                         SUFTABSUFFIX);
+                         GT_SUFTABSUFFIX);
       }
 #else
       gt_logger_log(logger,"read suftab in units of 4 bytes");
       INITBufferedfile(indexname,&suffixarray->suftabstream_GtUlong,GtUlong,
-                       SUFTABSUFFIX);
+                       GT_SUFTABSUFFIX);
 #endif
     }
     if (!haserr && !suffixarray->longest.defined)
@@ -395,7 +395,7 @@ static int inputsuffixarray(bool map,
       {
         suffixarray->lcptab
           = gt_fa_mmap_check_size_with_suffix(indexname,
-                                         LCPTABSUFFIX,
+                                         GT_LCPTABSUFFIX,
                                          suffixarray->numberofallsortedsuffixes,
                                          sizeof (*suffixarray->lcptab),
                                          err);
@@ -407,9 +407,10 @@ static int inputsuffixarray(bool map,
     } else
     {
       INITBufferedfile(indexname,&suffixarray->lcptabstream,GtUchar,
-                       LCPTABSUFFIX);
+                       GT_LCPTABSUFFIX);
       if (!haserr &&
-          fseek(suffixarray->lcptabstream.fp,(long) sizeof (GtUchar),SEEK_SET))
+          fseek(suffixarray->lcptabstream.fp,
+                (GtWord) sizeof (GtUchar),SEEK_SET))
       {
         gt_error_set(err,"fseek(esastream) failed: %s",strerror(errno));
         haserr = true;
@@ -426,8 +427,8 @@ static int inputsuffixarray(bool map,
       {
         suffixarray->llvtab
           = gt_fa_mmap_check_size_with_suffix(indexname,
-                                           LARGELCPTABSUFFIX,
-                                           (unsigned long)
+                                           GT_LARGELCPTABSUFFIX,
+                                           (GtUword)
                                            suffixarray->numoflargelcpvalues.
                                            valueunsignedlong,
                                            sizeof (*suffixarray->llvtab),
@@ -439,7 +440,7 @@ static int inputsuffixarray(bool map,
       } else
       {
         INITBufferedfile(indexname,&suffixarray->llvtabstream,Largelcpvalue,
-                         LARGELCPTABSUFFIX);
+                         GT_LARGELCPTABSUFFIX);
       }
     }
   }
@@ -449,7 +450,7 @@ static int inputsuffixarray(bool map,
     {
       suffixarray->bwttab
         = gt_fa_mmap_check_size_with_suffix(indexname,
-                                         BWTTABSUFFIX,
+                                         GT_BWTTABSUFFIX,
                                          totallength+1,
                                          sizeof (*suffixarray->bwttab),
                                          err);
@@ -460,7 +461,7 @@ static int inputsuffixarray(bool map,
     } else
     {
       INITBufferedfile(indexname,&suffixarray->bwttabstream,GtUchar,
-                       BWTTABSUFFIX);
+                       GT_BWTTABSUFFIX);
     }
   }
   if (!haserr && (demand & SARR_BCKTAB))
@@ -506,7 +507,7 @@ int gt_mapsuffixarray(Suffixarray *suffixarray,
                       GtError *err)
 {
   gt_error_check(err);
-  /* printf("sizeof (Suffixarray)=%lu\n",sizeof (Suffixarray)); */
+  /* printf("sizeof (Suffixarray)="GT_WU"\n",sizeof (Suffixarray)); */
   return inputsuffixarray(true,
                           suffixarray,
                           demand,
