@@ -42,12 +42,12 @@ typedef struct
 static void showmatch(void *processinfo,const GtIdxMatch *match)
 {
   Showmatchinfo *showmatchinfo = (Showmatchinfo *) processinfo;
-  unsigned long seqnum;
-  unsigned long relpos;
+  GtUword seqnum;
+  GtUword relpos;
 
   if (match->dbabsolute)
   {
-    unsigned long seqstartpos;
+    GtUword seqstartpos;
     seqnum = gt_encseq_seqnum(showmatchinfo->encseq, match->dbstartpos);
     seqstartpos = gt_encseq_seqstartpos(showmatchinfo->encseq, seqnum);
     gt_assert(seqstartpos <= match->dbstartpos);
@@ -57,9 +57,9 @@ static void showmatch(void *processinfo,const GtIdxMatch *match)
     relpos = match->dbstartpos;
     seqnum = match->dbseqnum;
   }
-  printf("%lu\t%lu\t",seqnum,relpos);
-  printf("%lu\t",match->dblen);
-  printf("\t" Formatuint64_t "\t%lu\t%lu\t%lu\n",
+  printf(""GT_WU"\t"GT_WU"\t",seqnum,relpos);
+  printf(""GT_WU"\t",match->dblen);
+  printf("\t" Formatuint64_t "\t"GT_WU"\t"GT_WU"\t"GT_WU"\n",
               PRINTuint64_tcast(showmatchinfo->queryunit),
               match->querystartpos,
               match->querylen,
@@ -83,7 +83,7 @@ typedef struct
 void gt_initstorematch(Storematchinfo *storematch,
                     const GtEncseq *encseq)
 {
-  unsigned long numofdbsequences = gt_encseq_num_of_sequences(encseq);
+  GtUword numofdbsequences = gt_encseq_num_of_sequences(encseq);
 
   storematch->encseq = encseq;
   GT_INITBITTAB(storematch->hasmatch,numofdbsequences);
@@ -92,7 +92,7 @@ void gt_initstorematch(Storematchinfo *storematch,
 static void storematch(void *info,const GtIdxMatch *match)
 {
   Storematchinfo *storematch = (Storematchinfo *) info;
-  unsigned long seqnum;
+  GtUword seqnum;
 
   if (match->dbabsolute)
   {
@@ -112,7 +112,7 @@ void gt_checkandresetstorematch(GT_UNUSED uint64_t queryunit,
                              Storematchinfo *storeonline,
                              Storematchinfo *storeoffline)
 {
-  unsigned long seqnum, countmatchseq = 0,
+  GtUword seqnum, countmatchseq = 0,
     numofdbsequences = gt_encseq_num_of_sequences(storeonline->encseq);
 
   for (seqnum = 0; seqnum < numofdbsequences; seqnum++)
@@ -121,7 +121,7 @@ void gt_checkandresetstorematch(GT_UNUSED uint64_t queryunit,
     if (GT_ISIBITSET(storeonline->hasmatch,seqnum) &&
         !GT_ISIBITSET(storeoffline->hasmatch,seqnum))
     {
-      fprintf(stderr,"query " Formatuint64_t " refseq %lu: "
+      fprintf(stderr,"query " Formatuint64_t " refseq "GT_WU": "
                      "online has match but offline not\n",
                      PRINTuint64_tcast(queryunit),seqnum);
       exit(GT_EXIT_PROGRAMMING_ERROR);
@@ -129,7 +129,7 @@ void gt_checkandresetstorematch(GT_UNUSED uint64_t queryunit,
     if (!GT_ISIBITSET(storeonline->hasmatch,seqnum) &&
         GT_ISIBITSET(storeoffline->hasmatch,seqnum))
     {
-      fprintf(stderr,"query " Formatuint64_t " refseq %lu: "
+      fprintf(stderr,"query " Formatuint64_t " refseq "GT_WU": "
                      "offline has match but online not\n",
                      PRINTuint64_tcast(queryunit),seqnum);
       exit(GT_EXIT_PROGRAMMING_ERROR);
@@ -142,7 +142,7 @@ void gt_checkandresetstorematch(GT_UNUSED uint64_t queryunit,
   }
   GT_CLEARBITTAB(storeonline->hasmatch,numofdbsequences);
   GT_CLEARBITTAB(storeoffline->hasmatch,numofdbsequences);
-  printf("matching sequences: %lu\n",countmatchseq);
+  printf("matching sequences: "GT_WU"\n",countmatchseq);
 }
 
 void gt_freestorematch(Storematchinfo *storematch)
@@ -197,7 +197,7 @@ int gt_runidxlocali(const IdxlocaliOptions *idxlocalioptions,GtError *err)
   {
     GtSeqIterator *seqit;
     const GtUchar *query;
-    unsigned long querylen;
+    GtUword querylen;
     char *desc = NULL;
     int retval;
     Limdfsresources *limdfsresources = NULL;
@@ -275,7 +275,7 @@ int gt_runidxlocali(const IdxlocaliOptions *idxlocalioptions,GtError *err)
         {
           break;
         }
-        printf("process sequence " Formatuint64_t " of length %lu\n",
+        printf("process sequence " Formatuint64_t " of length "GT_WU"\n",
                 PRINTuint64_tcast(showmatchinfo.queryunit),querylen);
         if (idxlocalioptions->doonline || idxlocalioptions->docompare)
         {
