@@ -33,7 +33,7 @@
 
 void gt_randomcodes_countocc_new(GtFirstcodesspacelog *fcsl,
                                        GtRandomcodestab *rct,
-                                       unsigned long numofsequences)
+                                       GtUword numofsequences)
 {
   rct->countocc_small = gt_calloc((size_t) (numofsequences+1),
                                   sizeof (*rct->countocc_small));
@@ -44,7 +44,7 @@ void gt_randomcodes_countocc_new(GtFirstcodesspacelog *fcsl,
   gt_assert(rct->countocc_exceptions != NULL);
   rct->outfilenameleftborder = NULL;
   rct->leftborder_samples = NULL;
-#ifdef _LP64
+#if defined (_LP64) || defined (_WIN64)
   rct->modvaluebits = 32U; /* XXX remove the following later */
   if (rct->modvaluebits == 32U)
   {
@@ -60,7 +60,7 @@ void gt_randomcodes_countocc_new(GtFirstcodesspacelog *fcsl,
 
 void gt_randomcodes_countocc_resize(GtFirstcodesspacelog *fcsl,
                                           GtRandomcodestab *rct,
-                                          unsigned long numofdifferentcodes)
+                                          GtUword numofdifferentcodes)
 {
   rct->countocc_small = gt_realloc(rct->countocc_small,
                                    sizeof (*rct->countocc_small) *
@@ -74,13 +74,13 @@ void gt_randomcodes_countocc_resize(GtFirstcodesspacelog *fcsl,
 
 typedef struct
 {
-  unsigned long smallcount, smallsum,
+  GtUword smallcount, smallsum,
                 largecount, largesum,
                 hugecount, hugesum;
 } GtCountdistri_info;
 
-static void gt_randomcodes_evaluate_distvalue(unsigned long key,
-                                             unsigned long long value,
+static void gt_randomcodes_evaluate_distvalue(GtUword key,
+                                             GtUint64 value,
                                              void *data)
 {
   GtCountdistri_info *cdi = (GtCountdistri_info *) data;
@@ -107,7 +107,7 @@ static void gt_randomcodes_evaluate_distvalue(unsigned long key,
 static void gt_randomcodes_evaluate_countdistri(const GtDiscDistri *countdistri)
 {
   GtCountdistri_info cdi;
-  unsigned long sum;
+  GtUword sum;
   size_t spacenow, spacedirectstore, spaceopt, spacewithhash;;
 
   cdi.smallcount = 0;
@@ -118,11 +118,11 @@ static void gt_randomcodes_evaluate_countdistri(const GtDiscDistri *countdistri)
   cdi.hugesum = 0;
   gt_disc_distri_foreach(countdistri,gt_randomcodes_evaluate_distvalue,&cdi);
   sum = cdi.smallsum + cdi.largesum + cdi.hugesum;
-  gt_log_log("small=%lu,%lu (%.2f)",cdi.smallcount,cdi.smallsum,
+  gt_log_log("small="GT_WU","GT_WU" (%.2f)",cdi.smallcount,cdi.smallsum,
           (double) cdi.smallsum/sum);
-  gt_log_log("large=%lu,%lu (%.2f)",cdi.largecount,cdi.largesum,
+  gt_log_log("large="GT_WU","GT_WU" (%.2f)",cdi.largecount,cdi.largesum,
           (double) cdi.largesum/sum);
-  gt_log_log("huge=%lu,%lu (%.2f)",cdi.hugecount,cdi.hugesum,
+  gt_log_log("huge="GT_WU","GT_WU" (%.2f)",cdi.hugecount,cdi.hugesum,
           (double) cdi.largesum/sum);
   spacenow = sizeof (uint32_t) * sum;
   spaceopt = sizeof (uint8_t) * sum;
@@ -136,10 +136,10 @@ static void gt_randomcodes_evaluate_countdistri(const GtDiscDistri *countdistri)
 #endif
 
 #ifdef SKDEBUG
-static void checkcodesorder(const unsigned long *tab,unsigned long len,
+static void checkcodesorder(const GtUword *tab,GtUword len,
                             bool allowequal)
 {
-  unsigned long idx;
+  GtUword idx;
 
   for (idx=1UL; idx < len; idx++)
   {
@@ -148,14 +148,14 @@ static void checkcodesorder(const unsigned long *tab,unsigned long len,
 }
 #endif
 
-unsigned long gt_randomcodes_remdups(unsigned long *allrandomcodes,
-    unsigned int codesize, unsigned long numofcodes, GtLogger *logger)
+GtUword gt_randomcodes_remdups(GtUword *allrandomcodes,
+    unsigned int codesize, GtUword numofcodes, GtLogger *logger)
 {
-  unsigned long numofdifferentcodes = 0,
-                shift = (unsigned long)GT_MULT2(GT_UNITSIN2BITENC - codesize);
+  GtUword numofdifferentcodes = 0,
+                shift = (GtUword)GT_MULT2(GT_UNITSIN2BITENC - codesize);
   if (numofcodes != 0)
   {
-    unsigned long *storeptr, *readptr;
+    GtUword *storeptr, *readptr;
 
     for (storeptr = allrandomcodes, readptr = allrandomcodes+1;
          readptr < allrandomcodes + numofcodes;
@@ -167,7 +167,7 @@ unsigned long gt_randomcodes_remdups(unsigned long *allrandomcodes,
         *storeptr = *readptr;
       }
     }
-    numofdifferentcodes = (unsigned long) (storeptr - allrandomcodes + 1);
+    numofdifferentcodes = (GtUword) (storeptr - allrandomcodes + 1);
     if (numofdifferentcodes < numofcodes)
     {
 #ifdef SKDEBUG
@@ -175,8 +175,8 @@ unsigned long gt_randomcodes_remdups(unsigned long *allrandomcodes,
 #endif
     }
   }
-  gt_logger_log(logger,"number of different bucket codes=%lu (%.2f%%) "
-                       "of %lu sampled codes",
+  gt_logger_log(logger,"number of different bucket codes="GT_WU" (%.2f%%) "
+                       "of "GT_WU" sampled codes",
                 numofdifferentcodes,
                 100.00 * (double) numofdifferentcodes/numofcodes,
                 numofcodes);
@@ -184,7 +184,7 @@ unsigned long gt_randomcodes_remdups(unsigned long *allrandomcodes,
 }
 
 static uint32_t gt_randomcodes_countocc_get(const GtRandomcodestab *rct,
-                                           unsigned long idx)
+                                           GtUword idx)
 {
   if (rct->countocc_small[idx] != GT_RANDOMCODES_COUNTOCC_OVERFLOW)
   {
@@ -198,7 +198,7 @@ static uint32_t gt_randomcodes_countocc_get(const GtRandomcodestab *rct,
   }
 }
 
-#ifdef _LP64
+#if defined (_LP64) || defined (_WIN64)
 #define GT_RCT_PARTIALSUM_LEFTBORDER_SET(BUF,VALUE)\
         if ((BUF)->nextfree == (BUF)->allocated)\
         {\
@@ -219,37 +219,37 @@ static uint32_t gt_randomcodes_countocc_get(const GtRandomcodestab *rct,
         gt_assert(samplecount < rct->numofsamples);\
         rct->leftborder_samples[samplecount++] = PARTSUM
 
-unsigned long gt_randomcodes_partialsums(GtFirstcodesspacelog *fcsl,
+GtUword gt_randomcodes_partialsums(GtFirstcodesspacelog *fcsl,
                                         GtRandomcodestab *rct,
-                                        GT_UNUSED unsigned long
+                                        GT_UNUSED GtUword
                                                             expectedlastpartsum)
 {
-  unsigned long idx, partsum, maxbucketsize, bitmask, samplecount = 0,
+  GtUword idx, partsum, maxbucketsize, bitmask, samplecount = 0,
                 spacewithhashmap = 0, spacewithouthashmap = 0;
   uint32_t currentcount;
   GtLeftborderOutbuffer *leftborderbuffer_all = NULL;
-#ifdef _LP64
+#if defined (_LP64) || defined (_WIN64)
   const unsigned int btp = gt_determinebitspervalue(expectedlastpartsum);
-  unsigned long exceedvalue = 1UL << rct->modvaluebits;
+  GtUword exceedvalue = 1UL << rct->modvaluebits;
 #endif
 #ifdef SKDEBUG
   GtDiscDistri *countdistri = gt_disc_distri_new();
 #endif
 
   gt_assert(rct->differentcodes < UINT32_MAX);
-  gt_log_log("hashmap_addcount=%lu (%.2f%%)",rct->hashmap_addcount,
+  gt_log_log("hashmap_addcount="GT_WU" (%.2f%%)",rct->hashmap_addcount,
                   100.0 * (double) rct->hashmap_addcount/
                                    rct->differentcodes);
-  gt_log_log("hashmap_incrementcount=%lu (%.2f%%)",
+  gt_log_log("hashmap_incrementcount="GT_WU" (%.2f%%)",
                   rct->hashmap_incrementcount,
                   100.0 * (double) rct->hashmap_incrementcount/
                                    rct->all_incrementcount);
-  gt_log_log("hashmap_getcount=%lu (%.2f%%)",
+  gt_log_log("hashmap_getcount="GT_WU" (%.2f%%)",
                   rct->hashmap_getcount,
                   100.0 * (double) rct->hashmap_getcount/
                                    rct->all_incrementcount);
 
-#ifdef _LP64
+#if defined (_LP64) || defined (_WIN64)
   if (btp <= rct->modvaluebits)
   {
     rct->bitchangepoints.allocatedGtUlong = 0;
@@ -257,7 +257,7 @@ unsigned long gt_randomcodes_partialsums(GtFirstcodesspacelog *fcsl,
   } else
   {
     rct->bitchangepoints.allocatedGtUlong = 1UL << (btp - rct->modvaluebits);
-    gt_log_log("lastpartsum=%lu, bitchangepoints.allocated=%lu",
+    gt_log_log("lastpartsum="GT_WU", bitchangepoints.allocated="GT_WU"",
               expectedlastpartsum,rct->bitchangepoints.allocatedGtUlong);
     rct->bitchangepoints.spaceGtUlong
       = gt_malloc(sizeof (*rct->bitchangepoints.spaceGtUlong)
@@ -266,10 +266,10 @@ unsigned long gt_randomcodes_partialsums(GtFirstcodesspacelog *fcsl,
   rct->bitchangepoints.nextfreeGtUlong = 0;
 #endif
   currentcount = gt_randomcodes_countocc_get(rct,0);
-  partsum = (unsigned long) currentcount;
-  maxbucketsize = (unsigned long) currentcount;
+  partsum = (GtUword) currentcount;
+  maxbucketsize = (GtUword) currentcount;
 #ifdef SKDEBUG
-  gt_disc_distri_add(countdistri,(unsigned long) currentcount);
+  gt_disc_distri_add(countdistri,(GtUword) currentcount);
 #endif
   rct->sampleshift = 9U;
   while (true)
@@ -293,18 +293,18 @@ unsigned long gt_randomcodes_partialsums(GtFirstcodesspacelog *fcsl,
   for (idx = 1UL; idx < rct->differentcodes; idx++)
   {
     currentcount = gt_randomcodes_countocc_get(rct,idx);
-#ifdef _LP64
+#if defined (_LP64) || defined (_WIN64)
     gt_assert(currentcount <= rct->modvaluemask);
 #endif
 #ifdef SKDEBUG
-    gt_disc_distri_add(countdistri,(unsigned long) currentcount);
+    gt_disc_distri_add(countdistri,(GtUword) currentcount);
 #endif
-    if (maxbucketsize < (unsigned long) currentcount)
+    if (maxbucketsize < (GtUword) currentcount)
     {
-      maxbucketsize = (unsigned long) currentcount;
+      maxbucketsize = (GtUword) currentcount;
     }
     partsum += currentcount;
-#ifdef _LP64
+#if defined (_LP64) || defined (_WIN64)
     if (rct->bitchangepoints.allocatedGtUlong > 0 && partsum >= exceedvalue)
     {
       gt_assert(idx > 0 && rct->bitchangepoints.nextfreeGtUlong <
@@ -312,8 +312,8 @@ unsigned long gt_randomcodes_partialsums(GtFirstcodesspacelog *fcsl,
       gt_assert(rct->bitchangepoints.spaceGtUlong != NULL);
       rct->bitchangepoints.spaceGtUlong
         [rct->bitchangepoints.nextfreeGtUlong++] = idx-1;
-      exceedvalue
-        = ((exceedvalue >> rct->modvaluebits) + 1) << rct->modvaluebits;
+      exceedvalue = ((GtUword) (exceedvalue >> rct->modvaluebits) + 1)
+                      << rct->modvaluebits;
     }
 #endif
     if ((idx & bitmask) == 0)
@@ -350,52 +350,52 @@ unsigned long gt_randomcodes_partialsums(GtFirstcodesspacelog *fcsl,
   gt_hashtable_delete(rct->countocc_exceptions);
   if (rct->hashmap_addcount > 0 && gt_ma_bookkeeping_enabled())
   {
-    unsigned long hashmapspace;
+    GtUword hashmapspace;
 
     spacewithouthashmap = gt_ma_get_space_current() + gt_fa_get_space_current();
     gt_assert(spacewithouthashmap < spacewithhashmap);
     hashmapspace = spacewithhashmap - spacewithouthashmap;
-    gt_log_log("space for hashmap=%.2f (%lu bytes per entry)",
+    gt_log_log("space for hashmap=%.2f ("GT_WU" bytes per entry)",
                GT_MEGABYTES(hashmapspace),hashmapspace/rct->hashmap_addcount);
   }
   rct->countocc_exceptions = NULL;
   return maxbucketsize;
 }
 
-unsigned long gt_randomcodes_get_sample(const GtRandomcodestab *rct,
-                                       unsigned long idx)
+GtUword gt_randomcodes_get_sample(const GtRandomcodestab *rct,
+                                       GtUword idx)
 {
   gt_assert(idx <= rct->numofsamples);
   return rct->leftborder_samples[idx];
 }
 
-unsigned long gt_randomcodes_get_leftborder(const GtRandomcodestab *rct,
-                                           unsigned long idx)
+GtUword gt_randomcodes_get_leftborder(const GtRandomcodestab *rct,
+                                           GtUword idx)
 {
-#ifdef _LP64
+#if defined (_LP64) || defined (_WIN64)
   GT_CHANGEPOINT_GET_RCT(changepoint);
 
-  return (unsigned long) rct->leftborder[idx]
+  return (GtUword) rct->leftborder[idx]
                          + (changepoint << rct->modvaluebits);
 #else
-  return (unsigned long) rct->leftborder[idx];
+  return (GtUword) rct->leftborder[idx];
 #endif
 }
 
-unsigned long gt_randomcodes_leftborder_entries(const GtRandomcodestab *rct)
+GtUword gt_randomcodes_leftborder_entries(const GtRandomcodestab *rct)
 {
   return rct->differentcodes + 1;
 }
 
-unsigned long gt_randomcodes_numofsamples(const GtRandomcodestab *rct)
+GtUword gt_randomcodes_numofsamples(const GtRandomcodestab *rct)
 {
   return rct->numofsamples;
 }
 
-unsigned long gt_randomcodes_findfirstsamplelarger(const GtRandomcodestab *rct,
-                                                  unsigned long suftaboffset)
+GtUword gt_randomcodes_findfirstsamplelarger(const GtRandomcodestab *rct,
+                                                  GtUword suftaboffset)
 {
-  unsigned long left = 0, right, mid, midval, found;
+  GtUword left = 0, right, mid, midval, found;
 
   right = found = rct->numofsamples;
   while (left+1 < right)
@@ -419,13 +419,13 @@ unsigned long gt_randomcodes_findfirstsamplelarger(const GtRandomcodestab *rct,
   return found;
 }
 
-unsigned long gt_randomcodes_sample2full(const GtRandomcodestab *rct,
-                                        unsigned long idx)
+GtUword gt_randomcodes_sample2full(const GtRandomcodestab *rct,
+                                        GtUword idx)
 {
   gt_assert(idx <= rct->numofsamples);
   if (idx < rct->numofsamples)
   {
-    return idx << rct->sampleshift;
+    return (GtUword) idx << (GtUword) rct->sampleshift;
   }
   return rct->differentcodes - 1;
 }
@@ -459,7 +459,7 @@ void gt_randomcodes_tab_delete(GtFirstcodesspacelog *fcsl,GtRandomcodestab *rct)
   gt_randomcodes_samples_delete(fcsl,rct);
   gt_str_delete(rct->outfilenameleftborder);
   rct->outfilenameleftborder = NULL;
-#ifdef _LP64
+#if defined (_LP64) || defined (_WIN64)
   GT_FREEARRAY(&rct->bitchangepoints,GtUlong);
 #endif
 }
@@ -478,7 +478,7 @@ void gt_randomcodes_countocc_setnull(GtRandomcodestab *rct)
   rct->all_incrementcount = 0;
   rct->hashmap_getcount = 0;
   rct->outfilenameleftborder = NULL;
-#ifdef _LP64
+#if defined (_LP64) || defined (_WIN64)
   GT_INITARRAY(&rct->bitchangepoints,GtUlong);
 #endif
 }
