@@ -23,12 +23,26 @@
 #include "core/logger.h"
 #include "core/error_api.h"
 
+/*
+ * File format:
+ *
+ * ELEM1 ELEM2
+ *
+ * ELEM1: 0   --> start new contig, from seq with seqnum ELEM2
+ *        >0  --> read chars (lastchar - ELEM1 + 1)..lastchar
+ *                from seq with seqnum ELEM2
+ * ELEM2: seqnum using encseq mirrored sequence numbering
+ *        (thus allowing to use reverse complements)
+ *
+ */
+
 typedef uint32_t GtContigpathElem;
 #define GT_CONTIGPATH_ELEM_MAX (GtContigpathElem)UINT32_MAX
 
 int gt_contigpaths_to_fasta(const char *indexname,
     const char *contigpaths_suffix, const char *fasta_suffix,
-    const GtEncseq *encseq, unsigned long min_contig_length, bool showpaths,
-    size_t buffersize, GtLogger *logger, GtError *err);
+    const GtEncseq *encseq, GtUword min_contig_length, bool showpaths,
+    bool astat, double coverage, bool load_copynum, size_t buffersize,
+    GtLogger *logger, GtError *err);
 
 #endif
