@@ -20,29 +20,29 @@
 #include "core/qsort_r.h"
 #include "core/array2dim_api.h"
 #include "core/mathsupport.h"
+#include "core/logger.h"
 #include "bcktab.h"
 #include "kmer2string.h"
-#include "core/logger.h"
 #include "sfx-copysort.h"
 
 typedef struct
 {
   bool hardworktodo,
        sorted;
-  unsigned long bucketend;
-} Bucketinfo;
+  GtUword bucketend;
+} GtBucketinfo2;
 
 struct GtBucketspec2
 {
-  unsigned long partwidth;
+  GtUword partwidth;
   const GtEncseq *encseq;
   GtReadmode readmode;
   unsigned int numofchars, numofcharssquared, prefixlength, *order;
   GtCodetype expandfactor, expandfillsum;
-  Bucketinfo *superbuckettab, **subbuckettab;
+  GtBucketinfo2 *superbuckettab, **subbuckettab;
 };
 
-static unsigned long superbucketsize(const GtBucketspec2 *bucketspec2,
+static GtUword superbucketsize(const GtBucketspec2 *bucketspec2,
                                      unsigned int bucketnum)
 {
   if (bucketnum == 0)
@@ -56,8 +56,8 @@ static unsigned long superbucketsize(const GtBucketspec2 *bucketspec2,
 static int comparesuperbucketsizes(const void *a,const void *b,void *data)
 {
   const GtBucketspec2 *bucketspec2 = (const GtBucketspec2 *) data;
-  unsigned long size1 = superbucketsize(bucketspec2, *(const unsigned int *) a);
-  unsigned long size2 = superbucketsize(bucketspec2, *(const unsigned int *) b);
+  GtUword size1 = superbucketsize(bucketspec2, *(const unsigned int *) a);
+  GtUword size2 = superbucketsize(bucketspec2, *(const unsigned int *) b);
   if (size1 < size2)
   {
     return -1;
@@ -69,7 +69,7 @@ static int comparesuperbucketsizes(const void *a,const void *b,void *data)
   return 0;
 }
 
-static unsigned long getstartidx(const GtBucketspec2 *bucketspec2,
+static GtUword getstartidx(const GtBucketspec2 *bucketspec2,
                                  unsigned int first,
                                  unsigned int second)
 {
@@ -86,7 +86,7 @@ static unsigned long getstartidx(const GtBucketspec2 *bucketspec2,
   return 0;
 }
 
-static unsigned long getendidx(const GtBucketspec2 *bucketspec2,
+static GtUword getendidx(const GtBucketspec2 *bucketspec2,
                         unsigned int first,
                         unsigned int second)
 {
@@ -108,7 +108,7 @@ static void resetsorted(GtBucketspec2 *bucketspec2)
     bucketspec2->superbuckettab[idx].sorted = false;
     for (idx2 = 0; idx2<bucketspec2->numofchars; idx2++)
     {
-      unsigned long startidx = getstartidx(bucketspec2,idx,idx2),
+      GtUword startidx = getstartidx(bucketspec2,idx,idx2),
              endidx = getendidx(bucketspec2,idx,idx2);
       bucketspec2->subbuckettab[idx][idx2].sorted =
         (startidx < endidx) ? false : true;
@@ -149,13 +149,13 @@ static GtCodetype expandtwocharcode(GtCodetype twocharcode,
   return twocharcode * bucketspec2->expandfactor + bucketspec2->expandfillsum;
 }
 
-static unsigned long *leftcontextofspecialchardist(unsigned int numofchars,
+static GtUword *leftcontextofspecialchardist(unsigned int numofchars,
                                                    const GtEncseq *encseq,
                                                    GtReadmode readmode)
 {
   GtUchar cc;
   unsigned int idx;
-  unsigned long *specialchardist,
+  GtUword *specialchardist,
                 totallength = gt_encseq_total_length(encseq);
   GtReadmode convertedreadmode = (readmode == GT_READMODE_REVERSE)
                                       ? GT_READMODE_FORWARD
@@ -230,7 +230,7 @@ static void showbucketspec2(const GtBucketspec2 *bucketspec2)
   {
     for (idx2 = 0; idx2 < bucketspec2->numofchars; idx2++)
     {
-      printf("subbucket[%u][%u]=%lu",idx1,idx2,
+      printf("subbucket[%u][%u]="GT_WU"",idx1,idx2,
               bucketspec2->subbuckettab[idx1][idx2].bucketend);
       if (bucketspec2->subbuckettab[idx1][idx2].sorted)
       {
@@ -240,7 +240,7 @@ static void showbucketspec2(const GtBucketspec2 *bucketspec2)
         printf("\n");
       }
     }
-    printf("superbucket[%u]=%lu\n",idx1,
+    printf("superbucket[%u]="GT_WU"\n",idx1,
            bucketspec2->superbuckettab[idx1].bucketend);
   }
 }
@@ -249,8 +249,7 @@ static void showexpandcode(const GtBucketspec2 *bucketspec2,
                            unsigned int prefixlength)
 {
   GtCodetype ecode, code2;
-  const GtUchar *characters =
-                     gt_encseq_alphabetcharacters(bucketspec2->encseq);
+  const GtUchar *characters = gt_encseq_alphabetcharacters(bucketspec2->encseq);
 
   for (code2 = 0; code2 < (GtCodetype) bucketspec2->numofcharssquared; code2++)
   {
@@ -262,7 +261,7 @@ static void showexpandcode(const GtBucketspec2 *bucketspec2,
                         bucketspec2->numofchars,
                         prefixlength,
                         (const char *) characters);
-    printf("code2=%u = %lu %s\n",(unsigned int) code2,ecode,buffer);
+    printf("code2=%u = "GT_WU" %s\n",(unsigned int) code2,ecode,buffer);
   }
 }
 #endif
@@ -272,7 +271,7 @@ static void fill2subbuckets(GtBucketspec2 *bucketspec2,const GtBcktab *bcktab)
   GtCodetype code, maxcode;
   unsigned int rightchar = 0, currentchar = 0;
   GtBucketspecification bucketspec;
-  unsigned long accubucketsize = 0;
+  GtUword accubucketsize = 0;
 
   maxcode = gt_bcktab_numofallcodes(bcktab) - 1;
   for (code = 0; code <= maxcode; code++)
@@ -306,7 +305,7 @@ static void fillanysubbuckets(GtBucketspec2 *bucketspec2,
 {
   GtCodetype code2, maxcode;
   unsigned int rightchar = 0, currentchar = 0;
-  unsigned long rightbound, *specialchardist;
+  GtUword rightbound, *specialchardist;
 
   maxcode = gt_bcktab_numofallcodes(bcktab) - 1;
   bucketspec2->expandfactor
@@ -352,7 +351,7 @@ static void fillanysubbuckets(GtBucketspec2 *bucketspec2,
 GtBucketspec2 *gt_copysort_new(const GtBcktab *bcktab,
                                const GtEncseq *encseq,
                                GtReadmode readmode,
-                               unsigned long partwidth,
+                               GtUword partwidth,
                                unsigned int numofchars)
 {
   GtBucketspec2 *bucketspec2;
@@ -369,8 +368,8 @@ GtBucketspec2 *gt_copysort_new(const GtBcktab *bcktab,
   bucketspec2->order = gt_malloc(sizeof (*bucketspec2->order) * numofchars);
   bucketspec2->superbuckettab
     = gt_malloc(sizeof (*bucketspec2->superbuckettab) * numofchars);
-  gt_array2dim_malloc(bucketspec2->subbuckettab,(unsigned long) numofchars,
-                      (unsigned long) numofchars);
+  gt_array2dim_malloc(bucketspec2->subbuckettab,(GtUword) numofchars,
+                      (GtUword) numofchars);
   if (bucketspec2->prefixlength == 2U)
   {
     fill2subbuckets(bucketspec2,bcktab);
@@ -394,59 +393,60 @@ GtBucketspec2 *gt_copysort_new(const GtBcktab *bcktab,
   return bucketspec2;
 }
 
-static void forwardderive(const GtBucketspec2 *bucketspec2,
-                          GtSuffixsortspace *suffixsortspace,
-                          unsigned long *targetoffset,
-                          unsigned int source,
-                          unsigned long idx)
+static void gt_copysort_forwardderive(const GtBucketspec2 *bucketspec2,
+                                      GtSuffixsortspace *suffixsortspace,
+                                      GtUword *targetoffset,
+                                      unsigned int source,
+                                      GtUword idx)
 {
-  unsigned long startpos;
-  GtUchar cc;
+  GtSuffixsortspace_exportptr *exportptr;
 
   gt_assert (idx < targetoffset[source]);
+  exportptr = gt_suffixsortspace_exportptr(suffixsortspace,0);
   for (; idx < targetoffset[source]; idx++)
   {
-    startpos = gt_suffixsortspace_getdirect(suffixsortspace,idx);
+    GtUword startpos = GT_SUFFIXSORTSPACE_EXPORT_GET(exportptr,idx);
     if (startpos > 0)
     {
-      cc = gt_encseq_get_encoded_char(bucketspec2->encseq,
-                                      startpos-1,
-                                      bucketspec2->readmode);
+      GtUchar cc = gt_encseq_get_encoded_char(bucketspec2->encseq,
+                                              startpos-1,
+                                              bucketspec2->readmode);
       if (ISNOTSPECIAL(cc) && !bucketspec2->superbuckettab[cc].sorted)
       {
-        gt_suffixsortspace_setdirect(suffixsortspace,targetoffset[cc],
-                                     startpos - 1);
+        GT_SUFFIXSORTSPACE_EXPORT_SET(suffixsortspace,exportptr,
+                                      targetoffset[cc],startpos - 1);
         targetoffset[cc]++;
       }
     }
   }
+  gt_suffixsortspace_export_done(suffixsortspace);
 }
 
-static void backwardderive(const GtBucketspec2 *bucketspec2,
-                           GtSuffixsortspace *suffixsortspace,
-                           unsigned long *targetoffset,
-                           unsigned int source,
-                           unsigned long idx)
+static void gt_copysort_backwardderive(const GtBucketspec2 *bucketspec2,
+                                       GtSuffixsortspace *suffixsortspace,
+                                       GtUword *targetoffset,
+                                       unsigned int source,
+                                       GtUword idx)
 {
-  unsigned long startpos;
-  GtUchar cc;
-
+  GtSuffixsortspace_exportptr *exportptr
+    = gt_suffixsortspace_exportptr(suffixsortspace,0);
   for (; idx + 1 > targetoffset[source] + 1; idx--)
   {
-    startpos = gt_suffixsortspace_getdirect(suffixsortspace,idx);
+    GtUword startpos = GT_SUFFIXSORTSPACE_EXPORT_GET(exportptr,idx);
     if (startpos > 0)
     {
-      cc = gt_encseq_get_encoded_char(bucketspec2->encseq,
-                                      startpos-1,
-                                      bucketspec2->readmode);
+      GtUchar cc = gt_encseq_get_encoded_char(bucketspec2->encseq,
+                                              startpos-1,
+                                              bucketspec2->readmode);
       if (ISNOTSPECIAL(cc) && !bucketspec2->superbuckettab[cc].sorted)
       {
-        gt_suffixsortspace_setdirect(suffixsortspace,targetoffset[cc],
-                                     startpos - 1);
+        GT_SUFFIXSORTSPACE_EXPORT_SET(suffixsortspace,exportptr,
+                                      targetoffset[cc],startpos - 1);
         targetoffset[cc]--;
       }
     }
   }
+  gt_suffixsortspace_export_done(suffixsortspace);
 }
 
 bool gt_copysort_checkhardwork(const GtBucketspec2 *bucketspec2,
@@ -466,24 +466,9 @@ void gt_copysort_derivesorting(const GtBucketspec2 *bucketspec2,
                                GtSuffixsortspace *suffixsortspace,
                                GtLogger *logger)
 {
-  unsigned long hardwork = 0,
-                *targetoffset;
+  GtUword hardwork = 0, *targetoffset;
   unsigned int idx, idxsource, source, second;
 
-#ifdef WITHSUFFIXES
-  {
-    unsigned long idx;
-    for (idx = 0; idx < bucketspec2->partwidth; idx++)
-    {
-      gt_encseq_showatstartpos(
-                            stdout,
-                            GT_ISDIRREVERSE(readmode) ? false : true,
-                            GT_ISDIRCOMPLEMENT(readmode) ? true : false,
-                            encseq,
-                            gt_suffixsortspace_getdirect(suffixsortspace,idx));
-    }
-  }
-#endif
   targetoffset = gt_malloc(sizeof (*targetoffset) * bucketspec2->numofchars);
   for (idxsource = 0; idxsource<bucketspec2->numofchars; idxsource++)
   {
@@ -509,7 +494,7 @@ void gt_copysort_derivesorting(const GtBucketspec2 *bucketspec2,
       {
         targetoffset[idx] = getstartidx(bucketspec2,idx,source);
       }
-      forwardderive(bucketspec2,
+      gt_copysort_forwardderive(bucketspec2,
                     suffixsortspace,
                     targetoffset,
                     source,
@@ -520,16 +505,17 @@ void gt_copysort_derivesorting(const GtBucketspec2 *bucketspec2,
     {
       for (idx = 0; idx < bucketspec2->numofchars; idx++)
       {
-        /* do not need to assert that getendidx(idx,source)  > 0, as later the
+        /* do not need to assert that getendidx(idx,source) > 0, as later the
            value stored in targetoffset is incremented */
         targetoffset[idx] = getendidx(bucketspec2,idx,source) - 1;
       }
       gt_assert(getendidx(bucketspec2,source,bucketspec2->numofchars) > 0);
-      backwardderive(bucketspec2,
-                     suffixsortspace,
-                     targetoffset,
-                     source,
-                     getendidx(bucketspec2,source,bucketspec2->numofchars) - 1);
+      gt_copysort_backwardderive(bucketspec2,
+                                 suffixsortspace,
+                                 targetoffset,
+                                 source,
+                                 getendidx(bucketspec2,source,
+                                           bucketspec2->numofchars) - 1);
     }
     for (idx = 0; idx < bucketspec2->numofchars; idx++)
     {
@@ -538,7 +524,7 @@ void gt_copysort_derivesorting(const GtBucketspec2 *bucketspec2,
     bucketspec2->superbuckettab[source].sorted = true;
   }
   gt_free(targetoffset);
-  gt_logger_log(logger,"hardwork = %lu (%.2f)",
+  gt_logger_log(logger,"hardwork = "GT_WU" (%.2f)",
                 hardwork,
                 (double) hardwork/gt_encseq_total_length(bucketspec2->encseq));
 }
