@@ -1,6 +1,7 @@
 /*
   Copyright (c) 2007-2010 Stefan Kurtz <kurtz@zbh.uni-hamburg.de>
-  Copyright (c) 2007-2010 Center for Bioinformatics, University of Hamburg
+  Copyright (c)      2013 Ole Eigenbrod <ole.eigenbrod@gmx.de>
+  Copyright (c) 2007-2013 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
   purpose with or without fee is hereby granted, provided that the above
@@ -17,25 +18,21 @@
 
 #ifndef S_SPLINT_S
 #include <ctype.h>
-#include <zlib.h>
 #endif
+#include <stdbool.h>
 #include <stdlib.h>
 #include <string.h>
-#include <stdbool.h>
+
+#include "core/alphabet.h"
 #include "core/assert_api.h"
 #include "core/chardef.h"
-#include "core/ma_api.h"
-#include "core/checkencchar.h"
 #include "core/divmodmul.h"
-#include "core/alphabet.h"
+#include "core/encseq.h"
 #include "core/error_api.h"
+#include "core/ma_api.h"
 #include "core/sequence_buffer_fasta.h"
 #include "core/sequence_buffer_plain.h"
-#include "core/str_array.h"
-#include "core/intbits.h"
-#include "core/encseq.h"
-#include "core/format64.h"
-#include "intcode-def.h"
+#include "core/types_api.h"
 #include "initbasepower.h"
 #include "sfx-mappedstr.h"
 #undef SKDEBUG
@@ -134,12 +131,10 @@ static GtCodetype prefixwindowkmer2code(unsigned int firstspecialpos,
   return integercode;
 }
 
-static bool determinefirstspecialposition(unsigned int *firstspecialpos,
-                                          unsigned int windowwidth,
-                                          unsigned int kmersize,
-                                                       const GtUchar
-                                                         *cyclicwindow,
-                                                       unsigned int firstindex)
+static unsigned int determinefirstspecialposition(unsigned int windowwidth,
+                                                  unsigned int kmersize,
+                                                  const GtUchar *cyclicwindow,
+                                                  unsigned int firstindex)
 {
   unsigned int i;
 
@@ -147,34 +142,44 @@ static bool determinefirstspecialposition(unsigned int *firstspecialpos,
   {
     if (ISSPECIAL(cyclicwindow[(firstindex+i) % kmersize]))
     {
-      *firstspecialpos = i;
-      return true;
+      return i;
     }
   }
-  *firstspecialpos = 0; /* Just for satisfying the compiler */
-  return false;
+  return kmersize;
 }
 #endif
 
-typedef struct
-{
-  unsigned int distvalue;
-  GtCodetype codeforleftcontext;
-} Specialitem;
+/* Each special character occurring in the current window defines
+   a value of type Specialcontext. The context of a special symbol N is
+   the maximal sequence in the current window to the left of N consisting of
+   non-special symbols only. So the context either starts with the
+   first symbol in the window or right after a special symbol. We store the
+   length of the context and the integer code for the context such that
+   the first symbol of the context is weighted by $\sigma^{q-1}$. */
 
 typedef struct
 {
-  Specialitem *queuespace;  /* the space to store the queue elements */
-  unsigned int enqueueindex,  /* entry into which element is to be enqued */
-               dequeueindex,  /* last element of queue */
-               queuesize,     /* size of the queue */
-               noofelements;  /* no ofelements between enqueueindex+1 and
-                                 dequeindex */
-} Specialpositions;
+  unsigned int lengthofleftcontext;
+  GtCodetype codeofleftcontext;
+} GtSpecialcontext;
+
+/* We store the special context in a queue, such that the first
+   special symbol in the window is at the head of the queue and the
+   last special symbol in the window is at the tail of the queue. */
 
 typedef struct
 {
-  Specialpositions spos;
+  GtSpecialcontext *queuespace,  /* the space to store the queue elements */
+                   *enqueueptr,  /* entry into which element is to be enqued */
+                   *dequeueptr;  /* last element of queue */
+  unsigned int queuesize,        /* size of the queue */
+               noofelements;     /* no ofelements between enqueueptr+1 and
+                                    dequeptr */
+} GtSpecialqueue;
+
+typedef struct
+{
+  GtSpecialqueue specialqueue;
   GtUchar cyclicwindow[MAXPREFIXLENGTH];
   unsigned int numofchars,
                kmersize,
@@ -185,101 +190,153 @@ typedef struct
              *filltable,
              **multimappower;
   GtKmercode currentkmercode;
-} Kmerstream;
+} GtKmerstream;
 
-static void specialemptyqueue(Specialpositions *spos,unsigned int queuesize)
+#ifdef SKDEBUG
+static void special_queue_verify(const GtKmerstream *kmerstream)
 {
-  spos->queuespace = gt_malloc(sizeof (*spos->queuespace) * queuesize);
-  spos->noofelements = 0;
-  spos->queuesize = queuesize;
-  spos->dequeueindex = spos->enqueueindex = queuesize - 1;
-}
+  unsigned int i, contextsize = 0, verified = 0;
+  GtSpecialcontext *queueptr = kmerstream->specialqueue.dequeueptr;
 
-static bool specialqueueisempty(const Specialpositions *spos)
-{
-  return (spos->noofelements == 0) ? true : false;
-}
-
-static Specialitem *specialheadofqueue(const Specialpositions *spos)
-{
-  return spos->queuespace + spos->dequeueindex;
-}
-
-static void specialdeleteheadofqueue(Specialpositions *spos)
-{
-  spos->noofelements--;
-  if (spos->dequeueindex > 0)
+  gt_assert(kmerstream->kmersize == kmerstream->windowwidth);
+  for (i=0; i < kmerstream->kmersize; i++)
   {
-    spos->dequeueindex--;
+    GtUchar cc = kmerstream->cyclicwindow[(kmerstream->firstindex+i) %
+                                           kmerstream->kmersize];
+    if (ISSPECIAL(cc))
+    {
+      gt_assert (queueptr->lengthofleftcontext == contextsize);
+      if (queueptr > kmerstream->specialqueue.queuespace)
+      {
+        queueptr--;
+      } else
+      {
+        queueptr = kmerstream->specialqueue.queuespace +
+                   kmerstream->specialqueue.queuesize - 1;
+      }
+      verified++;
+      contextsize = 0;
+    } else
+    {
+      contextsize++;
+    }
+  }
+  gt_assert(verified == kmerstream->specialqueue.noofelements);
+}
+#endif
+
+static void special_queue_reset(GtSpecialqueue *specialqueue)
+{
+  specialqueue->noofelements = 0;
+  specialqueue->dequeueptr = specialqueue->enqueueptr
+                           = specialqueue->queuespace +
+                             specialqueue->queuesize - 1;
+}
+
+static void special_queue_init(GtSpecialqueue *specialqueue,
+                               unsigned int queuesize)
+{
+  specialqueue->queuesize = queuesize;
+  specialqueue->queuespace
+    = gt_malloc(queuesize * sizeof (*specialqueue->queuespace));
+  special_queue_reset(specialqueue);
+}
+
+static bool special_queue_is_empty(const GtSpecialqueue *specialqueue)
+{
+  return (specialqueue->noofelements == 0) ? true : false;
+}
+
+static GtSpecialcontext *special_queue_head_get(const GtSpecialqueue
+                                                 *specialqueue)
+{
+  return specialqueue->dequeueptr;
+}
+
+static void special_queueu_head_delete(GtSpecialqueue *specialqueue)
+{
+  specialqueue->noofelements--;
+  if (specialqueue->dequeueptr > specialqueue->queuespace)
+  {
+    specialqueue->dequeueptr--;
   } else
   {
-    spos->dequeueindex = spos->queuesize - 1;
+    specialqueue->dequeueptr
+      = specialqueue->queuespace + specialqueue->queuesize - 1;
   }
 }
 
-static void specialenqueue(Specialpositions *spos,Specialitem elem)
+static void special_queue_enqueue(GtSpecialqueue *specialqueue,
+                                  unsigned int lengthofleftcontext,
+                                  GtCodetype codeofleftcontext)
 {
-  spos->noofelements++;
-  spos->queuespace[spos->enqueueindex] = elem;
-  if (spos->enqueueindex > 0)
+  specialqueue->noofelements++;
+  specialqueue->enqueueptr->codeofleftcontext = codeofleftcontext;
+  specialqueue->enqueueptr->lengthofleftcontext = lengthofleftcontext;
+  if (specialqueue->enqueueptr > specialqueue->queuespace)
   {
-    spos->enqueueindex--;
+    specialqueue->enqueueptr--;
   } else
   {
-    spos->enqueueindex = spos->queuesize - 1;
+    specialqueue->enqueueptr
+      = specialqueue->queuespace + specialqueue->queuesize - 1;
   }
 }
 
-static void specialwrapqueue(Specialpositions *spos)
+static void special_queue_delete(GtSpecialqueue *specialqueue)
 {
-  gt_free(spos->queuespace);
+  gt_free(specialqueue->queuespace);
 }
 
-static Kmerstream *kmerstream_new(unsigned int numofchars,unsigned int kmersize)
+static void kmerstream_init(GtKmerstream *spwp,
+                            unsigned int numofchars,
+                            unsigned int kmersize)
 {
-  Kmerstream *spwp;
-
-  gt_assert(kmersize <= (unsigned int) MAXPREFIXLENGTH);
-  spwp = gt_malloc(sizeof (*spwp));
-  spwp->multimappower = gt_initmultimappower(numofchars,kmersize);
   spwp->lengthwithoutspecial = 0;
   spwp->codewithoutspecial = 0;
   spwp->kmersize = kmersize;
   spwp->numofchars = numofchars;
   spwp->windowwidth = 0;
   spwp->firstindex = 0;
-  specialemptyqueue(&spwp->spos,kmersize);
+}
+
+static GtKmerstream *kmerstream_new(unsigned int numofchars,
+                                    unsigned int kmersize)
+{
+  GtKmerstream *spwp;
+
+  gt_assert(kmersize <= (unsigned int) MAXPREFIXLENGTH);
+  spwp = gt_malloc(sizeof (*spwp));
+  spwp->multimappower = gt_initmultimappower(numofchars,kmersize);
+  kmerstream_init(spwp, numofchars, kmersize);
+  special_queue_init(&spwp->specialqueue,kmersize);
   spwp->filltable = gt_filllargestchartable(numofchars,kmersize);
   return spwp;
 }
 
-static void updatespecialpositions(Kmerstream *spwp,
-                                   GtUchar charcode,
-                                   bool doshift,
-                                   GtUchar lchar)
+static void kmerstream_reset(GtKmerstream *spwp)
 {
-  if (doshift)
-  {
-    if (!specialqueueisempty(&spwp->spos))
-    {
-      Specialitem *head;
+  kmerstream_init(spwp, spwp->numofchars, spwp->kmersize);
+  special_queue_reset(&(spwp->specialqueue));
+}
 
-      /* only here we add some element to the queue */
-      head = specialheadofqueue(&spwp->spos);
-      if (head->distvalue > 0)
-      {
-        SUBTRACTLCHARANDSHIFT(head->codeforleftcontext,lchar,spwp->numofchars,
-                              spwp->multimappower[0]);
-        head->distvalue--;
-      } else
-      {
-        specialdeleteheadofqueue(&spwp->spos);
-        if (!specialqueueisempty(&spwp->spos))
-        {
-          head = specialheadofqueue(&spwp->spos);
-          head->distvalue--;
-        }
-      }
+static void kmerstream_updatespecialpositions(GtKmerstream *spwp,
+                                              GtUchar charcode,
+                                              bool doshift,
+                                              GtUchar leftchar)
+{
+  if (doshift && !special_queue_is_empty(&spwp->specialqueue))
+  {
+    GtSpecialcontext *head = special_queue_head_get(&spwp->specialqueue);
+
+    if (head->lengthofleftcontext > 0)
+    {
+      SUBTRACTLCHARANDSHIFT(head->codeofleftcontext,leftchar,spwp->numofchars,
+                            spwp->multimappower[0]);
+      head->lengthofleftcontext--;
+    } else
+    {
+      special_queueu_head_delete(&spwp->specialqueue);
     }
   }
   if (ISNOTSPECIAL(charcode))
@@ -287,106 +344,65 @@ static void updatespecialpositions(Kmerstream *spwp,
     if (spwp->lengthwithoutspecial == spwp->kmersize)
     {
       SUBTRACTLCHARSHIFTADDNEXT(spwp->codewithoutspecial,
-                                lchar,
+                                leftchar,
                                 spwp->numofchars,
                                 spwp->multimappower[0],
                                 charcode);
     } else
     {
-      spwp->codewithoutspecial +=
-        spwp->multimappower[spwp->lengthwithoutspecial][charcode];
+      spwp->codewithoutspecial
+        += spwp->multimappower[spwp->lengthwithoutspecial][charcode];
       spwp->lengthwithoutspecial++;
     }
   } else
   {
     /* only here we add some element to the queue */
-    Specialitem newelem;
-
-    if (specialqueueisempty(&spwp->spos))
-    {
-      newelem.distvalue = spwp->windowwidth-1;
-    } else
-    {
-      newelem.distvalue = spwp->lengthwithoutspecial+1;
-    }
+    unsigned int newelem_lengthofleftcontext
+      = special_queue_is_empty(&spwp->specialqueue)
+          ? (spwp->windowwidth - 1U)
+          : spwp->lengthwithoutspecial;
     if (spwp->lengthwithoutspecial == spwp->kmersize)
     {
-      SUBTRACTLCHARANDSHIFT(spwp->codewithoutspecial,lchar,
-                            spwp->numofchars,spwp->multimappower[0]);
+      SUBTRACTLCHARANDSHIFT(spwp->codewithoutspecial,
+                            leftchar,
+                            spwp->numofchars,
+                            spwp->multimappower[0]);
     }
-    newelem.codeforleftcontext = spwp->codewithoutspecial;
-    specialenqueue(&spwp->spos,newelem);
+    /* only here we add some element to the queue */
+    gt_assert(newelem_lengthofleftcontext < spwp->kmersize);
+    special_queue_enqueue(&spwp->specialqueue,
+                          newelem_lengthofleftcontext,
+                          spwp->codewithoutspecial);
     spwp->lengthwithoutspecial = 0;
     spwp->codewithoutspecial = 0;
   }
 }
 
-static void kmerstream_newcode(GtKmercode *kmercode, Kmerstream *spwp)
+static void kmerstream_newcode(GtKmercode *kmercode, GtKmerstream *spwp)
 {
-#ifdef SKDEBUG
-  bool firstspecialbrutedefined;
-  unsigned int firstspecialbrute;
-
-  if (!specialqueueisempty(&spwp->spos))
   {
-    Specialitem *head = specialheadofqueue(&spwp->spos);
-    GtCodetype tmpprefixcode = prefixwindowkmer2code(head->distvalue,
-                                                     spwp->kmersize,
-                                                     (const GtCodetype **)
-                                                       spwp->multimappower,
-                                                     spwp->cyclicwindow,
-                                                     spwp->firstindex);
-    gt_assert(tmpprefixcode == head->codeforleftcontext);
-  }
-  firstspecialbrutedefined
-    = determinefirstspecialposition(&firstspecialbrute,
-                                    spwp->windowwidth,
-                                    spwp->kmersize,
-                                    spwp->cyclicwindow,
-                                    spwp->firstindex);
-  if (specialqueueisempty(&spwp->spos))
-  {
-    gt_assert(!firstspecialbrutedefined);
-  } else
-  {
-    Specialitem *head = specialheadofqueue(&spwp->spos);
-    gt_assert(firstspecialbrutedefined ? 1 : 0);
-    gt_assert(head->distvalue == firstspecialbrute);
-  }
-#endif
-  {
-#ifdef SKDEBUG
-    GtCodetype wcode;
-
-    wcode = windowkmer2code(spwp->numofchars,
-                            spwp->kmersize,
-                            spwp->cyclicwindow,
-                            spwp->firstindex);
-#endif
-    if (specialqueueisempty(&spwp->spos))
+    if (special_queue_is_empty(&spwp->specialqueue))
     {
       kmercode->definedspecialposition = false;
       kmercode->specialposition = 0;
       kmercode->code = spwp->codewithoutspecial;
     } else
     {
-      Specialitem *head = specialheadofqueue(&spwp->spos);
-      kmercode->code = head->codeforleftcontext +
-                       spwp->filltable[head->distvalue];
+      GtSpecialcontext *head = special_queue_head_get(&spwp->specialqueue);
+      gt_assert(head->lengthofleftcontext < spwp->kmersize);
+      kmercode->code = head->codeofleftcontext +
+                       spwp->filltable[head->lengthofleftcontext];
       kmercode->definedspecialposition = true;
-      kmercode->specialposition = head->distvalue;
+      kmercode->specialposition = head->lengthofleftcontext;
     }
-#ifdef SKDEBUG
-    gt_assert(wcode == kmercode->code);
-#endif
   }
 }
 
-static void shiftrightwithchar(Kmerstream *spwp,GtUchar charcode)
+static void kmerstream_shiftrightwithchar(GtKmerstream *spwp, GtUchar charcode)
 {
   gt_assert(spwp->windowwidth == spwp->kmersize);
-  updatespecialpositions(spwp,charcode,true,
-                         spwp->cyclicwindow[spwp->firstindex]);
+  kmerstream_updatespecialpositions(spwp,charcode,true,
+                                    spwp->cyclicwindow[spwp->firstindex]);
   spwp->cyclicwindow[spwp->firstindex] = charcode;
   if (spwp->firstindex < spwp->kmersize-1)
   {
@@ -397,32 +413,77 @@ static void shiftrightwithchar(Kmerstream *spwp,GtUchar charcode)
   }
 }
 
-static void kmerstream_delete(Kmerstream *spwp)
+static void kmerstream_delete(GtKmerstream *spwp)
 {
-  gt_free(spwp->filltable);
-  gt_multimappower_delete(spwp->multimappower);
-  specialwrapqueue(&spwp->spos);
-  gt_free(spwp);
+  if (spwp != NULL) {
+    gt_free(spwp->filltable);
+    gt_multimappower_delete(spwp->multimappower);
+    special_queue_delete(&spwp->specialqueue);
+    gt_free(spwp);
+  }
 }
 
 struct GtKmercodeiterator
 {
-  unsigned long totallength, startpos;
+  GtUword totallength, startpos, currentposition;
+  bool hasprocessedfirst, inputexhausted;
   const GtEncseq *encseq;
   GtEncseqReader *esr;
   GtReadmode readmode;
-  Kmerstream *spwp;
-  unsigned long currentposition;
-  bool hasprocessedfirst, inputexhausted;
+  GtKmerstream *spwp;
   GtKmercode kmercode;
   GtSequenceBuffer *fb; /* only for generating from file */
 };
 
+void gt_kmercodeiterator_reset(GtKmercodeiterator *kmercodeiterator,
+                               GtReadmode readmode,
+                               GtUword startpos)
+{
+  GtUchar charcode;
+  const GtEncseq *encseq = kmercodeiterator->encseq;
+  GtUword kmersize = (GtUword) kmercodeiterator->spwp->kmersize;
+
+  gt_assert(!GT_ISDIRREVERSE(readmode) || startpos == 0);
+  kmercodeiterator->totallength = gt_encseq_total_length(encseq);
+  kmercodeiterator->startpos = startpos;
+  gt_assert(startpos < kmercodeiterator->totallength);
+  kmercodeiterator->fb = NULL;
+  if (kmercodeiterator->totallength - startpos < kmersize)
+  {
+    kmercodeiterator->inputexhausted = true;
+    gt_encseq_reader_delete(kmercodeiterator->esr);
+    kmercodeiterator->esr = NULL;
+    kmerstream_delete(kmercodeiterator->spwp);
+    kmercodeiterator->spwp = NULL;
+  } else
+  {
+    kmercodeiterator->inputexhausted = false;
+    kmercodeiterator->readmode = readmode;
+    gt_encseq_reader_reinit_with_readmode(kmercodeiterator->esr,
+                                          encseq,
+                                          readmode,
+                                          startpos);
+    kmerstream_reset(kmercodeiterator->spwp);
+    kmercodeiterator->hasprocessedfirst = false;
+    for (kmercodeiterator->currentposition = startpos;
+         kmercodeiterator->currentposition < startpos+(GtUword) kmersize;
+         kmercodeiterator->currentposition++)
+    {
+      charcode = gt_encseq_reader_next_encoded_char(kmercodeiterator->esr);
+      kmercodeiterator->spwp->windowwidth++;
+      kmerstream_updatespecialpositions(kmercodeiterator->spwp,charcode,
+                                        false,0);
+      kmercodeiterator->spwp->cyclicwindow[kmercodeiterator->
+                                           spwp->windowwidth-1] = charcode;
+    }
+  }
+}
+
 /*@notnull@*/ GtKmercodeiterator *gt_kmercodeiterator_encseq_new(
                                             const GtEncseq *encseq,
                                             GtReadmode readmode,
                                             unsigned int kmersize,
-                                            unsigned long startpos)
+                                            GtUword startpos)
 {
   GtKmercodeiterator *kmercodeiterator;
   unsigned int numofchars;
@@ -433,18 +494,16 @@ struct GtKmercodeiterator
   kmercodeiterator->totallength = gt_encseq_total_length(encseq);
   kmercodeiterator->startpos = startpos;
   gt_assert(startpos < kmercodeiterator->totallength);
-  if (kmercodeiterator->totallength - startpos < (unsigned long) kmersize)
+  kmercodeiterator->fb = NULL;
+  kmercodeiterator->encseq = encseq;
+  if (kmercodeiterator->totallength - startpos < (GtUword) kmersize)
   {
     kmercodeiterator->inputexhausted = true;
-    kmercodeiterator->fb = NULL;
-    kmercodeiterator->encseq = encseq;
     kmercodeiterator->esr = NULL;
     kmercodeiterator->spwp = NULL;
   } else
   {
     kmercodeiterator->inputexhausted = false;
-    kmercodeiterator->fb = NULL;
-    kmercodeiterator->encseq = encseq;
     kmercodeiterator->readmode = readmode;
     kmercodeiterator->esr = gt_encseq_create_reader_with_readmode(encseq,
                                                                   readmode,
@@ -453,12 +512,13 @@ struct GtKmercodeiterator
     kmercodeiterator->spwp = kmerstream_new(numofchars,kmersize);
     kmercodeiterator->hasprocessedfirst = false;
     for (kmercodeiterator->currentposition = startpos;
-         kmercodeiterator->currentposition < startpos+(unsigned long) kmersize;
+         kmercodeiterator->currentposition < startpos+(GtUword) kmersize;
          kmercodeiterator->currentposition++)
     {
       charcode = gt_encseq_reader_next_encoded_char(kmercodeiterator->esr);
       kmercodeiterator->spwp->windowwidth++;
-      updatespecialpositions(kmercodeiterator->spwp,charcode,false,0);
+      kmerstream_updatespecialpositions(kmercodeiterator->spwp,charcode,
+                                        false,0);
       kmercodeiterator->spwp->cyclicwindow[kmercodeiterator->
                                            spwp->windowwidth-1] = charcode;
     }
@@ -466,14 +526,27 @@ struct GtKmercodeiterator
   return kmercodeiterator;
 }
 
+/* TODO: remove this. Outside world should handle this on its own. */
+GtUword
+gt_kmercodeiterator_encseq_get_currentpos(GtKmercodeiterator *kmercodeiterator)
+{
+  return kmercodeiterator->currentposition;
+}
+
+void
+gt_kmercodeiterator_encseq_setexhausted(GtKmercodeiterator *kmercodeiterator,
+                                        bool exhausted)
+{
+  kmercodeiterator->inputexhausted = exhausted;
+}
+
 const GtKmercode *gt_kmercodeiterator_encseq_next(
                              GtKmercodeiterator *kmercodeiterator)
 {
   if (!kmercodeiterator->hasprocessedfirst)
   {
     gt_assert(kmercodeiterator->currentposition
-              == kmercodeiterator->startpos +
-                   (unsigned long) kmercodeiterator->spwp->kmersize);
+              == kmercodeiterator->startpos + kmercodeiterator->spwp->kmersize);
     kmerstream_newcode(&kmercodeiterator->kmercode, kmercodeiterator->spwp);
     kmercodeiterator->hasprocessedfirst = true;
     return &kmercodeiterator->kmercode;
@@ -482,7 +555,7 @@ const GtKmercode *gt_kmercodeiterator_encseq_next(
   {
     GtUchar charcode
       = gt_encseq_reader_next_encoded_char(kmercodeiterator->esr);
-    shiftrightwithchar(kmercodeiterator->spwp,charcode);
+    kmerstream_shiftrightwithchar(kmercodeiterator->spwp,charcode);
     kmerstream_newcode(&kmercodeiterator->kmercode, kmercodeiterator->spwp);
     kmercodeiterator->currentposition++;
     return &kmercodeiterator->kmercode;
@@ -490,7 +563,7 @@ const GtKmercode *gt_kmercodeiterator_encseq_next(
   if (kmercodeiterator->currentposition < kmercodeiterator->totallength +
                                           kmercodeiterator->spwp->kmersize)
   {
-    shiftrightwithchar(kmercodeiterator->spwp,(GtUchar) WILDCARD);
+    kmerstream_shiftrightwithchar(kmercodeiterator->spwp,(GtUchar) WILDCARD);
     kmerstream_newcode(&kmercodeiterator->kmercode, kmercodeiterator->spwp);
     kmercodeiterator->currentposition++;
     return &kmercodeiterator->kmercode;
@@ -501,36 +574,28 @@ const GtKmercode *gt_kmercodeiterator_encseq_next(
 const GtKmercode *gt_kmercodeiterator_encseq_nonspecial_next(
                              GtKmercodeiterator *kmercodeiterator)
 {
-  while (true)
-  {
-    if (!kmercodeiterator->hasprocessedfirst)
-    {
+  while (true) {
+    if (!kmercodeiterator->hasprocessedfirst) {
       gt_assert(kmercodeiterator->currentposition
                 == kmercodeiterator->startpos +
-                     (unsigned long) kmercodeiterator->spwp->kmersize);
+                   kmercodeiterator->spwp->kmersize);
       kmerstream_newcode(&kmercodeiterator->kmercode, kmercodeiterator->spwp);
       kmercodeiterator->hasprocessedfirst = true;
       if (!kmercodeiterator->kmercode.definedspecialposition)
-      {
         return &kmercodeiterator->kmercode;
-      }
-    } else
-    {
-      if (kmercodeiterator->currentposition < kmercodeiterator->totallength)
-      {
+    }
+    else {
+      if (kmercodeiterator->currentposition < kmercodeiterator->totallength) {
         GtUchar charcode
           = gt_encseq_reader_next_encoded_char(kmercodeiterator->esr);
-        shiftrightwithchar(kmercodeiterator->spwp,charcode);
+        kmerstream_shiftrightwithchar(kmercodeiterator->spwp,charcode);
         kmerstream_newcode(&kmercodeiterator->kmercode, kmercodeiterator->spwp);
         kmercodeiterator->currentposition++;
         if (!kmercodeiterator->kmercode.definedspecialposition)
-        {
           return &kmercodeiterator->kmercode;
-        }
-      } else
-      {
-        break;
       }
+      else
+        break;
     }
   }
   return NULL;
@@ -571,7 +636,7 @@ GtKmercodeiterator *gt_kmercodeiterator_filetab_new(
   {
     gt_sequence_buffer_set_symbolmap(kmercodeiterator->fb, symbolmap);
     for (kmercodeiterator->currentposition = 0;
-         kmercodeiterator->currentposition < (unsigned long) kmersize;
+         kmercodeiterator->currentposition < (GtUword) kmersize;
          kmercodeiterator->currentposition++)
     {
       retval = gt_sequence_buffer_next(kmercodeiterator->fb,&charcode,err);
@@ -586,7 +651,8 @@ GtKmercodeiterator *gt_kmercodeiterator_filetab_new(
         break;
       }
       kmercodeiterator->spwp->windowwidth++;
-      updatespecialpositions(kmercodeiterator->spwp,charcode,false,0);
+      kmerstream_updatespecialpositions(kmercodeiterator->spwp,charcode,
+                                        false,0);
       kmercodeiterator->spwp->cyclicwindow[kmercodeiterator->
                                            spwp->windowwidth-1] = charcode;
     }
@@ -618,7 +684,7 @@ int gt_kmercodeiterator_filetab_next(const GtKmercode **kmercodeptr,
       }
       if (retval != 0)
       {
-        shiftrightwithchar(kmercodeiterator->spwp,charcode);
+        kmerstream_shiftrightwithchar(kmercodeiterator->spwp,charcode);
         kmerstream_newcode(&kmercodeiterator->kmercode, kmercodeiterator->spwp);
         kmercodeiterator->currentposition++,
         *kmercodeptr = &kmercodeiterator->kmercode;
@@ -637,7 +703,7 @@ int gt_kmercodeiterator_filetab_next(const GtKmercode **kmercodeptr,
   if (kmercodeiterator->currentposition < kmercodeiterator->totallength +
                                           kmercodeiterator->spwp->kmersize)
   {
-    shiftrightwithchar(kmercodeiterator->spwp,(GtUchar) WILDCARD);
+    kmerstream_shiftrightwithchar(kmercodeiterator->spwp,(GtUchar) WILDCARD);
     kmerstream_newcode(&kmercodeiterator->kmercode, kmercodeiterator->spwp);
     kmercodeiterator->currentposition++,
     *kmercodeptr = &kmercodeiterator->kmercode;
@@ -656,55 +722,52 @@ bool gt_kmercodeiterator_inputexhausted(
 
 void gt_kmercodeiterator_delete(GtKmercodeiterator *kmercodeiterator)
 {
-  if (kmercodeiterator == NULL)
+  if (kmercodeiterator != NULL)
   {
-    return;
+    gt_encseq_reader_delete(kmercodeiterator->esr);
+    kmerstream_delete(kmercodeiterator->spwp);
+    gt_sequence_buffer_delete(kmercodeiterator->fb);
+    gt_free(kmercodeiterator);
   }
-  gt_encseq_reader_delete(kmercodeiterator->esr);
-  kmerstream_delete(kmercodeiterator->spwp);
-  gt_sequence_buffer_delete(kmercodeiterator->fb);
-  gt_free(kmercodeiterator);
 }
 
 void getencseqkmers(const GtEncseq *encseq,
                     GtReadmode readmode,
                     unsigned int kmersize,
                     void(*processkmercode)(void *,
-                                           unsigned long,
+                                           GtUword,
                                            const GtKmercode *),
                     void *processkmercodeinfo)
 {
-  unsigned long currentposition = 0, totallength;
-  Kmerstream *spwp;
+  GtUword currentposition = 0, totallength;
+  GtKmerstream *spwp;
   GtUchar charcode;
   GtEncseqReader *esr;
   unsigned int numofchars, overshoot;
 
   totallength = gt_encseq_total_length(encseq);
-  if (totallength < (unsigned long) kmersize)
+  if (totallength < (GtUword) kmersize)
   {
     return;
   }
   numofchars = gt_alphabet_num_of_chars(gt_encseq_alphabet(encseq));
   spwp = kmerstream_new(numofchars,kmersize);
   esr = gt_encseq_create_reader_with_readmode(encseq,readmode,0);
-  for (currentposition = 0; currentposition < (unsigned long) kmersize;
+  for (currentposition = 0; currentposition < (GtUword) kmersize;
        currentposition++)
   {
     charcode = gt_encseq_reader_next_encoded_char(esr);
-    GT_CHECKENCCHAR(charcode,encseq,currentposition,readmode);
     spwp->windowwidth++;
-    updatespecialpositions(spwp,charcode,false,0);
+    kmerstream_updatespecialpositions(spwp,charcode,false,0);
     spwp->cyclicwindow[spwp->windowwidth-1] = charcode;
   }
   kmerstream_newcode(&spwp->currentkmercode,spwp);
   processkmercode(processkmercodeinfo,0,&spwp->currentkmercode);
-  for (currentposition = (unsigned long) kmersize; currentposition<totallength;
+  for (currentposition = (GtUword) kmersize; currentposition<totallength;
        currentposition++)
   {
     charcode = gt_encseq_reader_next_encoded_char(esr);
-    GT_CHECKENCCHAR(charcode,encseq,currentposition,readmode);
-    shiftrightwithchar(spwp,charcode);
+    kmerstream_shiftrightwithchar(spwp,charcode);
     kmerstream_newcode(&spwp->currentkmercode,spwp);
     processkmercode(processkmercodeinfo,currentposition + 1 - spwp->kmersize,
                     &spwp->currentkmercode);
@@ -712,7 +775,7 @@ void getencseqkmers(const GtEncseq *encseq,
   gt_encseq_reader_delete(esr);
   for (overshoot=0; overshoot<kmersize; overshoot++)
   {
-    shiftrightwithchar(spwp,(GtUchar) WILDCARD);
+    kmerstream_shiftrightwithchar(spwp,(GtUchar) WILDCARD);
     kmerstream_newcode(&spwp->currentkmercode,spwp);
     processkmercode(processkmercodeinfo,
                     overshoot + currentposition + 1 - spwp->kmersize,
