@@ -32,6 +32,7 @@
 #include "core/timer_api.h"
 #include "core/unused_api.h"
 #include "core/xansi_api.h"
+#include "core/mathsupport.h"
 #include "esa-fileend.h"
 #include "esa-shulen.h"
 #include "giextract.h"
@@ -68,7 +69,7 @@ typedef struct
   FILE *outfpsuftab,
        *outfpbwttab,
        *outfpbcktab;
-  unsigned long numberofallsortedsuffixes;
+  GtUword numberofallsortedsuffixes;
   const GtEncseq *encseq;
   Definedunsignedlong longest;
   GtOutlcpinfo *outlcpinfo;
@@ -79,17 +80,17 @@ typedef struct
 static void gt_suflcptab2genomediff(GT_UNUSED void *data,
                                     const GtSuffixsortspace *sssp,
                                     const GtLcpvalues *tableoflcpvalues,
-                                    unsigned long bucketoffset,
-                                    unsigned long width,
-                                    unsigned long posoffset)
+                                    GtUword bucketoffset,
+                                    GtUword width,
+                                    GtUword posoffset)
 {
-  unsigned long idx, lcpvalue, suffix;
+  GtUword idx, lcpvalue, suffix;
 
   for (idx=0; idx < width; idx++)
   {
     lcpvalue = gt_lcptab_getvalue(tableoflcpvalues,bucketoffset,idx);
     suffix = gt_suffixsortspace_get(sssp,bucketoffset+posoffset,idx);
-    printf("%lu %lu\n",suffix,MIN(lcpvalue,LCPOVERFLOW));
+    printf(""GT_WU" "GT_WU"\n",suffix,MIN(lcpvalue,LCPOVERFLOW));
   }
 }
 */
@@ -97,9 +98,9 @@ static void gt_suflcptab2genomediff(GT_UNUSED void *data,
 static void gt_suflcptab2genomediff(void *data,
                                     const GtSuffixsortspace *sssp,
                                     const GtLcpvalues *tableoflcpvalues,
-                                    unsigned long bucketoffset,
-                                    unsigned long numberofsuffixes,
-                                    unsigned long posoffset)
+                                    GtUword bucketoffset,
+                                    GtUword numberofsuffixes,
+                                    GtUword posoffset)
 {
   (void) gt_sfx_multiesa2shulengthdist(
                   (GtBUstate_shulen *) data,
@@ -114,6 +115,7 @@ static int initoutfileinfo(Outfileinfo *outfileinfo,
                            unsigned int prefixlength,
                            const GtEncseq *encseq,
                            const Suffixeratoroptions *so,
+                           bool compressedoutput,
                            GenomediffInfo *gd_info,
                            GtError *err)
 {
@@ -148,13 +150,14 @@ static int initoutfileinfo(Outfileinfo *outfileinfo,
   }
   INITOUTFILEPTR(outfileinfo->outfpsuftab,
                  gt_index_options_outsuftab_value(so->idxopts),
-                 SUFTABSUFFIX);
+                 compressedoutput ? GT_SUFTABSUFFIX_BYTECOMPRESSED
+                                  : GT_SUFTABSUFFIX);
   INITOUTFILEPTR(outfileinfo->outfpbwttab,
                  gt_index_options_outbwttab_value(so->idxopts),
-                 BWTTABSUFFIX);
+                 GT_BWTTABSUFFIX);
   INITOUTFILEPTR(outfileinfo->outfpbcktab,
                  gt_index_options_outbcktab_value(so->idxopts),
-                 BCKTABSUFFIX);
+                 GT_BCKTABSUFFIX);
   if (gt_index_options_outsuftab_value(so->idxopts)
         || gt_index_options_outbwttab_value(so->idxopts)
         || so->outlcptab
@@ -171,7 +174,7 @@ static int initoutfileinfo(Outfileinfo *outfileinfo,
 static int bwttab2file(Outfileinfo *outfileinfo,
                        const GtSuffixsortspace *suffixsortspace,
                        GtReadmode readmode,
-                       unsigned long numberofsuffixes,
+                       GtUword numberofsuffixes,
                        GT_UNUSED GtError *err)
 {
   bool haserr = false;
@@ -179,7 +182,7 @@ static int bwttab2file(Outfileinfo *outfileinfo,
   gt_error_check(err);
   if (outfileinfo->outfpbwttab != NULL)
   {
-    unsigned long startpos, pos;
+    GtUword startpos, pos;
     GtUchar cc = 0;
 
     for (pos=0; pos < numberofsuffixes; pos++)
@@ -212,7 +215,7 @@ static int suffixeratorwithoutput(Outfileinfo *outfileinfo,
                                   GtReadmode readmode,
                                   unsigned int prefixlength,
                                   unsigned int numofparts,
-                                  unsigned long maximumspace,
+                                  GtUword maximumspace,
                                   bool swallow_tail,
                                   const Sfxstrategy *sfxstrategy,
                                   GtTimer *sfxprogress,
@@ -241,9 +244,17 @@ static int suffixeratorwithoutput(Outfileinfo *outfileinfo,
   } else
   {
     const GtSuffixsortspace *suffixsortspace;
-    unsigned long numberofsuffixes;
+    GtBitbuffer *bitbuffer = NULL;
+    GtUword numberofsuffixes;
     bool specialsuffixes = false;
 
+    if (sfxstrategy->compressedoutput)
+    {
+      GtUword totallength = gt_encseq_total_length(encseq);
+      unsigned int bitsperentry = gt_determinebitspervalue(totallength);
+
+      bitbuffer = gt_bitbuffer_new(outfileinfo->outfpsuftab,bitsperentry);
+    }
     while (true)
     {
       suffixsortspace = gt_Sfxiterator_next(&numberofsuffixes,&specialsuffixes,
@@ -255,13 +266,16 @@ static int suffixeratorwithoutput(Outfileinfo *outfileinfo,
       if (outfileinfo->outfpsuftab != NULL &&
           (!specialsuffixes || !swallow_tail))
       {
-        if (gt_suffixsortspace_to_file (outfileinfo->outfpsuftab,
-                                        suffixsortspace,
-                                        numberofsuffixes,
-                                        err) != 0)
+        if (sfxstrategy->compressedoutput)
         {
-          haserr = true;
-          break;
+          gt_suffixsortspace_compressed_to_file (suffixsortspace,
+                                                 bitbuffer,
+                                                 numberofsuffixes);
+        } else
+        {
+          gt_suffixsortspace_to_file (outfileinfo->outfpsuftab,
+                                      suffixsortspace,
+                                      numberofsuffixes);
         }
       }
       if (bwttab2file(outfileinfo,suffixsortspace,readmode,numberofsuffixes,
@@ -272,6 +286,10 @@ static int suffixeratorwithoutput(Outfileinfo *outfileinfo,
       }
       outfileinfo->numberofallsortedsuffixes += numberofsuffixes;
     }
+    if (sfxstrategy->compressedoutput)
+    {
+      gt_bitbuffer_delete(bitbuffer);
+    }
   }
   if (haserr)
   {
@@ -302,7 +320,7 @@ static int suffixeratorwithoutput(Outfileinfo *outfileinfo,
 static int detpfxlen(unsigned int *prefixlength,
                      const Suffixeratoroptions *so,
                      unsigned int numofchars,
-                     unsigned long totallength,
+                     GtUword totallength,
                      bool withspecialsuffixes,
                      GtLogger *logger,
                      GtError *err)
@@ -408,11 +426,11 @@ static int run_packedindexconstruction(GtLogger *logger,
 }
 #endif
 
-int runsuffixerator(bool doesa,
-                    Suffixeratoroptions *so,
-                    GenomediffInfo *gd_info,
-                    GtLogger *logger,
-                    GtError *err)
+int gt_runsuffixerator(bool doesa,
+                       Suffixeratoroptions *so,
+                       GenomediffInfo *gd_info,
+                       GtLogger *logger,
+                       GtError *err)
 {
   GtTimer *sfxprogress = NULL;
   Outfileinfo outfileinfo;
@@ -424,10 +442,9 @@ int runsuffixerator(bool doesa,
 
   gt_error_check(err);
 
-  so->outlcptab = so->genomediff
-    ? true
-    : gt_index_options_outlcptab_value(so->idxopts);
-
+  so->outlcptab
+    = so->genomediff ? true
+                     : gt_index_options_outlcptab_value(so->idxopts);
   if (gt_showtime_enabled())
   {
     sfxprogress = gt_timer_new_with_progress_description("determining sequence "
@@ -481,8 +498,8 @@ int runsuffixerator(bool doesa,
     ee = gt_encseq_encoder_new_from_options(so->encopts, err);
     /* '-plain' implies no description support */
     if (gt_encseq_options_plain_value(so->loadopts)) {
-      gt_encseq_encoder_do_not_create_des_tab(ee);
-      gt_encseq_encoder_do_not_create_sds_tab(ee);
+        gt_encseq_encoder_do_not_create_des_tab(ee);
+        gt_encseq_encoder_do_not_create_sds_tab(ee);
     }
     if (ee == NULL)
       haserr = true;
@@ -533,9 +550,8 @@ int runsuffixerator(bool doesa,
       }
     }
   }
-  if (!haserr
-        && gt_index_options_outkystab_value(so->idxopts)
-        && !gt_index_options_outkyssort_value(so->idxopts))
+  if (!haserr && gt_index_options_outkystab_value(so->idxopts)
+              && !gt_index_options_outkyssort_value(so->idxopts))
   {
     if (gt_extractkeysfromdesfile(gt_str_get(so->indexname),
                                   false, logger, err) != 0)
@@ -589,7 +605,8 @@ int runsuffixerator(bool doesa,
   outfileinfo.encseq = NULL;
   if (!haserr)
   {
-    if (initoutfileinfo(&outfileinfo,prefixlength,encseq,so,gd_info,err) != 0)
+    if (initoutfileinfo(&outfileinfo,prefixlength,encseq,so,
+                        sfxstrategy.compressedoutput,gd_info,err) != 0)
     {
       haserr = true;
     }
@@ -648,7 +665,7 @@ int runsuffixerator(bool doesa,
   gt_fa_fclose(outfileinfo.outfpbcktab);
   if (!haserr)
   {
-    unsigned long numoflargelcpvalues, maxbranchdepth;
+    GtUword numoflargelcpvalues, maxbranchdepth;
     double averagelcp;
 
     if (outfileinfo.outlcpinfo == NULL)
@@ -714,9 +731,9 @@ int gt_parseargsandcallsuffixerator(bool doesa,int argc,
     GtLogger *logger = gt_logger_new(so.beverbose,
                                      GT_LOGGER_DEFLT_PREFIX, stdout);
 
-    gt_logger_log(logger,"sizeof (unsigned long)=%lu",
-                  (unsigned long) (sizeof (unsigned long) * CHAR_BIT));
-    if (runsuffixerator(doesa,&so,NULL,logger,err) < 0)
+    gt_logger_log(logger,"sizeof (GtUword)="GT_WU"",
+                  (GtUword) (sizeof (GtUword) * CHAR_BIT));
+    if (gt_runsuffixerator(doesa,&so,NULL,logger,err) < 0)
     {
       haserr = true;
     }
