@@ -60,14 +60,14 @@ static size_t WriteMemoryCallback(void *ptr,
 }
 
 int mg_curl(ParseStruct *parsestruct_ptr,
-            unsigned long hit_counter, GtError * err)
+            GtUword hit_counter, GtError * err)
 {
   int had_err = 0,
     curl_errornr = 0;
 
   /* Laenge der aus dem XML-File stammenden Hit-DNA-Sequenz */
-  unsigned long seq_len;
-  long numb_from = 0, numb_to = 0, numb_diff = 0;
+  GtUword seq_len;
+  GtWord numb_from = 0, numb_to = 0, numb_diff = 0;
 
   GtStr *seq_var,
    *http_adr;
@@ -315,7 +315,7 @@ int mg_xmlparser(ParseStruct *parsestruct_ptr, GtFile * fp_xmlfile,
     {
       error = XML_GetErrorCode(parser);
       gt_error_set(err,
-                "an error occurred parsing line %lu of file \"%s\": %s",
+                "an error occurred parsing line "GT_WU" of file \"%s\": %s",
                 PARSESTRUCT(xml_linenumber), gt_str_get(PARSESTRUCT(xmlfile)),
                 XML_ErrorString(error));
 
@@ -411,9 +411,9 @@ static void XMLCALL endElement(void *data, const char *name)
 
     /* Temp-Variablen zum Zwischenspeichern der Query-Start- bzw.
        -End-Werte sowie der Frame-Informationen */
-    unsigned long ulong_numb_buf = 0,
+    GtUword ulong_numb_buf = 0,
       query_nr = 0, **query_nr_p;
-    long numb_buf = 0;
+    GtWord numb_buf = 0;
 
     /* Zeiger auf die erste Zahl der GI-Nr in einem Hit-ID-XML-Eintrag */
     const char *gi_ptr = NULL;
@@ -605,7 +605,7 @@ static void XMLCALL endElement(void *data, const char *name)
         ulong_numb_buf = atol(gt_str_get(PARSESTRUCT(buf_ptr)));
         /* Der Query-from Wert wird zum GtArray query_from hinzugefuegt */
         gt_array_add_elem(MATRIXSTRUCT(query_from), &ulong_numb_buf,
-                       sizeof (unsigned long));
+                       sizeof (GtUword));
       }
       /* Query-Stop-Wert wird gespeichert/Bearbeitung siehe
          Query-Start-Wert */
@@ -614,7 +614,7 @@ static void XMLCALL endElement(void *data, const char *name)
       {
         ulong_numb_buf = atol(gt_str_get(PARSESTRUCT(buf_ptr)));
         gt_array_add_elem(MATRIXSTRUCT(query_to), &ulong_numb_buf,
-                       sizeof (unsigned long));
+                       sizeof (GtUword));
       }
       /* Hit-from XML-Tag */
       else if (strcmp(name, gt_str_array_get(PARSESTRUCT(hit_hsp_array), 3)) ==
@@ -666,7 +666,8 @@ static void XMLCALL endElement(void *data, const char *name)
         /* abspeichern des query_frames fuer spaetere Sequenzberechnnugen
            als long Value */
         numb_buf = atol(gt_str_get(PARSESTRUCT(buf_ptr)));
-        gt_array_add_elem(MATRIXSTRUCT(query_frame), &numb_buf, sizeof (long));
+        gt_array_add_elem(MATRIXSTRUCT(query_frame), &numb_buf,
+                          sizeof (GtWord));
       }
       /* Hit-Frame XML-Tag/Bearbeitung siehe Query-Frame XML-Tag als
          String */
@@ -681,13 +682,13 @@ static void XMLCALL endElement(void *data, const char *name)
         /* abspeichern des hit_frames fuer spaetere Sequenzberechnnugen
            als long Value */
         numb_buf = atol(gt_str_get(PARSESTRUCT(buf_ptr)));
-        gt_array_add_elem(MATRIXSTRUCT(hit_frame), &numb_buf, sizeof (long));
+        gt_array_add_elem(MATRIXSTRUCT(hit_frame), &numb_buf, sizeof (GtWord));
 
         /* Wenn ein Hit-FASTA-File vorliegt existiert eine GtBioseq-Struktur
            und eine Hashtabelle, ueber die die Hit-Sequenz-Informationen
            eingelesen werden */
 
-        unsigned long hit_nr = 0;
+        GtUword hit_nr = 0;
 
         GtStr *hit_tmp;
         GtStr *hit_dna_tmp;
