@@ -1,12 +1,11 @@
 /*
-  Copyright (c) 2009 Sascha Steinbiss <steinbiss@zbh.uni-hamburg.de>
-  Copyright (c) 2012 Dirk Willrodt <willrodt@zbh.uni-hamburg.de>
-  Copyright (c) 2009-2012 Center for Bioinformatics, University of Hamburg
+  Copyright (c) 2009-2013 Sascha Steinbiss <steinbiss@zbh.uni-hamburg.de>
+  Copyright (c)      2012 Dirk Willrodt <willrodt@zbh.uni-hamburg.de>
+  Copyright (c) 2009-2013 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
   purpose with or without fee is hereby granted, provided that the above
-  copyright notice and this permission notice appear in all copies.
-
+  copyright notice and this permission notice appear in all copies
   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
   WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
   MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
@@ -32,10 +31,10 @@ int isupper(int c);
 #include "core/output_file_api.h"
 #include "core/sequence_buffer.h"
 #include "core/seq_iterator_sequence_buffer.h"
-#include "core/unused_api.h"
 #include "core/versionfunc.h"
 #include "core/progressbar.h"
 #include "extended/reverse_api.h"
+#include "core/unused_api.h"
 #include "tools/gt_convertseq.h"
 
 typedef struct
@@ -46,91 +45,89 @@ typedef struct
        showflv,
        showseq,
        verbose;
-  unsigned long fastawidth;
+  GtUword fastawidth;
   GtOutputFileInfo *ofi;
   GtFile *outfp;
-} ConvertseqOptions;
+} GtConvertseqArguments;
 
-static GtOPrval parse_options(ConvertseqOptions *opts, int *parsed_args,
-                              int argc, const char **argv, GtError *err)
+static void* gt_convertseq_arguments_new(void)
 {
-  GtOptionParser *op;
-  GtOption *optionverbose, *o;
-  GtOPrval oprval;
+  GtConvertseqArguments *arguments = gt_calloc((size_t) 1, sizeof *arguments);
+  arguments->ofi = gt_output_file_info_new();
+  arguments->outfp = NULL;
+  return arguments;
+}
 
-  gt_error_check(err);
+static void gt_convertseq_arguments_delete(void *tool_arguments)
+{
+  GtConvertseqArguments *arguments = tool_arguments;
+  if (!arguments) return;
+  gt_file_delete(arguments->outfp);
+  gt_output_file_info_delete(arguments->ofi);
+  gt_free(arguments);
+}
+
+static GtOptionParser* gt_convertseq_option_parser_new(void *tool_arguments)
+{
+  GtConvertseqArguments *arguments = tool_arguments;
+  GtOptionParser *op;
+  GtOption *o;
+  gt_assert(arguments);
 
   op = gt_option_parser_new("[options] file [...]",
                             "Parse and convert sequence file formats.");
 
-  optionverbose = gt_option_new_bool("v","be verbose",
-                                     &opts->verbose, false);
-  gt_option_parser_add_option(op, optionverbose);
+  o = gt_option_new_bool("v","be verbose", &arguments->verbose, false);
+  gt_option_parser_add_option(op, o);
 
-  optionverbose = gt_option_new_bool("r","reverse complement sequences",
-                                     &opts->revcomp, false);
-  gt_option_parser_add_option(op, optionverbose);
+  o = gt_option_new_bool("r","reverse complement sequences",
+                         &arguments->revcomp, false);
+  gt_option_parser_add_option(op, o);
 
   o = gt_option_new_bool("showfilelengthvalues","show filelengths",
-                         &opts->showflv, false);
+                         &arguments->showflv, false);
   gt_option_parser_add_option(op, o);
 
   o = gt_option_new_bool("noseq","do not show sequences",
-                         &opts->showseq, false);
+                         &arguments->showseq, false);
   gt_option_parser_add_option(op, o);
 
-  o = gt_option_new_ulong("fastawidth","FASTA output line width",
-                         &opts->fastawidth, 60UL);
+  o = gt_option_new_uword("fastawidth","FASTA output line width",
+                         &arguments->fastawidth, 60UL);
   gt_option_parser_add_option(op, o);
 
   o = gt_option_new_bool("contractdnawc", "replace stretches of DNA wildcards "
                                           "with a single 'N'",
-                         &opts->reduce_wc_dna, false);
+                         &arguments->reduce_wc_dna, false);
   gt_option_parser_add_option(op, o);
 
   o = gt_option_new_bool("contractproteinwc", "replace stretches of protein "
                                               "wildcards with a single 'X'",
-                         &opts->reduce_wc_prot, false);
+                         &arguments->reduce_wc_prot, false);
   gt_option_parser_add_option(op, o);
 
-  gt_output_file_register_options(op, &opts->outfp, opts->ofi);
+  gt_output_file_info_register_options(arguments->ofi, op, &arguments->outfp);
 
   gt_option_parser_set_min_args(op, 1U);
-  oprval = gt_option_parser_parse(op, parsed_args, argc, argv, gt_versionfunc,
-                                  err);
-  gt_option_parser_delete(op);
-  return oprval;
+
+  return op;
 }
 
-int gt_convertseq(int argc, const char **argv, GtError *err)
+static int gt_convertseq_runner(int argc, const char **argv, int parsed_args,
+                              void *tool_arguments, GtError *err)
 {
-  GtStrArray *files;
-  const GtUchar *sequence;
-  char *desc;
-  unsigned long len, j;
-  int i, parsed_args, had_err = 0;
-  off_t totalsize;
-  ConvertseqOptions opts;
+  GtConvertseqArguments *arguments = tool_arguments;
+  int had_err = 0, i;
   GtFilelengthvalues *flv;
   GtSeqIterator *seqit;
   GtSequenceBuffer *sb = NULL;
-  opts.ofi = gt_output_file_info_new();
-  opts.outfp = NULL;
-
+  GtStrArray *files;
+  const GtUchar *sequence;
+  char *desc;
+  GtUword len, j;
+  off_t totalsize;
   gt_error_check(err);
-
-  /* option parsing */
-  switch (parse_options(&opts,&parsed_args, argc, argv, err)) {
-    case GT_OPTION_PARSER_OK: break;
-    case GT_OPTION_PARSER_ERROR:
-        gt_file_delete(opts.outfp);
-        gt_output_file_info_delete(opts.ofi);
-        return -1;
-    case GT_OPTION_PARSER_REQUESTS_EXIT:
-        gt_file_delete(opts.outfp);
-        gt_output_file_info_delete(opts.ofi);
-        return 0;
-  }
+  gt_assert(arguments != NULL);
 
   files = gt_str_array_new();
   for (i = parsed_args; i < argc; i++)
@@ -150,22 +147,22 @@ int gt_convertseq(int argc, const char **argv, GtError *err)
     gt_sequence_buffer_set_filelengthtab(sb, flv);
     /* read input using seqiterator */
     seqit = gt_seq_iterator_sequence_buffer_new_with_buffer(sb);
-    if (opts.verbose)
+    if (arguments->verbose)
     {
       gt_progressbar_start(gt_seq_iterator_getcurrentcounter(seqit,
-                                                           (unsigned long long)
+                                                           (GtUint64)
                                                            totalsize),
-                           (unsigned long long) totalsize);
+                           (GtUint64) totalsize);
     }
     while (true)
     {
       GtUchar *seq = NULL;
       desc = NULL;
-      i = 0; j = 0UL;
+      j = 0UL;
       had_err = gt_seq_iterator_next(seqit, &sequence, &len, &desc, err);
       if (had_err != 1)
         break;
-      if (opts.revcomp) {
+      if (arguments->revcomp) {
         GtUchar *newseq = gt_calloc((size_t) len+1, sizeof (GtUchar));
         memcpy(newseq, sequence, (size_t) len*sizeof (GtUchar));
         had_err = gt_reverse_complement((char*) newseq, len, err);
@@ -174,11 +171,11 @@ int gt_convertseq(int argc, const char **argv, GtError *err)
         seq = newseq;
       } else seq = (GtUchar*) sequence;
 
-      if (!opts.showseq) {
+      if (!arguments->showseq) {
         bool in_wildcard = false;
-        gt_file_xprintf(opts.outfp, ">%s\n", desc);
-        for (i = 0; (unsigned long) i < len; i++) {
-          if (opts.reduce_wc_dna) {
+        gt_file_xprintf(arguments->outfp, ">%s\n", desc);
+        for (i = 0; (GtUword) i < len; i++) {
+          if (arguments->reduce_wc_dna) {
             switch (seq[i]) {
               case 'a':
               case 'A':
@@ -191,28 +188,28 @@ int gt_convertseq(int argc, const char **argv, GtError *err)
               case 'T':
               case 'U':
                 in_wildcard = false;
-                gt_file_xfputc((int) seq[i], opts.outfp);
+                gt_file_xfputc((int) seq[i], arguments->outfp);
                 j++;
                 break;
               default:
                 if (!in_wildcard) {
                   in_wildcard = true;
                   if (isupper((int) seq[i]))
-                    gt_file_xfputc((int) 'N', opts.outfp);
+                    gt_file_xfputc((int) 'N', arguments->outfp);
                   else
-                    gt_file_xfputc((int) 'n', opts.outfp);
+                    gt_file_xfputc((int) 'n', arguments->outfp);
                   j++;
                 }
             }
           }
-          else if (opts.reduce_wc_prot) {
+          else if (arguments->reduce_wc_prot) {
             switch (seq[i]) {
               case 'X':
               case 'B':
               case 'Z':
                 if (!in_wildcard) {
                   in_wildcard = true;
-                  gt_file_xfputc((int) 'N', opts.outfp);
+                  gt_file_xfputc((int) 'N', arguments->outfp);
                   j++;
                 }
                 break;
@@ -221,50 +218,58 @@ int gt_convertseq(int argc, const char **argv, GtError *err)
               case 'z':
                 if (!in_wildcard) {
                   in_wildcard = true;
-                  gt_file_xfputc((int) 'n', opts.outfp);
+                  gt_file_xfputc((int) 'n', arguments->outfp);
                   j++;
                 }
                 break;
               default:
                 in_wildcard = false;
-                gt_file_xfputc((int) seq[i], opts.outfp);
+                gt_file_xfputc((int) seq[i], arguments->outfp);
                 j++;
             }
           }
           else {
-            gt_file_xfputc((int) seq[i], opts.outfp);
+            gt_file_xfputc((int) seq[i], arguments->outfp);
             j++;
           }
-          if ((j % opts.fastawidth) == 0) {
+          if ((j % arguments->fastawidth) == 0) {
             j = 0;
-            gt_file_xprintf(opts.outfp, "\n");
+            gt_file_xprintf(arguments->outfp, "\n");
           }
         }
-        gt_file_xprintf(opts.outfp, "\n");
+        gt_file_xprintf(arguments->outfp, "\n");
       }
-      if (opts.revcomp) {
+      if (arguments->revcomp) {
         gt_free(seq);
       }
     }
-    if (opts.showflv) {
+    if (arguments->showflv) {
       for (j=0;j<gt_str_array_size(files);j++) {
-        fprintf(stderr, "file %lu (%s): %lu/%lu\n",
+        fprintf(stderr, "file "GT_WU" (%s): "GT_WU"/"GT_WU"\n",
                j,
                gt_str_array_get(files, j),
-               (unsigned long) flv[j].length,
-               (unsigned long) flv[j].effectivelength);
+               (GtUword) flv[j].length,
+               (GtUword) flv[j].effectivelength);
       }
     }
     gt_sequence_buffer_delete(sb);
     gt_seq_iterator_delete(seqit);
-    if (opts.verbose)
+    if (arguments->verbose)
     {
       gt_progressbar_stop();
     }
   }
-  gt_file_delete(opts.outfp);
-  gt_output_file_info_delete(opts.ofi);
   gt_str_array_delete(files);
   gt_free(flv);
+
   return had_err;
 }
+
+GtTool* gt_convertseq(void)
+{
+  return gt_tool_new(gt_convertseq_arguments_new,
+                     gt_convertseq_arguments_delete,
+                     gt_convertseq_option_parser_new,
+                     NULL,
+                     gt_convertseq_runner);
+}
