@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007-2010 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2007-2010 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2007-2008 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -17,9 +17,16 @@
 
 #include "core/cstr_array.h"
 #include "core/option_api.h"
+#include "core/tool.h"
+#include "core/toolbox.h"
 #include "core/versionfunc.h"
-#include "extended/toolbox.h"
+#include "gth/gt_gthbssmbuild.h"
+#include "gth/gt_gthbssmfileinfo.h"
+#include "gth/gt_gthbssmprint.h"
+#include "gth/gt_gthbssmrmsd.h"
+#include "gth/gt_gthbssmtrain.h"
 #include "gth/gt_gthmkbssmfiles.h"
+#include "tools/gt_compressedbits.h"
 #include "tools/gt_consensus_sa.h"
 #include "tools/gt_dev.h"
 #include "tools/gt_extracttarget.h"
@@ -29,6 +36,7 @@
 #include "tools/gt_magicmatch.h"
 #include "tools/gt_mergeesa.h"
 #include "tools/gt_paircmp.h"
+#include "tools/gt_parsexrf.h"
 #include "tools/gt_patternmatch.h"
 #include "tools/gt_readreads.h"
 #include "tools/gt_regioncov.h"
@@ -46,6 +54,9 @@ static void* gt_dev_arguments_new(void)
   GtToolbox *dev_toolbox = gt_toolbox_new();
   /* add development tools here with a function call like this:
      gt_toolbox_add(dev_toolbox, "devtool", gt_devtool); */
+  gt_toolbox_add(dev_toolbox, "gthbssmbuild", gt_gthbssmbuild);
+  gt_toolbox_add(dev_toolbox, "gthbssmfileinfo", gt_gthbssmfileinfo);
+  gt_toolbox_add(dev_toolbox, "gthbssmprint", gt_gthbssmprint);
   gt_toolbox_add(dev_toolbox, "gthmkbssmfiles", gt_gthmkbssmfiles);
   gt_toolbox_add(dev_toolbox, "guessprot", gt_guessprot);
   gt_toolbox_add(dev_toolbox, "mergeesa", gt_mergeesa);
@@ -53,11 +64,15 @@ static void* gt_dev_arguments_new(void)
   gt_toolbox_add(dev_toolbox, "patternmatch", gt_patternmatch);
   gt_toolbox_add(dev_toolbox, "regioncov", gt_regioncov);
   gt_toolbox_add(dev_toolbox, "trieins", gt_trieins);
+  gt_toolbox_add_tool(dev_toolbox, "compbits", gt_compressedbits());
   gt_toolbox_add_tool(dev_toolbox, "consensus_sa", gt_consensus_sa_tool());
   gt_toolbox_add_tool(dev_toolbox, "extracttarget", gt_extracttarget());
   gt_toolbox_add_tool(dev_toolbox, "gdiffcalc", gt_gdiffcalc());
+  gt_toolbox_add_tool(dev_toolbox, "gthbssmrmsd", gt_gthbssmrmsd());
+  gt_toolbox_add_tool(dev_toolbox, "gthbssmtrain", gt_gthbssmtrain());
   gt_toolbox_add_tool(dev_toolbox, "idxlocali", gt_idxlocali());
   gt_toolbox_add_tool(dev_toolbox, "magicmatch", gt_magicmatch());
+  gt_toolbox_add_tool(dev_toolbox, "parsexrf", gt_parsexrf());
   gt_toolbox_add_tool(dev_toolbox, "readreads", gt_readreads());
   gt_toolbox_add_tool(dev_toolbox, "sain", gt_sain());
   gt_toolbox_add_tool(dev_toolbox, "sambam", gt_sam_interface());
@@ -132,9 +147,11 @@ static int gt_dev_runner(int argc, const char **argv, int parsed_args,
 
 GtTool* gt_dev(void)
 {
-  return gt_tool_new(gt_dev_arguments_new,
-                     gt_dev_arguments_delete,
-                     gt_dev_option_parser_new,
-                     NULL,
-                     gt_dev_runner);
+  GtTool *tool = gt_tool_new(gt_dev_arguments_new,
+                             gt_dev_arguments_delete,
+                             gt_dev_option_parser_new,
+                             NULL,
+                             gt_dev_runner);
+  gt_tool_set_toolbox_new(tool, (GtToolToolboxNew) gt_dev_arguments_new);
+  return tool;
 }
