@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2011 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2006-2011 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2006-2008 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -31,10 +31,11 @@ typedef struct {
        translate,
        seqid,
        target,
-       verbose;
+       verbose,
+       retainids;
   GtStr *type;
   GtSeqid2FileInfo *s2fi;
-  unsigned long width;
+  GtUword width;
   GtOutputFileInfo *ofi;
   GtFile *outfp;
 } GtExtractFeatArguments;
@@ -100,6 +101,12 @@ static GtOptionParser* gt_extractfeat_option_parser_new(void *tool_arguments)
                               &arguments->target, false);
   gt_option_parser_add_option(op, option);
 
+  /* -retainids */
+  option = gt_option_new_bool("retainids", "use ID attributes of extracted "
+                              "features as FASTA descriptions",
+                              &arguments->retainids, false);
+  gt_option_parser_add_option(op, option);
+
   /* -seqfile, -matchdesc, -usedesc and -regionmapping */
   gt_seqid2file_register_options(op, arguments->s2fi);
 
@@ -112,7 +119,7 @@ static GtOptionParser* gt_extractfeat_option_parser_new(void *tool_arguments)
   gt_option_parser_add_option(op, option);
 
   /* output file options */
-  gt_output_file_register_options(op, &arguments->outfp, arguments->ofi);
+  gt_output_file_info_register_options(arguments->ofi, op, &arguments->outfp);
 
   gt_option_parser_set_comment_func(op, gt_gtdata_show_help, NULL);
   gt_option_parser_set_max_args(op, 1);
@@ -157,6 +164,10 @@ static int gt_extractfeat_runner(GT_UNUSED int argc, const char **argv,
                                     arguments->width,
                                     arguments->outfp);
 
+    if (arguments->retainids)
+      gt_extract_feature_stream_retain_id_attributes((GtExtractFeatureStream*)
+                                                       extract_feature_stream);
+
     /* pull the features through the stream and free them afterwards */
     had_err = gt_node_stream_pull(extract_feature_stream, err);
   }
