@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2013 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2005-2013 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2005-2008 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -30,8 +30,11 @@
 #include "extended/gtdatahelp.h"
 #include "extended/load_stream.h"
 #include "extended/merge_feature_stream_api.h"
+#include "extended/set_source_visitor_api.h"
 #include "extended/sort_stream_api.h"
 #include "extended/typecheck_info.h"
+#include "extended/visitor_stream_api.h"
+#include "extended/xrfcheck_info.h"
 #include "tools/gt_gff3.h"
 
 typedef struct {
@@ -47,10 +50,11 @@ typedef struct {
        tidy,
        show,
        fixboundaries;
-  long offset;
-  GtStr *offsetfile;
-  unsigned long width;
+  GtWord offset;
+  GtStr *offsetfile, *newsource;
+  GtUword width;
   GtTypecheckInfo *tci;
+  GtXRFCheckInfo *xci;
   GtOutputFileInfo *ofi;
   GtFile *outfp;
 } GFF3Arguments;
@@ -58,8 +62,10 @@ typedef struct {
 static void* gt_gff3_arguments_new(void)
 {
   GFF3Arguments *arguments = gt_calloc(1, sizeof *arguments);
+  arguments->newsource = gt_str_new();
   arguments->offsetfile = gt_str_new();
   arguments->tci = gt_typecheck_info_new();
+  arguments->xci = gt_xrfcheck_info_new();
   arguments->ofi = gt_output_file_info_new();
   return arguments;
 }
@@ -69,8 +75,10 @@ static void gt_gff3_arguments_delete(void *tool_arguments)
   GFF3Arguments *arguments = tool_arguments;
   if (!arguments) return;
   gt_file_delete(arguments->outfp);
+  gt_str_delete(arguments->newsource);
   gt_output_file_info_delete(arguments->ofi);
   gt_typecheck_info_delete(arguments->tci);
+  gt_xrfcheck_info_delete(arguments->xci);
   gt_str_delete(arguments->offsetfile);
   gt_free(arguments);
 }
@@ -81,7 +89,7 @@ static GtOptionParser* gt_gff3_option_parser_new(void *tool_arguments)
   GtOptionParser *op;
   GtOption *sort_option, *load_option, *strict_option, *tidy_option,
            *mergefeat_option, *addintrons_option, *offset_option,
-           *offsetfile_option, *option;
+           *offsetfile_option, *setsource_option, *option;
   gt_assert(arguments);
 
   /* init */
@@ -164,9 +172,9 @@ static GtOptionParser* gt_gff3_option_parser_new(void *tool_arguments)
   gt_option_parser_add_option(op, addintrons_option);
 
   /* -offset */
-  offset_option = gt_option_new_long("offset", "transform all features by the "
+  offset_option = gt_option_new_word("offset", "transform all features by the "
                                      "given offset", &arguments->offset,
-                                     GT_UNDEF_LONG);
+                                     GT_UNDEF_WORD);
   gt_option_parser_add_option(op, offset_option);
 
   /* -offsetfile */
@@ -176,9 +184,18 @@ static GtOptionParser* gt_gff3_option_parser_new(void *tool_arguments)
   gt_option_parser_add_option(op, offsetfile_option);
   gt_option_exclude(offset_option, offsetfile_option);
 
+  /* -setsource */
+  setsource_option = gt_option_new_string("setsource", "set the 'source' "
+                                          "value (2nd column) of each feature",
+                                          arguments->newsource, NULL);
+  gt_option_parser_add_option(op, setsource_option);
+
   /* typecheck options */
   gt_typecheck_info_register_options(arguments->tci, op);
 
+  /* xrfcheck options */
+  gt_xrfcheck_info_register_options(arguments->xci, op);
+
   /* -show */
   option = gt_option_new_bool("show", "show GFF3 output", &arguments->show,
                               true);
@@ -193,7 +210,7 @@ static GtOptionParser* gt_gff3_option_parser_new(void *tool_arguments)
   gt_option_parser_add_option(op, option);
 
   /* output file options */
-  gt_output_file_register_options(op, &arguments->outfp, arguments->ofi);
+  gt_output_file_info_register_options(arguments->ofi, op, &arguments->outfp);
 
   /* set comment function */
   gt_option_parser_set_comment_func(op, gt_gtdata_show_help, NULL);
@@ -206,11 +223,13 @@ static int gt_gff3_runner(int argc, const char **argv, int parsed_args,
 {
   GFF3Arguments *arguments = tool_arguments;
   GtTypeChecker *type_checker = NULL;
+  GtXRFChecker *xrf_checker = NULL;
   GtNodeStream *gff3_in_stream,
                *sort_stream = NULL,
                *load_stream = NULL,
                *merge_feature_stream = NULL,
                *add_introns_stream = NULL,
+               *set_source_stream = NULL,
                *gff3_out_stream = NULL,
                *last_stream;
   int had_err = 0;
@@ -239,8 +258,17 @@ static int gt_gff3_runner(int argc, const char **argv, int parsed_args,
       gt_gff3_in_stream_set_type_checker(gff3_in_stream, type_checker);
   }
 
+  /* set XRF checker if necessary */
+  if (gt_xrfcheck_info_option_used(arguments->xci)) {
+    xrf_checker = gt_xrfcheck_info_create_xrf_checker(arguments->xci, err);
+    if (!xrf_checker)
+      had_err = -1;
+    if (!had_err)
+      gt_gff3_in_stream_set_xrf_checker(gff3_in_stream, xrf_checker);
+  }
+
   /* set offset (if necessary) */
-  if (!had_err && arguments->offset != GT_UNDEF_LONG)
+  if (!had_err && arguments->offset != GT_UNDEF_WORD)
     gt_gff3_in_stream_set_offset(gff3_in_stream, arguments->offset);
 
   /* set offsetfile (if necessary) */
@@ -285,6 +313,14 @@ static int gt_gff3_runner(int argc, const char **argv, int parsed_args,
     last_stream = add_introns_stream;
   }
 
+  /* create setsource stream (if necessary) */
+  if (!had_err && gt_str_length(arguments->newsource) > 0) {
+    gt_assert(last_stream);
+    GtNodeVisitor *ssv = gt_set_source_visitor_new(arguments->newsource);
+    set_source_stream = gt_visitor_stream_new(last_stream, ssv);
+    last_stream = set_source_stream;
+  }
+
   /* create gff3 output stream */
   if (!had_err && arguments->show) {
     gff3_out_stream = gt_gff3_out_stream_new(last_stream, arguments->outfp);
@@ -305,8 +341,10 @@ static int gt_gff3_runner(int argc, const char **argv, int parsed_args,
   gt_node_stream_delete(load_stream);
   gt_node_stream_delete(merge_feature_stream);
   gt_node_stream_delete(add_introns_stream);
+  gt_node_stream_delete(set_source_stream);
   gt_node_stream_delete(gff3_in_stream);
   gt_type_checker_delete(type_checker);
+  gt_xrf_checker_delete(xrf_checker);
 
   return had_err;
 }
