@@ -30,7 +30,7 @@
 typedef struct
 {
   GtStr *charlist;
-  unsigned long len;
+  GtUword len;
 } Charlistlen;
 
 typedef struct
@@ -39,32 +39,34 @@ typedef struct
            *files;
   Charlistlen *charlistlen;
   GtStr *text;
+  bool showedist;
 } Cmppairwiseopt;
 
 static void showsimpleoptions(const Cmppairwiseopt *opt)
 {
   if (gt_str_array_size(opt->strings) > 0)
   {
-    printf("# two strings \"%s\" \"%s\"\n",gt_str_array_get(opt->strings,0),
-                                           gt_str_array_get(opt->strings,1UL));
+    if (!opt->showedist)
+      printf("# two strings \"%s\" \"%s\"\n", gt_str_array_get(opt->strings,0),
+             gt_str_array_get(opt->strings,1UL));
     return;
   }
   if (gt_str_array_size(opt->files) > 0)
   {
-    printf("# two files \"%s\" \"%s\"\n",gt_str_array_get(opt->files,0),
-                                         gt_str_array_get(opt->files,1UL));
+    printf("# two files \"%s\" \"%s\"\n", gt_str_array_get(opt->files,0),
+           gt_str_array_get(opt->files,1UL));
     return;
   }
   if (opt->charlistlen != NULL)
   {
-    printf("# alphalen \"%s\" %lu\n",
-             gt_str_get(opt->charlistlen->charlist),
-             opt->charlistlen->len);
+    printf("# alphalen \"%s\" " GT_WU "\n",
+           gt_str_get(opt->charlistlen->charlist),
+           opt->charlistlen->len);
     return;
   }
   if (gt_str_length(opt->text) > 0)
   {
-    printf("# text \"%s\"\n",gt_str_get(opt->text));
+    printf("# text \"%s\"\n", gt_str_get(opt->text));
     return;
   }
 }
@@ -77,7 +79,8 @@ static GtOPrval parse_options(int *parsed_args,
   GtOption *optionstrings,
          *optionfiles,
          *optioncharlistlen,
-         *optiontext;
+         *optiontext,
+         *optionshowedist;
   GtStrArray *charlistlen;
   GtOPrval oprval;
 
@@ -87,14 +90,15 @@ static GtOPrval parse_options(int *parsed_args,
   pw->files = gt_str_array_new();
   pw->text = gt_str_new();
   pw->charlistlen = NULL;
-  op = gt_option_parser_new("options","Apply function to pairs of strings.");
-  gt_option_parser_set_mail_address(op,"<kurtz@zbh.uni-hamburg.de>");
+  pw->showedist = false;
+  op = gt_option_parser_new("options", "Apply function to pairs of strings.");
+  gt_option_parser_set_mail_address(op, "<kurtz@zbh.uni-hamburg.de>");
 
-  optionstrings = gt_option_new_string_array("ss","use two strings",
+  optionstrings = gt_option_new_string_array("ss", "use two strings",
                                              pw->strings);
   gt_option_parser_add_option(op, optionstrings);
 
-  optionfiles = gt_option_new_filename_array("ff","use two files",
+  optionfiles = gt_option_new_filename_array("ff", "use two files",
                                              pw->files);
   gt_option_parser_add_option(op, optionfiles);
 
@@ -103,15 +107,20 @@ static GtOPrval parse_options(int *parsed_args,
                                              charlistlen);
   gt_option_parser_add_option(op, optioncharlistlen);
 
-  optiontext = gt_option_new_string("t","use text",pw->text, NULL);
+  optiontext = gt_option_new_string("t", "use text", pw->text, NULL);
   gt_option_parser_add_option(op, optiontext);
 
+  optionshowedist = gt_option_new_bool("e", "output unit edit distance",
+                      &pw->showedist, false);
+  gt_option_parser_add_option(op, optionshowedist);
+
   gt_option_exclude(optionstrings, optionfiles);
   gt_option_exclude(optionstrings, optioncharlistlen);
   gt_option_exclude(optionstrings, optiontext);
   gt_option_exclude(optionfiles, optioncharlistlen);
   gt_option_exclude(optionfiles, optiontext);
   gt_option_exclude(optioncharlistlen, optiontext);
+  gt_option_imply(optionshowedist, optionstrings);
 
   oprval = gt_option_parser_parse(op, parsed_args, argc, argv, gt_versionfunc,
                                   err);
@@ -137,7 +146,7 @@ static GtOPrval parse_options(int *parsed_args,
       {
         if (gt_option_is_set(optioncharlistlen))
         {
-          long readint;
+          GtWord readint;
 
           if (gt_str_array_size(charlistlen) != 2UL)
           {
@@ -149,14 +158,14 @@ static GtOPrval parse_options(int *parsed_args,
           pw->charlistlen->charlist =
             gt_str_ref(gt_str_array_get_str(charlistlen,
                                                                   0));
-          if (sscanf(gt_str_array_get(charlistlen,1UL),"%ld",&readint) != 1 ||
+          if (sscanf(gt_str_array_get(charlistlen,1UL), GT_WD, &readint) != 1 ||
               readint < 1L)
           {
             gt_error_set(err,
                          "option -a requires charlist and length argument");
             oprval = GT_OPTION_PARSER_ERROR;
           }
-          pw->charlistlen->len = (unsigned long) readint;
+          pw->charlistlen->len = (GtUword) readint;
         } else
         {
           if (!gt_option_is_set(optiontext))
@@ -191,7 +200,7 @@ static void freesimpleoption(Cmppairwiseopt *cmppairwise)
   }
 }
 
-static unsigned long applycheckfunctiontosimpleoptions(
+static GtUword applycheckfunctiontosimpleoptions(
                                   Checkcmppairfuntype checkfunction,
                                   const Cmppairwiseopt *opt)
 {
@@ -202,9 +211,9 @@ static unsigned long applycheckfunctiontosimpleoptions(
     {
       checkfunction(forward,
                     (const GtUchar *) gt_str_array_get(opt->strings,0),
-                    (unsigned long) strlen(gt_str_array_get(opt->strings,0)),
+                    (GtUword) strlen(gt_str_array_get(opt->strings,0)),
                     (const GtUchar *) gt_str_array_get(opt->strings,1UL),
-                    (unsigned long) strlen(gt_str_array_get(opt->strings,1UL)));
+                    (GtUword) strlen(gt_str_array_get(opt->strings,1UL)));
       if (!forward)
       {
         break;
@@ -228,7 +237,7 @@ static unsigned long applycheckfunctiontosimpleoptions(
   }
   if (gt_str_length(opt->text) > 0)
   {
-    return gt_runcheckfunctionontext(checkfunction,gt_str_get(opt->text));
+    return gt_runcheckfunctionontext(checkfunction, gt_str_get(opt->text));
   }
   gt_assert(false);
   return 0;
@@ -242,16 +251,28 @@ int gt_paircmp(int argc, const char **argv, GtError *err)
 
   gt_error_check(err);
 
-  oprval = parse_options(&parsed_args,&cmppairwise,argc, argv, err);
+  oprval = parse_options(&parsed_args, &cmppairwise, argc, argv, err);
   if (oprval == GT_OPTION_PARSER_OK)
   {
-    unsigned long testcases;
-
     gt_assert(parsed_args == argc);
     showsimpleoptions(&cmppairwise);
-    testcases = applycheckfunctiontosimpleoptions(gt_checkgreedyunitedist,
-                                                  &cmppairwise);
-    printf("# number of testcases: %lu\n",testcases);
+    if (cmppairwise.showedist)
+    {
+      GtUword edist;
+      edist = gt_computegreedyunitedist(
+        (const GtUchar *) gt_str_array_get(cmppairwise.strings,0),
+        (GtUword) strlen(gt_str_array_get(cmppairwise.strings,0)),
+        (const GtUchar *) gt_str_array_get(cmppairwise.strings,1UL),
+        (GtUword) strlen(gt_str_array_get(cmppairwise.strings,1UL)));
+      printf(GT_WU "\n", edist);
+    }
+    else
+    {
+      GtUword testcases;
+      testcases = applycheckfunctiontosimpleoptions(gt_checkgreedyunitedist,
+                                                    &cmppairwise);
+      printf("# number of testcases: " GT_WU "\n", testcases);
+    }
   }
   freesimpleoption(&cmppairwise);
   if (oprval == GT_OPTION_PARSER_REQUESTS_EXIT)
