@@ -36,11 +36,12 @@ typedef struct {
   unsigned int minmatchlength;
   unsigned int lengthcutoff, depthcutoff;
   GtStr  *readset, *buffersizearg;
-  bool errors, paths2seq, redtrans, elendistri;
+  bool errors, paths2seq, redtrans, save, load, vd, astat, copynum;
   unsigned int deadend, bubble, deadend_depth;
   GtOption *refoptionbuffersize;
-  unsigned long buffersize;
+  GtUword buffersize;
   unsigned int nspmfiles;
+  double coverage;
 } GtReadjoinerAssemblyArguments;
 
 static void* gt_readjoiner_assembly_arguments_new(void)
@@ -163,6 +164,31 @@ static GtOptionParser* gt_readjoiner_assembly_option_parser_new(
   gt_option_parser_add_option(op, option);
   arguments->refoptionbuffersize = gt_option_ref(option);
 
+  /* -vd */
+  option = gt_option_new_bool("vd", "use verbose descriptions for contigs",
+      &arguments->vd, false);
+  gt_option_is_development_option(option);
+  gt_option_parser_add_option(op, option);
+
+  /* -astat */
+  option = gt_option_new_bool("astat", "calculate A-statistics for each contig",
+      &arguments->astat, false);
+  gt_option_is_development_option(option);
+  gt_option_parser_add_option(op, option);
+
+  /* -cov */
+  option = gt_option_new_double("cov", "average coverage value to use for the "
+      "A-statistics calculation", &arguments->coverage, (double)0);
+  gt_option_is_development_option(option);
+  gt_option_parser_add_option(op, option);
+
+  /* -copynum */
+  option = gt_option_new_bool("copynum", "load reads copy numbers list from "
+      "file for the A-statistics calculation",
+      &arguments->copynum, false);
+  gt_option_is_development_option(option);
+  gt_option_parser_add_option(op, option);
+
   /* -v */
   v_option = gt_option_new_verbose(&arguments->verbose);
   gt_option_parser_add_option(op, v_option);
@@ -173,10 +199,15 @@ static GtOptionParser* gt_readjoiner_assembly_option_parser_new(
   gt_option_parser_add_option(op, q_option);
   gt_option_exclude(q_option, v_option);
 
-  /* -elendistri */
-  option = gt_option_new_bool("elendistri", "output edges lenght"
-      "distribution to <indexname>" GT_READJOINER_SUFFIX_ELEN_DISTRI,
-      &arguments->elendistri, false);
+  /* -load */
+  option = gt_option_new_bool("load", "save the string graph from file",
+      &arguments->load, false);
+  gt_option_is_development_option(option);
+  gt_option_parser_add_option(op, option);
+
+  /* -save */
+  option = gt_option_new_bool("save", "save the string graph to file",
+      &arguments->save, false);
   gt_option_is_development_option(option);
   gt_option_parser_add_option(op, option);
 
@@ -199,20 +230,24 @@ static int gt_readjoiner_assembly_arguments_check(GT_UNUSED int rest_argc,
   return had_err;
 }
 
-#define GT_READJOINER_MSG_COUNTSPM \
+#define GT_READJOINER_ASSEMBLY_MSG_COUNTSPM \
   "calculate edges space for each vertex"
-#define GT_READJOINER_MSG_BUILDSG \
+#define GT_READJOINER_ASSEMBLY_MSG_BUILDSG \
   "build string graph"
-#define GT_READJOINER_MSG_REDTRANS \
+#define GT_READJOINER_ASSEMBLY_MSG_REDTRANS \
   "reduce transitive edges"
-#define GT_READJOINER_MSG_CLEANSG \
+#define GT_READJOINER_ASSEMBLY_MSG_CLEANSG \
   "correct sequencing errors"
-#define GT_READJOINER_MSG_TRAVERSESG \
+#define GT_READJOINER_ASSEMBLY_MSG_TRAVERSESG \
   "save contig paths"
-#define GT_READJOINER_MSG_PUMPENCSEQ \
+#define GT_READJOINER_ASSEMBLY_MSG_PUMPENCSEQ \
   "pump encseq through cache"
-#define GT_READJOINER_MSG_OUTPUTCONTIGS \
+#define GT_READJOINER_ASSEMBLY_MSG_OUTPUTCONTIGS \
   "save contig sequences"
+#define GT_READJOINER_ASSEMBLY_MSG_LOADSG \
+  "load string graph from file"
+#define GT_READJOINER_ASSEMBLY_MSG_SAVESG \
+  "save string graph to file"
 
 static int gt_readjoiner_assembly_count_spm(const char *readset, bool eqlen,
     unsigned int minmatchlength, unsigned int nspmfiles, GtStrgraph *strgraph,
@@ -222,7 +257,7 @@ static int gt_readjoiner_assembly_count_spm(const char *readset, bool eqlen,
   int had_err = 0;
   unsigned int i;
   GtStr *filename = gt_str_new();
-  gt_logger_log(default_logger, GT_READJOINER_MSG_COUNTSPM);
+  gt_logger_log(default_logger, GT_READJOINER_ASSEMBLY_MSG_COUNTSPM);
   if (!eqlen)
   {
     skipdata.out.e.proc = gt_spmproc_strgraph_count;
@@ -236,7 +271,7 @@ static int gt_readjoiner_assembly_count_spm(const char *readset, bool eqlen,
     gt_str_append_uint(filename, i);
     gt_str_append_cstr(filename, GT_READJOINER_SUFFIX_SPMLIST);
     had_err = gt_spmlist_parse(gt_str_get(filename),
-        (unsigned long)minmatchlength,
+        (GtUword)minmatchlength,
         eqlen ? gt_spmproc_strgraph_count : gt_spmproc_skip,
         eqlen ? (void*)strgraph : (void*)&skipdata, err);
     gt_str_reset(filename);
@@ -250,7 +285,7 @@ static int gt_readjoiner_assembly_error_correction(GtStrgraph *strgraph,
     GtLogger *verbose_logger)
 {
   unsigned int i;
-  unsigned long retval, retval_sum;
+  GtUword retval, retval_sum;
   gt_logger_log(verbose_logger, "remove p-bubbles");
 
   retval_sum = 0;
@@ -259,25 +294,25 @@ static int gt_readjoiner_assembly_error_correction(GtStrgraph *strgraph,
   {
     retval = gt_strgraph_redpbubbles(strgraph, 0, 1UL, false);
     retval_sum += retval;
-    gt_logger_log(verbose_logger, "removed p-bubble edges [round %u] = %lu",
-        i + 1, retval);
+    gt_logger_log(verbose_logger, "removed p-bubble edges [round %u] = "GT_WU,
+                  i + 1, retval);
   }
-  gt_logger_log(verbose_logger, "removed p-bubble edges [%u rounds] = %lu", i,
-      retval_sum);
+  gt_logger_log(verbose_logger, "removed p-bubble edges [%u rounds] = "GT_WU,
+                i, retval_sum);
   gt_logger_log(verbose_logger, "remove dead-end paths");
 
   retval_sum = 0;
   retval = 1UL;
   for (i = 0; i < deadend && retval > 0; i++)
   {
-    retval = gt_strgraph_reddepaths(strgraph, (unsigned long)deadend_depth,
+    retval = gt_strgraph_reddepaths(strgraph, (GtUword)deadend_depth,
         false);
     retval_sum += retval;
     gt_logger_log(verbose_logger, "removed dead-end path edges [round %u] = "
-        "%lu", i + 1, retval);
+       GT_WU, i + 1, retval);
   }
   gt_logger_log(verbose_logger,
-      "removed dead-end path edges [%u rounds] = %lu", i, retval);
+      "removed dead-end path edges [%u rounds] = " GT_WU, i, retval_sum);
   return 0;
 }
 
@@ -288,7 +323,7 @@ static void gt_readjoiner_assembly_pump_encseq_through_cache(
       encseq);
   uint64_t sum = 0; /* compute the sum, so that the compiler does no remove the
                        code accessing twobitencoding during optimization */
-  unsigned long idx, totallength = gt_encseq_total_length(encseq),
+  GtUword idx, totallength = gt_encseq_total_length(encseq),
                 numofunits = ! gt_encseq_is_mirrored(encseq)
                   ? gt_unitsoftwobitencoding(totallength)
                   : gt_unitsoftwobitencoding((totallength - 1)/2);
@@ -301,7 +336,8 @@ static void gt_readjoiner_assembly_pump_encseq_through_cache(
 }
 
 static int gt_readjoiner_assembly_paths2seq(const char *readset,
-    unsigned long lengthcutoff, unsigned long buffersize,
+    GtUword lengthcutoff, bool showpaths, bool astat,
+    double coverage, bool load_copynum, GtUword buffersize,
     GtLogger *default_logger, GtTimer **timer, GtError *err)
 {
   int had_err;
@@ -314,14 +350,15 @@ static int gt_readjoiner_assembly_paths2seq(const char *readset,
     if (*timer == NULL) /* paths2seq */
     {
       *timer = gt_timer_new_with_progress_description(
-          GT_READJOINER_MSG_PUMPENCSEQ);
+          GT_READJOINER_ASSEMBLY_MSG_PUMPENCSEQ);
       gt_timer_show_cpu_time_by_progress(*timer);
       gt_timer_start(*timer);
     }
     else
-      gt_timer_show_progress(*timer, GT_READJOINER_MSG_PUMPENCSEQ, stdout);
+      gt_timer_show_progress(*timer, GT_READJOINER_ASSEMBLY_MSG_PUMPENCSEQ,
+          stdout);
   }
-  gt_logger_log(default_logger, GT_READJOINER_MSG_PUMPENCSEQ);
+  gt_logger_log(default_logger, GT_READJOINER_ASSEMBLY_MSG_PUMPENCSEQ);
   gt_encseq_loader_drop_description_support(el);
   gt_encseq_loader_disable_autosupport(el);
   gt_encseq_loader_mirror(el);
@@ -329,11 +366,12 @@ static int gt_readjoiner_assembly_paths2seq(const char *readset,
   gt_assert(reads != NULL);
   gt_readjoiner_assembly_pump_encseq_through_cache(reads);
   if (gt_showtime_enabled())
-    gt_timer_show_progress(*timer, GT_READJOINER_MSG_OUTPUTCONTIGS, stdout);
-  gt_logger_log(default_logger, GT_READJOINER_MSG_OUTPUTCONTIGS);
+    gt_timer_show_progress(*timer, GT_READJOINER_ASSEMBLY_MSG_OUTPUTCONTIGS,
+        stdout);
+  gt_logger_log(default_logger, GT_READJOINER_ASSEMBLY_MSG_OUTPUTCONTIGS);
   had_err = gt_contigpaths_to_fasta(readset, GT_READJOINER_SUFFIX_CONTIG_PATHS,
-      GT_READJOINER_SUFFIX_CONTIGS, reads, lengthcutoff, false,
-      (size_t)buffersize, default_logger, err);
+      GT_READJOINER_SUFFIX_CONTIGS, reads, lengthcutoff, showpaths,
+      astat, coverage, load_copynum, (size_t)buffersize, default_logger, err);
   gt_encseq_delete(reads);
   gt_encseq_loader_delete(el);
   return had_err;
@@ -341,7 +379,7 @@ static int gt_readjoiner_assembly_paths2seq(const char *readset,
 
 static inline void gt_readjoiner_assembly_show_current_space(const char *label)
 {
-  unsigned long m, f;
+  GtUword m, f;
   if (gt_ma_bookkeeping_enabled())
   {
     m = gt_ma_get_space_current();
@@ -352,6 +390,83 @@ static inline void gt_readjoiner_assembly_show_current_space(const char *label)
   }
 }
 
+static int gt_readjoiner_assembly_build_graph(
+    GtReadjoinerAssemblyArguments *arguments, GtStrgraph **strgraph,
+    GtEncseq *reads, const char *readset, bool eqlen, GtUword rlen,
+    GtUword nreads, GtBitsequence *contained, GtLogger *default_logger,
+    GtLogger *verbose_logger, GtTimer *timer, GtError *err)
+{
+  int had_err = 0;
+  *strgraph = gt_strgraph_new(nreads);
+
+  if (arguments->minmatchlength > 0)
+    gt_logger_log(verbose_logger, "SPM length cutoff = %u",
+        arguments->minmatchlength);
+
+  had_err = gt_readjoiner_assembly_count_spm(readset, eqlen,
+      arguments->minmatchlength, arguments->nspmfiles, *strgraph, contained,
+      default_logger, err);
+  gt_readjoiner_assembly_show_current_space("(edges counted)");
+  if (gt_showtime_enabled())
+    gt_timer_show_progress(timer, GT_READJOINER_ASSEMBLY_MSG_BUILDSG, stdout);
+  gt_logger_log(default_logger, GT_READJOINER_ASSEMBLY_MSG_BUILDSG);
+
+  if (had_err == 0)
+  {
+    gt_assert((eqlen && rlen > 0 && reads == NULL) ||
+        (!eqlen && rlen == 0 && reads != NULL));
+    gt_strgraph_allocate_graph(*strgraph, rlen, reads);
+    gt_readjoiner_assembly_show_current_space("(graph allocated)");
+    had_err = gt_strgraph_load_spm_from_file(*strgraph,
+        (GtUword)arguments->minmatchlength, arguments->redtrans,
+        contained, readset, arguments->nspmfiles,
+        GT_READJOINER_SUFFIX_SPMLIST, err);
+  }
+  return had_err;
+}
+
+static void gt_readjoiner_assembly_load_graph(GtStrgraph **strgraph,
+    GtEncseq *reads, const char *readset, GtUword rlen,
+    GtLogger *default_logger, GtTimer *timer)
+{
+  *strgraph = gt_strgraph_new_from_file(reads, rlen, readset,
+      GT_READJOINER_SUFFIX_SG);
+
+  if (gt_showtime_enabled())
+    gt_timer_show_progress(timer, GT_READJOINER_ASSEMBLY_MSG_LOADSG, stdout);
+  gt_logger_log(default_logger, GT_READJOINER_ASSEMBLY_MSG_LOADSG);
+
+  gt_readjoiner_assembly_show_current_space("(graph loaded)");
+}
+
+static int gt_readjoiner_assembly_build_contained_reads_list(
+    GtReadjoinerAssemblyArguments *arguments, GtBitsequence **contained,
+    GtError *err)
+{
+  int had_err = 0;
+  unsigned int i;
+  GtUword nofreads, nofreads_i;
+  GtStr *filename;
+
+  filename = gt_str_clone(arguments->readset);
+  gt_str_append_cstr(filename, ".0" GT_READJOINER_SUFFIX_CNTLIST);
+  had_err = gt_cntlist_parse(gt_str_get(filename), true, contained,
+    &nofreads, err);
+  for (i = 1U; i < arguments->nspmfiles && had_err == 0; i++)
+  {
+    gt_str_reset(filename);
+    gt_str_append_str(filename, arguments->readset);
+    gt_str_append_char(filename, '.');
+    gt_str_append_uint(filename, i);
+    gt_str_append_cstr(filename, GT_READJOINER_SUFFIX_CNTLIST);
+    had_err = gt_cntlist_parse(gt_str_get(filename), false, contained,
+        &nofreads_i, err);
+    gt_assert(nofreads == nofreads_i);
+  }
+  gt_str_delete(filename);
+  return had_err;
+}
+
 static int gt_readjoiner_assembly_runner(GT_UNUSED int argc,
     GT_UNUSED const char **argv, GT_UNUSED int parsed_args,
     void *tool_arguments, GtError *err)
@@ -365,7 +480,7 @@ static int gt_readjoiner_assembly_runner(GT_UNUSED int argc,
   GtBitsequence *contained = NULL;
   const char *readset = gt_str_get(arguments->readset);
   bool eqlen;
-  unsigned long nreads, tlen, rlen;
+  GtUword nreads, tlen, rlen;
   int had_err = 0;
 
   gt_assert(arguments);
@@ -378,6 +493,13 @@ static int gt_readjoiner_assembly_runner(GT_UNUSED int argc,
       stdout);
   gt_logger_log(verbose_logger, "verbose output activated");
   gt_logger_log(verbose_logger, "readset name = %s", readset);
+  if (gt_showtime_enabled())
+  {
+    timer = gt_timer_new_with_progress_description(
+        GT_READJOINER_ASSEMBLY_MSG_COUNTSPM);
+    gt_timer_start(timer);
+    gt_timer_show_cpu_time_by_progress(timer);
+  }
 
   if (!arguments->paths2seq)
   {
@@ -388,40 +510,23 @@ static int gt_readjoiner_assembly_runner(GT_UNUSED int argc,
     gt_assert(reads != NULL);
     eqlen = gt_encseq_accesstype_get(reads) == GT_ACCESS_TYPE_EQUALLENGTH;
     nreads = gt_encseq_num_of_sequences(reads);
-    gt_logger_log(default_logger, "number of reads in filtered readset = %lu",
-        nreads);
+    gt_logger_log(default_logger, "number of reads in filtered readset = "
+                  GT_WU, nreads);
     tlen = gt_encseq_total_length(reads) - nreads + 1;
-    gt_logger_log(verbose_logger, "total length of filtered readset = %lu",
+    gt_logger_log(verbose_logger, "total length of filtered readset = " GT_WU,
         tlen);
 
     if (eqlen)
     {
       rlen = gt_encseq_seqlength(reads, 0);
-      gt_logger_log(verbose_logger, "read length = %lu", rlen);
+      gt_logger_log(verbose_logger, "read length = " GT_WU, rlen);
       gt_encseq_delete(reads);
       reads = NULL;
     }
     else
     {
-      unsigned int i;
-      unsigned long nofreads;
-      GtStr *filename = gt_str_clone(arguments->readset);
-      gt_str_append_cstr(filename, ".0" GT_READJOINER_SUFFIX_CNTLIST);
-      had_err = gt_cntlist_parse(gt_str_get(filename), true, &contained,
-          &nofreads, err);
-      for (i = 1U; i < arguments->nspmfiles && had_err == 0; i++)
-      {
-        unsigned long nofreads_i;
-        gt_str_reset(filename);
-        gt_str_append_str(filename, arguments->readset);
-        gt_str_append_char(filename, '.');
-        gt_str_append_uint(filename, i);
-        gt_str_append_cstr(filename, GT_READJOINER_SUFFIX_CNTLIST);
-        had_err = gt_cntlist_parse(gt_str_get(filename), false, &contained,
-            &nofreads_i, err);
-        gt_assert(nofreads == nofreads_i);
-      }
-      gt_str_delete(filename);
+      had_err = gt_readjoiner_assembly_build_contained_reads_list(
+        arguments, &contained, err);
       rlen = 0;
       gt_logger_log(verbose_logger, "read length = variable");
       gt_assert(reads != NULL);
@@ -429,44 +534,17 @@ static int gt_readjoiner_assembly_runner(GT_UNUSED int argc,
 
     if (had_err == 0)
     {
-      if (arguments->minmatchlength > 0)
-        gt_logger_log(verbose_logger, "SPM length cutoff = %u",
-            arguments->minmatchlength);
-
-      strgraph = gt_strgraph_new(nreads);
-      if (gt_showtime_enabled())
+      if (!arguments->load)
       {
-        timer = gt_timer_new_with_progress_description(
-            GT_READJOINER_MSG_COUNTSPM);
-        gt_timer_start(timer);
-        gt_timer_show_cpu_time_by_progress(timer);
+        had_err = gt_readjoiner_assembly_build_graph(arguments, &strgraph,
+            reads, readset, eqlen, rlen, nreads, contained, default_logger,
+            verbose_logger, timer, err);
+      }
+      else
+      {
+        gt_readjoiner_assembly_load_graph(&strgraph, reads, readset, rlen,
+            default_logger, timer);
       }
-      had_err = gt_readjoiner_assembly_count_spm(readset, eqlen,
-         arguments->minmatchlength, arguments->nspmfiles, strgraph, contained,
-         default_logger, err);
-      gt_readjoiner_assembly_show_current_space("(edges counted)");
-      if (gt_showtime_enabled())
-        gt_timer_show_progress(timer, GT_READJOINER_MSG_BUILDSG, stdout);
-      gt_logger_log(default_logger, GT_READJOINER_MSG_BUILDSG);
-    }
-    if (had_err == 0)
-    {
-      gt_assert((eqlen && rlen > 0 && reads == NULL) ||
-          (!eqlen && rlen == 0 && reads != NULL));
-      gt_strgraph_allocate_graph(strgraph, rlen, reads);
-      gt_readjoiner_assembly_show_current_space("(graph allocated)");
-      had_err = gt_strgraph_load_spm_from_file(strgraph,
-            (unsigned long)arguments->minmatchlength, arguments->redtrans,
-            contained, readset, arguments->nspmfiles,
-            GT_READJOINER_SUFFIX_SPMLIST, err);
-    }
-    if (had_err == 0)
-    {
-      if (arguments->elendistri)
-        gt_strgraph_show_edge_lengths_distribution(strgraph, readset,
-            GT_READJOINER_SUFFIX_ELEN_DISTRI);
-      gt_strgraph_log_stats(strgraph, verbose_logger);
-      gt_strgraph_log_space(strgraph);
     }
 
     if (!eqlen && reads != NULL && !arguments->errors)
@@ -480,7 +558,8 @@ static int gt_readjoiner_assembly_runner(GT_UNUSED int argc,
     if (had_err == 0 && arguments->redtrans)
     {
       if (gt_showtime_enabled())
-        gt_timer_show_progress(timer, GT_READJOINER_MSG_REDTRANS, stdout);
+        gt_timer_show_progress(timer, GT_READJOINER_ASSEMBLY_MSG_REDTRANS,
+            stdout);
       gt_strgraph_sort_edges_by_len(strgraph, false);
       (void)gt_strgraph_redtrans(strgraph, false);
       (void)gt_strgraph_redself(strgraph, false);
@@ -491,13 +570,24 @@ static int gt_readjoiner_assembly_runner(GT_UNUSED int argc,
     if (had_err == 0 && arguments->errors)
     {
       if (gt_showtime_enabled())
-        gt_timer_show_progress(timer, GT_READJOINER_MSG_CLEANSG, stdout);
-      gt_logger_log(default_logger, GT_READJOINER_MSG_CLEANSG);
+        gt_timer_show_progress(timer, GT_READJOINER_ASSEMBLY_MSG_CLEANSG,
+            stdout);
+      gt_logger_log(default_logger, GT_READJOINER_ASSEMBLY_MSG_CLEANSG);
       had_err = gt_readjoiner_assembly_error_correction(strgraph,
           arguments->bubble, arguments->deadend, arguments->deadend_depth,
           verbose_logger);
     }
 
+    if (had_err == 0 && arguments->save)
+    {
+      if (gt_showtime_enabled())
+        gt_timer_show_progress(timer, GT_READJOINER_ASSEMBLY_MSG_SAVESG,
+            stdout);
+      gt_logger_log(default_logger, GT_READJOINER_ASSEMBLY_MSG_SAVESG);
+      gt_strgraph_show(strgraph, GT_STRGRAPH_BIN,
+          gt_str_get(arguments->readset), GT_READJOINER_SUFFIX_SG, false);
+    }
+
     if (!eqlen && reads != NULL)
     {
       gt_encseq_delete(reads);
@@ -509,11 +599,12 @@ static int gt_readjoiner_assembly_runner(GT_UNUSED int argc,
     if (had_err == 0)
     {
       if (gt_showtime_enabled())
-        gt_timer_show_progress(timer, GT_READJOINER_MSG_TRAVERSESG, stdout);
-      gt_logger_log(default_logger, GT_READJOINER_MSG_TRAVERSESG);
+        gt_timer_show_progress(timer, GT_READJOINER_ASSEMBLY_MSG_TRAVERSESG,
+            stdout);
+      gt_logger_log(default_logger, GT_READJOINER_ASSEMBLY_MSG_TRAVERSESG);
       gt_readjoiner_assembly_show_current_space("(before traversal)");
-      gt_strgraph_spell(strgraph, (unsigned long)arguments->depthcutoff,
-          (unsigned long)arguments->lengthcutoff, false, readset,
+      gt_strgraph_spell(strgraph, (GtUword)arguments->depthcutoff,
+          (GtUword)arguments->lengthcutoff, arguments->vd, readset,
           GT_READJOINER_SUFFIX_CONTIG_PATHS, NULL, true, false,
           verbose_logger);
     }
@@ -530,7 +621,8 @@ static int gt_readjoiner_assembly_runner(GT_UNUSED int argc,
   {
     gt_readjoiner_assembly_show_current_space("(before paths2seq)");
     had_err = gt_readjoiner_assembly_paths2seq(readset,
-        (unsigned long)arguments->lengthcutoff,
+        (GtUword)arguments->lengthcutoff, arguments->vd,
+        arguments->astat, arguments->coverage, arguments->copynum,
         arguments->buffersize, default_logger, &timer, err);
   }
 
