@@ -41,7 +41,7 @@ typedef struct {
   unsigned int minmatchlength,
                numofparts,
                w_maxsize;
-  unsigned long maximumspace,
+  GtUword maximumspace,
                 phase2extra;
   GtStr *encseqinput,
         *memlimitarg,
@@ -209,11 +209,6 @@ static int gt_readjoiner_overlap_arguments_check(int rest_argc,
     {
       haserr = true;
     }
-    if (!haserr && !gt_ma_bookkeeping_enabled()) {
-      gt_error_set(err, "option '-memlimit' requires "
-                        "GT_MEM_BOOKKEEPING=on");
-      haserr = true;
-    }
   }
   if (!haserr && gt_option_is_set(arguments->refoptionphase2extra))
   {
@@ -225,15 +220,6 @@ static int gt_readjoiner_overlap_arguments_check(int rest_argc,
       haserr = true;
     }
   }
-#ifdef GT_THREADS_ENABLED
-  if (!haserr) {
-    if (gt_jobs > 1 && gt_ma_bookkeeping_enabled()) {
-      gt_error_set(err, "gt option '-j' and GT_MEM_BOOKKEEPING=on "
-                        "are incompatible");
-      haserr = true;
-    }
-  }
-#endif
   return haserr ? -1 : 0;
 }
 
@@ -250,7 +236,7 @@ static int gt_readjoiner_overlap_runner(GT_UNUSED int argc,
   unsigned int kmersize;
   bool haserr = false;
   bool eqlen;
-  unsigned long total_nof_irr_spm = 0, total_nof_trans_spm = 0;
+  GtUword total_nof_irr_spm = 0, total_nof_trans_spm = 0;
 
   gt_error_check(err);
   gt_assert(arguments);
@@ -295,8 +281,8 @@ static int gt_readjoiner_overlap_runner(GT_UNUSED int argc,
       {
         state_table[threadcount]
           = gt_spmfind_eqlen_state_new(encseq,
-                (unsigned long)arguments->minmatchlength,
-                (unsigned long)arguments->w_maxsize, arguments->elimtrans,
+                (GtUword)arguments->minmatchlength,
+                (GtUword)arguments->w_maxsize, arguments->elimtrans,
                 arguments->showspm, gt_str_get(arguments->encseqinput),
                 threadcount, default_logger, verbose_logger, err);
       }
@@ -316,7 +302,7 @@ static int gt_readjoiner_overlap_runner(GT_UNUSED int argc,
         total_nof_irr_spm +=
           gt_spmfind_eqlen_nof_irr_spm(state_table[threadcount]);
         total_nof_trans_spm +=
-          gt_spmfind_eqlen_nof_irr_spm(state_table[threadcount]);
+          gt_spmfind_eqlen_nof_trans_spm(state_table[threadcount]);
         gt_spmfind_eqlen_state_delete(state_table[threadcount]);
       }
       gt_free(state_table);
@@ -330,8 +316,8 @@ static int gt_readjoiner_overlap_runner(GT_UNUSED int argc,
       {
         state_table[threadcount]
            = gt_spmfind_varlen_state_new(encseq,
-                  (unsigned long)arguments->minmatchlength,
-                  (unsigned long)arguments->w_maxsize, arguments->elimtrans,
+                  (GtUword)arguments->minmatchlength,
+                  (GtUword)arguments->w_maxsize, arguments->elimtrans,
                   arguments->showspm, gt_str_get(arguments->encseqinput),
                   threadcount, default_logger, verbose_logger, err);
       }
@@ -350,20 +336,24 @@ static int gt_readjoiner_overlap_runner(GT_UNUSED int argc,
       {
         gt_spmfind_varlen_state_delete(state_table[threadcount]);
         total_nof_irr_spm +=
-          gt_spmfind_eqlen_nof_irr_spm(state_table[threadcount]);
+          gt_spmfind_varlen_nof_irr_spm(state_table[threadcount]);
         total_nof_trans_spm +=
-          gt_spmfind_eqlen_nof_irr_spm(state_table[threadcount]);
+          gt_spmfind_varlen_nof_trans_spm(state_table[threadcount]);
       }
       gt_free(state_table);
     }
   }
   if (!haserr)
   {
-    gt_logger_log(default_logger, "number of %ssuffix-prefix matches = %lu",
+    gt_logger_log(default_logger, "number of %ssuffix-prefix matches = "GT_WU"",
         arguments->elimtrans ? "irreducible " : "", total_nof_irr_spm);
+    gt_logger_log(default_logger, "average %sSPM/read = %.2f",
+        arguments->elimtrans ? "irreducible " : "", (float)total_nof_irr_spm /
+        (arguments->singlestrand ? gt_encseq_num_of_sequences(encseq)
+        : GT_DIV2(gt_encseq_num_of_sequences(encseq))));
     if (arguments->elimtrans)
       gt_logger_log(default_logger, "number of transitive suffix-prefix "
-          "matches = %lu", total_nof_trans_spm);
+          "matches = "GT_WU"", total_nof_trans_spm);
   }
   gt_logger_delete(default_logger);
   gt_logger_delete(verbose_logger);
