@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2010 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2006-2010 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2006-2008 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -29,7 +29,7 @@ typedef struct {
        gc_content,
        stat,
        seqlengthdistri;
-  unsigned long showseqnum,
+  GtUword showseqnum,
                 width;
   GtStr *reader;
   GtOutputFileInfo *ofi;
@@ -79,10 +79,10 @@ static GtOptionParser* gt_seq_option_parser_new(void *tool_arguments)
   gt_option_parser_add_option(op, option_showfasta);
 
   /* -showseqnum */
-  option_showseqnum = gt_option_new_ulong_min("showseqnum", "show sequence "
+  option_showseqnum = gt_option_new_uword_min("showseqnum", "show sequence "
                                               "with given number (in FASTA "
                                               "format)", &arguments->showseqnum,
-                                              GT_UNDEF_ULONG, 1);
+                                              GT_UNDEF_UWORD, 1);
   gt_option_parser_add_option(op, option_showseqnum);
 
   /* -gc-content */
@@ -106,7 +106,7 @@ static GtOptionParser* gt_seq_option_parser_new(void *tool_arguments)
   gt_option_parser_add_option(op, option_width);
 
   /* output file options */
-  gt_output_file_register_options(op, &arguments->outfp, arguments->ofi);
+  gt_output_file_info_register_options(arguments->ofi, op, &arguments->outfp);
 
   /* option implications */
   gt_option_imply_either_2(option_width, option_showfasta, option_showseqnum);
@@ -129,7 +129,7 @@ static int gt_seq_arguments_check(int rest_argc, void *tool_arguments,
   gt_error_check(err);
   gt_assert(arguments);
   /* option -showseqnum makes only sense if we got a single sequence file */
-  if (arguments->showseqnum != GT_UNDEF_ULONG && rest_argc > 1) {
+  if (arguments->showseqnum != GT_UNDEF_UWORD && rest_argc > 1) {
     gt_error_set(err, "option '-showseqnum' makes only sense with a single "
                       "sequence_file");
     return -1;
@@ -159,10 +159,11 @@ static int gt_seq_runner(int argc, const char **argv, int parsed_args,
     if (!had_err && arguments->showfasta)
       gt_bioseq_show_as_fasta(bioseq, arguments->width, arguments->outfp);
 
-    if (!had_err && arguments->showseqnum != GT_UNDEF_ULONG) {
+    if (!had_err && arguments->showseqnum != GT_UNDEF_UWORD) {
       if (arguments->showseqnum > gt_bioseq_number_of_sequences(bioseq)) {
-        gt_error_set(err, "argument '%lu' to option '-showseqnum' is too "
-                     "large. The sequence index contains only '%lu' sequences.",
+        gt_error_set(err, "argument '"GT_WU"' to option '-showseqnum' is too "
+                     "large. The sequence index contains only '"GT_WU"' "
+                     "sequences.",
                      arguments->showseqnum,
                      gt_bioseq_number_of_sequences(bioseq));
         had_err = -1;
