@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2008-2010 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2008-2010 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2008      Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -25,7 +25,7 @@
 #include "tools/gt_seqfilter.h"
 
 typedef struct {
-  unsigned long minlength,
+  GtUword minlength,
                 maxlength,
                 maxseqnum,
                 width;
@@ -57,33 +57,33 @@ static GtOptionParser* gt_seqfilter_option_parser_new(void *tool_arguments)
   gt_assert(arguments);
 
   op = gt_option_parser_new("[option ...] [sequence_file ...]",
-                            "Filter the given sequence_file(s) and show the "
+                            "Filter the given sequence file(s) and show the "
                             "results on stdout.");
 
   /* -minlength */
-  option = gt_option_new_ulong("minlength",
+  option = gt_option_new_uword("minlength",
                                "set minimum length a sequence must "
                                "have to pass the filter", &arguments->minlength,
-                               GT_UNDEF_ULONG);
+                               GT_UNDEF_UWORD);
   gt_option_parser_add_option(op, option);
 
   /* -maxlength */
-  option = gt_option_new_ulong("maxlength", "set maximum length a sequence can "
+  option = gt_option_new_uword("maxlength", "set maximum length a sequence can "
                                "have to pass the filter", &arguments->maxlength,
-                               GT_UNDEF_ULONG);
+                               GT_UNDEF_UWORD);
   gt_option_parser_add_option(op, option);
 
   /* -maxseqnum */
-  option = gt_option_new_ulong("maxseqnum", "set the maximum number of "
+  option = gt_option_new_uword("maxseqnum", "set the maximum number of "
                                "sequences which can pass the filter",
-                               &arguments->maxseqnum, GT_UNDEF_ULONG);
+                               &arguments->maxseqnum, GT_UNDEF_UWORD);
   gt_option_parser_add_option(op, option);
 
   /* -width */
   option = gt_option_new_width(&arguments->width);
   gt_option_parser_add_option(op, option);
 
-  gt_output_file_register_options(op, &arguments->outfp, arguments->ofi);
+  gt_output_file_info_register_options(arguments->ofi, op, &arguments->outfp);
 
   return op;
 }
@@ -94,8 +94,8 @@ static int gt_seqfilter_runner(int argc, const char **argv, int parsed_args,
   SeqFilterArguments *arguments = tool_arguments;
   GtBioseqIterator *bsi;
   GtBioseq *bioseq;
-  unsigned long i;
-  unsigned long long passed = 0, filtered = 0, num_of_sequences = 0;
+  GtUword i;
+  GtUint64 passed = 0, filtered = 0, num_of_sequences = 0;
   int had_err = 0;
 
   gt_error_check(err);
@@ -106,11 +106,11 @@ static int gt_seqfilter_runner(int argc, const char **argv, int parsed_args,
   while (!(had_err = gt_bioseq_iterator_next(bsi, &bioseq, err)) && bioseq) {
     for (i = 0; i < gt_bioseq_number_of_sequences(bioseq); i++) {
       char *seq;
-      if ((arguments->minlength == GT_UNDEF_ULONG ||
+      if ((arguments->minlength == GT_UNDEF_UWORD ||
            gt_bioseq_get_sequence_length(bioseq, i) >= arguments->minlength) &&
-          (arguments->maxlength == GT_UNDEF_ULONG ||
+          (arguments->maxlength == GT_UNDEF_UWORD ||
            gt_bioseq_get_sequence_length(bioseq, i) <= arguments->maxlength) &&
-          (arguments->maxseqnum == GT_UNDEF_ULONG ||
+          (arguments->maxseqnum == GT_UNDEF_UWORD ||
            passed + 1 <= arguments->maxseqnum)) {
         seq = gt_bioseq_get_sequence(bioseq, i);
         gt_fasta_show_entry(gt_bioseq_get_description(bioseq, i),
@@ -130,8 +130,8 @@ static int gt_seqfilter_runner(int argc, const char **argv, int parsed_args,
   /* show statistics */
   if (!had_err) {
     gt_assert(passed + filtered == num_of_sequences);
-    fprintf(stderr, "# %llu out of %llu sequences have been removed (%.3f%%)\n",
-            filtered, num_of_sequences,
+    fprintf(stderr, "# "GT_LLU" out of "GT_LLU" sequences have been removed "
+            "(%.3f%%)\n", filtered, num_of_sequences,
             ((double) filtered / num_of_sequences) * 100.0);
   }
 
