@@ -32,7 +32,7 @@
 typedef struct {
   GtOutputFileInfo *ofi;
   GtFile *outfp;
-  unsigned long fasta_width;
+  GtUword fasta_width;
   bool reverse;
 } GtTranslateArguments;
 
@@ -68,11 +68,11 @@ static GtOptionParser* gt_seqtranslate_option_parser_new(void *tool_arguments)
                               &arguments->reverse, true);
   gt_option_parser_add_option(op, option);
 
-  option = gt_option_new_ulong("fastawidth", "width of the FASTA output",
+  option = gt_option_new_uword("fastawidth", "width of the FASTA output",
                               &arguments->fasta_width, 60);
   gt_option_parser_add_option(op, option);
 
-  gt_output_file_register_options(op, &arguments->outfp, arguments->ofi);
+  gt_output_file_info_register_options(arguments->ofi, op, &arguments->outfp);
   gt_option_parser_set_min_args(op, 1);
 
   return op;
@@ -92,7 +92,7 @@ static int gt_seqtranslate_arguments_check(GT_UNUSED int rest_argc,
 
 static int gt_seqtranslate_do_translation(GtTranslateArguments *arguments,
                                        const char *sequence,
-                                       unsigned long length,
+                                       GtUword length,
                                        const char *desc,
                                        GtStr **translations,
                                        bool rev,
@@ -170,7 +170,7 @@ static int gt_seqtranslate_runner(int argc, const char **argv, int parsed_args,
   if (!had_err) {
     char *desc;
     const GtUchar *sequence;
-    unsigned long len;
+    GtUword len;
     while (!had_err && (rval = gt_seq_iterator_next(si,
                                                    &sequence,
                                                    &len, &desc, err))) {
