@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2008-2011 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2008-2011 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2011      Giorgio Gonnella <gonnella@zbh.uni-hamburg.de>
   Copyright (c) 2008-2011 Center for Bioinformatics, University of Hamburg
 
@@ -31,7 +31,7 @@
 
 typedef struct {
   bool seqit, verbose, rev;
-  unsigned long width, nofseqs;
+  GtUword width, nofseqs;
   GtOutputFileInfo *ofi;
   GtFile *outfp;
 } GtSequniqArguments;
@@ -61,8 +61,8 @@ static GtOptionParser* gt_sequniq_option_parser_new(void *tool_arguments)
   gt_assert(arguments);
 
   op = gt_option_parser_new("[option ...] sequence_file [...] ",
-                            "Filter out repeated sequences in given in given "
-                            "sequence_file(s).");
+                            "Filter out repeated sequences in given "
+                            "sequence files.");
 
   /* -seqit */
   seqit_option = gt_option_new_bool("seqit", "use sequence iterator",
@@ -71,7 +71,7 @@ static GtOptionParser* gt_sequniq_option_parser_new(void *tool_arguments)
   gt_option_parser_add_option(op, seqit_option);
 
   /* -nofseqs */
-  nofseqs_option = gt_option_new_ulong("nofseqs", "number of sequences "
+  nofseqs_option = gt_option_new_uword("nofseqs", "number of sequences "
       "(improves efficiency)\ndefault: unspecified",
       &arguments->nofseqs, 0);
   gt_option_is_development_option(nofseqs_option);
@@ -92,7 +92,7 @@ static GtOptionParser* gt_sequniq_option_parser_new(void *tool_arguments)
   width_option = gt_option_new_width(&arguments->width);
   gt_option_parser_add_option(op, width_option);
 
-  gt_output_file_register_options(op, &arguments->outfp, arguments->ofi);
+  gt_output_file_info_register_options(arguments->ofi, op, &arguments->outfp);
 
   /* option implications */
   gt_option_imply(verbose_option, seqit_option);
@@ -105,7 +105,7 @@ static int gt_sequniq_runner(int argc, const char **argv, int parsed_args,
                              void *tool_arguments, GtError *err)
 {
   GtSequniqArguments *arguments = tool_arguments;
-  unsigned long long duplicates = 0, num_of_sequences = 0;
+  GtUint64 duplicates = 0, num_of_sequences = 0;
   int i, had_err = 0;
   GtMD5Set *md5set;
 
@@ -113,7 +113,7 @@ static int gt_sequniq_runner(int argc, const char **argv, int parsed_args,
   gt_assert(arguments);
   md5set = gt_md5set_new(arguments->nofseqs);
   if (!arguments->seqit) {
-    unsigned long j;
+    GtUword j;
     GtBioseq *bs;
 
     for (i = parsed_args; !had_err && i < argc; i++) {
@@ -147,7 +147,7 @@ static int gt_sequniq_runner(int argc, const char **argv, int parsed_args,
     off_t totalsize;
     const GtUchar *sequence;
     char *desc;
-    unsigned long len;
+    GtUword len;
 
     files = gt_str_array_new();
     for (i = parsed_args; i < argc; i++)
@@ -159,9 +159,9 @@ static int gt_sequniq_runner(int argc, const char **argv, int parsed_args,
     if (!had_err) {
       if (arguments->verbose) {
         gt_progressbar_start(gt_seq_iterator_getcurrentcounter(seqit,
-                                                            (unsigned long long)
+                                                            (GtUint64)
                                                             totalsize),
-                             (unsigned long long) totalsize);
+                             (GtUint64) totalsize);
       }
       while (!had_err) {
         GtMD5SetStatus retval;
@@ -188,8 +188,9 @@ static int gt_sequniq_runner(int argc, const char **argv, int parsed_args,
 
   /* show statistics */
   if (!had_err) {
-    fprintf(stderr, "# %lu out of %lu sequences have been removed (%.3f%%)\n",
-            (unsigned long)duplicates, (unsigned long)num_of_sequences,
+    fprintf(stderr,
+            "# "GT_WU" out of "GT_WU" sequences have been removed (%.3f%%)\n",
+            (GtUword)duplicates, (GtUword)num_of_sequences,
             ((double) duplicates / (double)num_of_sequences) * 100.0);
   }
 
