@@ -21,6 +21,9 @@
 #include "core/option_api.h"
 #include "core/str_array_api.h"
 #include "core/unused_api.h"
+#include "core/format64.h"
+#include "core/fa.h"
+#include "core/mathsupport.h"
 #include "match/echoseq.h"
 #include "match/eis-voiditf.h"
 #include "match/esa-lcpintervals.h"
@@ -35,10 +38,10 @@
 #include "match/sfx-strategy.h"
 #include "match/sfx-suffixgetset.h"
 #include "match/sfx-suftaborder.h"
-#include "match/stamp.h"
-#include "match/test-mappedstr.pr"
-#include "match/twobits2kmers.h"
 #include "match/sfx-linlcp.h"
+#include "match/sfx-lwcheck.h"
+#include "match/twobits2kmers.h"
+#include "match/esa-fileend.h"
 #include "tools/gt_sfxmap.h"
 
 typedef struct
@@ -61,9 +64,11 @@ typedef struct
        enumlcpitvtreeBU,
        diffcovercheck,
        wholeleafcheck,
+       compressedesa,
+       compresslcp,
        spmitv,
        ownencseq2file;
-  unsigned long delspranges;
+  GtUword delspranges;
   GtStr *esaindexname,
         *pckindexname;
   unsigned int sortmaxdepth,
@@ -72,13 +77,13 @@ typedef struct
              *streamesq;
 } Sfxmapoptions;
 
-static void deletethespranges(const GtEncseq *encseq,
-                              unsigned long delspranges)
+static void gt_sfxmap_deletethespranges(const GtEncseq *encseq,
+                                        GtUword delspranges)
 {
   GtSpecialrangeiterator *sri;
   GtRange range;
-  unsigned long rangewidth, nextpos = 0, totallength;
-  const unsigned long fastawidth = 70UL;
+  GtUword rangewidth, nextpos = 0, totallength;
+  const GtUword fastawidth = 70UL;
 
   sri = gt_specialrangeiterator_new(encseq,true);
   printf(">\n");
@@ -86,7 +91,7 @@ static void deletethespranges(const GtEncseq *encseq,
   {
     gt_assert(range.end > range.start);
     rangewidth = range.end - range.start;
-    if (rangewidth > (unsigned long) delspranges)
+    if (rangewidth > (GtUword) delspranges)
     {
       if (range.start == 0)
       {
@@ -157,7 +162,8 @@ static GtOptionParser* gt_sfxmap_option_parser_new(void *tool_arguments)
          *optionwholeleafcheck,
          *optionenumlcpitvs, *optionenumlcpitvtree, *optionenumlcpitvtreeBU,
          *optionscanesa, *optionspmitv, *optionownencseq2file,
-         *optionbfcheck;
+         *optionbfcheck, *optioncompressedesa,
+         *optioncompresslcp;
 
   gt_assert(arguments != NULL);
   op = gt_option_parser_new("[options]",
@@ -206,7 +212,7 @@ static GtOptionParser* gt_sfxmap_option_parser_new(void *tool_arguments)
                                      &arguments->bfcheck,false);
   gt_option_parser_add_option(op, optionbfcheck);
 
-  optiondelspranges = gt_option_new_ulong("delspranges",
+  optiondelspranges = gt_option_new_uword("delspranges",
                                           "delete ranges of special values",
                                            &arguments->delspranges,
                                            0);
@@ -309,10 +315,27 @@ static GtOptionParser* gt_sfxmap_option_parser_new(void *tool_arguments)
   gt_option_parser_add_option(op, optionownencseq2file);
   gt_option_imply(optionownencseq2file, optionesaindex);
 
+  optioncompressedesa = gt_option_new_bool("compressedesa",
+                                           "input the compressed tables of the "
+                                           "enhanced suffix array",
+                                           &arguments->compressedesa,
+                                           false);
+  gt_option_parser_add_option(op, optioncompressedesa);
+  gt_option_imply(optioncompressedesa, optionesaindex);
+
+  optioncompresslcp = gt_option_new_bool("compresslcp",
+                                          "compress the lcp value into byte "
+                                          "compressed form",
+                                          &arguments->compresslcp,
+                                          false);
+  gt_option_parser_add_option(op, optioncompresslcp);
+  gt_option_imply(optioncompresslcp, optionesaindex);
+
   optionverbose = gt_option_new_verbose(&arguments->verbose);
   gt_option_parser_add_option(op, optionverbose);
 
   gt_option_exclude(optionenumlcpitvs,optionenumlcpitvtree);
+  gt_option_exclude(optioncompresslcp,optioncompressedesa);
   gt_option_exclude(optionenumlcpitvs,optionenumlcpitvtreeBU);
   gt_option_exclude(optionenumlcpitvtree,optionenumlcpitvtreeBU);
   gt_option_imply(optionlcp,optionsuf);
@@ -329,21 +352,21 @@ static int gt_sfxmap_arguments_check(GT_UNUSED int rest_argc,
   return 0;
 }
 
-static void showcomparisonfailureESA(const char *filename,
+static void gt_sfxmap_showcomparisonfailureESA(const char *filename,
                                      int line,
                                      const char *where,
                                      const GtEncseq *encseq,
                                      GtReadmode readmode,
                                      const ESASuffixptr *suftab,
-                                     unsigned long depth,
-                                     unsigned long idx1,
-                                     unsigned long idx2,
+                                     GtUword depth,
+                                     GtUword idx1,
+                                     GtUword idx2,
                                      int cmp,
-                                     unsigned long maxlcp)
+                                     GtUword maxlcp)
 {
   fprintf(stderr,"ERROR: file \"%s\", line %d: ",filename,line);
-  fprintf(stderr,"%s(%lu vs %lu"
-                 " %lu=\"",
+  fprintf(stderr,"%s("GT_WU" vs "GT_WU""
+                 " "GT_WU"=\"",
                        where,
                        idx1,
                        idx2,
@@ -353,15 +376,15 @@ static void showcomparisonfailureESA(const char *filename,
   fprintf(stderr,"\",\"");
   gt_encseq_showatstartposwithdepth(stderr,encseq,readmode,
                                     ESASUFFIXPTRGET(suftab,idx2),depth);
-  fprintf(stderr,"\"=%lu)=%d with maxlcp %lu\n",ESASUFFIXPTRGET(suftab,idx2),
-                                                cmp,
-                                                maxlcp);
+  fprintf(stderr,"\"="GT_WU")=%d with maxlcp "GT_WU"\n",
+          ESASUFFIXPTRGET(suftab,idx2),cmp,maxlcp);
 }
 
-static unsigned long determinenumberofwholeleaves(const GtEncseq *encseq,
+static GtUword gt_sfxmap_determinenumberofwholeleaves(
+                                                  const GtEncseq *encseq,
                                                   GtReadmode readmode)
 {
-  unsigned long idx, wholeleafcount = 0, totallength;
+  GtUword idx, wholeleafcount = 0, totallength;
   GtEncseqReader* esr;
   GtUchar cc;
   bool sequencestart = true;
@@ -390,16 +413,16 @@ static unsigned long determinenumberofwholeleaves(const GtEncseq *encseq,
   return wholeleafcount;
 }
 
-static int gt_encseq_check_comparefullsuffixes(const GtEncseq *encseq,
-                                               GtReadmode readmode,
-                                               unsigned long *maxlcp,
-                                               unsigned long start1,
-                                               unsigned long start2,
-                                               GtEncseqReader *esr1,
-                                               GtEncseqReader *esr2)
+static int gt_sfxmap_comparefullsuffixes(const GtEncseq *encseq,
+                                         GtReadmode readmode,
+                                         GtUword *maxlcp,
+                                         GtUword start1,
+                                         GtUword start2,
+                                         GtEncseqReader *esr1,
+                                         GtEncseqReader *esr2)
 {
   GtUchar cc1, cc2;
-  unsigned long pos1, pos2, totallength;
+  GtUword pos1, pos2, totallength;
   int retval;
 
   totallength = gt_encseq_total_length(encseq);
@@ -477,20 +500,20 @@ static int gt_encseq_check_comparefullsuffixes(const GtEncseq *encseq,
   return retval;
 }
 
-static int gt_checkentiresuftab(const char *filename,
+static int gt_sfxmap_checkentiresuftab(const char *filename,
                                 int line,
                                 const GtEncseq *encseq,
                                 GtReadmode readmode,
                                 const ESASuffixptr *suftab,
-                                unsigned long numberofsuffixes,
+                                GtUword numberofsuffixes,
                                 bool wholeleafcheck,
                                 Sequentialsuffixarrayreader *ssar,
                                 GT_UNUSED bool specialsareequal,
                                 GT_UNUSED bool specialsareequalatdepth0,
-                                unsigned long depth,
+                                GtUword depth,
                                 GT_UNUSED GtError *err)
 {
-  unsigned long idx, maxlcp,
+  GtUword idx, maxlcp,
                 currentlcp = 0,
                 countbitsset = 0,
                 wholeleafcount = 0,
@@ -502,7 +525,7 @@ static int gt_checkentiresuftab(const char *filename,
   GtEncseqReader *esr;
   /*
 #define MAXDIST 100
-  unsigned long countdist[MAXDIST+1] = {0};
+  GtUword countdist[MAXDIST+1] = {0};
   */
 
   gt_error_check(err);
@@ -515,10 +538,10 @@ static int gt_checkentiresuftab(const char *filename,
   esr = gt_encseq_create_reader_with_readmode(encseq,readmode,0);
   for (idx = 0; idx < numberofsuffixes; idx++)
   {
-    unsigned long position = ESASUFFIXPTRGET(suftab,idx);
+    GtUword position = ESASUFFIXPTRGET(suftab,idx);
     if (GT_ISIBITSET(startposoccurs,position))
     {
-      fprintf(stderr,"ERROR: suffix with startpos %lu already occurs\n",
+      fprintf(stderr,"ERROR: suffix with startpos "GT_WU" already occurs\n",
               ESASUFFIXPTRGET(suftab,idx));
       exit(GT_EXIT_PROGRAMMING_ERROR);
     }
@@ -530,7 +553,7 @@ static int gt_checkentiresuftab(const char *filename,
                                                            position - 1,
                                                            readmode))
       {
-        /*printf("whole %lu\n",position);*/
+        /*printf("whole "GT_WU"\n",position);*/
         wholeleafcount++;
       }
     }
@@ -539,12 +562,13 @@ static int gt_checkentiresuftab(const char *filename,
   gt_free(startposoccurs);
   if (wholeleafcheck)
   {
-    unsigned long expectednumofwholeleaves
-      = determinenumberofwholeleaves(encseq,readmode);
+    GtUword expectednumofwholeleaves
+      = gt_sfxmap_determinenumberofwholeleaves(encseq,readmode);
     if (wholeleafcount != expectednumofwholeleaves)
     {
-      fprintf(stderr,"wholeleafcount=%lu != %lu=expectednumofwholeleaves\n",
-                      wholeleafcount,expectednumofwholeleaves);
+      fprintf(stderr,
+              "wholeleafcount="GT_WU" != "GT_WU"=expectednumofwholeleaves\n",
+              wholeleafcount,expectednumofwholeleaves);
       exit(EXIT_FAILURE);
     }
   }
@@ -562,18 +586,18 @@ static int gt_checkentiresuftab(const char *filename,
     if (idx < totallength)
     {
       gt_assert(ESASUFFIXPTRGET(suftab,idx) < totallength);
-      cmp = gt_encseq_check_comparefullsuffixes(encseq,
-                                                readmode,
-                                                &maxlcp,
-                                                ESASUFFIXPTRGET(suftab,idx-1),
-                                                ESASUFFIXPTRGET(suftab,idx),
-                                                esr1,
-                                                esr2);
+      cmp = gt_sfxmap_comparefullsuffixes(encseq,
+                                          readmode,
+                                          &maxlcp,
+                                          ESASUFFIXPTRGET(suftab,idx-1),
+                                          ESASUFFIXPTRGET(suftab,idx),
+                                          esr1,
+                                          esr2);
       if (cmp >= 0)
       {
-        showcomparisonfailureESA(filename,
+        gt_sfxmap_showcomparisonfailureESA(filename,
                                  line,
-                                 "checkentiresuftab",
+                                 __func__,
                                  encseq,
                                  readmode,
                                  suftab,
@@ -595,11 +619,11 @@ static int gt_checkentiresuftab(const char *filename,
     }
     if (ssar != NULL)
     {
-      NEXTSEQUENTIALLCPTABVALUE(currentlcp,ssar);
+      SSAR_NEXTSEQUENTIALLCPTABVALUE(currentlcp,ssar);
       if (maxlcp != currentlcp)
       {
-        fprintf(stderr,"%lu: startpos=%lu, firstchar=%u, "
-                "startpos=%lu,firstchar=%u",
+        fprintf(stderr,""GT_WU": startpos="GT_WU", firstchar=%u, "
+                "startpos="GT_WU",firstchar=%u",
                 idx,
                 ESASUFFIXPTRGET(suftab,idx-1),
                 (unsigned int)
@@ -613,7 +637,7 @@ static int gt_checkentiresuftab(const char *filename,
                                                                      idx),
                                                      readmode)
                    : SEPARATOR);
-        fprintf(stderr,", maxlcp(bruteforce) = %lu != %lu(fast)\n",
+        fprintf(stderr,", maxlcp(bruteforce) = "GT_WU" != "GT_WU"(fast)\n",
                           maxlcp, currentlcp);
         exit(GT_EXIT_PROGRAMMING_ERROR);
       }
@@ -622,19 +646,29 @@ static int gt_checkentiresuftab(const char *filename,
   gt_encseq_reader_delete(esr1);
   gt_encseq_reader_delete(esr2);
   return haserr ? -1 : 0;
-  /*
-  printf("# gt_checkentiresuftab with mode 'specials are %s'\n",
-               specialsareequal ? "equal" : "different");
-  */
 }
 
-static int sfxmap_esa(const Sfxmapoptions *arguments, GtLogger *logger,
-                      GtError *err)
+static GtUchar sfx_accesschar_encseq(const void *encseq,GtUword position,
+                                     GtReadmode readmode)
+{
+  return gt_encseq_get_encoded_char((const GtEncseq *) encseq,
+                                    position,
+                                    readmode);
+}
+
+GtUword sfx_charcount_encseq(const void *encseq,GtUchar idx)
+{
+  return gt_encseq_charcount((const GtEncseq *) encseq, idx);
+}
+
+static int gt_sfxmap_esa(const Sfxmapoptions *arguments, GtLogger *logger,
+                         GtError *err)
 {
   bool haserr = false;
   Suffixarray suffixarray;
   unsigned int demand = 0;
 
+  gt_error_check(err);
   if (arguments->inputtis || arguments->delspranges > 0 || arguments->inputsuf)
   {
     demand |= SARR_ESQTAB;
@@ -681,10 +715,10 @@ static int sfxmap_esa(const Sfxmapoptions *arguments, GtLogger *logger,
   {
     if (arguments->delspranges > 0)
     {
-      deletethespranges(suffixarray.encseq,arguments->delspranges);
+      gt_sfxmap_deletethespranges(suffixarray.encseq,arguments->delspranges);
     } else
     {
-      unsigned long totallength = gt_encseq_total_length(suffixarray.encseq);
+      GtUword totallength = gt_encseq_total_length(suffixarray.encseq);
       if (!haserr && arguments->inputsuf && !arguments->usestream)
       {
         if (suffixarray.numberofallsortedsuffixes != totallength + 1 ||
@@ -697,15 +731,15 @@ static int sfxmap_esa(const Sfxmapoptions *arguments, GtLogger *logger,
             ssar = gt_newSequentialsuffixarrayreaderfromfile(
                                           gt_str_get(arguments->esaindexname),
                                           SARR_LCPTAB | SARR_ESQTAB,
-                                          SEQ_scan,
+                                          true,
                                           logger,
                                           err);
           } else
           {
             ssar = NULL;
           }
-          gt_logger_log(logger, "checkentiresuftab");
-          if (gt_checkentiresuftab(__FILE__,
+          gt_logger_log(logger, __func__);
+          if (gt_sfxmap_checkentiresuftab(__FILE__,
                                    __LINE__,
                                    suffixarray.encseq,
                                    suffixarray.readmode,
@@ -718,7 +752,7 @@ static int sfxmap_esa(const Sfxmapoptions *arguments, GtLogger *logger,
                                    0,
                                    err) != 0)
           {
-            fprintf(stderr,"gt_checkentiresuftab failed\n");
+            fprintf(stderr,"%s\n",__func__);
             exit(GT_EXIT_PROGRAMMING_ERROR);
           }
           if (ssar != NULL)
@@ -729,8 +763,15 @@ static int sfxmap_esa(const Sfxmapoptions *arguments, GtLogger *logger,
         {
           if (suffixarray.numberofallsortedsuffixes == totallength + 1)
           {
-            gt_suftab_lightweightcheck(suffixarray.encseq, suffixarray.readmode,
-                                       totallength,suffixarray.suftab,
+            gt_suftab_lightweightcheck(sfx_accesschar_encseq,
+                                       sfx_charcount_encseq,
+                                       suffixarray.encseq,
+                                       suffixarray.readmode,
+                                       totallength,
+                                       gt_encseq_alphabetnumofchars(
+                                                 suffixarray.encseq),
+                                       suffixarray.suftab,
+                                       sizeof suffixarray.suftab,
                                        logger);
             if (arguments->inputlcp)
             {
@@ -753,8 +794,8 @@ static int sfxmap_esa(const Sfxmapoptions *arguments, GtLogger *logger,
       }
       if (!haserr && arguments->inputbwt)
       {
-        unsigned long bwtdifferentconsecutive = 0, idx;
-        GT_UNUSED unsigned long longest;
+        GtUword bwtdifferentconsecutive = 0, idx;
+        GT_UNUSED GtUword longest;
 
         gt_assert(suffixarray.longest.defined);
         longest = suffixarray.longest.valueunsignedlong;
@@ -767,7 +808,7 @@ static int sfxmap_esa(const Sfxmapoptions *arguments, GtLogger *logger,
         }
         if (!arguments->usestream)
         {
-          for (idx = (unsigned long) 1; idx<totallength; idx++)
+          for (idx = (GtUword) 1; idx<totallength; idx++)
           {
             if (suffixarray.bwttab[idx-1] != suffixarray.bwttab[idx] ||
                 ISSPECIAL(suffixarray.bwttab[idx]))
@@ -793,7 +834,7 @@ static int sfxmap_esa(const Sfxmapoptions *arguments, GtLogger *logger,
             }
           }
         }
-        gt_logger_log(logger,"bwtdifferentconsecutive=%lu (%.4f)",
+        gt_logger_log(logger,"bwtdifferentconsecutive="GT_WU" (%.4f)",
                bwtdifferentconsecutive,
                (double) bwtdifferentconsecutive/totallength);
       }
@@ -808,18 +849,206 @@ static int sfxmap_esa(const Sfxmapoptions *arguments, GtLogger *logger,
   return haserr ? -1 : 0;
 }
 
-static int comparelcpvalue(void *info,unsigned long lcp,GtError *err)
+static int gt_sfxmap_compressedesa(const char *indexname,GtError *err)
 {
-  unsigned long currentlcpvalue;
+  bool haserr = false;
+  GtEncseq *encseq;
+  GtEncseqLoader *encseq_loader = gt_encseq_loader_new();
+
+  gt_error_check(err);
+  encseq = gt_encseq_loader_load(encseq_loader,indexname, err);
+  gt_encseq_loader_delete(encseq_loader);
+  if (encseq == NULL)
+  {
+    haserr = true;
+  }
+  if (!haserr)
+  {
+    uint64_t writtenbits;
+    uint8_t bitsperentry;
+    GtUword numberofentries = 0;
+    GtUword totallength = gt_encseq_total_length(encseq);
+    FILE *fp;
+
+    fp = gt_fa_fopen_with_suffix(indexname,GT_SUFTABSUFFIX_BYTECOMPRESSED,
+                                 "rb",err);
+    if (fp == NULL)
+    {
+      haserr = true;
+    }
+    if (!haserr)
+    {
+      if (fread(&writtenbits,sizeof writtenbits,(size_t) 1,fp)
+          != (size_t) 1)
+      {
+        gt_error_set(err,"cannot read %d bytes from %s%s at offset 0",
+                        (int) sizeof writtenbits,
+                        indexname,GT_SUFTABSUFFIX_BYTECOMPRESSED);
+        haserr = true;
+      }
+    }
+    if (!haserr)
+    {
+      if (fread(&bitsperentry,sizeof bitsperentry,(size_t) 1,fp)
+          != (size_t) 1)
+      {
+        gt_error_set(err,"cannot read %d bytes from %s%s at offset %d",
+                        (int) sizeof bitsperentry,
+                        indexname,GT_SUFTABSUFFIX_BYTECOMPRESSED,
+                        (int) sizeof writtenbits);
+        haserr = true;
+      }
+      gt_assert(writtenbits % bitsperentry == 0);
+      numberofentries = (GtUword) (writtenbits/bitsperentry);
+      gt_assert(numberofentries == totallength + 1);
+    }
+    if (!haserr)
+    {
+      uint64_t readvalue = 0;
+      const unsigned int bitspervalue = 64U;
+      unsigned int bits2add = (unsigned int) bitsperentry,
+                   remainingbits = 0;
+      GtUword bitbuffer = 0,
+                    countentries = 0,
+                    *suftabptr,
+                    *suftab = gt_malloc(sizeof *suftab *
+                                        (size_t) numberofentries);
+
+      suftabptr = suftab;
+      while (true)
+      {
+        if (remainingbits == 0)
+        {
+          if (fread(&readvalue,sizeof readvalue,(size_t) 1,fp) != (size_t) 1)
+          {
+            break;
+          }
+          remainingbits = bitspervalue;
+        } else
+        {
+          if (remainingbits >= (unsigned int) bits2add)
+          {
+            if (suftabptr >= suftab + numberofentries)
+            {
+              break;
+            }
+            bitbuffer |= ((GtUword) (readvalue) &
+                         ((1UL << bits2add) - 1)) << (bitsperentry-bits2add);
+            readvalue >>= bits2add;
+            remainingbits -= bits2add;
+            gt_assert(bitbuffer < (1UL << bitsperentry));
+            *suftabptr++ = bitbuffer;
+            bitbuffer = 0;
+            bits2add = (unsigned int) bitsperentry;
+            countentries++;
+          } else
+          {
+            bitbuffer |= (readvalue & ((((uint64_t) 1) << remainingbits) - 1))
+                         << (bitsperentry-bits2add);
+            readvalue >>= remainingbits;
+            bits2add -= remainingbits;
+            remainingbits = 0;
+          }
+        }
+      }
+      gt_assert(countentries == numberofentries);
+      gt_suftab_lightweightcheck(sfx_accesschar_encseq,
+                                 sfx_charcount_encseq,
+                                 encseq,
+                                 GT_READMODE_FORWARD,
+                                 totallength,
+                                 gt_encseq_alphabetnumofchars(encseq),
+                                 suftab,
+                                 sizeof *suftab,
+                                 NULL);
+      gt_free(suftab);
+    }
+    gt_fa_fclose(fp);
+  }
+  gt_encseq_delete(encseq);
+  return haserr ? -1 : 0;
+}
+
+static int gt_sfxmap_compresslcp(const char *indexname,
+                                 GtLogger *logger,GtError *err)
+{
+  Sequentialsuffixarrayreader *ssar = NULL;
+  bool haserr = false;
+
+  gt_error_check(err);
+  ssar = gt_newSequentialsuffixarrayreaderfromfile(
+                                          indexname,
+                                          SARR_LCPTAB | SARR_ESQTAB,
+                                          true,
+                                          logger,
+                                          err);
+  if (ssar == NULL)
+  {
+    haserr = true;
+  }
+  if (!haserr)
+  {
+    GtUword elems = 0;
+    GT_UNUSED GtUword totallength
+      = gt_Sequentialsuffixarrayreader_totallength(ssar);
+    GtUword maxbranchdepth
+      = gt_Sequentialsuffixarrayreader_maxbranchdepth(ssar);
+    FILE *fpcompressedlcp = gt_fa_fopen_with_suffix(indexname,
+                                     GT_LCPTABSUFFIX_BYTECOMPRESSED,"wb",err);
+    unsigned int bitsperentry = gt_determinebitspervalue(maxbranchdepth);
+    GtBitbuffer *bitbuffer = NULL;
+
+    gt_assert(ssar != NULL);
+    if (fpcompressedlcp == NULL)
+    {
+       haserr = true;
+    } else
+    {
+      bitbuffer = gt_bitbuffer_new(fpcompressedlcp,bitsperentry);
+    }
+    if (bitsperentry > 0)
+    {
+      if (!haserr)
+      {
+        gt_bitbuffer_next_fixed_bits_value (bitbuffer,0UL);
+        while (true)
+        {
+          GtUword currentlcp;
+
+          SSAR_NEXTSEQUENTIALLCPTABVALUE(currentlcp,ssar);
+          gt_bitbuffer_next_fixed_bits_value (bitbuffer,currentlcp);
+          elems++;
+        }
+      }
+      if (!haserr)
+      {
+        gt_assert(elems == totallength);
+      }
+    }
+    gt_freeSequentialsuffixarrayreader(&ssar);
+    gt_bitbuffer_delete(bitbuffer);
+    if (fpcompressedlcp != NULL)
+    {
+      gt_fa_fclose(fpcompressedlcp);
+    }
+  }
+  return haserr ? -1 : 0;
+}
+
+static int gt_sfxmap_comparelcpvalue(void *info,GtUword lcp,GtError *err)
+{
+  GtUword currentlcpvalue;
   Sequentialsuffixarrayreader *ssar = (Sequentialsuffixarrayreader *) info;
   bool haserr = false;
 
+  gt_error_check(err);
   do /* fake loop to allow for the use of a break statement */
   {
-    NEXTSEQUENTIALLCPTABVALUE(currentlcpvalue,ssar);
+    SSAR_NEXTSEQUENTIALLCPTABVALUE(currentlcpvalue,ssar);
     if (lcp != currentlcpvalue)
     {
-      gt_error_set(err,"lcp=%lu != %lu=currentlcpvalue",lcp,currentlcpvalue);
+      gt_error_set(err,"lcp="GT_WU" != "GT_WU"=currentlcpvalue",
+                   lcp,currentlcpvalue);
       haserr = true;
       break;
     }
@@ -828,16 +1057,17 @@ static int comparelcpvalue(void *info,unsigned long lcp,GtError *err)
   return haserr ? -1 : 0;
 }
 
-static int sfxmap_pck(const Sfxmapoptions *arguments,GtLogger *logger,
-                      GtError *err)
+static int gt_sfxmap_pck(const Sfxmapoptions *arguments,GtLogger *logger,
+                         GtError *err)
 {
   bool haserr = false;
   FMindex *fmindex;
-  unsigned long totallength = 0;
+  GtUword totallength = 0;
   unsigned int numofchars = 0;
   GtEncseqMetadata *encseqmetadata = NULL;
-  Sequentialsuffixarrayreader *ssar;
+  Sequentialsuffixarrayreader *ssar = NULL;
 
+  gt_error_check(err);
   gt_assert(gt_str_length(arguments->pckindexname) > 0);
   fmindex = gt_loadvoidBWTSeqForSA(gt_str_get(arguments->pckindexname),false,
                                    err);
@@ -863,22 +1093,19 @@ static int sfxmap_pck(const Sfxmapoptions *arguments,GtLogger *logger,
                                           gt_str_get(arguments->esaindexname),
                                           arguments->cmpsuf ? SARR_SUFTAB
                                                             : SARR_LCPTAB,
-                                          SEQ_scan,
+                                          true,
                                           logger,
                                           err);
       if (ssar == NULL)
       {
         haserr = true;
       }
-    } else
-    {
-      ssar = NULL;
     }
   }
   if (!haserr)
   {
-    unsigned long idx, pos, numofnonspecials;
-    GT_UNUSED unsigned long currentsuffix = 0;
+    GtUword idx, pos, numofnonspecials;
+    GT_UNUSED GtUword currentsuffix = 0;
     GtSpecialcharinfo specialcharinfo;
     Bwtseqpositioniterator *bspi;
 
@@ -899,10 +1126,10 @@ static int sfxmap_pck(const Sfxmapoptions *arguments,GtLogger *logger,
       }
       if (arguments->cmpsuf && ssar != NULL)
       {
-        NEXTSEQUENTIALSUFTABVALUE(currentsuffix,ssar);
+        SSAR_NEXTSEQUENTIALSUFTABVALUE(currentsuffix,ssar);
         gt_assert(pos == currentsuffix);
       }
-      /*printf("%lu: pos = %lu\n",idx,pos);*/
+      /*printf(""GT_WU": pos = "GT_WU"\n",idx,pos);*/
     }
     gt_assert(idx == numofnonspecials);
     gt_Bwtseqpositioniterator_delete(bspi);
@@ -926,7 +1153,7 @@ static int sfxmap_pck(const Sfxmapoptions *arguments,GtLogger *logger,
       if (gt_fmindex_dfstraverse(fmindex,
                                  numofchars,
                                  totallength,
-                                 comparelcpvalue,
+                                 gt_sfxmap_comparelcpvalue,
                                  (void *) ssar,
                                  err) != 0)
       {
@@ -963,15 +1190,16 @@ static const Optionargmodedesc stream_esq_operation[] =
                    (unsigned int) BSRS_hashfirstcodes}
 };
 
-static int stream_esq(const Sfxmapoptions *arguments,GtError *err)
+static int gt_sfxmap_stream_esq(const Sfxmapoptions *arguments,GtError *err)
 {
   GtEncseqLoader *el = NULL;
   GtEncseq *encseq = NULL;
   bool haserr = false;
   Bitstreamreadmode brsmode = BSRS_stream_single;
   int multiarg = 0;
-  unsigned long streamesq_size = gt_str_array_size(arguments->streamesq);
+  GtUword streamesq_size = gt_str_array_size(arguments->streamesq);
 
+  gt_error_check(err);
   if (streamesq_size == 2UL || streamesq_size == 3UL)
   {
     int mode;
@@ -979,7 +1207,7 @@ static int stream_esq(const Sfxmapoptions *arguments,GtError *err)
     mode = gt_optionargsetsingle(stream_esq_operation,
                                  sizeof stream_esq_operation/
                                  sizeof stream_esq_operation[0],
-                                 "stream-esq",
+                                 __func__,
                                  gt_str_array_get(arguments->streamesq,1UL),
                                  err);
     if (mode < 0)
@@ -1065,10 +1293,11 @@ typedef struct
   GtSuffixsortspace *sssp;
 } Checkunsortedrangeinfo;
 
-static void sortmaxdepth_processunsortedrange(void *voiddcov,
-                                              unsigned long subbucketleft,
-                                              unsigned long width,
-                                              GT_UNUSED unsigned long depth)
+static void gt_sfxmap_sortmaxdepth_processunsortedrange(void *voiddcov,
+                                              GT_UNUSED GtSuffixsortspace *sssp,
+                                              GtUword subbucketleft,
+                                              GtUword width,
+                                              GT_UNUSED GtUword depth)
 {
   Checkunsortedrangeinfo *curi = voiddcov;
 
@@ -1079,11 +1308,11 @@ static void sortmaxdepth_processunsortedrange(void *voiddcov,
                                  curi->sssp,
                                  subbucketleft,
                                  width,
-                                 (unsigned long) curi->sortmaxdepth);
+                                 (GtUword) curi->sortmaxdepth);
 }
 
-static int performsortmaxdepth(const Sfxmapoptions *arguments,
-                               GtLogger *logger,GtError *err)
+static int gt_sfxmap_performsortmaxdepth(const Sfxmapoptions *arguments,
+                                         GtLogger *logger,GtError *err)
 {
   bool haserr = false;
   GtEncseqLoader *el = NULL;
@@ -1091,6 +1320,7 @@ static int performsortmaxdepth(const Sfxmapoptions *arguments,
   Sfxstrategy sfxstrategy;
   const char *indexname;
 
+  gt_error_check(err);
   indexname = gt_str_get(arguments->esaindexname);
   el = gt_encseq_loader_new();
   curi.encseq = gt_encseq_loader_load(el, indexname, err);
@@ -1100,7 +1330,7 @@ static int performsortmaxdepth(const Sfxmapoptions *arguments,
   }
   if (!haserr)
   {
-    gt_logger_log(logger,"performsortmaxdepth(%s,%u)",
+    gt_logger_log(logger,"%s(%s,%u)",__func__,
                   indexname,arguments->sortmaxdepth);
     defaultsfxstrategy(&sfxstrategy,
                        gt_encseq_bitwise_cmp_ok(curi.encseq) ? false : true);
@@ -1112,14 +1342,10 @@ static int performsortmaxdepth(const Sfxmapoptions *arguments,
   }
   if (!haserr)
   {
-    unsigned long idx, totallength = gt_encseq_total_length(curi.encseq);
+    GtUword totallength = gt_encseq_total_length(curi.encseq);
 
-    curi.sssp = gt_suffixsortspace_new(totallength+1, totallength, true,
-                                       logger);
-    for (idx=0; idx<=totallength; idx++)
-    {
-      gt_suffixsortspace_setdirect(curi.sssp,idx,idx);
-    }
+    curi.sssp = gt_suffixsortspace_new(totallength+1,totallength, true, logger);
+    gt_suffixsortspace_init_identity(curi.sssp,totallength+1);
     curi.readmode = GT_READMODE_FORWARD;
     curi.sortmaxdepth = arguments->sortmaxdepth;
     gt_sortallsuffixesfromstart(curi.sssp,
@@ -1129,7 +1355,7 @@ static int performsortmaxdepth(const Sfxmapoptions *arguments,
                                 NULL,
                                 arguments->sortmaxdepth,
                                 &sfxstrategy,
-                                sortmaxdepth_processunsortedrange,
+                                gt_sfxmap_sortmaxdepth_processunsortedrange,
                                 &curi, /* voiddcov */
                                 logger);
     gt_checksortedsuffixes(__FILE__,
@@ -1141,7 +1367,7 @@ static int performsortmaxdepth(const Sfxmapoptions *arguments,
                            totallength+1,
                            false, /* specialsareequal  */
                            false,  /* specialsareequalatdepth0 */
-                           (unsigned long) curi.sortmaxdepth);
+                           (GtUword) curi.sortmaxdepth);
     gt_suffixsortspace_delete(curi.sssp,false);
   }
   gt_encseq_delete(curi.encseq);
@@ -1149,13 +1375,15 @@ static int performsortmaxdepth(const Sfxmapoptions *arguments,
   return haserr ? -1 : 0;
 }
 
-static int run_diffcover_check(const Sfxmapoptions *arguments, GtError *err)
+static int gt_sfxmap_run_diffcover_check(const Sfxmapoptions *arguments,
+                                         GtError *err)
 {
   int had_err = 0;
   GtEncseqLoader *el = NULL;
   GtEncseq *encseq = NULL;
   const char *indexname;
 
+  gt_error_check(err);
   indexname = gt_str_get(arguments->esaindexname);
   el = gt_encseq_loader_new();
   encseq = gt_encseq_loader_load(el, indexname, err);
@@ -1187,35 +1415,55 @@ static int gt_sfxmap_runner(GT_UNUSED int argc,
   logger = gt_logger_new(arguments->verbose, GT_LOGGER_DEFLT_PREFIX, stdout);
   if (gt_str_length(arguments->esaindexname) > 0)
   {
-    if (sfxmap_esa(arguments,logger,err) != 0)
+    if (arguments->compressedesa)
     {
-      haserr = true;
+      if (gt_sfxmap_compressedesa(gt_str_get(arguments->esaindexname),
+                                   err) != 0)
+      {
+        haserr = true;
+      }
+    } else
+    {
+      if (arguments->compresslcp)
+      {
+        if (gt_sfxmap_compresslcp(gt_str_get(arguments->esaindexname),
+                                  logger,err) != 0)
+        {
+          haserr = true;
+        }
+      } else
+      {
+        if (gt_sfxmap_esa(arguments,logger,err) != 0)
+        {
+          haserr = true;
+        }
+      }
     }
   }
   if (!haserr && gt_str_length(arguments->pckindexname) > 0)
   {
-    if (sfxmap_pck(arguments,logger,err) != 0)
+    if (gt_sfxmap_pck(arguments,logger,err) != 0)
     {
       haserr = true;
     }
   }
   if (!haserr && gt_str_array_size(arguments->streamesq) > 0)
   {
-    if (stream_esq(arguments,err) != 0)
+    if (gt_sfxmap_stream_esq(arguments,err) != 0)
     {
       haserr = true;
     }
   }
   if (!haserr && arguments->sortmaxdepth > 0)
   {
-    if (performsortmaxdepth(arguments,logger,err) != 0)
+    if (gt_sfxmap_performsortmaxdepth(arguments,logger,err) != 0)
     {
       haserr = true;
     }
   }
   if (!haserr && arguments->diffcovercheck)
   {
-    if (run_diffcover_check(arguments, err) != 0)
+    if (gt_sfxmap_run_diffcover_check(arguments, err) != 0)
     {
       haserr = true;
     }
