@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2008-2010 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2008-2010 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2008      Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -26,7 +26,7 @@
 #include "tools/gt_shredder.h"
 
 typedef struct {
-  unsigned long coverage,
+  GtUword coverage,
                 minlength,
                 maxlength,
                 overlap,
@@ -61,19 +61,19 @@ static GtOptionParser* gt_shredder_option_parser_new(void *tool_arguments)
   op = gt_option_parser_new("[option ...] [sequence_file ...]",
                             "Shredder sequence file(s) into consecutive pieces "
                             "of random length.");
-  o = gt_option_new_ulong_min("coverage", "set the number of times the "
+  o = gt_option_new_uword_min("coverage", "set the number of times the "
                               "sequence_file is shreddered",
                               &arguments->coverage, 1, 1);
   gt_option_parser_add_option(op, o);
-  o = gt_option_new_ulong("minlength",
+  o = gt_option_new_uword("minlength",
                           "set the minimum length of the shreddered "
                           "fragments", &arguments->minlength, 300);
   gt_option_parser_add_option(op, o);
-  o = gt_option_new_ulong("maxlength",
+  o = gt_option_new_uword("maxlength",
                           "set the maximum length of the shreddered "
                           "fragments", &arguments->maxlength, 700);
   gt_option_parser_add_option(op, o);
-  o = gt_option_new_ulong("overlap", "set the overlap between consecutive "
+  o = gt_option_new_uword("overlap", "set the overlap between consecutive "
                           "pieces", &arguments->overlap, 0);
   gt_option_parser_add_option(op, o);
   o = gt_option_new_probability("sample", "take samples of the generated "
@@ -82,7 +82,7 @@ static GtOptionParser* gt_shredder_option_parser_new(void *tool_arguments)
   gt_option_parser_add_option(op, o);
   o = gt_option_new_width(&arguments->width);
   gt_option_parser_add_option(op, o);
-  gt_output_file_register_options(op, &arguments->outfp, arguments->ofi);
+  gt_output_file_info_register_options(arguments->ofi, op, &arguments->outfp);
   gt_option_parser_set_comment_func(op, gt_gtdata_show_help, NULL);
   return op;
 }
@@ -106,7 +106,7 @@ static int gt_shredder_runner(GT_UNUSED int argc, const char **argv,
 {
   ShredderArguments *arguments = tool_arguments;
   GtBioseqIterator *bsi;
-  unsigned long i;
+  GtUword i;
   GtBioseq *bioseq;
   int had_err;
   GtStr *desc;
@@ -122,7 +122,7 @@ static int gt_shredder_runner(GT_UNUSED int argc, const char **argv,
   while (!(had_err = gt_bioseq_iterator_next(bsi, &bioseq, err)) && bioseq) {
     for (i = 0; i < arguments->coverage; i++) {
       GtShredder *shredder;
-      unsigned long fragment_length;
+      GtUword fragment_length;
       char *fragment;
       shredder = gt_shredder_new(bioseq, arguments->minlength,
                               arguments->maxlength);
