@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2003-2010 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2003-2010 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2003-2008 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -16,6 +16,7 @@
 */
 
 #include "core/bioseq.h"
+#include "core/compat.h"
 #include "core/fa.h"
 #include "core/fasta.h"
 #include "core/fileutils_api.h"
@@ -27,7 +28,7 @@
 #include "tools/gt_splitfasta.h"
 
 typedef struct {
-  unsigned long max_filesize_in_MB, width;
+  GtUword max_filesize_in_MB, width;
   unsigned int num_files;
   GtStr *splitdesc;
   bool force;
@@ -64,7 +65,7 @@ static GtOptionParser* gt_splitfasta_option_parser_new(void *tool_arguments)
                                            1);
   gt_option_parser_add_option(op, numfiles_option);
 
-  targetsize_option = gt_option_new_ulong_min("targetsize",
+  targetsize_option = gt_option_new_uword_min("targetsize",
                                               "set the target file "
                                               "size in MB",
                                               &arguments->max_filesize_in_MB,
@@ -88,7 +89,7 @@ static GtOptionParser* gt_splitfasta_option_parser_new(void *tool_arguments)
   return op;
 }
 
-static unsigned long buf_contains_separator(char *buf, int offset,
+static GtUword buf_contains_separator(char *buf, int offset,
                                             int read_bytes)
 {
   char *cc;
@@ -101,9 +102,9 @@ static unsigned long buf_contains_separator(char *buf, int offset,
 }
 
 static int split_description(const char *filename, GtStr *splitdesc,
-                             unsigned long width, bool force, GtError *err)
+                             GtUword width, bool force, GtError *err)
 {
-  unsigned long i;
+  GtUword i;
   GtBioseq *bioseq;
   GtStr *descname;
   int had_err = 0;
@@ -119,7 +120,7 @@ static int split_description(const char *filename, GtStr *splitdesc,
     char *seq;
     gt_str_reset(descname);
     gt_str_append_str(descname, splitdesc);
-    gt_str_append_char(descname, '/');
+    gt_str_append_char(descname, GT_PATH_SEPARATOR);
     gt_str_append_cstr(descname, gt_bioseq_get_description(bioseq, i));
     gt_str_append_cstr(descname, gt_file_suffix(filename));
     if (!(outfp = gt_output_file_xopen_forcecheck(gt_str_get(descname), "w",
@@ -141,12 +142,12 @@ static int split_description(const char *filename, GtStr *splitdesc,
   return had_err;
 }
 
-static int split_fasta_file(const char *filename, unsigned long max_filesize,
+static int split_fasta_file(const char *filename, GtUword max_filesize,
                             bool force, GtError *err)
 {
   GtFile *srcfp = NULL, *destfp = NULL;
   GtStr *destfilename = NULL;
-  unsigned long filenum = 0, bytecount = 0, separator_pos;
+  GtUword filenum = 0, bytecount = 0, separator_pos;
   int read_bytes, had_err = 0;
   char buf[BUFSIZ];
 
@@ -256,7 +257,7 @@ static int gt_splitfasta_runner(GT_UNUSED int argc, const char **argv,
                                 arguments->width, arguments->force, err);
   }
   else {
-    unsigned long max_filesize;
+    GtUword max_filesize;
     if (num_files) {
       /* set the maxfile size based on requested number of files */
       file_size = gt_file_estimate_size(filename);
