@@ -310,6 +310,13 @@ Test do
   run "diff #{last_stdout} #{$testdata}addintrons.out"
 end
 
+Name "gt gff3 test option -setsource"
+Keywords "gt_gff3"
+Test do
+  run_test "#{$bin}gt gff3 -setsource GFF3spec #{$testdata}resetsource.gff3"
+  run "diff #{last_stdout} #{$testdata}resetsource.out"
+end
+
 Name "gt gff3 test option -offset 1000"
 Keywords "gt_gff3 offset"
 Test do
@@ -331,11 +338,20 @@ Test do
   run "diff #{last_stdout} #{$testdata}gt_gff3_offset_test.out-999"
 end
 
-Name "gt gff3 test option -offset -1001 (overflow)"
+Name "gt gff3 test option -offset -1000 (start 0)"
+Keywords "gt_gff3 offset"
+Test do
+  run_test("#{$bin}gt gff3 -offset -1000 #{$testdata}gt_gff3_offset_test.gff3",
+           :retval => 1)
+  grep last_stderr, "leads to start 0"
+end
+
+Name "gt gff3 test option -offset -1001 (underflow)"
 Keywords "gt_gff3 offset"
 Test do
   run_test("#{$bin}gt gff3 -offset -1001 #{$testdata}gt_gff3_offset_test.gff3",
            :retval => 1)
+  grep last_stderr, "leads to underflow"
 end
 
 Name "gt gff3 test option -offsetfile"
@@ -618,12 +634,133 @@ Test do
   run_test "#{$bin}gt gff3 -typecheck so-xp #{obo_gff3_file}"
 end
 
+Name "gt gff3 -xrfcheck (short)"
+Keywords "gt_gff3 xrfcheck"
+Test do
+  run_test "#{$bin}gt gff3 -xrfcheck GO #{$testdata}dbxref.gff3"
+end
+
+Name "gt gff3 -xrfcheck (full filename)"
+Keywords "gt_gff3 xrfcheck"
+Test do
+  run_test "#{$bin}gt gff3 -xrfcheck #{$cur}/gtdata/xrf_abbr/GO.xrf_abbr #{$testdata}dbxref.gff3"
+end
+
+Name "gt gff3 -xrfcheck (no argument)"
+Keywords "gt_gff3 xrfcheck"
+Test do
+  run_test "#{$bin}gt gff3 -xrfcheck < #{$testdata}dbxref.gff3"
+end
+
+Name "gt gff3 -xrfcheck failure (invalid database)"
+Keywords "gt_gff3 xrfcheck"
+Test do
+  run_test("#{$bin}gt gff3 -xrfcheck GO #{$testdata}dbxref_invalid2.gff3", :retval => 1)
+  grep last_stderr, "unknown database abbreviation"
+end
+
+Name "gt gff3 -xrfcheck failure (invalid local ID)"
+Keywords "gt_gff3 xrfcheck"
+Test do
+  run_test("#{$bin}gt gff3 -xrfcheck GO #{$testdata}dbxref_invalid.gff3", :retval => 1)
+  grep last_stderr, "local ID"
+end
+
+Name "gt gff3 -xrfcheck failure (missing abbrev)"
+Keywords "gt_gff3 xrfcheck"
+Test do
+  run_test("#{$bin}gt gff3 -xrfcheck #{$testdata}missingabbr.XRF_abbr #{$testdata}dbxref.gff3", :retval => 1)
+  grep last_stderr, "required label"
+end
+
+Name "gt gff3 -xrfcheck failure (duplicate abbrev)"
+Keywords "gt_gff3 xrfcheck"
+Test do
+  run_test("#{$bin}gt gff3 -xrfcheck #{$testdata}duplicate.XRF_abbr #{$testdata}dbxref.gff3", :retval => 1)
+  grep last_stderr, "duplicate abbreviation"
+end
+
+Name "gt gff3 -xrfcheck failure (invalid regex)"
+Keywords "gt_gff3 xrfcheck"
+Test do
+  run_test("#{$bin}gt gff3 -xrfcheck #{$testdata}invalidregex.XRF_abbr #{$testdata}dbxref.gff3", :retval => 1)
+  grep last_stderr, "invalid regular"
+end
+
+Name "gt gff3 -xrfcheck failure (unknown label)"
+Keywords "gt_gff3 xrfcheck"
+Test do
+  run_test("#{$bin}gt gff3 -xrfcheck #{$testdata}invalidtag.XRF_abbr #{$testdata}dbxref.gff3", :retval => 0)
+  grep last_stderr, "unknown label"
+end
+
+Name "gt gff3 -xrfcheck failure (shorthand too long)"
+Keywords "gt_gff3 xrfcheck"
+Test do
+  run_test("#{$bin}gt gff3 -xrfcheck #{$testdata}shorthand.XRF_abbr #{$testdata}dbxref.gff3", :retval => 1)
+  grep last_stderr, "is not less than 10"
+end
+
 Name "gt gff3 blank attributes"
 Keywords "gt_gff3"
 Test do
   run_test "#{$bin}gt gff3 #{$testdata}blank_attributes.gff3"
 end
 
+Name "gt gff3 Gap attribute"
+Keywords "gt_gff3 gap"
+Test do
+  run_test "#{$bin}gt gff3 -typecheck so #{$testdata}match_part_gap.gff3"
+end
+
+Name "gt gff3 Gap attribute failure (eop too short)"
+Keywords "gt_gff3 gap"
+Test do
+  run_test("#{$bin}gt gff3 -typecheck so #{$testdata}gap_fail1.gff3", :retval => 1)
+  grep last_stderr, "too short"
+end
+
+Name "gt gff3 Gap attribute failure (invalid eop code)"
+Keywords "gt_gff3 gap"
+Test do
+  run_test("#{$bin}gt gff3 -typecheck so #{$testdata}gap_fail2.gff3", :retval => 1)
+  grep last_stderr, "invalid edit operation code"
+end
+
+Name "gt gff3 Gap attribute failure (inconsistent length)"
+Keywords "gt_gff3 gap"
+Test do
+  run_test("#{$bin}gt gff3 -typecheck so #{$testdata}gap_fail3.gff3", :retval => 1)
+  grep last_stderr, "does not match the length of its"
+end
+
+Name "gt gff3 Gap attribute failure (eop length not numeric)"
+Keywords "gt_gff3 gap"
+Test do
+  run_test("#{$bin}gt gff3 -typecheck so #{$testdata}gap_fail4.gff3", :retval => 1)
+  grep last_stderr, "cannot parse edit length"
+end
+
+Name "gt gff3 Gap attribute failure (protein length)"
+Keywords "gt_gff3 gap"
+Test do
+  run_test("#{$bin}gt gff3 -typecheck so #{$testdata}gap_fail5.gff3", :retval => 0)
+end
+
+Name "gt gff3 Gap attribute failure (protein match length)"
+Keywords "gt_gff3 gap"
+Test do
+  run_test("#{$bin}gt gff3 -typecheck so #{$testdata}gap_fail6.gff3", :retval => 1)
+  grep last_stderr, "does not match the length of its"
+end
+
+Name "gt gff3 Gap attribute failure (frameshifts in nucl match)"
+Keywords "gt_gff3 gap"
+Test do
+  run_test("#{$bin}gt gff3 -typecheck so #{$testdata}gap_fail7.gff3", :retval => 1)
+  grep last_stderr, "only allowed in nucleotide"
+end
+
 Name "gt gff3 minimal fasta file"
 Keywords "gt_gff3 fasta"
 Test do
@@ -1253,6 +1390,13 @@ Test do
   grep last_stderr, "wrong separator"
 end
 
+Name "gt gff3 blank after seqid"
+Keywords "gt_gff3"
+Test do
+  run_test "#{$bin}gt gff3 #{$testdata}gt_gff3_whitespace_problem.gff3"
+  grep last_stderr, "ends with a blank, removing"
+end
+
 def large_gff3_test(name, file)
   Name "gt gff3 #{name}"
   Keywords "gt_gff3 large_gff3"
