@@ -1,6 +1,6 @@
 #!/usr/bin/env ruby
 #
-# Copyright (c) 2006-2008 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+# Copyright (c) 2006-2008 Gordon Gremme <gordon@gremme.org>
 # Copyright (c) 2006-2008 Center for Bioinformatics, University of Hamburg
 #
 # Permission to use, copy, modify, and distribute this software for any
@@ -73,6 +73,12 @@ end
 $systemname=`uname -s`
 $systemname.chomp!
 
+if $arguments["seed"] then
+  $SEED = $arguments["seed"]
+else
+  $SEED = rand(2**31)
+end
+
 $MEMCHECK_SUPPORTEDPLATFORMS = ["Linux", "Darwin"]
 
 # define helper function
@@ -88,28 +94,81 @@ def run_test(str, opts = {})
   else
     $memcheck = ""
   end
-  run("#{$memcheck} #{$path}#{str}", opts)
+  run("env G_DEBUG=gc-friendly G_SLICE=always-malloc GT_SEED=#{$SEED} " + \
+      "#{$memcheck} #{$path}#{str}", opts)
 end
 
 def run_ruby(str, opts = {})
-  run("env LD_LIBRARY_PATH=#{$cur}/lib ruby -I #{$gtruby} #{$path}#{str}", opts)
+  run("env G_DEBUG=gc-friendly G_SLICE=always-malloc " + \
+      "DYLD_LIBRARY_PATH=#{$cur}/lib LD_LIBRARY_PATH=#{$cur}/lib " + \
+      "ruby -I #{$gtruby} #{$path}#{str}", opts)
 end
 
 def run_python(str, opts = {})
-  run("env PYTHONPATH=#{$gtpython} LD_LIBRARY_PATH=#{$cur}/lib python " + \
+  run("env G_DEBUG=gc-friendly G_SLICE=always-malloc " + \
+      "PYTHONPATH=#{$gtpython} DYLD_LIBRARY_PATH=#{$cur}/lib " + \
+      "LD_LIBRARY_PATH=#{$cur}/lib python " + \
       "#{$path}#{str}", opts)
 end
 
+def with_environment(variables={})
+  if block_given?
+    old_values = variables.map{ |k,v| [k,ENV[k]] }
+    begin
+       variables.each{ |k,v| ENV[k] = v }
+       result = yield
+    ensure
+      old_values.each{ |k,v| ENV[k] = v }
+    end
+    result
+  else
+    variables.each{ |k,v| ENV[k] = v }
+  end
+end
+
+def python_tests_runnable?
+  if `which python`.empty? then
+    return false
+  end
+  require "open3"
+  runline = "python #{$gtpython}/gt/dlload.py"
+  with_environment({"PYTHONPATH" => $gtpython, \
+                    "DYLD_LIBRARY_PATH" => "#{$cur}/lib", \
+                    "LD_LIBRARY_PATH" => "#{$cur}/lib"}) do
+    stdin, stdout, stderr = Open3.popen3(runline)
+    result = stderr.read.match(/OSError/).nil?
+    result
+  end
+end
+
+def ruby_tests_runnable?
+  rv = RUBY_VERSION.match(/^(\d+\.\d+)/)
+  if rv.nil? or rv[1].to_f >= 1.9 then
+    return false
+  end
+  require "open3"
+  runline = "ruby -I #{$gtruby} #{$gtruby}/gtdlload.rb"
+  with_environment({"GTRUBY" => $gtruby, \
+                    "DYLD_LIBRARY_PATH" => "#{$cur}/lib", \
+                    "LD_LIBRARY_PATH" => "#{$cur}/lib"}) do
+    stdin, stdout, stderr = Open3.popen3(runline)
+    result = stderr.read.match(/RuntimeError/).nil?
+    result
+  end
+end
+
 # include the actual test modules
 require 'gt_bed_to_gff3_include'
 require 'gt_cds_include'
 require 'gt_chseqids_include'
+require 'gt_condenser_include'
 require 'gt_consensus_sa_include'
 require 'gt_csa_include'
 require 'gt_csr_include.rb'
 require 'gt_encseq_include'
 require 'gt_eval_include'
 require 'gt_extractfeat_include'
+require 'gt_fastq_sample_include'
 require 'gt_featureindex_include'
 require 'gt_fingerprint_include'
 require 'gt_genomediff_include'
@@ -120,6 +179,7 @@ require 'gt_hop_include'
 require 'gt_id_to_md5_include'
 require 'gt_include'
 require 'gt_interfeat_include'
+require 'gt_loccheck_include'
 require 'gt_ltrdigest_include'
 require 'gt_ltrharvest_include'
 require 'gt_magicmatch_include'
@@ -131,11 +191,15 @@ require 'gt_mergefeat_include'
 require 'gt_mgth_include'
 require 'gt_mmapandread_include'
 require 'gt_orffinder_include'
-require 'gt_python_include'
+if python_tests_runnable? then
+  require 'gt_python_include'
+end
 require 'gt_readjoiner_include'
 require 'gt_readreads_include'
 require 'gt_regioncov_include'
-require 'gt_ruby_include'
+if ruby_tests_runnable? then
+  require 'gt_ruby_include'
+end
 require 'gt_sambam_include'
 require 'gt_script_filter_include'
 require 'gt_scripts_include'
@@ -155,6 +219,7 @@ require 'gt_simreads_include'
 require 'gt_splicesiteinfo_include'
 require 'gt_splitfasta_include'
 require 'gt_stat_include'
+require 'gt_tirvish_include'
 require 'gt_uniq_include'
 if not $arguments["nocairo"] then
   require 'gt_sketch_include'
@@ -185,4 +250,9 @@ end
 if $arguments["threads"] then
   $testsuite.nof_threads = $arguments["threads"].to_i
 end
+
+#output seed
+puts "seed=#{$SEED}"
+
+#start tests
 $testsuite.run
